// Copyright (c) 2026 Marshall A. Greenblatt. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//    * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//    * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//    * Neither the name of Google Inc. nor the name Chromium Embedded
// Framework nor the names of its contributors may be used to endorse
// or promote products derived from this software without specific prior
// written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// ---------------------------------------------------------------------------
//
// This file is generated by the make_pack_header.py tool.
//

#ifndef CEF_INCLUDE_CEF_PACK_STRINGS_H_
#define CEF_INCLUDE_CEF_PACK_STRINGS_H_
#pragma once

// ---------------------------------------------------------------------------
// From app_locale_settings.h:

#define IDS_WEB_FONT_FAMILY 50383
#define IDS_WEB_FONT_SIZE 50384

// ---------------------------------------------------------------------------
// From auto_image_annotation_strings.h:

#define IDS_AX_UNLABELED_IMAGE_ROLE_DESCRIPTION 50390
#define IDS_AX_IMAGE_ELIGIBLE_FOR_ANNOTATION 50392
#define IDS_AX_IMAGE_ANNOTATION_PENDING 50393
#define IDS_AX_IMAGE_ANNOTATION_ADULT 50394
#define IDS_AX_IMAGE_ANNOTATION_NO_DESCRIPTION 50395
#define IDS_AX_IMAGE_ANNOTATION_OCR_CONTEXT 50396
#define IDS_AX_IMAGE_ANNOTATION_DESCRIPTION_CONTEXT 50397
#define IDS_AX_IMAGE_ANNOTATION_ICON_PLUS 50398
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_BACKWARD 50399
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_FORWARD 50400
#define IDS_AX_IMAGE_ANNOTATION_ICON_CALL 50401
#define IDS_AX_IMAGE_ANNOTATION_ICON_CHAT 50402
#define IDS_AX_IMAGE_ANNOTATION_ICON_CHECK 50403
#define IDS_AX_IMAGE_ANNOTATION_ICON_X 50404
#define IDS_AX_IMAGE_ANNOTATION_ICON_DELETE 50405
#define IDS_AX_IMAGE_ANNOTATION_ICON_EDIT 50406
#define IDS_AX_IMAGE_ANNOTATION_ICON_EMOJI 50407
#define IDS_AX_IMAGE_ANNOTATION_ICON_END_CALL 50408
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_DOWNWARD 50409
#define IDS_AX_IMAGE_ANNOTATION_ICON_HEART 50410
#define IDS_AX_IMAGE_ANNOTATION_ICON_HOME 50411
#define IDS_AX_IMAGE_ANNOTATION_ICON_INFO 50412
#define IDS_AX_IMAGE_ANNOTATION_ICON_LAUNCH_APPS 50413
#define IDS_AX_IMAGE_ANNOTATION_ICON_THUMBS_UP 50414
#define IDS_AX_IMAGE_ANNOTATION_ICON_THREE_BARS 50415
#define IDS_AX_IMAGE_ANNOTATION_ICON_THREE_DOTS 50416
#define IDS_AX_IMAGE_ANNOTATION_ICON_NOTIFICATIONS 50417
#define IDS_AX_IMAGE_ANNOTATION_ICON_PAUSE 50418
#define IDS_AX_IMAGE_ANNOTATION_ICON_PLAY 50419
#define IDS_AX_IMAGE_ANNOTATION_ICON_REFRESH 50420
#define IDS_AX_IMAGE_ANNOTATION_ICON_MAGNIFYING_GLASS 50421
#define IDS_AX_IMAGE_ANNOTATION_ICON_SEND 50422
#define IDS_AX_IMAGE_ANNOTATION_ICON_SETTINGS 50423
#define IDS_AX_IMAGE_ANNOTATION_ICON_SHARE 50424
#define IDS_AX_IMAGE_ANNOTATION_ICON_STAR 50425
#define IDS_AX_IMAGE_ANNOTATION_ICON_TAKE_PHOTO 50426
#define IDS_AX_IMAGE_ANNOTATION_ICON_TIME 50427
#define IDS_AX_IMAGE_ANNOTATION_ICON_VIDEOCAM 50428
#define IDS_AX_IMAGE_ANNOTATION_ICON_EXPAND 50429
#define IDS_AX_IMAGE_ANNOTATION_ICON_CONTRACT 50430
#define IDS_AX_IMAGE_ANNOTATION_ICON_GOOGLE 50431
#define IDS_AX_IMAGE_ANNOTATION_ICON_TWITTER 50432
#define IDS_AX_IMAGE_ANNOTATION_ICON_FACEBOOK 50433
#define IDS_AX_IMAGE_ANNOTATION_ICON_ASSISTANT 50434
#define IDS_AX_IMAGE_ANNOTATION_ICON_WEATHER 50435
#define IDS_AX_IMAGE_ANNOTATION_ICON_SHOPPING_CART 50436
#define IDS_AX_IMAGE_ANNOTATION_ICON_UPLOAD 50437
#define IDS_AX_IMAGE_ANNOTATION_ICON_QUESTION 50438
#define IDS_AX_IMAGE_ANNOTATION_ICON_MIC 50439
#define IDS_AX_IMAGE_ANNOTATION_ICON_MIC_MUTE 50440
#define IDS_AX_IMAGE_ANNOTATION_ICON_GALLERY 50441
#define IDS_AX_IMAGE_ANNOTATION_ICON_COMPASS 50442
#define IDS_AX_IMAGE_ANNOTATION_ICON_PEOPLE 50443
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_UPWARD 50444
#define IDS_AX_IMAGE_ANNOTATION_ICON_ENVELOPE 50445
#define IDS_AX_IMAGE_ANNOTATION_ICON_EMOJI_FACE 50446
#define IDS_AX_IMAGE_ANNOTATION_ICON_PAPERCLIP 50447
#define IDS_AX_IMAGE_ANNOTATION_ICON_CAST 50448
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_UP 50449
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_DOWN 50450
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_STATE 50451
#define IDS_AX_IMAGE_ANNOTATION_ICON_VOLUME_MUTE 50452
#define IDS_AX_IMAGE_ANNOTATION_ICON_STOP 50453
#define IDS_AX_IMAGE_ANNOTATION_ICON_SHOPPING_BAG 50454
#define IDS_AX_IMAGE_ANNOTATION_ICON_LIST 50455
#define IDS_AX_IMAGE_ANNOTATION_ICON_LOCATION 50456
#define IDS_AX_IMAGE_ANNOTATION_ICON_CALENDAR 50457
#define IDS_AX_IMAGE_ANNOTATION_ICON_THUMBS_DOWN 50458
#define IDS_AX_IMAGE_ANNOTATION_ICON_HEADSET 50459
#define IDS_AX_IMAGE_ANNOTATION_ICON_REDO 50460
#define IDS_AX_IMAGE_ANNOTATION_ICON_UNDO 50461
#define IDS_AX_IMAGE_ANNOTATION_ICON_DOWNLOAD 50462
#define IDS_AX_IMAGE_ANNOTATION_ICON_ARROW_DOWNWARD 50463
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_UPWARD 50464
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_FORWARD 50465
#define IDS_AX_IMAGE_ANNOTATION_ICON_V_BACKWARD 50466
#define IDS_AX_IMAGE_ANNOTATION_ICON_HISTORY 50467
#define IDS_AX_IMAGE_ANNOTATION_ICON_PERSON 50468
#define IDS_AX_IMAGE_ANNOTATION_ICON_HAPPY_FACE 50469
#define IDS_AX_IMAGE_ANNOTATION_ICON_SAD_FACE 50470
#define IDS_AX_IMAGE_ANNOTATION_ICON_MOON 50471
#define IDS_AX_IMAGE_ANNOTATION_ICON_CLOUD 50472
#define IDS_AX_IMAGE_ANNOTATION_ICON_SUN 50473

// ---------------------------------------------------------------------------
// From blink_strings.h:

#define IDS_DETAILS_WITHOUT_SUMMARY_LABEL 46840
#define IDS_FORM_CALENDAR_CLEAR 46841
#define IDS_FORM_CALENDAR_TODAY 46842
#define IDS_FORM_SUBMIT_LABEL 46843
#define IDS_FORM_INPUT_ALT 46844
#define IDS_FORM_RESET_LABEL 46845
#define IDS_FORM_FILE_BUTTON_LABEL 46846
#define IDS_FORM_MULTIPLE_FILES_BUTTON_LABEL 46847
#define IDS_FORM_FILE_NO_FILE_LABEL 46848
#define IDS_FORM_FILE_MULTIPLE_UPLOAD 46849
#define IDS_FORM_OTHER_COLOR_LABEL 46850
#define IDS_FORM_OTHER_DATE_LABEL 46851
#define IDS_FORM_OTHER_MONTH_LABEL 46852
#define IDS_FORM_OTHER_WEEK_LABEL 46853
#define IDS_FORM_PLACEHOLDER_FOR_DAY_OF_MONTH_FIELD 46854
#define IDS_FORM_PLACEHOLDER_FOR_MONTH_FIELD 46855
#define IDS_FORM_PLACEHOLDER_FOR_YEAR_FIELD 46856
#define IDS_FORM_SELECT_MENU_LIST_TEXT 46857
#define IDS_FORM_THIS_MONTH_LABEL 46858
#define IDS_FORM_THIS_WEEK_LABEL 46859
#define IDS_FORM_WEEK_NUMBER_LABEL 46860
#define IDS_DEBUGGER_PAUSED_IN_ANOTHER_TAB 46861
#define IDS_VIEW_SOURCE_LINE_WRAP 46862
#define IDS_FORM_INPUT_WEEK_TEMPLATE 46863
#define IDS_FORM_VALIDATION_VALUE_MISSING_MULTIPLE_FILE 46864
#define IDS_FORM_VALIDATION_TYPE_MISMATCH 46865
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_EMPTY 46866
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_EMPTY_DOMAIN 46867
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_EMPTY_LOCAL 46868
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_INVALID_DOMAIN 46869
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_INVALID_DOTS 46870
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_INVALID_LOCAL 46871
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL_NO_AT_SIGN 46872
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_MULTIPLE_EMAIL 46873
#define IDS_FORM_VALIDATION_VALUE_NOT_EQUAL 46874
#define IDS_FORM_VALIDATION_VALUE_NOT_EQUAL_DATETIME 46875
#define IDS_FORM_VALIDATION_RANGE_UNDERFLOW 46876
#define IDS_FORM_VALIDATION_RANGE_UNDERFLOW_DATETIME 46877
#define IDS_FORM_VALIDATION_RANGE_OVERFLOW 46878
#define IDS_FORM_VALIDATION_RANGE_OVERFLOW_DATETIME 46879
#define IDS_FORM_VALIDATION_REVERSED_RANGE_OUT_OF_RANGE_TIME 46880
#define IDS_FORM_VALIDATION_RANGE_REVERSED 46881
#define IDS_FORM_VALIDATION_RANGE_INVALID_DATETIME 46882
#define IDS_FORM_VALIDATION_BAD_INPUT_DATETIME 46883
#define IDS_FORM_VALIDATION_BAD_INPUT_NUMBER 46884
#define IDS_PRETTY_PRINT_JSON 46885
#define IDS_FORM_VALIDATION_VALUE_MISSING 46886
#define IDS_FORM_VALIDATION_VALUE_MISSING_CHECKBOX 46887
#define IDS_FORM_VALIDATION_VALUE_MISSING_FILE 46888
#define IDS_FORM_VALIDATION_VALUE_MISSING_RADIO 46889
#define IDS_FORM_VALIDATION_VALUE_MISSING_SELECT 46890
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_EMAIL 46891
#define IDS_FORM_VALIDATION_TYPE_MISMATCH_URL 46892
#define IDS_FORM_VALIDATION_PATTERN_MISMATCH 46893
#define IDS_FORM_VALIDATION_STEP_MISMATCH 46894
#define IDS_FORM_VALIDATION_STEP_MISMATCH_CLOSE_TO_LIMIT 46895
#define IDS_FORM_VALIDATION_TOO_LONG 46896
#define IDS_FORM_VALIDATION_TOO_SHORT 46897
#define IDS_FORM_VALIDATION_TOO_SHORT_PLURAL 46898
#define IDS_MEDIA_SESSION_DATA_SOURCE 46899
#define IDS_MEDIA_SESSION_FILE_SOURCE 46900
#define IDS_MEDIA_OVERFLOW_MENU_CLOSED_CAPTIONS 46901
#define IDS_MEDIA_OVERFLOW_MENU_CLOSED_CAPTIONS_SUBMENU_TITLE 46902
#define IDS_MEDIA_TRACK_IDENTIFIER_VERBOSE_TITLE_NUMBERED 46903
#define IDS_MEDIA_OVERFLOW_MENU_SHOW_AUDIO_TRACK_MENU_BUTTON 46904
#define IDS_MEDIA_OVERFLOW_MENU_SHOW_VIDEO_TRACK_MENU_BUTTON 46905
#define IDS_MEDIA_OVERFLOW_MENU_TRACK_SELECTION_SUBMENU_TITLE 46906
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED 46907
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_SUBMENU_TITLE 46908
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_0_25X_TITLE 46909
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_0_5X_TITLE 46910
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_0_75X_TITLE 46911
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_NORMAL_TITLE 46912
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_1_25X_TITLE 46913
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_1_5X_TITLE 46914
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_1_75X_TITLE 46915
#define IDS_MEDIA_OVERFLOW_MENU_PLAYBACK_SPEED_2X_TITLE 46916
#define IDS_MEDIA_OVERFLOW_MENU_CAST 46917
#define IDS_MEDIA_OVERFLOW_MENU_ENTER_FULLSCREEN 46918
#define IDS_MEDIA_OVERFLOW_MENU_EXIT_FULLSCREEN 46919
#define IDS_MEDIA_OVERFLOW_MENU_MUTE 46920
#define IDS_MEDIA_OVERFLOW_MENU_UNMUTE 46921
#define IDS_MEDIA_OVERFLOW_MENU_PLAY 46922
#define IDS_MEDIA_OVERFLOW_MENU_PAUSE 46923
#define IDS_MEDIA_OVERFLOW_MENU_DOWNLOAD 46924
#define IDS_MEDIA_OVERFLOW_MENU_ENTER_PICTURE_IN_PICTURE 46925
#define IDS_MEDIA_OVERFLOW_MENU_EXIT_PICTURE_IN_PICTURE 46926
#define IDS_MEDIA_PICTURE_IN_PICTURE_INTERSTITIAL_TEXT 46927
#define IDS_MEDIA_REMOTING_CAST_TEXT 46928
#define IDS_MEDIA_REMOTING_CAST_TO_UNKNOWN_DEVICE_TEXT 46929
#define IDS_MEDIA_REMOTING_STOP_TEXT 46930
#define IDS_MEDIA_REMOTING_STOP_BY_PLAYBACK_QUALITY_TEXT 46931
#define IDS_MEDIA_REMOTING_STOP_BY_ERROR_TEXT 46932
#define IDS_MEDIA_SCRUBBING_MESSAGE_TEXT 46933
#define IDS_MEDIA_TRACKS_NO_LABEL 46934
#define IDS_MEDIA_TRACKS_OFF 46935
#define IDS_PLUGIN_INITIALIZATION_ERROR 46936
#define IDS_MEDIA_PLAYBACK_ERROR 46937
#define IDS_UNITS_KIBIBYTES 46938
#define IDS_UNITS_MEBIBYTES 46939
#define IDS_UNITS_GIBIBYTES 46940
#define IDS_UNITS_TEBIBYTES 46941
#define IDS_UNITS_PEBIBYTES 46942

// ---------------------------------------------------------------------------
// From branded_strings.h:

#define IDS_RELAUNCH_CONFIRMATION_DIALOG_TITLE 800
#define IDS_SETTINGS_ABOUT_PROGRAM 801
#define IDS_SETTINGS_GET_HELP_USING_CHROME 802
#define IDS_SETTINGS_UPGRADE_UPDATING 803
#define IDS_SETTINGS_UPGRADE_UPDATING_PERCENT 804
#define IDS_SETTINGS_UPGRADE_SUCCESSFUL_RELAUNCH 805
#define IDS_SETTINGS_UPGRADE_UP_TO_DATE 806
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_OFFLINE 809
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_SIGNED_OUT 810
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_NO_PASSWORDS 811
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_QUOTA_LIMIT_GOOGLE_ACCOUNT 812
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_QUOTA_LIMIT 813
#define IDS_SETTINGS_CHECK_PASSWORDS_ERROR_GENERIC 814
#define IDS_SETTINGS_NO_COMPROMISED_CREDENTIALS_LABEL 815
#define IDS_SETTINGS_SIGNED_OUT_USER_LABEL 816
#define IDS_SETTINGS_SIGNED_OUT_USER_HAS_COMPROMISED_CREDENTIALS_LABEL 817
#define IDS_SETTINGS_WEAK_PASSWORDS_DESCRIPTION_GENERATION 818
#define IDS_SETTINGS_COMPROMISED_EDIT_DISCLAIMER_DESCRIPTION 819
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON_USE_TO_FILL 820
#define IDS_SETTINGS_DEFAULT_BROWSER_DEFAULT 821
#define IDS_SETTINGS_DEFAULT_BROWSER_DEFAULT_THANK_YOU 822
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT 823
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_USER_VALUE 824
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_AND_PIN 825
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_AND_PIN_USER_VALUE 826
#define IDS_SETTINGS_DEFAULT_BROWSER_ERROR 827
#define IDS_SETTINGS_DEFAULT_BROWSER_SECONDARY 828
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_WHEN_ON_BULLET_TWO 829
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_WHEN_ON_BULLET_TWO 830
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_THINGS_TO_CONSIDER_BULLET_TWO 831
#define IDS_SETTINGS_PRELOAD_PAGES_THINGS_TO_CONSIDER_BULLET_ONE 832
#define IDS_SETTINGS_SPELLING_PREF_DESC 833
#define IDS_SETTINGS_RESTART_TO_APPLY_CHANGES 834
#define IDS_SETTINGS_SIGNIN_ALLOWED 835
#define IDS_SETTINGS_SIGNIN_ALLOWED_DESC 836
#define IDS_SETTINGS_SIGNIN_ALLOWED_DESC_2 837
#define IDS_SETTINGS_SITE_SETTINGS_PDFS_BLOCKED 838
#define IDS_SETTINGS_SITE_SITE_DETAILS_CAMERA_BLOCKED_BY_OS 839
#define IDS_SETTINGS_SITE_SITE_DETAILS_MICROPHONE_BLOCKED_BY_OS 840
#define IDS_SETTINGS_SITE_SITE_DETAILS_LOCATION_BLOCKED_BY_OS 841
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED_BY_OS 842
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED_BY_OS 843
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED_BY_OS 844
#define IDS_SETTINGS_SITE_DATA_PAGE_CLEAR_ON_EXIT_WITH_EXCEPTION_RADIO_SUBLABEL 845
#define IDS_SETTINGS_SITE_DATA_PAGE_DELETE_ON_EXIT_EXCEPTIONS_SUB_HEADING 846
#define IDS_SETTINGS_PRIVACY_GUIDE_PROMO_BODY 847
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_STANDARD_PROTECTION_FEATURE_DESCRIPTION2 848
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_STANDARD_PROTECTION_PRIVACY_DESCRIPTION1 849
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_PRIVACY_SANDBOX_SUB_LABEL 850
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_WAA_SUB_LABEL 851
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_FEATURE_DESCRIPTION3 852
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_PRIVACY_DESCRIPTION2 853
#define IDS_SETTINGS_PRIVACY_SANDBOX_LEARN_MORE_DIALOG_TOPICS_TITLE 854
#define IDS_SETTINGS_PRIVACY_SANDBOX_AD_MEASUREMENT_DIALOG_DESCRIPTION 855
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_SETTING_SUBLABEL 856
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_AND_NOTIFICATIONS_SETTING_SUBLABEL 857
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_TWO 858
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_BULLET_TWO 859
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_ONE 860
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_LEARN_MORE_LABEL 861
#define IDS_SETTINGS_SECURE_DNS_DESCRIPTION 862
#define IDS_SETTINGS_SYNC_DISCONNECT_DELETE_PROFILE_WARNING_WITH_COUNTS_SINGULAR 863
#define IDS_SETTINGS_SYNC_DISCONNECT_DELETE_PROFILE_WARNING_WITH_COUNTS_PLURAL 864
#define IDS_SETTINGS_SYNC_DISCONNECT_DELETE_PROFILE_WARNING_WITHOUT_COUNTS 865
#define IDS_SETTINGS_CUSTOMIZE_YOUR_CHROME_PROFILE 866
#define IDS_SETTING_NAME_YOUR_PROFILE 867
#define IDS_SETTINGS_PEOPLE_SIGN_IN_PROMPT_SECONDARY_WITH_ACCOUNT 868
#define IDS_SETTINGS_PEOPLE_EXPLICIT_SIGN_IN_PROMPT_SECONDARY_WITH_NO_ACCOUNT 869
#define IDS_SETTINGS_PEOPLE_EXPLICIT_SIGN_IN_PROMPT_SECONDARY_WITH_NO_ACCOUNT_WITH_BOOKMARKS 870
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_TITLE 871
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTIONS_TITLE 873
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTIONS_DESC 874
#define IDS_SETTINGS_PEOPLE_SIGNIN_SECTION_SIGNED_OUT_TITLE 875
#define IDS_SETTINGS_SYNC_DATA_ENCRYPTED_TEXT 876
#define IDS_SETTINGS_SYNC_DISCONNECT_TITLE 877
#define IDS_SETTINGS_SUGGEST_PREF_DESC 878
#define IDS_SETTINGS_SEARCH_AGGREGATOR_PREF_DESC 879
#define IDS_SETTINGS_SYNC_SIGN_IN_PROMPT_WITH_NO_ACCOUNT 880
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_DESC 881
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_DESC_WITH_LINKED_SERVICES 882
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_LINKED_SERVICES_DESC 883
#define IDS_SETTINGS_ERROR_PASSPHRASE_USER_ERROR_DESCRIPTION 884
#define IDS_SETTINGS_ERROR_TRUSTED_VAULT_USER_ERROR_DESCRIPTION 885
#define IDS_SETTINGS_ERROR_UPGRADE_CLIENT_USER_ERROR_DESCRIPTION 886
#define IDS_SETTINGS_PENDING_STATE_DESCRIPTION 887
#define IDS_SETTINGS_ERROR_PASSPHRASE_USER_ERROR_DESCRIPTION_WITH_EMAIL 888
#define IDS_SETTINGS_SIGN_OUT 889
#define IDS_SETTINGS_ACCOUNT_DATA_DASHBOARD 890
#define IDS_SETTINGS_ENCRYPT_ACCOUNT_DATA_WITH_PASSPHRASE_LABEL 891
#define IDS_SETTINGS_ENCRYPT_ACCOUNT_DATA_WITH_PASSPHRASE_EXPLANATION_TEXT 892
#define IDS_SETTINGS_PASSPHRASE_RESET_HINT_ACCOUNT_DATA_ENCRYPTION 893
#define IDS_SETTINGS_PAGE_CONTENT_THINGS_TO_CONSIDER_BULLET_TWO 894
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_SETTING_DESCRIPTION 895
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_SETTING_DESCRIPTION 896
#define IDS_SETTINGS_PERFORMANCE_PRELOAD_TOGGLE_SUMMARY 897
#define IDS_SETTINGS_SYSTEM_BACKGROUND_APPS_LABEL 900
#define IDS_SETTINGS_RESET_PROFILE_FEEDBACK 901
#define IDS_SETTINGS_SAFETY_HUB_ENTRY_POINT_NOTHING_TO_DO 902
#define IDS_SETTINGS_SAFETY_HUB_ENTRY_POINT_HEADER 903
#define IDS_SETTINGS_SAFETY_HUB_EMPTY_STATE_MODULE_SUBHEADER 904
#define IDS_SETTINGS_SAFETY_HUB_VERSION_MODULE_UPPERCASE_NAME 905
#define IDS_SETTINGS_SAFETY_HUB_VERSION_MODULE_LOWERCASE_NAME 906
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_NO_PASSWORDS 907
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_MODULE_HEADER 908
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_DATA_HEADER 909
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_DATA_SUBHEADER 910
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_INCOGNITO_HEADER 911
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_SAFE_BROWSING_SUBHEADER 912
#define IDS_SETTINGS_SAFETY_HUB_VERSION_CARD_HEADER_RESTART 913
#define IDS_SETTINGS_SAFETY_HUB_VERSION_CARD_HEADER_UPDATED 914
#define IDS_SETTINGS_SAFETY_HUB_VERSION_NAVIGATION_ARIA_LABEL 915
#define IDS_SETTINGS_SAFETY_HUB_VERSION_RELAUNCH_ARIA_LABEL 916
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_ONE_PERMISSION_LABEL 917
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_TWO_PERMISSIONS_LABEL 918
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_THREE_PERMISSIONS_LABEL 919
#define IDS_SETTINGS_SAFETY_HUB_UNUSED_SITE_PERMISSIONS_REMOVED_FOUR_OR_MORE_PERMISSIONS_LABEL 920
#define IDS_SETTINGS_SAFETY_HUB_ABUSIVE_NOTIFICATION_PERMISSIONS_SETTING_SUBLABEL 921
#define IDS_SETTINGS_SECURITY_PASSWORDS_LEAK_DETECTION_DESC 922
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_HOW_IT_WORKS_CONTENT 923
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_UNRECOGNIZED_SITES_DESCRIPTION 924
#define IDS_SETTINGS_SECURITY_BUNDLE_ENHANCED_BULLET_ONE 925
#define IDS_SETTINGS_SECURE_CONNECTIONS_SECTION_DESCRIPTION 926
#define IDS_SETTINGS_HTTPS_FIRST_MODE_SUBTITLE 927
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_FULL_SUBLABEL 928
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_INCOGNITO_SUBLABEL 929
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DISABLED_SUBLABEL 930
#define IDS_PRODUCT_NAME 931
#define IDS_SHORT_PRODUCT_NAME 932
#define IDS_FIRST_RUN_DIALOG_WINDOW_TITLE 938
#define IDS_TERMS_DIALOG_ACCEPT 939
#define IDS_TERMS_DIALOG_CANCEL 940
#define IDS_TERMS_DIALOG_TITLE 941
#define IDS_TERMS_DIALOG_ACCESSIBILITY_LABEL 942
#define IDS_PRODUCT_LOGO_ENTERPRISE_ALT_TEXT 946
#define IDS_TASK_MANAGER_TITLE 948
#define IDS_TASK_MANAGER_SEARCH_PLACEHOLDER 949
#define IDS_TASK_MANAGER_SEARCH_ACCESSIBILITY_NAME 950
#define IDS_TASK_MANAGER_CLEAR_SEARCH_BUTTON_ACCESSIBILITY_NAME 951
#define IDS_TASK_MANAGER_KILL_ACCESSIBILITY_NAME 952
#define IDS_TASK_MANAGER_TASK_KILL_SUCCESS_ACCESSIBILITY_MESSAGE 953
#define IDS_TASK_MANAGER_TASK_KILL_FAIL_ACCESSIBILITY_MESSAGE 954
#define IDS_TASK_MANAGER_CATEGORY_TABS_AND_EXTENSIONS_NAME 955
#define IDS_TASK_MANAGER_CATEGORY_SYSTEM_NAME 956
#define IDS_TASK_MANAGER_CATEGORY_BROWSER_NAME 957
#define IDS_TASK_MANAGER_CATEGORY_ALL_NAME 958
#define IDS_SESSION_CRASHED_VIEW_UMA_OPTIN 959
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_TOO_MANY_BOOKMARKS_BODY 960
#define IDS_RESET_PROFILE_SETTINGS_EXPLANATION_IN_BULLET_POINTS 961
#define IDS_BROWSER_WINDOW_TITLE_FORMAT 962
#define IDS_CAPTIVE_PORTAL_BROWSER_WINDOW_TITLE_FORMAT 963
#define IDS_ACCESSIBLE_BROWSER_WINDOW_TITLE_FORMAT 964
#define IDS_ACCESSIBLE_BETA_BROWSER_WINDOW_TITLE_FORMAT 965
#define IDS_ACCESSIBLE_DEV_BROWSER_WINDOW_TITLE_FORMAT 966
#define IDS_ACCESSIBLE_CANARY_BROWSER_WINDOW_TITLE_FORMAT 967
#define IDS_ABOUT_VERSION_COMPANY_NAME 968
#define IDS_ABOUT_VERSION_COPYRIGHT 969
#define IDS_ABOUT_TERMS_OF_SERVICE 973
#define IDS_LINUX_OBSOLETE 979
#define IDS_ACCNAME_APP 980
#define IDS_COULDNT_STARTUP_PROFILE_ERROR 982
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_HELP_TEXT_NO_DEVICES 983
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_HELP_TEXT_NO_DEVICES_ORIGIN 984
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_DEVICE_NOT_FOUND 985
#define IDS_FR_CUSTOMIZE_DEFAULT_BROWSER 989
#define IDS_DEFAULT_BROWSER_CHANGED_MESSAGE 990
#define IDS_STATUS_TRAY_KEEP_CHROME_RUNNING_IN_BACKGROUND 991
#define IDS_STATUS_TRAY_KEEP_CHROME_RUNNING_IN_BACKGROUND_SETTING 992
#define IDS_CANT_WRITE_USER_DIRECTORY_SUMMARY 993
#define IDS_PROFILE_TOO_NEW_ERROR 995
#define IDS_PREFERENCES_UNREADABLE_ERROR 996
#define IDS_PREFERENCES_CORRUPT_ERROR 997
#define IDS_DESKTOP_SHORTCUT_COMMENT 998
#define IDS_PASSWORD_MANAGER_ONBOARDING_DETAILS_C 999
#define IDS_PASSWORD_MANAGER_TITLE_BRAND 1000
#define IDS_PASSWORD_BUBBLES_PASSWORD_MANAGER_LINK_TEXT_SAVING_ON_DEVICE 1001
#define IDS_PASSWORD_MANAGER_SAVE_PASSWORD_SIGNED_OUT_MESSAGE_DESCRIPTION 1002
#define IDS_PASSWORD_MANAGER_UPDATE_PASSWORD_SIGNED_OUT_MESSAGE_DESCRIPTION 1003
#define IDS_PASSWORD_MANAGER_IMPORT_DIALOG_TITLE 1024
#define IDS_PASSWORD_MANAGER_EXPORT_DIALOG_TITLE 1025
#define IDS_DEFAULT_BROWSER_INFOBAR_TEXT 1033
#define IDS_DEFAULT_BROWSER_PIN_INFOBAR_TEXT 1034
#define IDS_DEFAULT_BROWSER_MODAL_TITLE_WITH_SETTINGS_ILLUSTRATION 1035
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITH_SETTINGS_ILLUSTRATION 1036
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITH_SETTINGS_ILLUSTRATION_UNPINNED 1037
#define IDS_DEFAULT_BROWSER_MODAL_TITLE_WITHOUT_SETTINGS_ILLUSTRATION 1038
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITHOUT_SETTINGS_ILLUSTRATION 1039
#define IDS_DEFAULT_BROWSER_MODAL_BODY_WITHOUT_SETTINGS_ILLUSTRATION_UNPINNED 1040
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_TITLE 1041
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_BODY 1042
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_STEPS_PINNED_COMBINED 1043
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_UNKNOWN_SOURCE 1045
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_BLOCKED_LEARN_MORE_LINK 1046
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_DEEP_SCANNING_PROMPT_LOCAL_DECRYPTION 1047
#define IDS_DOWNLOAD_STATUS_CRX_INSTALL_RUNNING 1048
#define IDS_PROMPT_DOWNLOAD_CHANGES_SETTINGS 1049
#define IDS_PROMPT_MALICIOUS_DOWNLOAD_URL 1050
#define IDS_PROMPT_MALICIOUS_DOWNLOAD_CONTENT 1051
#define IDS_BLOCK_REASON_PROMPT_FOR_SCANNING 1052
#define IDS_BLOCK_DOWNLOAD_REASON_DANGEROUS_FILETYPE 1053
#define IDS_BLOCK_DOWNLOAD_REASON_DANGEROUS 1054
#define IDS_BLOCK_DOWNLOAD_REASON_DANGEROUS_COOKIE_THEFT 1055
#define IDS_BLOCK_DOWNLOAD_REASON_UNCOMMON 1056
#define IDS_BLOCK_DOWNLOAD_REASON_UNCOMMON_SUSPICIOUS_ARCHIVE 1057
#define IDS_BLOCK_DOWNLOAD_REASON_POTENTIALLY_UNWANTED 1058
#define IDS_BLOCK_DOWNLOAD_REASON_INSECURE 1059
#define IDS_BLOCK_DOWNLOAD_REASON_UNVERIFIED_NO_SAFE_BROWSING 1060
#define IDS_DOWNLOAD_WARNING_BYPASS_PROMPT_LEARN_MORE_LINK 1061
#define IDS_DOWNLOAD_WARNING_BYPASS_PROMPT_LEARN_MORE_LINK_ACCESSIBLE 1062
#define IDS_ABANDON_DOWNLOAD_DIALOG_BROWSER_MESSAGE 1063
#define IDS_MISSING_GOOGLE_API_KEYS 1065
#define IDS_EXTENSION_INSTALLED_HEADING 1066
#define IDS_EXTENSION_UNINSTALL_PROMPT_REMOVE_DATA_CHECKBOX 1068
#define IDS_EXTENSION_ALERT_ITEM_BLOCKLISTED_MALWARE 1069
#define IDS_EXTENSIONS_ALERT_ITEM_BLOCKLISTED_MALWARE_TITLE 1070
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_KEEP_DIALOG_DESCRIPTION 1071
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_DESCRIPTION 1072
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_DISABLED_SUBTITLE 1073
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_DISABLED_SUBTITLE 1074
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_REMOVE_BUTTON_ACC_LABEL 1075
#define IDS_EXTENSIONS_MENU_ZERO_STATE_DESC 1076
#define IDS_OPEN_WEB_STORE_BUTTON_TEXT 1077
#define IDS_SAFETY_CHECK_EXTENSIONS_MALWARE 1078
#define IDS_SAFETY_CHECK_EXTENSIONS_POLICY_VIOLATION 1079
#define IDS_SAFETY_CHECK_EXTENSIONS_UNPUBLISHED 1080
#define IDS_EXTENSIONS_SAFETY_CHECK_PRIMARY_LABEL 1081
#define IDS_EXTENSIONS_SAFETY_CHECK_OFFSTORE 1082
#define IDS_EXTENSIONS_SAFETY_CHECK_OFFSTORE_ON 1083
#define IDS_EXTENSIONS_SAFETY_CHECK_OFFSTORE_OFF 1084
#define IDS_EXTENSIONS_SAFETY_CHECK_NO_PRIVACY_PRACTICES 1085
#define IDS_EXTENSIONS_SC_DESCRIPTION 1086
#define IDS_EXTENSIONS_ITEM_SHOW_ACCESS_REQUESTS_IN_TOOLBAR 1087
#define IDS_EXTENSIONS_INCOGNITO_WARNING 1088
#define IDS_EXTENSIONS_UNINSTALL 1089
#define IDS_EXTENSIONS_SHORTCUT_SCOPE_IN_CHROME 1090
#define IDS_PENDING_CHANGE_WARNING 1091
#define IDS_EXTENSIONS_MULTIPLE_UNSUPPORTED_DISABLED_BODY 1092
#define IDS_EXTENSIONS_SINGLE_UNSUPPORTED_DISABLED_BODY 1093
#define IDS_APPMENU_TOOLTIP 1094
#define IDS_APPMENU_TOOLTIP_UPDATE_AVAILABLE 1095
#define IDS_APPMENU_TOOLTIP_ALERT 1096
#define IDS_OPEN_IN_CHROME 1097
#define IDS_ABOUT 1098
#define IDS_RELAUNCH_TO_UPDATE 1099
#define IDS_CUSTOMIZE_CHROME 1103
#define IDS_OTHER_CHROME_PROFILES_TITLE 1104
#define IDS_MANAGE_CHROME_PROFILES 1105
#define IDS_VIEW_PASSWORDS 1106
#define IDS_CHROME_SIGNIN_TITLE 1107
#define IDS_PROFILES_DICE_SYNC_PROMO 1108
#define IDS_SYNC_WRONG_EMAIL 1109
#define IDS_SYNC_USED_PROFILE_ERROR 1110
#define IDS_SESSION_RESTORE_TURN_OFF_RESTORE_FROM_SESSION 1111
#define IDS_SESSION_RESTORE_TURN_OFF_RESTORE_FROM_RESTART 1112
#define IDS_SESSION_RESTORE_TURN_ON 1113
#define IDS_SESSION_RESTORE_LINK 1114
#define IDS_SESSION_RESTORE_LINK_ARIA_LABEL 1115
#define IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_REQUIRED_BY_ORG_TITLE 1116
#define IDS_AI_SIGNIN_PROMO_SUBTITLE 1117
#define IDS_AI_SIGNIN_PROMO_AVATAR_PILL_TEXT 1118
#define IDS_ENTERPRISE_SIGNIN_TITLE 1119
#define IDS_ENTERPRISE_SIGNIN_EXPLANATION_WITHOUT_PROFILE_CREATION 1120
#define IDS_ENTERPRISE_SIGNIN_EXPLANATION_WITH_PROFILE_CREATION 1121
#define IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_REQUIRED_BY_ORG_KNOWN_DOMAIN_TITLE 1122
#define IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_SUGGESTED_TITLE 1123
#define IDS_MANAGEMENT_DIALOG_BROWSER_MANAGED 1124
#define IDS_MANAGEMENT_DIALOG_BROWSER_MANAGED_BY 1125
#define IDS_MANAGEMENT_DIALOG_BROWSER_MANAGED_BY_MULTIPLE_ORGANIZATIONS 1126
#define IDS_MANAGED_PROFILE_INTERSTITIAL_PRIMARY_PARAGRAPH 1127
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_TITLE 1128
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_BODY_PART_1 1129
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_TITLE_FALLBACK 1130
#define IDS_ABOUT_BROWSER_SWITCH_DESCRIPTION_UNKNOWN_BROWSER 1131
#define IDS_ABOUT_BROWSER_SWITCH_DESCRIPTION_KNOWN_BROWSER 1132
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_YOUR_CHROME 1133
#define IDS_NTP_CUSTOMIZE_BUTTON_LABEL 1134
#define IDS_NTP_MODULES_SETUP_LIST_TITLE 1135
#define IDS_NTP_CUSTOMIZE_CHROME_RESET_TO_CLASSIC_CHROME_LABEL 1136
#define IDS_NTP_CUSTOMIZATION_PROMO 1137
#define IDS_NTP_MOBILE_PROMO_TITLE 1138
#define IDS_NTP_MOBILE_PROMO_PASSWORDS_TITLE 1139
#define IDS_IPH_CUSTOMIZE_CHROME_AUTO_OPEN_BODY 1140
#define IDS_IPH_CUSTOMIZE_CHROME_AUTO_OPEN_SCREENREADER 1141
#define IDS_IPH_REALBOX_CONTEXTUAL_ENTRYPOINT 1142
#define IDS_IPH_REALBOX_CONTEXTUAL_ENTRYPOINT_SCREENREADER 1143
#define IDS_SIGNIN_EMAIL_CONFIRMATION_TITLE 1144
#define IDS_AVATAR_BUTTON_INTERCEPT_BUBBLE_CHROME_SIGNIN_TEXT 1145
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_TITLE 1146
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_DECLINE_TEXT 1147
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_TITLE_V2 1148
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_TITLE 1149
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC_V2 1150
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_DESC_V2_SUPERVISED 1151
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CONSUMER_BUBBLE_DESC 1152
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_DESC 1153
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE 1154
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE_WITH_BOOKMARKS 1155
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_SUBTITLE_SUPERVISED 1156
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_TEXT_SIGNIN_REMINDER 1157
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_TEXT_SIGNIN_REMINDER_SCREENREADER 1158
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_NO_UNSYNCED_TITLE 1159
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_NO_UNSYNCED_BODY 1160
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_NO_UNSYNCED_DATA_BODY 1161
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_VERIFY_BODY 1162
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_VERIFY_BODY_WITH_COUNT 1163
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_UNSYNCED_BODY 1164
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_UNSYNCED_BODY_WITH_COUNT 1165
#define IDS_CLOSE_WARNING_FOR_CLEAR_COOKIES_ON_EXIT_TEXT 1166
#define IDS_SYNC_PASSPHRASE_DIALOG_FOOTER 1167
#define IDS_SYNC_PASSPHRASE_DIALOG_FOOTER_LINK_ACC 1168
#define IDS_SYNC_PASSPHRASE_DIALOG_BODY 1169
#define IDS_AVATAR_BUTTON_INTERCEPT_BUBBLE_CHROME_SIGNIN_ACCESSIBILITY_LABEL 1170
#define IDS_AVATAR_BUTTON_SIGNIN_PENDING_ACCESSIBILITY_LABEL 1171
#define IDS_AUTOFILL_SIGNIN_PROMO_SUBTITLE_PASSWORD 1172
#define IDS_AUTOFILL_SIGNIN_PROMO_SUBTITLE_ADDRESS 1173
#define IDS_PROFILE_CUSTOMIZATION_TEXT 1174
#define IDS_PROFILE_CUSTOMIZATION_TITLE_V2 1175
#define IDS_PROFILE_MENU_SIGNIN_PROMO_BUTTON 1180
#define IDS_PROFILE_MENU_PLACEHOLDER_PROFILE_NAME 1181
#define IDS_PROFILE_MENU_SIGN_OUT_WHEN_SIGNIN_PENDING 1182
#define IDS_PROFILE_MENU_PROFILES_LIST_TITLE 1183
#define IDS_PROFILE_MENU_MANAGE_PROFILES 1184
#define IDS_PROFILE_MENU_SIGN_OUT 1185
#define IDS_PROFILE_MENU_ADD_PROFILE 1186
#define IDS_APP_ALSO_DELETE_APPS_DATA 1188
#define IDS_APP_SHORTCUTS_SUBDIR_NAME 1189
#define IDS_APP_SHORTCUTS_SUBDIR_NAME_CANARY 1190
#define IDS_MEDIA_STREAM_STATUS_TRAY_TEXT_AUDIO_AND_VIDEO 1194
#define IDS_MEDIA_STREAM_STATUS_TRAY_TEXT_AUDIO_ONLY 1195
#define IDS_MEDIA_STREAM_STATUS_TRAY_TEXT_VIDEO_ONLY 1196
#define IDS_WEBHID_SYSTEM_TRAY_ICON_TITLE 1197
#define IDS_WEBUSB_SYSTEM_TRAY_ICON_TITLE 1198
#define IDS_PROFILE_IN_USE_POSIX 1199
#define IDS_LOGIN_POD_USER_REMOVE_WARNING_SYNC 1201
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_INTRO_TITLE 1202
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_INTRO_TEXT 1203
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_YOUR_CHROME_TITLE 1204
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_YOUR_CHROME_TEXT 1205
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_GUEST_TEXT 1206
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_FRIENDS_TEXT 1207
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_OUTRO_TEXT 1208
#define IDS_USER_MANAGER_TUTORIAL_SLIDE_OUTRO_ADD_USER 1209
#define IDS_TUTORIAL_PASSWORD_MANAGER_OPEN_APP_MENU 1210
#define IDS_TUTORIAL_PASSWORD_MANAGER_CLICK_PASSWORD_MANAGER 1211
#define IDS_TUTORIAL_PASSWORD_MANAGER_SUCCESS_BODY 1212
#define IDS_PASSWORD_MANAGER_IPH_CREATE_SHORTCUT_BODY 1213
#define IDS_EXTENSIONS_SETTINGS_API_SECOND_LINE_START_PAGES 1214
#define IDS_EXTENSIONS_SETTINGS_API_SECOND_LINE_START_AND_SEARCH 1215
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_ACTIVE_SHORTCUTS_EXPLANATION 1216
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_INACTIVE_SHORTCUTS_EXPLANATION 1217
#define IDS_WEBSTORE_APP_DESCRIPTION 1218
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_TEXT 1227
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_TEXT_ONCE 1228
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_TEXT 1229
#define IDS_CONTENT_CONTEXT_OPENLINKNEWTAB_INAPP 1230
#define IDS_CONTENT_CONTEXT_OPENLINKOFFTHERECORD_INAPP 1231
#define IDS_AVATAR_BUTTON_MAKING_CHROME_YOURS 1232
#define IDS_AVATAR_BUTTON_SIGNIN_PROMO 1233
#define IDS_UPDATE_RECOMMENDED_DIALOG_TITLE 1234
#define IDS_UPDATE_RECOMMENDED 1235
#define IDS_RELAUNCH_AND_UPDATE 1236
#define IDS_UPDATE_RECOMMENDED_DIALOG_TITLE_ALT 1237
#define IDS_UPDATE_RECOMMENDED_ALT 1238
#define IDS_REINSTALL_APP 1239
#define IDS_UPGRADE_BUBBLE_MENU_ITEM 1240
#define IDS_UPGRADE_BUBBLE_TITLE 1241
#define IDS_UPGRADE_BUBBLE_TEXT 1242
#define IDS_SYNC_ERROR_USER_MENU_UPGRADE_BUTTON 1243
#define IDS_SYNC_ERROR_PASSPHRASE_USER_MENU_ERROR_DESCRIPTION 1244
#define IDS_SYNC_ERROR_TRUSTED_VAULT_USER_MENU_ERROR_DESCRIPTION 1245
#define IDS_SYNC_ERROR_UPGRADE_CLIENT_USER_MENU_TITLE 1246
#define IDS_SYNC_ERROR_UPGRADE_CLIENT_USER_MENU_ERROR_DESCRIPTION 1247
#define IDS_SYNC_UPGRADE_CLIENT 1248
#define IDS_SYNC_UPGRADE_CLIENT_BUTTON 1249
#define IDS_RECOVERY_BUBBLE_TITLE 1250
#define IDS_RUN_RECOVERY 1251
#define IDS_RECOVERY_BUBBLE_TEXT 1252
#define IDS_CRITICAL_NOTIFICATION_TITLE 1253
#define IDS_CRITICAL_NOTIFICATION_TITLE_ALTERNATE 1254
#define IDS_CRITICAL_NOTIFICATION_TEXT 1255
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_TAB 1256
#define IDS_DESKTOP_MEDIA_PICKER_SCREEN_PERMISSION_TEXT_MAC 1257
#define IDS_DESKTOP_MEDIA_PICKER_SCREEN_PERMISSION_TEXT_PERIOD_MAC 1258
#define IDS_DESKTOP_MEDIA_PICKER_WINDOW_PERMISSION_TEXT_MAC 1259
#define IDS_DESKTOP_MEDIA_PICKER_WINDOW_PERMISSION_TEXT_PERIOD_MAC 1260
#define IDS_DESKTOP_MEDIA_PICKER_PERMISSION_RESTART_TEXT_MAC 1261
#define IDS_DESKTOP_MEDIA_PICKER_SYSTEM_AUDIO_PERMISSION_TEXT_MAC 1262
#define IDS_SIDE_PANEL_CUSTOMIZE_CHROME_TITLE 1280
#define IDS_HISTORY_HISTORY_MENU_ITEM 1281
#define IDS_LENS_SEND_FEEDBACK 1282
#define IDS_LENS_SEND_FEEDBACK_PLACEHOLDER 1283
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_IPH 1284
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_IPH_SCREENREADER 1285
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_FOLLOWUP_IPH 1286
#define IDS_SIDE_PANEL_LENS_OVERLAY_PINNABLE_FOLLOWUP_IPH_SCREENREADER 1287
#define IDS_LENS_OVERLAY_COPY 1288
#define IDS_LENS_OVERLAY_COPY_TEXT 1289
#define IDS_LENS_OVERLAY_COPY_TOAST_MESSAGE 1290
#define IDS_LENS_OVERLAY_COPY_AS_IMAGE_TOAST_MESSAGE 1291
#define IDS_LENS_OVERLAY_FEEDBACK_TOAST_MESSAGE 1292
#define IDS_LENS_OVERLAY_FEEDBACK_TOAST_MESSAGE_ALT 1293
#define IDS_LENS_OVERLAY_SEND_FEEDBACK_BUTTON_LABEL 1294
#define IDS_LENS_OVERLAY_CLOSE_FEEDBACK_TOAST_ACCESSIBILITY_LABEL 1295
#define IDS_LENS_OVERLAY_MORE_OPTIONS_BUTTON_LABEL 1296
#define IDS_LENS_OVERLAY_MY_ACTIVITY 1297
#define IDS_LENS_OVERLAY_TOAST_PAGE_CONTENT_NOT_FOUND_MESSAGE 1298
#define IDS_LENS_OVERLAY_TOAST_DISMISS_MESSAGE 1299
#define IDS_LENS_OVERLAY_TRANSLATE 1300
#define IDS_LENS_OVERLAY_SELECT_TEXT 1301
#define IDS_LENS_OVERLAY_COPY_AS_IMAGE 1302
#define IDS_LENS_OVERLAY_SAVE_AS_IMAGE 1303
#define IDS_LENS_OVERLAY_LEARN_MORE 1304
#define IDS_LENS_OVERLAY_INITIAL_TOAST_LABEL 1305
#define IDS_LENS_OVERLAY_INITIAL_TOAST_MESSAGE 1306
#define IDS_LENS_OVERLAY_INITIAL_TOAST_LABEL_SIMPLIFIED 1307
#define IDS_LENS_OVERLAY_INITIAL_TOAST_MESSAGE_SIMPLIFIED 1308
#define IDS_LENS_OVERLAY_INITIAL_TOAST_MESSAGE_SELECT_TEXT 1309
#define IDS_LENS_OVERLAY_INITIAL_TOAST_ERROR_MESSAGE 1310
#define IDS_LENS_OVERLAY_INITIAL_TOAST_ERROR_EXIT_BUTTON_TEXT 1311
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_DRAG_MESSAGE 1312
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_TEXT_HIGHLIGHT_MESSAGE 1313
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_CLICK_MESSAGE 1314
#define IDS_LENS_OVERLAY_CURSOR_TOOLTIP_LIVE_PAGE_MESSAGE 1315
#define IDS_LENS_OVERLAY_AUTO_DETECT_LANGUAGE_LABEL 1316
#define IDS_LENS_OVERLAY_TRANSLATE_BUTTON_LABEL 1317
#define IDS_LENS_OVERLAY_SOURCE_LANGUAGE_PICKER_MENU_TITLE 1318
#define IDS_LENS_OVERLAY_TARGET_LANGUAGE_PICKER_MENU_TITLE 1319
#define IDS_LENS_OVERLAY_RECENT_LANGUAGES_LABEL 1320
#define IDS_LENS_OVERLAY_ALL_LANGUAGES_LABEL 1321
#define IDS_LENS_OVERLAY_DETECTED_LABEL 1322
#define IDS_LENS_OVERLAY_DETECT_LANGUAGE_LABEL 1323
#define IDS_LENS_OVERLAY_RENDERER_LABEL 1324
#define IDS_LENS_OVERLAY_CLOSE_TRANSLATE_SCREEN_LABEL 1325
#define IDS_LENS_OVERLAY_LANGUAGE_PICKER_LABEL 1326
#define IDS_LENS_OVERLAY_SOURCE_LANGUAGE_ACCESSIBILITY_LABEL 1327
#define IDS_LENS_OVERLAY_TARGET_LANGUAGE_ACCESSIBILITY_LABEL 1328
#define IDS_LENS_OVERLAY_SEARCH_LANGUAGE_PICKER_LABEL 1329
#define IDS_LENS_OVERLAY_TOP_LEFT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1330
#define IDS_LENS_OVERLAY_TOP_RIGHT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1331
#define IDS_LENS_OVERLAY_BOTTOM_RIGHT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1332
#define IDS_LENS_OVERLAY_BOTTOM_LEFT_CORNER_SLIDER_ACCESSIBILITY_LABEL 1333
#define IDS_LENS_OVERLAY_SEARCH_SCREENSHOT_ACCESSIBILITY_LABEL 1334
#define IDS_LENS_OVERLAY_TRANSLATE_BUTTON_IPH 1335
#define IDS_LENS_OVERLAY_TRANSLATE_BUTTON_IPH_SCREENREADER 1336
#define IDS_CONTENT_CONTEXT_LENS_OVERLAY 1337
#define IDS_CONTENT_LENS_OVERLAY_ENTRYPOINT_LABEL 1338
#define IDS_CONTENT_LENS_OVERLAY_HOMEWORK_ENTRYPOINT_LABEL 1339
#define IDS_CONTENT_LENS_OVERLAY_ASK_GOOGLE_ENTRYPOINT_LABEL 1340
#define IDS_SIDE_PANEL_LENS_OVERLAY_TOOLBAR_TOOLTIP 1341
#define IDS_LENS_OVERLAY_ENTRYPOINT_LABEL_ALT1 1342
#define IDS_LENS_OVERLAY_ENTRYPOINT_LABEL_ALT2 1343
#define IDS_LENS_OVERLAY_ENTRYPOINT_LABEL_ALT3 1344
#define IDS_LENS_OVERLAY_IMAGE_ENTRYPOINT_LABEL_ALT1 1345
#define IDS_LENS_OVERLAY_IMAGE_ENTRYPOINT_LABEL_ALT2 1346
#define IDS_LENS_OVERLAY_IMAGE_ENTRYPOINT_LABEL_ALT3 1347
#define IDS_LENS_OVERLAY_TAB_ENTRYPOINT_LABEL 1348
#define IDS_LENS_OVERLAY_VIDEO_ENTRYPOINT_LABEL_ALT1 1349
#define IDS_LENS_OVERLAY_VIDEO_ENTRYPOINT_LABEL_ALT2 1350
#define IDS_LENS_OVERLAY_VIDEO_ENTRYPOINT_LABEL_ALT3 1351
#define IDS_AI_MODE_ENTRYPOINT_LABEL 1352
#define IDS_SIDE_PANEL_LENS_OVERLAY_GENERIC_ERROR_PAGE_FIRST_LINE 1353
#define IDS_SIDE_PANEL_LENS_OVERLAY_GENERIC_ERROR_PAGE_SECOND_LINE 1354
#define IDS_SIDE_PANEL_LENS_OVERLAY_PROTECTED_PAGE_ERROR_FIRST_LINE 1355
#define IDS_SIDE_PANEL_LENS_OVERLAY_PROTECTED_PAGE_ERROR_SECOND_LINE 1356
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_CANCEL_BUTTON 1357
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_CONTINUE_BUTTON 1358
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_CSB_DESCRIPTION 1359
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_NON_BLOCKING_DESCRIPTION 1360
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_DESCRIPTION 1361
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_LEARN_MORE_LINK 1362
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_LEARN_MORE_ABOUT_GOOGLE_LENS_LINK 1363
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_TITLE 1364
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_TAB_TO_CONTINUE 1365
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_GOT_IT 1366
#define IDS_LENS_PERMISSION_BUBBLE_DIALOG_REMIND_ME_LATER 1367
#define IDS_SHOW_LENS_OVERLAY 1369
#define IDS_CONTEXT_MENU_SHOW_GOOGLE_LENS_SHORTCUT 1368
#define IDS_LENS_CONTEXTUAL_SEARCH_DEFAULT_QUERY 1370
#define IDS_LENS_CONTEXTUAL_SEARCH_ZERO_STATE_QUERY 1371
#define IDS_LENS_COMPOSEBOX_HINT_TEXT 1372
#define IDS_LENS_COMPOSEBOX_HINT_TEXT_SEARCH_PAGE 1373
#define IDS_LENS_COMPOSEBOX_HINT_TEXT_SELECT_PAGE 1374
#define IDS_LENS_COMPOSEBOX_HINT_TEXT_ASK_ANYTHING 1375
#define IDS_AI_MODE_ASK_ABOUT_THIS_TAB 1376
#define IDS_AI_MODE_NEW_SEARCH 1377
#define IDS_CONTEXT_MENU_SHOW_AI_MODE_OMNIBOX_BUTTON 1378
#define IDS_RELAUNCH_RECOMMENDED_TITLE 1382
#define IDS_RELAUNCH_RECOMMENDED_BODY 1383
#define IDS_RELAUNCH_REQUIRED_TITLE_DAYS 1384
#define IDS_RELAUNCH_REQUIRED_TITLE_HOURS 1385
#define IDS_RELAUNCH_REQUIRED_TITLE_MINUTES 1386
#define IDS_RELAUNCH_REQUIRED_TITLE_SECONDS 1387
#define IDS_RELAUNCH_REQUIRED_BODY 1388
#define IDS_ADVANCED_PROTECTION_RELAUNCH_REQUIRED_BODY 1389
#define IDS_ENTERPRISE_STARTUP_CLOUD_POLICY_ENROLLMENT_TOOLTIP 1390
#define IDS_ENTERPRISE_STARTUP_CLOUD_POLICY_ENROLLMENT_ERROR 1391
#define IDS_ENTERPRISE_STARTUP_RELAUNCH_BUTTON 1392
#define IDS_DESKTOP_MEDIA_PICKER_TITLE_WEB_CONTENTS_ONLY 1393
#define IDS_IDLE_BUBBLE_TITLE_CLOSE 1394
#define IDS_IDLE_BUBBLE_BODY_CLOSE_AND_CLEAR 1395
#define IDS_IDLE_BUBBLE_BODY_CLEAR 1396
#define IDS_IDLE_BUBBLE_BODY_CLOSE 1397
#define IDS_IDLE_TIMEOUT_CLOSE_TITLE 1398
#define IDS_IDLE_TIMEOUT_CLEAR_TITLE 1399
#define IDS_IDLE_TIMEOUT_CLOSE_AND_CLEAR_TITLE 1400
#define IDS_IDLE_TIMEOUT_CLOSE_BODY 1401
#define IDS_IDLE_TIMEOUT_CLEAR_BODY 1402
#define IDS_IDLE_TIMEOUT_CLOSE_AND_CLEAR_BODY 1403
#define IDS_IDLE_DISMISS_BUTTON 1404
#define IDS_HATS_BUBBLE_TITLE 1405
#define IDS_EXTENSION_PERMISSIONS_BLOCKED_BY_PARENT_PROMPT_MESSAGE 1407
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_TITLE_APP 1408
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_TITLE_EXTENSION 1409
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_TITLE_THEME 1410
#define IDS_EXTENSION_EXTERNAL_INITIAL_INSTALL_PROMPT_TITLE_EXTENSION 1411
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ABORT_BUTTON 1412
#define IDS_ENTERPRISE_WELCOME_PROFILE_INFORMATION_DETAILS 1413
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE 1414
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_V2 1415
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_KEEP_EVERYTHING_IN_CHROME 1416
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE 1417
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_KEEP_WORK_AND_LIFE_SEPARATE 1418
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_GOT_ANOTHER_GOOGLE_ACCOUNT 1419
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_KEEP_TASKS_SEPARATE 1420
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_PROFILE_TYPE_CHOICE_TITLE 1421
#define IDS_PROFILE_PICKER_IPH_FOR_PROFILES_TEXT 1422
#define IDS_PROFILE_PICKER_IPH_FOR_ADD_PROFILE_TEXT 1423
#define IDS_PROFILE_PICKER_PROFILE_SWITCH_TITLE 1424
#define IDS_PROFILE_PICKER_PROFILE_SWITCH_SUBTITLE 1425
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_SUPPORTED_BY_GLIC_FLOW_BODY 1426
#define IDS_FRE_SIGN_IN_TITLE_0 1427
#define IDS_FRE_GET_YOUR_BROWSER_READY_TITLE 1428
#define IDS_FRE_DEFAULT_BROWSER_TITLE 1429
#define IDS_FRE_DEFAULT_BROWSER_AND_PINNING_TITLE 1430
#define IDS_FRE_DEFAULT_BROWSER_SUBTITLE_NEW 1431
#define IDS_FRE_DEFAULT_BROWSER_AND_PINNING_SUBTITLE 1432
#define IDS_FRE_DEFAULT_BROWSER_ILLUSTRATION_ALT_TEXT 1433
#define IDS_APP_MENU_TOOLTIP_DEFAULT_PROMPT 1434
#define IDS_APP_MENU_BUTTON_DEFAULT_PROMPT 1435
#define IDS_SET_BROWSER_AS_DEFAULT_MENU_ITEM 1436
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_TITLE 1437
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_SUBTITLE 1438
#define IDS_PROFILE_SWITCH_PROMO 1439
#define IDS_PROFILE_SWITCH_PROMO_SCREENREADER 1440
#define IDS_PASSWORD_MANAGER_IPH_BODY_WEB_APP_PROFILE_SWITCH 1441
#define IDS_SIGNOUT_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNOUT_IPH_TEXT 1442
#define IDS_SIGNOUT_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNOUT_IPH_TEXT_SCREENREADER 1443
#define IDS_QUIET_NOTIFICATION_IPH_TEXT 1444
#define IDS_QUIET_NOTIFICATION_IPH_TEXT_SCREENREADER 1445
#define IDS_CHROMELABS_RELAUNCH_FOOTER_MESSAGE 1446
#define IDS_SERIAL_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH 1447
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_NOTIFICATION_TITLE 1448
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_TITLE 1449
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_DESCRIPTION 1450
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_DESCRIPTION_UPDATED 1451
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_MESSAGE_ACCEPT 1452
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_OPTIMIZATION_LINK_ROW_ENABLED 1457
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_OPTIMIZATION_LINK_ROW_DISABLED 1458
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_DESCRIPTION 1459
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_ALLOWED_SUB_LABEL 1460
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_SUB_LABEL 1461
#define IDS_MEMORY_SAVER_DIALOG_BODY 1527
#define IDS_MEMORY_SAVER_MODE_PROMO_TITLE 1528
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_BODY_V1 1529
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_BODY_SINGULAR_V1 1530
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_UPDATED_V3 1531
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_SIGNED_IN 1532
#define IDS_CREATE_SHORTCUT_NOT_APPS_DIALOG_SUBTITLE 1533
#define IDS_CLEAR_BROWSING_DATA_TOAST_BODY 1535
#define IDS_SKILL_SAVED_TOAST_BUTTON 1536
#define IDS_GLIC_PROMO_TITLE 1537
#define IDS_GLIC_TAB_STRIP_BUTTON_TOOLTIP 1538
#define IDS_GLIC_TAB_STRIP_BUTTON_TOOLTIP_CLOSE 1539
#define IDS_GLIC_THREE_DOT_MENU_ITEM 1540
#define IDS_GLIC_STATUS_ICON_TOOLTIP 1541
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CANARY 1542
#define IDS_GLIC_STATUS_ICON_TOOLTIP_DEV 1543
#define IDS_GLIC_STATUS_ICON_TOOLTIP_BETA 1544
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE 1545
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE_CANARY 1546
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE_DEV 1547
#define IDS_GLIC_STATUS_ICON_TOOLTIP_CLOSE_BETA 1548
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE 1549
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE_CANARY 1550
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE_DEV 1551
#define IDS_GLIC_STATUS_ICON_TOOLTIP_TOGGLE_BETA 1552
#define IDS_GLIC_STATUS_ICON_MENU_SHOW 1553
#define IDS_GLIC_STATUS_ICON_MENU_CLOSE 1554
#define IDS_GLIC_STATUS_ICON_MENU_TOGGLE 1555
#define IDS_GLIC_INELIGIBLE_PROFILE_NOTICE 1556
#define IDS_SETTINGS_GLIC_PAGE_TITLE 1557
#define IDS_SETTINGS_GLIC_SECTION_TITLE 1558
#define IDS_SETTINGS_GLIC_ROW_LABEL 1559
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE 1560
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_SUBLABEL 1561
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_GLIC 1562
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_GLIC_NO_PROFILE 1563
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_GLIC 1564
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_GLIC_NO_PROFILE 1565
#define IDS_PROFILE_PICKER_ADD_PROFILE_HELPER_GLIC 1566
#define IDS_GLIC_CONTEXTUAL_CUEING_ANNOUNCEMENT 1567
#define IDS_GLIC_BUTTON_ENTRYPOINT_ASK_BROWSER_LABEL 1568
#define IDS_EXTENSION_INSTALLED_PROMO_EXPLICIT_SIGNIN_MESSAGE 1569
#define IDS_BOOKMARK_INSTALLED_PROMO_EXPLICIT_SIGNIN_MESSAGE 1570
#define IDS_BOOKMARK_INSTALLED_BUBBLE_PROMO_EXPLICIT_SIGNIN_MESSAGE 1571
#define IDS_DICE_MIGRATION_CONFIRMATION_TOAST_MESSAGE 1572
#define IDS_DICE_MIGRATION_CONFIRMATION_TOAST_BUTTON 1573
#define IDS_PROFILE_MENU_ACCOUNT_SETTINGS_BUTTON 1574
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_DESCRIPTION_REMINDER 1575
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_TITLE_QR 1576
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_DESCRIPTION_REMINDER 1577
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_TITLE 1578
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_BUTTON_ACCEPT_QR 1579
#define IDS_IOS_DESKTOP_PROMO_QR_CODE_ALT_TEXT 1580
#define IDS_IOS_DESKTOP_PROMO_REMINDER_CONFIRMATION 1581
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_REMINDER_CONFIRMATION 1582
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_DESCRIPTION_REMINDER 1583
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_TITLE_QR 1584
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_DESCRIPTION_QR 1585
#define IDS_IOS_DESKTOP_LENS_PROMO_NOTIFICATION_TITLE 1586
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_NOTIFICATION_TITLE 1587
#define IDS_IOS_DESKTOP_PRICE_TRACKING_DESCRIPTION_QR 1588
#define IDS_IOS_DESKTOP_PRICE_TRACKING_REMINDER_CONFIRMATION 1589
#define IDS_IOS_DESKTOP_SAFE_BROWSING_PROMO_NOTIFICATION_TITLE 1590
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_DESCRIPTION_QR 1591
#define IDS_IOS_DESKTOP_TAB_GROUPS_REMINDER_CONFIRMATION 1592
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_TITLE 1593
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_BODY 1594
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_GOT_IT_BUTTON 1595
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_LEARN_MORE_BUTTON 1596
#define IDS_DEFAULT_SEARCH_ENGINE_RESET_NOTIFICATION_SEARCH_SETTINGS_BUTTON 1597
#define IDS_REPORT_UNSAFE_SITE_DIALOG_TITLE 1598
#define IDS_REPORT_UNSAFE_SITE_DIALOG_DESCRIPTION 1599
#define IDS_REPORT_UNSAFE_SITE_DIALOG_FOOTER 1600
#define IDS_INDIGO_ENTRYPOINT_CHIP_TEXT 1601
#define IDS_INDIGO_ENTRYPOINT_CHIP_TOOLTIP_TEXT 1602
#define IDS_INDIGO_ENTRYPOINT_ANCHORED_MESSAGE_TEXT 1603
#define IDS_INDIGO_TITLE 1604
#define IDS_INDIGO_TEXT_LAYER_STEP_1 1605
#define IDS_INDIGO_TEXT_LAYER_STEP_2 1606
#define IDS_INDIGO_TEXT_LAYER_STEP_3 1607
#define IDS_INDIGO_DISCLAIMER_LINE_1 1608
#define IDS_INDIGO_DISCLAIMER_LINE_2 1609
#define IDS_JS_OPTIMIZATION_BUBBLE_BODY_NON_POLICY_BODY 1610

// ---------------------------------------------------------------------------
// From cef_strings.h:

#define IDS_TEXT_FILES 59450
#define IDS_CONTENT_CONTEXT_NO_SPELLING_SUGGESTIONS 59451

// ---------------------------------------------------------------------------
// From components_branded_strings.h:

#define IDS_ERRORPAGES_SUGGESTION_NETWORK_PREDICTION_BODY 35390
#define IDS_ERRORPAGES_SUGGESTION_FIREWALL_CONFIG_HEADER 35391
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_CLIENT 35392
#define IDS_ERRORPAGES_SUGGESTION_PROXY_DISABLE_PLATFORM 35393
#define IDS_FLAGS_UI_RELAUNCH_NOTICE 35396
#define IDS_CRASH_DISABLED_MESSAGE 35397
#define IDS_SHORT_PRODUCT_LOGO_ALT_TEXT 35398
#define IDS_VERSION_UI_LICENSE 35399
#define IDS_PAGE_INFO_INTERNAL_PAGE 35402
#define IDS_SESSION_CRASHED_VIEW_MESSAGE 35403
#define IDS_BLUETOOTH_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH 35404
#define IDS_INTERNAL_DEBUG_PAGES_DISABLED_BODY 35405

// ---------------------------------------------------------------------------
// From components_strings.h:

#define IDS_ASH_ARC_APP_COMPAT_DISABLED_COMPAT_MODE_BUTTON_TOOLTIP_PHONE 35420
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_TITLE 35421
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_BODY 35422
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_ACCEPT 35423
#define IDS_ASH_ARC_APP_COMPAT_RESIZE_CONFIRM_DONT_ASK_ME 35424
#define IDS_ASH_ARC_NEARBY_SHARE_FILE_PREPARATION_PROGRESS 35425
#define IDS_ASH_ARC_NEARBY_SHARE_FILES_PREPARATION_PROGRESS 35426
#define IDS_ASH_ARC_NEARBY_SHARE_ERROR_DIALOG_MESSAGE 35427
#define IDS_ASH_ARC_NEARBY_SHARE_ERROR_DIALOG_MESSAGE_PH 35428
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_TITLE 35429
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_MESSAGE 35430
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_MESSAGE_PH 35431
#define IDS_ASH_ARC_NEARBY_SHARE_LOW_DISK_SPACE_DIALOG_STORAGE_BUTTON 35432
#define IDS_ARC_COMPAT_MODE_RESIZE_TOGGLE_MENU_RESIZE_SETTINGS 35433
#define IDS_ARC_COMPAT_MODE_RESIZE_TOGGLE_MENU_TITLE 35434
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_TITLE 35435
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_BODY 35436
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_BODY_UNRESIZABLE 35437
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_CLOSE 35438
#define IDS_ARC_COMPAT_MODE_SPLASH_SCREEN_LINK 35439
#define IDS_ARC_COMPAT_MODE_DISABLE_RESIZE_LOCK_TOAST 35440
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_ICON 35441
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_THROBBER 35442
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_MESSAGE 35443
#define IDS_ARC_GHOST_WINDOW_APP_LAUNCHING_AOD_MESSAGE 35444
#define IDS_ARC_GHOST_WINDOW_APP_FIXUP_MESSAGE 35445
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_TITLE 35446
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_BODY 35447
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_BODY_WITH_LEARN_MORE 35448
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_SUBSCRIPTION_BODY_WITH_LEARN_MORE 35449
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_LEARN_MORE_LABEL 35450
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_ALLOW_BUTTON 35451
#define IDS_ASH_ARC_PASSPOINT_APP_APPROVAL_DONT_ALLOW_BUTTON 35452
#define IDS_ARC_VM_DATA_MIGRATION_NOTIFICATION_TITLE 35453
#define IDS_ARC_VM_DATA_MIGRATION_NOTIFICATION_DAYS_UNTIL_DEADLINE 35454
#define IDS_ARC_VM_DATA_MIGRATION_NOTIFICATION_ACCEPT_BUTTON_LABEL 35455
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_TITLE 35456
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_SAVE_WORK_MESSAGE 35457
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_DAYS_UNTIL_DEADLINE 35458
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_UPDATE_NOW_BUTTON_LABEL 35459
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_SKIP_BUTTON_LABEL 35460
#define IDS_ARC_VM_DATA_MIGRATION_DIALOG_UPDATE_BUTTON_LABEL 35461
#define IDS_ARC_VM_DATA_MIGRATION_LOADING_SCREEN_MESSAGE 35462
#define IDS_ARC_VM_DATA_MIGRATION_WELCOME_SCREEN_TITLE 35463
#define IDS_ARC_VM_DATA_MIGRATION_WHAT_TO_EXPECT_TITLE 35464
#define IDS_ARC_VM_DATA_MIGRATION_UPDATE_DESCRIPTION 35465
#define IDS_ARC_VM_DATA_MIGRATION_BLOCKING_BEHAVIOR_DESCRIPTION 35466
#define IDS_ARC_VM_DATA_MIGRATION_CONNECT_TO_CHARGER_MESSAGE 35467
#define IDS_ARC_VM_DATA_MIGRATION_NOT_ENOUGH_FREE_DISK_SPACE_MESSAGE 35468
#define IDS_ARC_VM_DATA_MIGRATION_NOT_ENOUGH_BATTERY_MESSAGE 35469
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_UPDATE_BUTTON_LABEL 35470
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_SKIP_BUTTON_LABEL 35471
#define IDS_ARC_VM_DATA_MIGRATION_RESUME_SCREEN_TITLE 35472
#define IDS_ARC_VM_DATA_MIGRATION_RESUME_DESCRIPTION 35473
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_RESUME_BUTTON_LABEL 35474
#define IDS_ARC_VM_DATA_MIGRATION_PROGRESS_SCREEN_TITLE 35475
#define IDS_ARC_VM_DATA_MIGRATION_PROGRESS_DESCRIPTION 35476
#define IDS_ARC_VM_DATA_MIGRATION_SUCCESS_SCREEN_TITLE 35477
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_FINISH_BUTTON_LABEL 35478
#define IDS_ARC_VM_DATA_MIGRATION_FAILURE_SCREEN_TITLE 35479
#define IDS_ARC_VM_DATA_MIGRATION_FAILURE_DESCRIPTION 35480
#define IDS_ARC_VM_DATA_MIGRATION_SEND_FEEDBACK_MESSAGE 35481
#define IDS_ARC_VM_DATA_MIGRATION_SCREEN_REPORT_BUTTON_LABEL 35482
#define IDS_ARC_VM_PRELOAD_NOTIFICATION_TITLE 35483
#define IDS_ARC_VM_PRELOAD_STARTED_MESSAGE 35484
#define IDS_ARC_VM_PRELOAD_SUCCEEDED_MESSAGE 35485
#define IDS_ARC_VM_PRELOAD_FAILED_MESSAGE 35486
#define IDS_AUTOFILL_NO_THANKS_DESKTOP_LOCAL_SAVE 35487
#define IDS_AUTOFILL_NO_THANKS_DESKTOP_UPLOAD_SAVE 35488
#define IDS_AUTOFILL_SAVE_IBAN_BUBBLE_SAVE_NO_THANKS 35489
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_NO_THANKS 35490
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_ACCEPT 35491
#define IDS_AUTOFILL_GOOGLE_PAY_LOGO_ACCESSIBLE_NAME 35494
#define IDS_AUTOFILL_GOOGLE_WALLET_LOGO_ACCESSIBLE_NAME 35495
#define IDS_AUTOFILL_CHROME_LOGO_ACCESSIBLE_NAME 35496
#define IDS_AUTOFILL_FIELD_LABEL_PHONE 35497
#define IDS_AUTOFILL_FIELD_LABEL_BILLING_ADDRESS 35498
#define IDS_AUTOFILL_SAVE_CARD_BUBBLE_LOCAL_SAVE_ACCEPT 35500
#define IDS_AUTOFILL_SAVE_CARD_BUBBLE_UPLOAD_SAVE_ACCEPT 35501
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CONTINUE 35503
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_LOCAL 35504
#define IDS_AUTOFILL_SAVE_CARD_ONLY_PROMPT_EXPLANATION_LOCAL 35506
#define IDS_AUTOFILL_SAVE_CARD_WITH_CVC_PROMPT_EXPLANATION_LOCAL 35507
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_TITLE_LOCAL 35508
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_EXPLANATION_LOCAL 35509
#define IDS_AUTOFILL_FIX_FLOW_PROMPT_SAVE_CARD_LABEL 35510
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_TO_CLOUD 35511
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_TO_CLOUD_V4 35513
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_TO_CLOUD_SECURITY 35514
#define IDS_AUTOFILL_SAVE_CARD_IN_GOOGLE_WALLET_PROMPT_TITLE 35515
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_TITLE_TO_CLOUD 35516
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARD_DESCRIPTION 35517
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARD_DESCRIPTION_WITH_NICKNAME 35518
#define IDS_AUTOFILL_CARD_SAVED 35522
#define IDS_AUTOFILL_CVC_SAVED 35523
#define IDS_AUTOFILL_DONE 35524
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION 35525
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_TO_WALLET_EXPLANATION 35527
#define IDS_AUTOFILL_SAVE_CVC_PROMPT_EXPLANATION_UPLOAD 35528
#define IDS_AUTOFILL_SAVE_CVC_TO_WALLET_PROMPT_EXPLANATION_UPLOAD 35529
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION_SECURITY 35530
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_TO_WALLET_EXPLANATION_SECURITY 35531
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_TO_WALLET_V2_EXPLANATION 35532
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARDHOLDER_NAME 35537
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_CARDHOLDER_NAME_TOOLTIP 35538
#define IDS_AUTOFILL_SAVE_CARD_CARDHOLDER_NAME_FIX_FLOW_HEADER 35539
#define IDS_AUTOFILL_SAVE_CARD_UPDATE_EXPIRATION_DATE_TITLE 35540
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION_TOOLTIP 35543
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_UPLOAD_EXPLANATION_AND_CARDHOLDER_NAME_TOOLTIP 35544
#define IDS_AUTOFILL_SAVE_CARD_PROMPT_LOADING_THROBBER_ACCESSIBLE_NAME 35545
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_LOADING_THROBBER_ACCESSIBLE_NAME 35546
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_TITLE 35547
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPLANATION_LOCAL 35548
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPLANATION_UPLOAD 35549
#define IDS_AUTOFILL_SAVE_AND_FILL_TO_WALLET_DIALOG_EXPLANATION_UPLOAD 35550
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_CARD_NUMBER_LABEL 35551
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_CVC_LABEL 35552
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_CVC_PLACEHOLDER 35553
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPIRATION_DATE_LABEL 35554
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_EXPIRATION_DATE_PLACEHOLDER 35555
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_NAME_ON_CARD_LABEL 35556
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_ACCEPT 35557
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_CARD_NUMBER 35558
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_CVC 35559
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_EXPIRATION_DATE 35560
#define IDS_AUTOFILL_SAVE_AND_FILL_DIALOG_INVALID_NAME_ON_CARD 35561
#define IDS_AUTOFILL_PENDING_DIALOG_LOADING_ACCESSIBILITY_DESCRIPTION 35562
#define IDS_AUTOFILL_MASKED_SERVER_CARD_RISK_BASED_UNMASKING_ERROR_TITLE 35563
#define IDS_AUTOFILL_VIRTUAL_CARD_TEMPORARY_ERROR_TITLE 35564
#define IDS_AUTOFILL_VIRTUAL_CARD_PERMANENT_ERROR_TITLE 35565
#define IDS_AUTOFILL_VIRTUAL_CARD_TEMPORARY_ERROR_DESCRIPTION 35566
#define IDS_AUTOFILL_VIRTUAL_CARD_PERMANENT_ERROR_DESCRIPTION 35567
#define IDS_AUTOFILL_VIRTUAL_CARD_NOT_ELIGIBLE_ERROR_TITLE 35568
#define IDS_AUTOFILL_VIRTUAL_CARD_NOT_ELIGIBLE_ERROR_DESCRIPTION 35569
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_TEMPORARY_ERROR_TITLE 35570
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_PERMANENT_ERROR_TITLE 35571
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_TEMPORARY_ERROR_DESCRIPTION 35572
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_PERMANENT_ERROR_DESCRIPTION 35573
#define IDS_AUTOFILL_ERROR_DIALOG_NEGATIVE_BUTTON_LABEL 35574
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_TRY_AGAIN_CVC 35575
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_TRY_AGAIN_SECURITY_CODE 35576
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_PERMANENT 35577
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_ERROR_NETWORK 35578
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_SECURITY_CODE_POSITION_BACK_OF_CARD 35579
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_SECURITY_CODE_POSITION_FRONT_OF_CARD 35580
#define IDS_AUTOFILL_CARD_UNMASK_CVC_IMAGE_DESCRIPTION 35581
#define IDS_AUTOFILL_CARD_UNMASK_CVC_IMAGE_DESCRIPTION_FOR_AMEX 35582
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_INSTRUCTIONS_DEFAULT 35583
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_INSTRUCTIONS_EXPIRED_CARD 35584
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_INSTRUCTIONS_VIRTUAL_CARD 35585
#define IDS_AUTOFILL_CARD_UNMASK_VERIFICATION_TITLE 35586
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_TITLE 35590
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_TITLE_SECURITY_CODE 35591
#define IDS_AUTOFILL_CARD_UNMASK_PROMPT_EXPIRED_TITLE 35592
#define IDS_AUTOFILL_CARD_UNMASK_CONFIRM_BUTTON 35607
#define IDS_AUTOFILL_CARD_UNMASK_VERIFY_BUTTON 35608
#define IDS_AUTOFILL_CARD_UNMASK_EXPIRATION_MONTH 35609
#define IDS_AUTOFILL_CARD_UNMASK_EXPIRATION_YEAR 35610
#define IDS_AUTOFILL_CARD_UNMASK_VERIFICATION_IN_PROGRESS 35611
#define IDS_AUTOFILL_CARD_UNMASK_VERIFICATION_SUCCESS 35612
#define IDS_AUTOFILL_CARD_UNMASK_INVALID_EXPIRATION_DATE 35613
#define IDS_AUTOFILL_EXPIRATION_DATE_SEPARATOR 35614
#define IDS_AUTOFILL_CARD_UNMASK_NEW_CARD_LINK 35615
#define IDS_AUTOFILL_DIALOG_PLACEHOLDER_CVC 35616
#define IDS_AUTOFILL_DIALOG_ACCESSIBLE_NAME_SECURITY_CODE 35617
#define IDS_AUTOFILL_CARD_UNMASK_PROGRESS_BAR_MESSAGE 35618
#define IDS_AUTOFILL_MASKED_SERVER_CARD_RISK_BASED_UNMASK_PROGRESS_BAR_MESSAGE 35619
#define IDS_AUTOFILL_CARD_UNMASK_PROGRESS_DIALOG_TITLE 35620
#define IDS_AUTOFILL_IBAN_UNMASK_PROGRESS_DIALOG_TITLE 35621
#define IDS_AUTOFILL_IBAN_UNMASK_PROGRESS_BAR_MESSAGE 35622
#define IDS_AUTOFILL_CARD_UNMASK_CONFIRMATION_DIALOG_TITLE 35623
#define IDS_AUTOFILL_CARD_UNMASK_CANCEL_BUTTON_LABEL 35624
#define IDS_AUTOFILL_CARD_UNMASK_CONFIRMATION_MESSAGE 35625
#define IDS_AUTOFILL_3DS_FETCH_VCN_PROGRESS_DIALOG_LOADING_MESSAGE 35627
#define IDS_AUTOFILL_3DS_FETCH_VCN_PROGRESS_DIALOG_CONFIRMATION_MESSAGE 35628
#define IDS_AUTOFILL_IBAN_UNMASK_ERROR_DIALOG_TITLE 35629
#define IDS_AUTOFILL_IBAN_UNMASK_ERROR_DIALOG_MESSAGE 35630
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_TITLE 35640
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_TITLE_ERROR 35641
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_INSTRUCTION 35642
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_OK_BUTTON_LABEL 35643
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_INSTRUCTION_ERROR 35644
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_CANCEL_BUTTON_LABEL 35645
#define IDS_AUTOFILL_WEBAUTHN_OPT_IN_DIALOG_CANCEL_BUTTON_LABEL_ERROR 35646
#define IDS_AUTOFILL_WEBAUTHN_VERIFY_PENDING_DIALOG_TITLE 35647
#define IDS_AUTOFILL_WEBAUTHN_VERIFY_PENDING_DIALOG_CANCEL_BUTTON_LABEL 35648
#define IDS_AUTOFILL_WALLET_MANAGEMENT_LINK_TEXT 35649
#define IDS_AUTOFILL_FROM_GOOGLE_ACCOUNT_LONG 35650
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_TITLE_LOCAL 35651
#define IDS_AUTOFILL_SAVE_IBAN_LABEL 35652
#define IDS_AUTOFILL_IBANS_TITLE 35653
#define IDS_AUTOFILL_SAVE_IBAN_BUBBLE_SAVE_ACCEPT 35654
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_NICKNAME 35655
#define IDS_AUTOFILL_SAVE_IBAN_PLACEHOLDER 35656
#define IDS_IBAN_NICKNAME_COUNT_BY 35657
#define IDS_AUTOFILL_IBAN_SAVED 35658
#define IDS_AUTOFILL_MANAGE_SAVED_PAYMENT_METHODS 35659
#define IDS_AUTOFILL_SAVE_IBAN_PROMPT_TITLE_SERVER 35660
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_PROMPT_TITLE 35661
#define IDS_AUTOFILL_UPLOAD_IBAN_PROMPT_EXPLANATION 35662
#define IDS_AUTOFILL_UPLOAD_IBAN_TO_WALLET_PROMPT_EXPLANATION 35663
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_TITLE 35669
#define IDS_AUTOFILL_MANDATORY_REAUTH_OPT_IN_EXPLANATION 35670
#define IDS_AUTOFILL_MANDATORY_REAUTH_ICON_TOOLTIP 35671
#define IDS_AUTOFILL_MANDATORY_REAUTH_CONFIRMATION_TITLE 35672
#define IDS_AUTOFILL_MANDATORY_REAUTH_CONFIRMATION_EXPLANATION 35673
#define IDS_AUTOFILL_MANDATORY_REAUTH_CONFIRMATION_SETTINGS_LINK 35674
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_TITLE 35678
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EDUCATIONAL_BODY_LABEL 35679
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_LEARN_MORE_LINK_LABEL 35680
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARD_NUMBER_LABEL 35681
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_ENROLLED_CARD_UNMASK_PROGRESS_DIALOG_TITLE 35682
#define IDS_AUTOFILL_VIRTUAL_CARD_ENTRY_PREFIX 35683
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_FALLBACK_ICON_TOOLTIP 35684
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_TITLE_VIRTUAL_CARD 35685
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EDUCATIONAL_BODY_LABEL_VIRTUAL_CARD 35686
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_LEARN_MORE_LINK_LABEL_VIRTUAL_CARD 35687
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARD_NUMBER_LABEL_VIRTUAL_CARD 35688
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EXP_DATE_LABEL_VIRTUAL_CARD 35689
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARDHOLDER_NAME_LABEL_VIRTUAL_CARD 35690
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CVC_LABEL_VIRTUAL_CARD 35691
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_VIRTUAL_CARD_LABEL 35692
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_ICON_TOOLTIP_VIRTUAL_CARD 35693
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_BUTTON_TOOLTIP_NORMAL_VIRTUAL_CARD 35694
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_BUTTON_TOOLTIP_CLICKED_VIRTUAL_CARD 35695
#define IDS_AUTOFILL_VIRTUAL_CARD_SUGGESTION_IPH_BUBBLE_LABEL 35696
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_ACCEPT_BUTTON_LABEL 35697
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_TITLE_LABEL 35698
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_TITLE_LABEL_V2 35699
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_CONTENT_LABEL 35700
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DIALOG_CONTENT_LABEL_V2 35701
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DECLINE_BUTTON_LABEL_SKIP 35702
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_DECLINE_BUTTON_LABEL_NO_THANKS 35703
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_LEARN_MORE_LINK_LABEL 35704
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLLMENT_CARD_IMAGE_TOOLTIP 35705
#define IDS_AUTOFILL_VIRTUAL_CARD_SUGGESTION_OPTION_VALUE 35706
#define IDS_AUTOFILL_IBAN_SUGGESTION_OPTION_VALUE 35707
#define IDS_AUTOFILL_VIRTUAL_CARD_NUMBER_SWITCH_LABEL 35708
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_LOADING_THROBBER_ACCESSIBLE_NAME 35709
#define IDS_AUTOFILL_VIRTUAL_CARD_STANDALONE_CVC_SUGGESTION_IPH_BUBBLE_LABEL 35721
#define IDS_AUTOFILL_VIRTUAL_CARD_STANDALONE_CVC_SUGGESTION_IPH_BUBBLE_LABEL_SCREENREADER 35722
#define IDS_AUTOFILL_VIRTUAL_CARD_STANDALONE_CVC_SUGGESTION_TITLE 35723
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CARD_NUMBER_LABEL_VIRTUAL_CARD_IOS 35724
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_EXP_DATE_LABEL_VIRTUAL_CARD_IOS 35725
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_NAME_ON_CARD_LABEL_VIRTUAL_CARD_IOS 35726
#define IDS_AUTOFILL_FILLED_CARD_INFORMATION_BUBBLE_CVC_LABEL_VIRTUAL_CARD_IOS 35727
#define IDS_AUTOFILL_VIRTUAL_CARD_DISABLED_SUGGESTION_OPTION_VALUE 35728
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_SUGGESTION_IPH_BUBBLE_LABEL 35729
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_SUGGESTION_IPH_BUBBLE_LABEL_SCREENREADER 35730
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_OR_ZIP_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP 35731
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_OR_ZIP_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 35732
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_ZIP_OR_KLARNA_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP 35733
#define IDS_AUTOFILL_CARD_BNPL_AFFIRM_ZIP_OR_KLARNA_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 35734
#define IDS_AUTOFILL_CARD_BNPL_SUGGESTION_WITH_GOOGLE_PAY_IPH_BUBBLE_LABEL_DESKTOP 35735
#define IDS_AUTOFILL_CARD_BNPL_SUGGESTION_WITH_GOOGLE_PAY_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 35736
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_AFFIRM_AND_AFTERPAY 35737
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_ZIP 35738
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_KLARNA 35739
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_AFFIRM_AND_AFTERPAY 35740
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_ZIP 35741
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_KLARNA 35742
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_CLEAR_FORM_TO_ENABLE 35743
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_NOT_AVAILABLE_RIGHT_NOW 35744
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_CURRENCY_NOT_SUPPORTED 35745
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_NOT_AVAILABLE_FOR_MERCHANT 35746
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_NOT_SUPPORTED_BY_MERCHANT 35747
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_LOW 35748
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_HIGH 35749
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_LOW 35750
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_PAYMENT_OPTION_CHECKOUT_AMOUNT_TOO_HIGH 35751
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_AI_FOOTNOTE 35752
#define IDS_AUTOFILL_CARD_BNPL_PAY_LATER_OPTIONS_AI_FOOTNOTE 35753
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_FOOTNOTE_FOR_AI_AMOUNT_EXTRACTION_NOTE 35754
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_FOOTNOTE_HIDE_OPTION 35755
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_FOOTNOTE_HIDE_OPTION_PAYMENT_SETTINGS_LINK_TEXT 35756
#define IDS_AUTOFILL_CARD_BNPL_SELECT_PROVIDER_TITLE 35757
#define IDS_AUTOFILL_BNPL_SELECT_PROVIDER_TITLE_DESCRIPTION 35758
#define IDS_AUTOFILL_CARD_BNPL_LINKED_ISSUER_PILL_LABEL 35759
#define IDS_AUTOFILL_PAY_NOW 35760
#define IDS_AUTOFILL_PAY_LATER 35761
#define IDS_AUTOFILL_PAY_NOW_PAY_LATER_TAB_ACCESSIBILITY_ANNOUNCEMENT 35762
#define IDS_AUTOFILL_A11Y_ANNOUNCEMENT_CONCATENATE_TWO_STRINGS 35763
#define IDS_AUTOFILL_CARD_INFO_RETRIEVAL_SUGGESTION_IPH_BUBBLE_FALLBACK_LABEL 35764
#define IDS_AUTOFILL_DISABLED_VIRTUAL_CARD_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP 35765
#define IDS_AUTOFILL_DISABLED_VIRTUAL_CARD_SUGGESTION_IPH_BUBBLE_LABEL_DESKTOP_SCREENREADER 35766
#define IDS_AUTOFILL_DOWNSTREAM_CARD_AWARENESS_IPH_BUBBLE_LABEL 35767
#define IDS_AUTOFILL_DOWNSTREAM_CARD_AWARENESS_IPH_BUBBLE_LABEL_SCREENREADER 35768
#define IDS_AUTOFILL_CARD_AUTH_SELECTION_DIALOG_TITLE_MULTIPLE_OPTIONS 35769
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_ISSUER_CONFIRMATION_TEXT 35770
#define IDS_AUTOFILL_AUTHENTICATION_MODE_SECURITY_CODE 35771
#define IDS_AUTOFILL_AUTHENTICATION_MODE_GET_TEXT_MESSAGE 35772
#define IDS_AUTOFILL_AUTHENTICATION_MODE_TEXT_MESSAGE 35773
#define IDS_AUTOFILL_AUTHENTICATION_MODE_GET_EMAIL 35774
#define IDS_AUTOFILL_AUTHENTICATION_MODE_THREE_DOMAIN_SECURE 35775
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_CURRENT_INFO_NOT_SEEN_TEXT 35776
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_OK_BUTTON_LABEL_CONTINUE 35777
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_OK_BUTTON_LABEL_SEND 35778
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_CVC_CHALLENGE_INFO 35779
#define IDS_AUTOFILL_CARD_UNMASK_AUTHENTICATION_SELECTION_DIALOG_THREE_DOMAIN_SECURE_CHALLENGE_INFO 35780
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_TITLE 35781
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_FOOTER_MESSAGE 35782
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_NEW_CODE_MESSAGE 35783
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_TEXTFIELD_PLACEHOLDER_MESSAGE 35784
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_PENDING_MESSAGE 35785
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_VERIFICATION_CODE_EXPIRED_LABEL 35786
#define IDS_AUTOFILL_CARD_UNMASK_OTP_INPUT_DIALOG_ENTER_CORRECT_CODE_LABEL 35787
#define IDS_AUTOFILL_LOADING_AND_CONSENT_DIALOG_TITLE_VCN_3DS 35788
#define IDS_AUTOFILL_PAYMENTS_WINDOW_USER_CONSENT_DIALOG_DESCRIPTION_VCN_3DS 35789
#define IDS_AUTOFILL_PAYMENTS_WINDOW_USER_CONSENT_DIALOG_OK_BUTTON_LABEL_VCN_3DS 35790
#define IDS_AUTOFILL_PAYMENTS_WINDOW_USER_CONSENT_DIALOG_ACCEPTANCE_ACCESSIBILITY_ANNOUNCEMENT 35791
#define IDS_AUTOFILL_REGULAR_CARD_MANUAL_FALLBACK_BUBBLE_CARD_NUMBER_LABEL_IOS 35792
#define IDS_AUTOFILL_BNPL_PAY_LATER_OPTIONS_TEXT 35793
#define IDS_AUTOFILL_BNPL_CREDIT_CARD_SUGGESTION_LABEL 35794
#define IDS_AUTOFILL_BNPL_CREDIT_CARD_SUGGESTION_LABEL_TWO_ISSUERS 35795
#define IDS_AUTOFILL_BNPL_CREDIT_CARD_SUGGESTION_LABEL_THREE_ISSUERS 35796
#define IDS_AUTOFILL_BNPL_SUGGESTION_LABEL_FOR_UNAVAILABLE_PURCHASE 35797
#define IDS_AUTOFILL_BNPL_SETTINGS_LABEL 35798
#define IDS_AUTOFILL_BNPL_SETTINGS_SUBLABEL 35799
#define IDS_AUTOFILL_BNPL_AFFIRM 35800
#define IDS_AUTOFILL_BNPL_ZIP 35801
#define IDS_AUTOFILL_BNPL_AFTER_PAY 35802
#define IDS_AUTOFILL_BNPL_KLARNA 35803
#define IDS_AUTOFILL_GOOGLE_PAY_AND_AFFIRM_LOGO_ACCESSIBLE_NAME 35804
#define IDS_AUTOFILL_GOOGLE_PAY_AND_ZIP_LOGO_ACCESSIBLE_NAME 35805
#define IDS_AUTOFILL_GOOGLE_PAY_AND_AFTERPAY_LOGO_ACCESSIBLE_NAME 35806
#define IDS_AUTOFILL_GOOGLE_PAY_AND_KLARNA_LOGO_ACCESSIBLE_NAME 35807
#define IDS_AUTOFILL_BNPL_FILLED_CARD_INFORMATION_BUBBLE_TITLE 35808
#define IDS_AUTOFILL_BNPL_FILLED_CARD_INFORMATION_BUBBLE_EDUCATIONAL_BODY_LABEL 35809
#define IDS_AUTOFILL_BNPL_FILLED_CARD_SNACKBAR_MESSAGE_TEXT 35810
#define IDS_AUTOFILL_BNPL_TOS_OK_BUTTON_LABEL 35811
#define IDS_AUTOFILL_BNPL_TOS_CANCEL_BUTTON_LABEL 35812
#define IDS_AUTOFILL_BNPL_TOS_TITLE_DESCRIPTION 35813
#define IDS_AUTOFILL_BNPL_TOS_UNLINKED_TITLE 35815
#define IDS_AUTOFILL_BNPL_TOS_LINKED_TITLE 35816
#define IDS_AUTOFILL_BNPL_TOS_REVIEW_TEXT 35817
#define IDS_AUTOFILL_BNPL_TOS_REVIEW_TEXT_WALLET_BRANDING 35818
#define IDS_AUTOFILL_BNPL_TOS_APPROVE_TEXT 35819
#define IDS_AUTOFILL_BNPL_TOS_LINK_TEXT 35820
#define IDS_AUTOFILL_BNPL_FETCH_VCN_PROGRESS_DIALOG_TITLE 35821
#define IDS_AUTOFILL_BNPL_PROGRESS_DIALOG_LOADING_MESSAGE 35822
#define IDS_AUTOFILL_BNPL_FETCH_VCN_PROGRESS_DIALOG_CONFIRMATION_MESSAGE 35823
#define IDS_AUTOFILL_BNPL_ERROR_DIALOG_TITLE 35824
#define IDS_AUTOFILL_BNPL_TEMPORARY_ERROR_DESCRIPTION 35825
#define IDS_AUTOFILL_BNPL_PERMANENT_ERROR_DESCRIPTION 35826
#define IDS_AUTOFILL_BNPL_ERROR_OK_BUTTON 35827
#define IDS_AUTOFILL_BNPL_UNSUPPORTED_CURRENCY_ERROR_DIALOG_TITLE 35829
#define IDS_AUTOFILL_BNPL_UNSUPPORTED_CURRENCY_ERROR_DESCRIPTION 35830
#define IDS_AUTOFILL_CREDIT_CARD_BENEFIT_TEXT_FOR_SUGGESTIONS 35831
#define IDS_AUTOFILL_CREDIT_CARD_BENEFIT_IPH_BUBBLE_LABEL 35832
#define IDS_AUTOFILL_CREDIT_CARD_BENEFIT_IPH_BUBBLE_LABEL_SCREENREADER 35833
#define IDS_AUTOFILL_SETTINGS_PAGE_CARD_BENEFITS_LABEL 35834
#define IDS_AUTOFILL_SETTINGS_PAGE_CARD_BENEFITS_TOGGLE_SUBLABEL_WITH_LEARN_LINK 35835
#define IDS_AUTOFILL_SETTINGS_PAGE_CARD_BENEFITS_TOGGLE_SUBLABEL_WITH_ISSUER_TERMS_APPLY_TEXT_AND_LEARN_LINK 35836
#define IDS_AUTOFILL_SETTINGS_PAGE_BENEFITS_TERMS_TAG_FOR_CREDIT_CARD_LIST_ENTRY 35837
#define IDS_AUTOFILL_SETTINGS_PAGE_BENEFITS_TERMS_ARIA_LABEL 35838
#define IDS_AUTOFILL_OFFERS_CASHBACK 35845
#define IDS_AUTOFILL_CARD_LINKED_OFFER_REMINDER_TITLE 35846
#define IDS_AUTOFILL_OFFERS_REMINDER_POSITIVE_BUTTON_LABEL 35847
#define IDS_AUTOFILL_PROMO_CODE_SUGGESTIONS_FOOTER_TEXT 35848
#define IDS_AUTOFILL_OFFERS_REMINDER_ICON_TOOLTIP_TEXT 35849
#define IDS_AUTOFILL_OFFERS_REMINDER_DESCRIPTION_TEXT 35850
#define IDS_AUTOFILL_PROMO_CODE_OFFERS_REMINDER_TITLE 35853
#define IDS_AUTOFILL_GPAY_PROMO_CODE_OFFERS_REMINDER_TITLE 35854
#define IDS_AUTOFILL_PROMO_CODE_OFFER_BUTTON_TOOLTIP_NORMAL 35855
#define IDS_AUTOFILL_PROMO_CODE_OFFER_BUTTON_TOOLTIP_CLICKED 35856
#define IDS_AUTOFILL_GPAY_PROMO_CODE_OFFERS_REMINDER_VALUE_PROP_TEXT 35857
#define IDS_AUTOFILL_PROMO_CODE_OFFERS_USE_THIS_CODE_TEXT 35858
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_CANT_FIND_CODE_MESSAGE 35859
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_OTP_INPUT_HINT 35860
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_POSITIVE_BUTTON_LABEL 35861
#define IDS_AUTOFILL_PAYMENTS_OTP_VERIFICATION_DIALOG_NEGATIVE_BUTTON_LABEL 35862
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_PAYMENT_METHOD_MANDATORY_REAUTH_LABEL 35918
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_PAYMENT_METHOD_MANDATORY_REAUTH_SUBLABEL 35919
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_LABEL 35922
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_ARIA_LABEL_FOR_NO_CVC_SAVED 35923
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_SUBLABEL 35924
#define IDS_AUTOFILL_SETTINGS_PAGE_ENABLE_CVC_STORAGE_WITH_DELETE_LINK_SUBLABEL 35925
#define IDS_AUTOFILL_SETTINGS_PAGE_BULK_REMOVE_CVC_TITLE 35926
#define IDS_AUTOFILL_SETTINGS_PAGE_BULK_REMOVE_CVC_DESCRIPTION 35927
#define IDS_AUTOFILL_SETTINGS_PAGE_BULK_REMOVE_CVC_FROM_WALLET_DESCRIPTION 35928
#define IDS_AUTOFILL_SETTINGS_PAGE_CVC_TAG_FOR_CREDIT_CARD_LIST_ENTRY 35929
#define IDS_AUTOFILL_CVC_SUGGESTION_MAIN_TEXT 35932
#define IDS_AUTOFILL_SETTINGS_PAGE_CVC_SAVED_LABEL 35933
#define IDS_AUTOFILL_SETTINGS_PAGE_SUMMARY_SEPARATED_BY_PIPE 35934
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_SUCCESS_TITLE_TEXT 35938
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_FAILURE_TITLE_TEXT 35939
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_SUCCESS_TITLE_TEXT 35940
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_FAILURE_TITLE_TEXT 35941
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_SUCCESS_TITLE_TEXT 35942
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_FAILURE_TITLE_TEXT 35943
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35944
#define IDS_AUTOFILL_SAVE_CARD_TO_WALLET_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35945
#define IDS_AUTOFILL_SAVE_CARD_TO_WALLET_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT_V2 35946
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35947
#define IDS_AUTOFILL_SAVE_CARD_TO_WALLET_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35948
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35949
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35950
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35951
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35952
#define IDS_AUTOFILL_SAVE_IBAN_CONFIRMATION_FAILURE_HIT_MAX_STRIKE_DESCRIPTION_TEXT 35953
#define IDS_AUTOFILL_SAVE_IBAN_TO_WALLET_CONFIRMATION_FAILURE_HIT_MAX_STRIKE_DESCRIPTION_TEXT 35954
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_SUCCESS_DESCRIPTION_TEXT 35955
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_FAILURE_DESCRIPTION_TEXT 35956
#define IDS_AUTOFILL_SAVE_CARD_AND_VIRTUAL_CARD_ENROLL_CONFIRMATION_BUTTON_TEXT 35957
#define IDS_AUTOFILL_SAVE_CARD_CONFIRMATION_FAILURE_OK_BUTTON_ACCESSIBLE_NAME 35958
#define IDS_AUTOFILL_VIRTUAL_CARD_ENROLL_CONFIRMATION_FAILURE_OK_BUTTON_ACCESSIBLE_NAME 35959
#define IDS_AUTOFILL_CLEAR_FORM_MENU_ITEM 35961
#define IDS_AUTOFILL_UNDO_MENU_ITEM 35962
#define IDS_AUTOFILL_WARNING_INSECURE_CONNECTION 35963
#define IDS_AUTOFILL_WARNING_MIXED_FORM 35964
#define IDS_AUTOFILL_DELETE_AUTOCOMPLETE_SUGGESTION_CONFIRMATION_BODY 35968
#define IDS_AUTOFILL_DELETE_CREDIT_CARD_SUGGESTION_CONFIRMATION_BODY 35969
#define IDS_AUTOFILL_DELETE_PROFILE_SUGGESTION_CONFIRMATION_BODY 35970
#define IDS_AUTOFILL_REMOVE_HOME_PROFILE_SUGGESTION_CONFIRMATION_TITLE 35971
#define IDS_AUTOFILL_REMOVE_HOME_PROFILE_SUGGESTION_CONFIRMATION_BODY 35972
#define IDS_AUTOFILL_REMOVE_WORK_PROFILE_SUGGESTION_CONFIRMATION_TITLE 35973
#define IDS_AUTOFILL_REMOVE_WORK_PROFILE_SUGGESTION_CONFIRMATION_BODY 35974
#define IDS_AUTOFILL_REMOVE_ACCOUNT_NAME_AND_EMAIL_PROFILE_SUGGESTION_CONFIRMATION_TITLE 35975
#define IDS_AUTOFILL_REMOVE_ACCOUNT_NAME_AND_EMAIL_PROFILE_SUGGESTION_CONFIRMATION_BODY 35976
#define IDS_AUTOFILL_REMOVE_SUGGESTION_BUTTON 35977
#define IDS_AUTOFILL_DELETE_SUGGESTION_BUTTON 35978
#define IDS_AUTOFILL_DELETE_AUTOCOMPLETE_SUGGESTION_TOOLTIP 35979
#define IDS_AUTOFILL_AUTOCOMPLETE_ENTRY_DELETED_A11Y_HINT 35980
#define IDS_AUTOFILL_DELETE_AUTOCOMPLETE_SUGGESTION_A11Y_HINT 35981
#define IDS_HOME_SUGGESTION_VOICE_OVER 35982
#define IDS_WORK_SUGGESTION_VOICE_OVER 35983
#define IDS_AUTOFILL_CC_AMEX 35984
#define IDS_AUTOFILL_CC_AMEX_SHORT 35985
#define IDS_AUTOFILL_CC_DINERS 35986
#define IDS_AUTOFILL_CC_DISCOVER 35987
#define IDS_AUTOFILL_CC_ELO 35988
#define IDS_AUTOFILL_CC_GOOGLE_PAY 35989
#define IDS_AUTOFILL_CC_JCB 35990
#define IDS_AUTOFILL_CC_MASTERCARD 35991
#define IDS_AUTOFILL_CC_MIR 35992
#define IDS_AUTOFILL_CC_TROY 35993
#define IDS_AUTOFILL_CC_UNION_PAY 35994
#define IDS_AUTOFILL_CC_VERVE 35995
#define IDS_AUTOFILL_CC_VISA 35996
#define IDS_AUTOFILL_CC_GENERIC 35997
#define IDS_AUTOFILL_IBAN_GENERIC 35998
#define IDS_AUTOFILL_LOYALTY_CARD_GENERIC 35999
#define IDS_AUTOFILL_LOYALTY_CARDS_SUBMENU_TITLE 36000
#define IDS_AUTOFILL_LOYALTY_CARDS_ALL_YOUR_CARDS_SUBMENU_TITLE 36001
#define IDS_AUTOFILL_ADDRESS_SUMMARY_SEPARATOR 36002
#define IDS_AUTOFILL_DEVELOPER_TOOLS 36003
#define IDS_AUTOFILL_TEST_ADDRESS_BY_COUNTRY 36004
#define IDS_AUTOFILL_TEST_ADDRESS_SELECTED_A11Y_HINT 36005
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILLED_FORM 36006
#define IDS_AUTOFILL_A11Y_ANNOUNCE_EXPANDABLE_ONLY_ENTRY 36007
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILLED_CARD_INFORMATION_ENTRY 36008
#define IDS_AUTOFILL_A11Y_ANNOUNCE_EDIT_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 36009
#define IDS_AUTOFILL_A11Y_ANNOUNCE_DELETE_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 36010
#define IDS_AUTOFILL_A11Y_ANNOUNCE_CLEARED_FORM 36011
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILL_ADDRESS_GROUP_POPUP_OPTION_SELECTED 36012
#define IDS_AUTOFILL_FILL_ADDRESS_GROUP_POPUP_OPTION_SELECTED 36013
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILL_NAME_GROUP_POPUP_OPTION_SELECTED 36014
#define IDS_AUTOFILL_FILL_NAME_GROUP_POPUP_OPTION_SELECTED 36015
#define IDS_AUTOFILL_A11Y_ANNOUNCE_FILL_EVERYTHING_FROM_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 36016
#define IDS_AUTOFILL_HIDE_SUGGESTIONS 36017
#define IDS_AUTOFILL_EDIT_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 36018
#define IDS_AUTOFILL_DELETE_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 36019
#define IDS_AUTOFILL_HOUSE_NUMBER_SUGGESTION_SECONDARY_TEXT_OPTION_SELECTED 36020
#define IDS_AUTOFILL_STREET_NAME_SUGGESTION_SECONDARY_TEXT_OPTION_SELECTED 36021
#define IDS_AUTOFILL_HOUSE_NUMBER_SUGGESTION_SECONDARY_TEXT 36022
#define IDS_AUTOFILL_STREET_NAME_SUGGESTION_SECONDARY_TEXT 36023
#define IDS_AUTOFILL_FILL_EVERYTHING_FROM_ADDRESS_PROFILE_POPUP_OPTION_SELECTED 36024
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_PROVIDED_MINOR_TEXT 36025
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_VERIFIED_MINOR_TEXT 36026
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_VERIFIED_EMAIL_LABEL 36027
#define IDS_AUTOFILL_IDENTITY_CREDENTIAL_LABEL_TEXT 36028
#define IDS_AUTOFILL_MANAGE_ADDRESSES 36029
#define IDS_AUTOFILL_MANAGE_PAYMENT_METHODS 36030
#define IDS_AUTOFILL_MANAGE_PASSWORDS 36031
#define IDS_AUTOFILL_MANAGE_LOYALTY_CARDS 36032
#define IDS_AUTOFILL_MANAGE_LOYALTY_CARDS_A11Y_HINT 36033
#define IDS_AUTOFILL_SCAN_CREDIT_CARD 36034
#define IDS_AUTOFILL_SHOW_ALL_SAVED_FALLBACK 36035
#define IDS_AUTOFILL_SAVE_AND_FILL_SUGGESTION_TITLE 36036
#define IDS_AUTOFILL_LOCAL_SAVE_AND_FILL_SUGGESTION_DESCRIPTION 36037
#define IDS_AUTOFILL_SERVER_SAVE_AND_FILL_SUGGESTION_DESCRIPTION 36038
#define IDS_AUTOFILL_POPUP_ACCESSIBLE_NODE_DATA 36039
#define IDS_AUTOFILL_IPH_EXTERNAL_ACCOUNT_PROFILE_SUGGESTION 36040
#define IDS_AUTOFILL_IPH_HOME_AND_WORK_ACCOUNT_PROFILE_SUGGESTION 36041
#define IDS_AUTOFILL_IPH_HOME_AND_WORK_ACCOUNT_PROFILE_SUGGESTION_SCREENREADER 36042
#define IDS_AUTOFILL_IPH_HOME_AND_WORK_ACCOUNT_PROFILE_SUGGESTION_TITLE 36043
#define IDS_AUTOFILL_IPH_ACCOUNT_NAME_EMAIL_SUGGESTION 36044
#define IDS_AUTOFILL_IPH_ACCOUNT_NAME_EMAIL_SUGGESTION_SCREENREADER 36045
#define IDS_AUTOFILL_IPH_ACCOUNT_NAME_EMAIL_SUGGESTION_TITLE 36046
#define IDS_AUTOFILL_SUGGESTION_LABEL_SEPARATOR 36047
#define IDS_AUTOFILL_CREDIT_CARD_EXPIRATION_DATE_ABBR 36048
#define IDS_AUTOFILL_CREDIT_CARD_EXPIRATION_DATE_ABBR_V2 36049
#define IDS_AUTOFILL_CREDIT_CARD_TWO_LINE_LABEL_FROM_NAME 36050
#define IDS_AUTOFILL_CREDIT_CARD_TWO_LINE_LABEL_FROM_CARD_NUMBER 36051
#define IDS_AUTOFILL_LOADING_REGIONS 36052
#define IDS_AUTOFILL_ADDRESSES 36053
#define IDS_AUTOFILL_ADDRESSES_TABLE_ARIA_LABEL 36054
#define IDS_AUTOFILL_ENABLE_PROFILES_TOGGLE_SUBLABEL 36055
#define IDS_AUTOFILL_LOCAL_PROFILE_ICON_ACCESSIBILITY_LABEL 36056
#define IDS_AUTOFILL_HOME_PROFILE_ICON_ACCESSIBILITY_LABEL 36057
#define IDS_AUTOFILL_WORK_PROFILE_ICON_ACCESSIBILITY_LABEL 36058
#define IDS_AUTOFILL_ENABLE_CREDIT_CARDS_TOGGLE_SUBLABEL 36059
#define IDS_AUTOFILL_DELETE_ACCOUNT_ADDRESS_RECORD_TYPE_NOTICE 36060
#define IDS_AUTOFILL_DELETE_SYNC_ADDRESS_RECORD_TYPE_NOTICE 36061
#define IDS_AUTOFILL_DELETE_LOCAL_ADDRESS_RECORD_TYPE_NOTICE 36062
#define IDS_AUTOFILL_SAVE_IN_ACCOUNT_MESSAGE_ADDRESS_RECORD_TYPE_NOTICE 36063
#define IDS_AUTOFILL_SAVE_IN_ACCOUNT_MESSAGE_ADDRESS_MIGRATION_RECORD_TYPE_NOTICE 36064
#define IDS_AUTOFILL_ADDRESS_ALREADY_SAVED_IN_ACCOUNT_RECORD_TYPE_NOTICE 36065
#define IDS_AUTOFILL_ADDRESS_WILL_BE_SAVED_IN_ACCOUNT_RECORD_TYPE_NOTICE 36066
#define IDS_AUTOFILL_ADDRESS_HOME_RECORD_TYPE_NOTICE 36067
#define IDS_AUTOFILL_ADDRESS_WORK_RECORD_TYPE_NOTICE 36068
#define IDS_AUTOFILL_ADDRESS_HOME_AND_WORK_RECORD_TYPE_NOTICE 36069
#define IDS_AUTOFILL_EDIT_ADDRESS_REQUIRED_FIELD_FORM_ERROR 36070
#define IDS_AUTOFILL_EDIT_ADDRESS_REQUIRED_FIELDS_FORM_ERROR 36071
#define IDS_AUTOFILL_LOCAL_ADDRESS_ICON_A11Y_LABEL 36072
#define IDS_AUTOFILL_HOME_ADDRESS_ICON_A11Y_LABEL 36073
#define IDS_AUTOFILL_WORK_ADDRESS_ICON_A11Y_LABEL 36074
#define IDS_AUTOFILL_HOME_WORK_ADDRESS_EDIT_A11Y_LABEL 36075
#define IDS_AUTOFILL_SYNC_TOGGLE_LABEL 36076
#define IDS_AUTOFILL_ADDRESSES_SETTINGS_TITLE 36077
#define IDS_AUTOFILL_ADDRESSES_SETTINGS_SUBLABEL 36078
#define IDS_AUTOFILL_PAYMENT_METHODS 36079
#define IDS_AUTOFILL_PAYMENT_METHODS_KEYWORDS 36080
#define IDS_AUTOFILL_PAYMENT_METHODS_TABLE_ARIA_LABEL 36081
#define IDS_AUTOFILL_ENABLE_PROFILES_TOGGLE_LABEL 36082
#define IDS_AUTOFILL_DISABLE_SETTINGS_EXPLANATION_TITLE 36083
#define IDS_AUTOFILL_DISABLE_SETTINGS_EXPLANATION 36084
#define IDS_AUTOFILL_DISABLE_SETTINGS_EXPLANATION_V2 36085
#define IDS_AUTOFILL_DISABLE_SETTINGS_BUTTON_LABEL 36086
#define IDS_AUTOFILL_ENABLE_CREDIT_CARDS_TOGGLE_LABEL 36087
#define IDS_AUTOFILL_DELETE_ADDRESS_CONFIRMATION_DIALOG_TITLE 36088
#define IDS_SYNC_DATATYPE_PAYMENTS_AND_INFO 36099
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_OK_BUTTON_LABEL 36108
#define IDS_AUTOFILL_SAVE_ADDRESS_WITH_MORE_INFO_ADDRESS_PROMPT_TITLE 36109
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_MIGRATION_OK_BUTTON_LABEL 36110
#define IDS_AUTOFILL_ACCOUNT_MIGRATE_ADDRESS_PROMPT_TITLE 36111
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_OK_BUTTON_LABEL 36112
#define IDS_AUTOFILL_ADD_NEW_INFO_ADDRESS_PROMPT_TITLE 36113
#define IDS_AUTOFILL_UPDATE_ADDRESS_ADD_NEW_INFO_PROMPT_OK_BUTTON_LABEL 36114
#define IDS_AUTOFILL_ADDRESS_MIGRATION_TO_ACCOUNT_PROMPT_OK_BUTTON_LABEL 36115
#define IDS_AUTOFILL_ADDRESS_MIGRATION_TO_ACCOUNT_PROMPT_CANCEL_BUTTON_LABEL 36116
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_NEW_VALUES_SECTION_LABEL 36117
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_OLD_VALUES_SECTION_LABEL 36118
#define IDS_AUTOFILL_MIGRATE_ADDRESS_PROMPT_CANCEL_BUTTON_LABEL 36119
#define IDS_AUTOFILL_SAVE_IN_ACCOUNT_PROMPT_ADDRESS_SOURCE_NOTICE 36120
#define IDS_AUTOFILL_UPDATE_PROMPT_ACCOUNT_ADDRESS_SOURCE_NOTICE 36121
#define IDS_AUTOFILL_SYNCABLE_PROFILE_MIGRATION_PROMPT_NOTICE 36122
#define IDS_AUTOFILL_LOCAL_PROFILE_MIGRATION_PROMPT_NOTICE 36123
#define IDS_AUTOFILL_SAVE_PROMPT_ADDRESS_SECTION_A11Y_LABEL 36124
#define IDS_AUTOFILL_SAVE_PROMPT_PHONE_SECTION_A11Y_LABEL 36125
#define IDS_AUTOFILL_SAVE_PROMPT_EMAIL_SECTION_A11Y_LABEL 36126
#define IDS_AUTOFILL_CONTACT_INFO_TITLE 36149
#define IDS_AUTOFILL_PAYMENTS_TITLE 36150
#define IDS_AUTOFILL_IDENTITY_DOCS_TITLE 36151
#define IDS_AUTOFILL_TRAVEL_TITLE 36152
#define IDS_AUTOFILL_TRAVEL_OPT_IN_TOGGLE_LABEL 36153
#define IDS_AUTOFILL_TRAVEL_OPT_IN_TOGGLE_SUB_LABEL 36154
#define IDS_AUTOFILL_IDENTITY_DOCS_OPT_IN_TOGGLE_LABEL 36155
#define IDS_AUTOFILL_IDENTITY_DOCS_OPT_IN_TOGGLE_SUB_LABEL 36156
#define IDS_AUTOFILL_SHOPPING_TITLE 36157
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_TITLE 36127
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_CANCEL_BUTTON_LABEL 36164
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_EDIT_BUTTON_TOOLTIP 36131
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_TITLE 36129
#define IDS_AUTOFILL_UPDATE_ADDRESS_ADD_NEW_INFO_PROMPT_CANCEL_BUTTON_LABEL 36165
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_PROMPT_TITLE 36166
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_EDITOR_TITLE 36167
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_INTO_CHROME_PROMPT_BODY_TEXT 36168
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_INTO_ACCOUNT_PROMPT_BODY_TEXT 36169
#define IDS_AUTOFILL_UPDATE_ADDRESS_PROMPT_CANCEL_BUTTON_LABEL 36170
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_NAME_EMAIL_HOME_WORK_MERGE_PROMPT_TITLE 36171
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_NAME_EMAIL_HOME_WORK_MERGE_OK_BUTTON_LABEL 36172
#define IDS_AUTOFILL_SAVE_ADDRESS_PROMPT_NAME_EMAIL_HOME_WORK_MERGE_CANCEL_BUTTON_LABEL 36173
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_TITLE 36132
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_OK_BUTTON_LABEL_SAVE 36174
#define IDS_AUTOFILL_MIGRATE_ADDRESS_DIALOG_OK_BUTTON_LABEL_SAVE 36175
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_OK_BUTTON_LABEL_UPDATE 36176
#define IDS_AUTOFILL_ADD_NEW_ADDRESS_DIALOG_OK_BUTTON_LABEL 36177
#define IDS_AUTOFILL_EDIT_ADDRESS_DIALOG_CANCEL_BUTTON_LABEL 36178
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_FILL_ADDRESS_A11Y_ADDON 36179
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_EXPAND_SHORTCUT 36180
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_EXPAND_SHORTCUT_RTL 36181
#define IDS_AUTOFILL_EXPANDABLE_SUGGESTION_SUBMENU_HINT 36182
#define IDS_AUTOFILL_SIGNIN_PROMO_TITLE_PASSWORD 36183
#define IDS_AUTOFILL_VERIFY_PROMO_SUBTITLE_PASSWORD 36184
#define IDS_AUTOFILL_POPUP_SEARCH_BAR_CLEAR_SEARCH_BUTTON_A11Y_NAME 36185
#define IDS_AUTOFILL_POPUP_SEARCH_BAR_PASSWORDS_INPUT_PLACEHOLDER 36186
#define IDS_AUTOFILL_AT_MEMORY_POPUP_SEARCH_BAR_PLACEHOLDER 36187
#define IDS_AUTOFILL_AT_MEMORY_POPUP_NO_RESULTS 36188
#define IDS_AUTOFILL_POPUP_SEARCH_BAR_PASSWORDS_NOT_FOUND 36189
#define IDS_AUTOFILL_SIGNIN_PROMO_TITLE_ADDRESS 36190
#define IDS_AUTOFILL_VERIFY_PROMO_SUBTITLE_ADDRESS 36191
#define IDS_AUTOFILL_IPH_LOYALTY_CARD_SUGGESTION_TITLE 36192
#define IDS_AUTOFILL_IPH_LOYALTY_CARD_SUGGESTION_BODY 36193
#define IDS_AUTOFILL_IPH_LOYALTY_CARD_SUGGESTION_SCREENREADER 36194
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_RECOVERY_SHOWN_A11Y_ANNOUNCEMENT 36195
#define IDS_AUTOFILL_SHOPPING_OPT_IN_TOGGLE_LABEL 36196
#define IDS_AUTOFILL_SHOPPING_OPT_IN_TOGGLE_SUB_LABEL 36197
#define IDS_AUTOFILL_AI_SAVE_OR_UPDATE_LOCAL_ENTITY_SOURCE_NOTICE 36198
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_ATTRIBUTION_TITLE 36199
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_ATTRIBUTION_DESCRIPTION 36200
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_GMAIL 36201
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_CALENDAR 36202
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_PHOTOS 36203
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_AMBIENT 36204
#define IDS_AUTOFILL_AT_MEMORY_SOURCE_LIVETABS 36205
#define IDS_AUTOFILL_AT_MEMORY_NO_DATA 36206
#define IDS_AUTOFILL_AT_MEMORY_UNSUPPORTED_QUERY_TITLE 36207
#define IDS_AUTOFILL_AT_MEMORY_UNSUPPORTED_QUERY_DESCRIPTION 36208
#define IDS_AUTOFILL_ADDRESS_EDIT_DIALOG_HISPANIC_MUNICIPIO 36209
#define IDS_AUTOFILL_ADDRESS_EDIT_DIALOG_FRENCH_LOCALITY_2 36210
#define IDS_AUTOFILL_ADDRESS_EDIT_DIALOG_JAPANESE_ALTERNATIVE_NAME 36211
#define IDS_SETTINGS_AUTOFILL_AI_ENTERPRISE_LOGGING_MANAGED_DISABLED 36214
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_ENTITY_NAME 36215
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_ENTITY_NAME 36216
#define IDS_AUTOFILL_AI_ID_CARD_ENTITY_NAME 36217
#define IDS_AUTOFILL_AI_PASSPORT_ENTITY_NAME 36218
#define IDS_AUTOFILL_AI_VEHICLE_ENTITY_NAME 36219
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_ENTITY_NAME 36220
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_ENTITY_NAME 36221
#define IDS_AUTOFILL_AI_FLIGHT_RESERVATION_ENTITY_NAME 36222
#define IDS_AUTOFILL_AI_ORDER_ENTITY_NAME 36223
#define IDS_AUTOFILL_AI_SHIPMENT_ENTITY_NAME 36224
#define IDS_AUTOFILL_AI_DRIVERS_LICENSES_TITLE 36225
#define IDS_AUTOFILL_AI_NATIONAL_IDS_TITLE 36226
#define IDS_AUTOFILL_AI_PASSPORTS_TITLE 36227
#define IDS_AUTOFILL_AI_VEHICLES_TITLE 36228
#define IDS_AUTOFILL_AI_TRAVEL_INFO_TITLE 36229
#define IDS_AUTOFILL_AI_FLIGHT_RESERVATIONS_TITLE 36230
#define IDS_AUTOFILL_AI_ORDERS_TITLE 36231
#define IDS_AUTOFILL_AI_SHIPMENTS_TITLE 36232
#define IDS_AUTOFILL_AI_ADD_DRIVERS_LICENSE_ENTITY 36233
#define IDS_AUTOFILL_AI_ADD_NATIONAL_ID_CARD_ENTITY 36234
#define IDS_AUTOFILL_AI_ADD_PASSPORT_ENTITY 36235
#define IDS_AUTOFILL_AI_ADD_VEHICLE_ENTITY 36236
#define IDS_AUTOFILL_AI_ADD_KNOWN_TRAVELER_NUMBER_ENTITY 36237
#define IDS_AUTOFILL_AI_ADD_REDRESS_NUMBER_ENTITY 36238
#define IDS_AUTOFILL_AI_EDIT_DRIVERS_LICENSE_ENTITY 36239
#define IDS_AUTOFILL_AI_EDIT_NATIONAL_ID_CARD_ENTITY 36240
#define IDS_AUTOFILL_AI_EDIT_PASSPORT_ENTITY 36241
#define IDS_AUTOFILL_AI_EDIT_VEHICLE_ENTITY 36242
#define IDS_AUTOFILL_AI_EDIT_KNOWN_TRAVELER_NUMBER_ENTITY 36243
#define IDS_AUTOFILL_AI_EDIT_REDRESS_NUMBER_ENTITY 36244
#define IDS_AUTOFILL_AI_DELETE_DRIVERS_LICENSE_ENTITY 36245
#define IDS_AUTOFILL_AI_DELETE_NATIONAL_ID_CARD_ENTITY 36246
#define IDS_AUTOFILL_AI_DELETE_PASSPORT_ENTITY 36247
#define IDS_AUTOFILL_AI_DELETE_VEHICLE_ENTITY 36248
#define IDS_AUTOFILL_AI_DELETE_KNOWN_TRAVELER_NUMBER_ENTITY 36249
#define IDS_AUTOFILL_AI_DELETE_REDRESS_NUMBER_ENTITY 36250
#define IDS_AUTOFILL_AI_ORDER_ID_ATTRIBUTE_NAME 36251
#define IDS_AUTOFILL_AI_ORDER_ACCOUNT_ATTRIBUTE_NAME 36252
#define IDS_AUTOFILL_AI_ORDER_DATE_ATTRIBUTE_NAME 36253
#define IDS_AUTOFILL_AI_ORDER_MERCHANT_NAME_ATTRIBUTE_NAME 36254
#define IDS_AUTOFILL_AI_ORDER_MERCHANT_DOMAIN_ATTRIBUTE_NAME 36255
#define IDS_AUTOFILL_AI_ORDER_PRODUCT_NAMES_ATTRIBUTE_NAME 36256
#define IDS_AUTOFILL_AI_SHIPMENT_TRACKING_NUMBER_ATTRIBUTE_NAME 36257
#define IDS_AUTOFILL_AI_SHIPMENT_DELIVERY_ZIP_CODE_ATTRIBUTE_NAME 36258
#define IDS_AUTOFILL_AI_SHIPMENT_CARRIER_NAME_ATTRIBUTE_NAME 36259
#define IDS_AUTOFILL_AI_SHIPMENT_CARRIER_DOMAIN_ATTRIBUTE_NAME 36260
#define IDS_AUTOFILL_AI_SHIPMENT_ESTIMATED_DELIVERY_DATE_ATTRIBUTE_NAME 36261
#define IDS_AUTOFILL_AI_SHIPMENT_ORDER_IDS_ATTRIBUTE_NAME 36262
#define IDS_AUTOFILL_AI_SHIPMENT_ORDER_DATES_ATTRIBUTE_NAME 36263
#define IDS_AUTOFILL_AI_SHIPMENT_MERCHANT_NAME_ATTRIBUTE_NAME 36264
#define IDS_AUTOFILL_AI_SHIPMENT_PRODUCT_NAMES_ATTRIBUTE_NAME 36265
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_NAME_ATTRIBUTE_NAME 36266
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_STATE_ATTRIBUTE_NAME 36267
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_NUMBER_ATTRIBUTE_NAME 36268
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_NUMBER_ATTRIBUTE_NAME_NEW 36269
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_EXPIRATION_DATE_ATTRIBUTE_NAME 36270
#define IDS_AUTOFILL_AI_DRIVERS_LICENSE_ISSUE_DATE_ATTRIBUTE_NAME 36271
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_NAME_ATTRIBUTE_NAME 36272
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_NUMBER_ATTRIBUTE_NAME 36273
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_COUNTRY_ATTRIBUTE_NAME 36274
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_COUNTRY_ATTRIBUTE_NAME_NEW 36275
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_EXPIRATION_DATE_ATTRIBUTE_NAME 36276
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_ISSUE_DATE_ATTRIBUTE_NAME 36277
#define IDS_AUTOFILL_AI_NATIONAL_ID_CARD_ISSUE_DATE_ATTRIBUTE_NAME_NEW 36278
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_NAME_ATTRIBUTE_NAME 36279
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_ATTRIBUTE_NAME 36280
#define IDS_AUTOFILL_AI_KNOWN_TRAVELER_NUMBER_EXPIRATION_DATE_ATTRIBUTE_NAME 36281
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_NAME_ATTRIBUTE_NAME 36282
#define IDS_AUTOFILL_AI_REDRESS_NUMBER_ATTRIBUTE_NAME 36283
#define IDS_AUTOFILL_AI_PASSPORT_NAME_ATTRIBUTE_NAME 36284
#define IDS_AUTOFILL_AI_PASSPORT_NUMBER_ATTRIBUTE_NAME 36285
#define IDS_AUTOFILL_AI_PASSPORT_COUNTRY_ATTRIBUTE_NAME 36286
#define IDS_AUTOFILL_AI_PASSPORT_EXPIRATION_DATE_ATTRIBUTE_NAME 36287
#define IDS_AUTOFILL_AI_PASSPORT_ISSUE_DATE_ATTRIBUTE_NAME 36288
#define IDS_AUTOFILL_AI_VEHICLE_MAKE_ATTRIBUTE_NAME 36289
#define IDS_AUTOFILL_AI_VEHICLE_MODEL_ATTRIBUTE_NAME 36290
#define IDS_AUTOFILL_AI_VEHICLE_YEAR_ATTRIBUTE_NAME 36291
#define IDS_AUTOFILL_AI_VEHICLE_OWNER_ATTRIBUTE_NAME 36292
#define IDS_AUTOFILL_AI_VEHICLE_PLATE_NUMBER_ATTRIBUTE_NAME 36293
#define IDS_AUTOFILL_AI_VEHICLE_PLATE_STATE_ATTRIBUTE_NAME 36294
#define IDS_AUTOFILL_AI_VEHICLE_VEHICLE_IDENTIFICATION_NUMBER_ATTRIBUTE_NAME 36295
#define IDS_AUTOFILL_AI_MANAGE_SUGGESTION_MAIN_TEXT 36296
#define IDS_AUTOFILL_AI_MANAGE_IDENTITY_DOCS_SUGGESTION_MAIN_TEXT 36297
#define IDS_AUTOFILL_AI_MANAGE_TRAVEL_SUGGESTION_MAIN_TEXT 36298
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_SAVE_DIALOG_NO_THANKS_BUTTON 36299
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_SAVE_DIALOG_SAVE_BUTTON 36300
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_UPDATE_DIALOG_UPDATE_BUTTON 36301
#define IDS_AUTOFILL_PREDICTION_IMPROVEMENTS_SAVE_DIALOG_FOOTER_DETAILS 36302
#define IDS_AUTOFILL_AI_OPT_IN_IPH_TITLE 36303
#define IDS_AUTOFILL_AI_OPT_IN_IPH_BODY 36304
#define IDS_AUTOFILL_AI_OPT_IN_IPH_TURN_ON 36305
#define IDS_AUTOFILL_AI_OPT_IN_IPH_MAYBE_LATER 36306
#define IDS_AUTOFILL_AI_VALUABLES_IPH_TITLE 36307
#define IDS_AUTOFILL_AI_VALUABLES_IPH_BODY 36308
#define IDS_AUTOFILL_AI_VALUABLES_IPH_SCREENREADER 36309
#define IDS_AUTOFILL_GOOGLE_WALLET_TITLE 36310
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_TO_WALLET_DIALOG_SUBTITLE 36311
#define IDS_AUTOFILL_AI_SAVE_ENTITY_TO_WALLET_DIALOG_SUBTITLE_NEW 36312
#define IDS_AUTOFILL_AI_SAVE_DRIVERS_LICENSE_ENTITY_DIALOG_TITLE 36313
#define IDS_AUTOFILL_AI_SAVE_NATIONAL_ID_CARD_ENTITY_DIALOG_TITLE 36314
#define IDS_AUTOFILL_AI_SAVE_ID_CARD_ENTITY_DIALOG_TITLE 36315
#define IDS_AUTOFILL_AI_SAVE_PASSPORT_ENTITY_DIALOG_TITLE 36316
#define IDS_AUTOFILL_AI_SAVE_VEHICLE_ENTITY_DIALOG_TITLE 36317
#define IDS_AUTOFILL_AI_SAVE_KNOWN_TRAVELER_NUMBER_ENTITY_DIALOG_TITLE 36318
#define IDS_AUTOFILL_AI_SAVE_REDRESS_NUMBER_ENTITY_DIALOG_TITLE 36319
#define IDS_AUTOFILL_AI_UPDATE_DRIVERS_LICENSE_ENTITY_DIALOG_TITLE 36320
#define IDS_AUTOFILL_AI_UPDATE_NATIONAL_ID_CARD_ENTITY_DIALOG_TITLE 36321
#define IDS_AUTOFILL_AI_UPDATE_ID_CARD_ENTITY_DIALOG_TITLE 36322
#define IDS_AUTOFILL_AI_UPDATE_PASSPORT_ENTITY_DIALOG_TITLE 36323
#define IDS_AUTOFILL_AI_UPDATE_VEHICLE_ENTITY_DIALOG_TITLE 36324
#define IDS_AUTOFILL_AI_UPDATE_KNOWN_TRAVELER_NUMBER_ENTITY_DIALOG_TITLE 36325
#define IDS_AUTOFILL_AI_UPDATE_REDRESS_NUMBER_ENTITY_DIALOG_TITLE 36326
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_SUBTITLE 36327
#define IDS_AUTOFILL_AI_SAVE_ENTITY_DIALOG_SUBTITLE 36328
#define IDS_AUTOFILL_AI_SAVE_ENTITY_TO_WALLET_DIALOG_SUBTITLE 36329
#define IDS_AUTOFILL_MANAGE_YOUR_INFO_LINK 36330
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_UPDATED_ATTRIBUTE_ACCESSIBLE_NAME 36331
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_NEW_ATTRIBUTE_ACCESSIBLE_NAME 36332
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_NEW_ATTRIBUTE_ACCESSIBLE_NAME_V2 36333
#define IDS_AUTOFILL_AI_UPDATE_ENTITY_DIALOG_UPDATED_ATTRIBUTE_ACCESSIBLE_NAME_V2 36334
#define IDS_AUTOFILL_AI_WALLET_UPLOAD_THROBBER_ACCESSIBLE_NAME 36335
#define IDS_AUTOFILL_AI_LOCAL_SAVE_NOTIFICATION_TITLE 36336
#define IDS_AUTOFILL_AI_LOCAL_SAVE_NOTIFICATION_DESCRIPTION 36337
#define IDS_AUTOFILL_AI_LOCAL_SAVE_NOTIFICATION_DISMISS_BUTTON_LABEL 36338
#define IDS_AUTOFILL_AI_WALLET_UPDATE_OR_MIGRATE_FAILURE_NOTIFICATION 36339
#define IDS_AUTOFILL_AI_WALLET_FETCH_FAILURE_NOTIFICATION 36340
#define IDS_AUTOFILL_AI_FFR_WHEN_ON_TITLE 36372
#define IDS_AUTOFILL_AI_FFR_WHEN_ON_DESCRIPTION 36373
#define IDS_AUTOFILL_AI_FFR_CONSIDER_DESCRIPTION 36374
#define IDS_AUTOFILL_AI_FFR_CONSIDER_LEARN_MORE 36375
#define IDS_SETTINGS_AUTOFILL_AI_AUTHENTICATION_TOGGLE_TITLE 36376
#define IDS_AT_MEMORY_PROMO_TITLE 36377
#define IDS_AT_MEMORY_PROMO_DESCRIPTION 36378
#define IDS_AT_MEMORY_PROMO_LEARN_MORE_BUTTON 36379
#define IDS_AT_MEMORY_PROMO_GOT_IT_BUTTON 36380
#define IDS_SETTINGS_AUTOFILL_AI_AUTHENTICATION_TOGGLE_SUBTITLE 36381
#define IDS_SETTINGS_AUTOFILL_AI_PAGE_TITLE 36382
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON 36383
#define IDS_SETTINGS_AUTOFILL_AI_THINGS_TO_CONSIDER 36384
#define IDS_SETTINGS_AUTOFILL_SERVICE_PROVIDER 36385
#define IDS_SETTINGS_AUTOFILL_AI_TO_CONSIDER_DATA_USAGE 36386
#define IDS_SETTINGS_AUTOFILL_AI_DESCRIPTION 36387
#define IDS_SETTINGS_AUTOFILL_AI_TOGGLE_SUB_LABEL 36388
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON_CAN_FILL_DIFFICULT_FIELDS 36389
#define IDS_AUTOFILL_WALLET_DATA_SHARING_PROMO_TITLE 36390
#define IDS_AUTOFILL_WALLET_DATA_SHARING_PROMO_SUBTITLE 36391
#define IDS_AUTOFILL_WALLET_DATA_SHARING_PROMO_BUTTON_LABEL 36392
#define IDS_BOOKMARK_BAR_FOLDER_NAME 36395
#define IDS_BOOKMARK_BAR_MOBILE_FOLDER_NAME 36396
#define IDS_BOOKMARK_BAR_OTHER_FOLDER_NAME 36397
#define IDS_BOOKMARK_BAR_MANAGED_FOLDER_DOMAIN_NAME 36398
#define IDS_BOOKMARK_BAR_MANAGED_FOLDER_DEFAULT_NAME 36399
#define IDS_BOOKMARK_EDITOR_TITLE 36400
#define IDS_BOOKMARK_MOVE_DIALOG_TITLE 36401
#define IDS_BOOKMARK_EDITOR_NEW_FOLDER_NAME 36402
#define IDS_BOOKMARK_BUBBLE_REMOVE_BOOKMARK 36403
#define IDS_BOOKMARK_MANAGER_NAME_INPUT_PLACE_HOLDER 36404
#define IDS_BOOKMARK_MANAGER_URL_INPUT_PLACE_HOLDER 36405
#define IDS_TOOLTIP_STAR 36406
#define IDS_CLEAR_BROWSING_DATA_CALCULATING 36407
#define IDS_DEL_BROWSING_HISTORY_COUNTER 36408
#define IDS_DEL_BROWSING_HISTORY_COUNTER_SYNCED 36409
#define IDS_DEL_NO_BROWSING_HISTORY_TEXT 36410
#define IDS_DEL_NO_BROWSING_HISTORY_SYNC_TEXT 36411
#define IDS_DEL_BROWSING_HISTORY_DOMAIN_COUNT_TEXT 36412
#define IDS_DEL_BROWSING_HISTORY_DOMAIN_COUNT_SYNC_TEXT 36413
#define IDS_DEL_BROWSING_HISTORY_COUNTER_MULTIPLE_DOMAINS_TEXT 36414
#define IDS_DEL_BROWSING_HISTORY_COUNTER_SINGLE_DOMAIN_TEXT 36415
#define IDS_DEL_BROWSING_HISTORY_COUNTER_SINGLE_DOMAIN_SYNC_TEXT 36416
#define IDS_DEL_CACHE_COUNTER_UPPER_ESTIMATE 36417
#define IDS_DEL_CACHE_COUNTER_ALMOST_EMPTY 36418
#define IDS_DEL_CACHE_COUNTER_BASIC 36419
#define IDS_DEL_CACHE_COUNTER_UPPER_ESTIMATE_BASIC 36420
#define IDS_DEL_CACHE_COUNTER_ALMOST_EMPTY_BASIC 36421
#define IDS_ANDROID_DEL_CACHE_COUNTER_ADVANCED 36422
#define IDS_ANDROID_DEL_CACHE_COUNTER_ADVANCED_UPPER_ESTIMATE 36423
#define IDS_ANDROID_DEL_CACHE_COUNTER_ADVANCED_ALMOST_EMPTY 36424
#define IDS_DEL_PASSWORDS_COUNTER 36425
#define IDS_DEL_PASSWORDS_COUNTER_SYNCED 36426
#define IDS_DEL_ACCOUNT_PASSWORDS_COUNTER 36427
#define IDS_DEL_PASSWORDS_DOMAINS_DISPLAY 36428
#define IDS_DEL_PASSWORDS_COUNTER_AND_X_MORE 36429
#define IDS_DEL_SIGNIN_DATA_COUNTER 36430
#define IDS_DEL_PASSWORDS_AND_SIGNIN_DATA_COUNTER_NONE 36431
#define IDS_DEL_PASSWORDS_AND_SIGNIN_DATA_COUNTER_COMBINATION 36432
#define IDS_DEL_SITE_SETTINGS_COUNTER 36433
#define IDS_DEL_AUTOFILL_COUNTER_EMPTY 36434
#define IDS_DEL_AUTOFILL_COUNTER_PAYMENT_METHODS 36435
#define IDS_DEL_AUTOFILL_COUNTER_ADDRESSES 36436
#define IDS_DEL_AUTOFILL_COUNTER_SUGGESTIONS 36437
#define IDS_DEL_AUTOFILL_COUNTER_USER_ANNOTATION_ENTRIES 36438
#define IDS_DEL_AUTOFILL_COUNTER_SUGGESTIONS_LONG 36439
#define IDS_DEL_AUTOFILL_COUNTER_SUGGESTIONS_SHORT 36440
#define IDS_DEL_AUTOFILL_COUNTER_ONE_TYPE_SYNCED 36441
#define IDS_DEL_AUTOFILL_COUNTER_TWO_TYPES 36442
#define IDS_DEL_AUTOFILL_COUNTER_TWO_TYPES_SYNCED 36443
#define IDS_DEL_AUTOFILL_COUNTER_THREE_TYPES 36444
#define IDS_DEL_AUTOFILL_COUNTER_THREE_TYPES_SYNCED 36445
#define IDS_DEL_AUTOFILL_SYNCABLE_NON_SYNCABLE_COMBINATION 36446
#define IDS_DEL_COOKIES_COUNTER 36447
#define IDS_DEL_COOKIES_COUNTER_ADVANCED 36448
#define IDS_DEL_COOKIES_COUNTER_ADVANCED_WITH_SIGNED_IN_EXCEPTION 36449
#define IDS_ANDROID_DEL_COOKIES_COUNTER_ADVANCED 36450
#define IDS_DEL_DOWNLOADS_COUNTER 36451
#define IDS_DEL_HOSTED_APPS_COUNTER 36452
#define IDS_DEL_HOSTED_APPS_COUNTER_AND_X_MORE 36453
#define IDS_DEL_TABS_COUNTER 36454
#define IDS_TABS_COUNT 36455
#define IDS_WINDOWS_COUNT 36456
#define IDS_DEL_TABS_MULTIWINDOW_COUNTER 36457
#define IDS_DEL_GOOGLE_COOKIES_SIGNOUT_LINK 36458
#define IDS_SETTINGS_MANAGE_IN_GOOGLE_PASSWORD_MANAGER 36459
#define IDS_SETTINGS_MANAGE_IN_YOUR_GOOGLE_ACCOUNT 36460
#define IDS_SETTINGS_MANAGE_OTHER_DATA_LABEL 36461
#define IDS_SETTINGS_MANAGE_OTHER_GOOGLE_DATA_LABEL 36462
#define IDS_SETTINGS_MY_ACTIVITY 36463
#define IDS_SETTINGS_OTHER_DATA_TITLE 36464
#define IDS_SETTINGS_OTHER_GOOGLE_DATA_TITLE 36465
#define IDS_SETTINGS_PASSWORDS_AND_PASSKEYS 36466
#define IDS_SETTINGS_MANAGE_PASSWORDS_SUB_LABEL 36467
#define IDS_SETTINGS_SEARCH_HISTORY 36468
#define IDS_SETTINGS_MANAGE_OTHER_DATA_SUB_LABEL 36469
#define IDS_SETTINGS_OTHER_DATA_DESCRIPTION 36470
#define IDS_SETTINGS_CLEAR_NON_GOOGLE_SEARCH_HISTORY_NON_PREPOPULATED_DSE 36471
#define IDS_SETTINGS_CLEAR_NON_GOOGLE_SEARCH_HISTORY_PREPOPULATED_DSE 36472
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_TITLE 36473
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_CONTENT 36474
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_NO_THANKS 36475
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_GET_DISCOUNTS 36476
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_ACCEPTED_CONFIRMATION_TITLE 36477
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_ACCEPTED_CONFIRMATION_CONTENT 36478
#define IDS_DISCOUNT_CONTEXTUAL_CONSENT_ACCEPTED_CONFIRMATION_DONE 36479
#define IDS_NATIVE_NTP_CART_DISCOUNT_CONSENT_ACCEPT_BUTTON 36480
#define IDS_NATIVE_NTP_CART_DISCOUNT_CONSENT_TITLE 36481
#define IDS_NATIVE_NTP_CART_DISCOUNT_CONSENT_BODY 36482
#define IDS_NTP_CART_DISCOUNT_STEP_ONE_CONTENT 36483
#define IDS_OMNIBOX_TRACK_PRICE 36484
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_TITLE 36485
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_DESCRIPTION 36486
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_EMAIL_DESCRIPTION 36487
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_ACTION_BUTTON 36488
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_ERROR_DESCRIPTION 36489
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_ERROR_BUTTON 36490
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_TITLE_FIRST_RUN 36491
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_DESCRIPTION_FIRST_RUN 36492
#define IDS_OMNIBOX_TRACK_PRICE_DIALOG_CANCEL_BUTTON 36493
#define IDS_PRICE_TRACKING_SAVE_DESCRIPTION 36494
#define IDS_PRICE_TRACKING_SAVE_LOCATION 36495
#define IDS_PRICE_TRACKING_EMAIL_CONSENT_BODY 36496
#define IDS_PRICE_TRACKING_EMAIL_CONSENT_TITLE 36497
#define IDS_PRICE_TRACKING_EMAIL_CONSENT_LEARN_MORE_LINK_TEXT 36498
#define IDS_PRICE_TRACKING_NOT_NOW 36499
#define IDS_PRICE_TRACKING_YES_IM_IN 36500
#define IDS_OMNIBOX_TRACKING_PRICE 36501
#define IDS_OMNIBOX_TRACKING_PRICE_DIALOG_TITLE 36502
#define IDS_OMNIBOX_TRACKING_PRICE_DIALOG_ACTION_BUTTON 36503
#define IDS_OMNIBOX_TRACKING_PRICE_DIALOG_UNTRACK_BUTTON 36504
#define IDS_OMNIBOX_PRICE_TRACKING_OFF_DIALOG_TITLE 36505
#define IDS_OMNIBOX_PRICE_TRACKING_OFF_DIALOG_DESCRIPTION 36506
#define IDS_OMNIBOX_PRICE_TRACKING_OFF_DIALOG_DESCRIPTION_BOOKMARK_REMOVED 36507
#define IDS_OMNIBOX_PRICE_TRACKING_OFF_DIALOG_ACTION_BUTTON 36508
#define IDS_BOOKMARK_STAR_DIALOG_TRACK_PRICE_DESCRIPTION 36509
#define IDS_BOOKMARK_STAR_DIALOG_TRACK_PRICE_DESCRIPTION_EMAIL_OFF 36510
#define IDS_BOOKMARKS_MANAGER_TRACKED_PRODUCTS 36511
#define IDS_BOOKMARKS_MANAGER_UNTRACK_BUTTON 36512
#define IDS_PRICE_TRACKING_SIDE_PANEL_IPH 36513
#define IDS_SIDE_PANEL_TRACKED_PRODUCTS 36514
#define IDS_PRICE_TRACKING_CHIP_IPH 36515
#define IDS_SIDE_PANEL_UNTRACK_BUTTON 36516
#define IDS_SIDE_PANEL_TRACK_BUTTON 36517
#define IDS_BOOKMARKS_MENU_UNTRACK_PRICE 36518
#define IDS_BOOKMARKS_MENU_TRACK_PRICE 36519
#define IDS_PRICE_TRACKING_UNTRACK_PRODUCT_ACCESSIBILITY 36520
#define IDS_PRICE_TRACKING_TRACK_PRODUCT_ACCESSIBILITY 36521
#define IDS_PRICE_TRACKING_SIDE_PANEL_ERROR_BUTTON 36522
#define IDS_PRICE_TRACKING_SETTINGS_TITLE 36523
#define IDS_PRICE_TRACKING_SETTINGS_EMAIL_DESCRIPTION 36524
#define IDS_PRICE_TRACKING_SETTINGS_POPUP_DESCRIPTION 36525
#define IDS_PRICE_TRACKING_SIDE_PANEL_ERROR_MESSAGE 36526
#define IDS_SHOPPING_COLLECTION_IPH_TITLE 36527
#define IDS_SHOPPING_COLLECTION_IPH_BODY 36528
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TITLE 36529
#define IDS_PRICE_HISTORY_TITLE 36530
#define IDS_PRICE_HISTORY_TITLE_MULTIPLE_OPTIONS 36531
#define IDS_PRICE_HISTORY_MULTIPLE_OPTIONS_LOW_PRICE 36532
#define IDS_PRICE_HISTORY_MULTIPLE_OPTIONS_HIGH_PRICE 36533
#define IDS_PRICE_HISTORY_MULTIPLE_OPTIONS_TYPICAL_PRICE 36534
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TRACK_PRICE_TITLE 36535
#define IDS_SHOPPING_INSIGHTS_ICON_TOOLTIP_TEXT 36536
#define IDS_SHOPPING_INSIGHTS_BUYING_OPTIONS 36537
#define IDS_PRICE_HISTORY_TODAY_PRICE 36538
#define IDS_PRICE_HISTORY_YESTERDAY_PRICE 36539
#define IDS_PRICE_HISTORY_DESCRIPTION 36540
#define IDS_PRICE_HISTORY_GRAPH_ACCESSIBILITY 36541
#define IDS_SHOPPING_INSIGHTS_COLLECT_FEEDBACK 36542
#define IDS_SHOPPING_INSIGHTS_FEEDBACK_FORM_TITLE 36543
#define IDS_PRICE_HISTORY_SINGLE_OPTION_LOW_PRICE 36544
#define IDS_PRICE_HISTORY_SINGLE_OPTION_HIGH_PRICE 36545
#define IDS_PRICE_HISTORY_SINGLE_OPTION_TYPICAL_PRICE 36546
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TRACK_PRICE_DESCRIPTION 36547
#define IDS_SHOPPING_INSIGHTS_SIDE_PANEL_TRACK_PRICE_ERROR 36548
#define IDS_DISCOUNT_USE_THIS_CODE_AT_CHECKOUT_WITH_EXPIRATION_DATE 36549
#define IDS_DISCOUNT_USE_THIS_CODE_AT_CHECKOUT 36550
#define IDS_DISCOUNT_EXPIRATION_DATE 36551
#define IDS_TWO_STRINGS_CONNECTOR 36552
#define IDS_TWO_STRINGS_CONNECTOR_WITH_SPACE 36553
#define IDS_SELLER_TERMS_AND_CONDITIONS_DIALOG_TITLE 36554
#define IDS_SELLER_TERMS_AND_CONDITIONS_DIALOG_FOOTER 36555
#define IDS_SEE_SELLER_TERMS_AND_CONDITIONS 36556
#define IDS_DISCOUNTS_COUPON_CODE_BUTTON_TOOLTIP 36557
#define IDS_DISCOUNTS_COUPON_CODE_BUTTON_TOOLTIP_CLICKED 36558
#define IDS_PRICE_DROP_POPUP_CONTENT_TITLE 36571
#define IDS_PRICE_DROP_POPUP_CONTENT_TEXT 36572
#define IDS_PRICE_DROP_POPUP_ACTION_BUTTON 36573
#define IDS_PRICE_DROP_POPUP_UNTRACK_BUTTON 36574
#define IDS_PRICE_RANGE_ALL_OPTIONS 36575
#define IDS_PRICE_RANGE_ALL_OPTIONS_ONE_TYPICAL_PRICE 36576
#define IDS_PRICE_RANGE_SINGLE_OPTION 36577
#define IDS_PRICE_RANGE_SINGLE_OPTION_ONE_TYPICAL_PRICE 36578
#define IDS_PRICE_TRACKING_DESCRIPTION 36579
#define IDS_PRICE_INSIGHTS_BUYING_OPTIONS_TITLE 36580
#define IDS_PRICE_INSIGHTS_BUYING_OPTIONS_SUBTITLE 36581
#define IDS_PRICE_INSIGHTS_TRACK_BUTTON_TITLE 36582
#define IDS_PRICE_INSIGHTS_TRACKING_BUTTON_TITLE 36583
#define IDS_INSIGHTS_ICON_EXPANDED_TEXT_GOOD_DEAL 36584
#define IDS_INSIGHTS_RICH_IPH_TEXT 36585
#define IDS_PRICE_INSIGHTS_ACCESSIBILITY 36586
#define IDS_PRICE_INSIGHTS_GRAPH_ACCESSIBILITY_LABEL 36587
#define IDS_PRICE_INSIGHTS_SNACKBAR_BUTTON_TITLE 36588
#define IDS_PRICE_INSIGHTS_SNACKBAR_MESSAGE_TITLE_NOTIFICATION_DISABLED 36589
#define IDS_PRICE_INSIGHTS_SNACKBAR_MESSAGE_TITLE_NOTIFICATION_ENABLED 36590
#define IDS_PRICE_RANGE_ACCESSIBILITY_DESCRIPTION 36591
#define IDS_BUYING_OPTIONS_ACCESSIBILITY_DESCRIPTION 36592
#define IDS_PRICE_TRACKING_DESCRIPTION_TRACKED 36593
#define IDS_PRICE_HISTORY_TITLE_WITH_VARIANTS 36594
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_TITLE 36595
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_MESSAGE 36596
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_CLOSE 36597
#define IDS_IOS_PRICE_INSIGHTS_PRICE_TRACK_PERMISSION_REDIRECT_ALERT_REDIRECT 36598
#define IDS_PRICE_INSIGHTS_UNTRACK_SNACKBAR_MESSAGE 36599
#define IDS_PRICE_INSIGHTS_UNTRACK_SNACKBAR_BUTTON_TITLE 36600
#define IDS_PRICE_HISTORY_TITLE_SINGLE_OPTION 36601
#define IDS_SHOPPING_INSIGHTS_ICON_EXPANDED_TEXT_LOW_PRICE 36602
#define IDS_SHOPPING_INSIGHTS_ICON_EXPANDED_TEXT_HIGH_PRICE 36603
#define IDS_SHOPPING_COLLECTION_FOLDER_NAME 36604
#define IDS_DISCOUNT_CODE_COPY_BUTTON_TEXT 36605
#define IDS_DISCOUNT_ICON_EXPANDED_TEXT 36606
#define IDS_SETTINGS_TITLE 36615
#define IDS_SETTINGS_HIDE_ADVANCED_SETTINGS 36616
#define IDS_SETTINGS_SHOW_ADVANCED_SETTINGS 36617
#define IDS_NETWORK_PREDICTION_ENABLED_DESCRIPTION 36618
#define IDS_SYSTEM_TITLE 36619
#define IDS_OPTIONS_PROXIES_CONFIGURE_BUTTON 36620
#define IDS_COMPOSE_SUGGESTION_MAIN_TEXT 36621
#define IDS_COMPOSE_CONTEXT_MENU_TEXT 36622
#define IDS_COMPOSE_SUGGESTION_LABEL 36623
#define IDS_COMPOSE_SUGGESTION_SAVED_TEXT 36624
#define IDS_COMPOSE_SUGGESTION_SAVED_LABEL 36625
#define IDS_COMPOSE_SUGGESTION_AX_MESSAGE_ON_SHOW_PROACTIVE 36626
#define IDS_COMPOSE_SUGGESTION_AX_MESSAGE_ON_SHOW_RESUME 36627
#define IDS_COMPOSE_DONT_SHOW_ON_THIS_SITE_CHILD_SUGGESTION_TEXT 36628
#define IDS_COMPOSE_DISABLE_HELP_ME_WRITE_CHILD_SUGGESTION_TEXT 36629
#define IDS_COMPOSE_GO_TO_SETTINGS_CHILD_SUGGESTION_TEXT 36630
#define IDS_COMPOSE_FRE_TITLE 36631
#define IDS_COMPOSE_FRE_MAIN_TOP 36632
#define IDS_COMPOSE_FRE_MAIN_MID 36633
#define IDS_COMPOSE_FRE_MAIN_MID_ENTERPRISE 36634
#define IDS_COMPOSE_FRE_OK_BUTTON 36635
#define IDS_COMPOSE_FRE_MSBB_TITLE 36636
#define IDS_COMPOSE_FRE_MSBB_MAIN 36637
#define IDS_COMPOSE_FRE_MSBB_SETTINGS_BUTTON 36638
#define IDS_COMPOSE_MSBB_IPH_BUBBLE_TEXT 36639
#define IDS_COMPOSE_MSBB_IPH_BUBBLE_TEXT_SCREENREADER 36640
#define IDS_COMPOSE_MSBB_IPH_BUBBLE_CLOSE_BUTTON_LABEL_TEXT 36641
#define IDS_COMPOSE_DIALOG_TITLE 36642
#define IDS_COMPOSE_INPUT_PLACEHOLDER_TITLE 36643
#define IDS_COMPOSE_INPUT_PLACEHOLDER_LINE_1 36644
#define IDS_COMPOSE_INPUT_PLACEHOLDER_LINE_2 36645
#define IDS_COMPOSE_INPUT_PLACEHOLDER_LINE_3 36646
#define IDS_COMPOSE_INPUT_FOOTER 36647
#define IDS_COMPOSE_INPUT_FOOTER_ENTERPRISE 36648
#define IDS_COMPOSE_INPUT_MODE_POLISH 36649
#define IDS_COMPOSE_INPUT_MODE_ELABORATE 36650
#define IDS_COMPOSE_INPUT_MODE_FORMALIZE 36651
#define IDS_COMPOSE_SUBMIT_BUTTON 36652
#define IDS_COMPOSE_EDIT_UPDATE_BUTTON 36653
#define IDS_COMPOSE_EDIT 36654
#define IDS_COMPOSE_MODIFIERS_MENU_TITLE 36655
#define IDS_COMPOSE_MODIFIERS_MENU_LABEL 36656
#define IDS_COMPOSE_MENU_RETRY_OPTION 36657
#define IDS_COMPOSE_MENU_LENGTH_TITLE 36658
#define IDS_COMPOSE_MENU_SHORTER_OPTION 36659
#define IDS_COMPOSE_MENU_LONGER_OPTION 36660
#define IDS_COMPOSE_MENU_TONE_TITLE 36661
#define IDS_COMPOSE_MENU_CASUAL_OPTION 36662
#define IDS_COMPOSE_MENU_FORMAL_OPTION 36663
#define IDS_COMPOSE_UNDO_BUTTON_TEXT 36664
#define IDS_COMPOSE_UNDO_LABEL 36665
#define IDS_COMPOSE_REDO_BUTTON_TEXT 36666
#define IDS_COMPOSE_REDO_LABEL 36667
#define IDS_COMPOSE_RESUBMIT 36668
#define IDS_COMPOSE_INSERT_BUTTON 36669
#define IDS_COMPOSE_REPLACE_BUTTON 36670
#define IDS_COMPOSE_THUMBS_DOWN 36671
#define IDS_COMPOSE_THUMBS_UP 36672
#define IDS_COMPOSE_RESULT_TEXT_LABEL 36673
#define IDS_COMPOSE_RESULT_LOADING_A11Y_MESSAGE 36674
#define IDS_COMPOSE_RESULT_UPDATED_A11Y_MESSAGE 36675
#define IDS_COMPOSE_UNDO_RESULT_A11Y_MESSAGE 36676
#define IDS_COMPOSE_REDO_RESULT_A11Y_MESSAGE 36677
#define IDS_COMPOSE_ERROR_TOO_SHORT 36678
#define IDS_COMPOSE_ERROR_TOO_LONG 36679
#define IDS_COMPOSE_ERROR_TRY_AGAIN 36680
#define IDS_COMPOSE_ERROR_TRY_AGAIN_LATER 36681
#define IDS_COMPOSE_ERROR_FILTERED 36682
#define IDS_COMPOSE_ERROR_FILTERED_BACK_BUTTON 36683
#define IDS_COMPOSE_ERROR_UNSUPPORTED_LANGUAGE 36684
#define IDS_COMPOSE_ERROR_PERMISSION_DENIED 36685
#define IDS_COMPOSE_ERROR_REQUEST_THROTTLED 36686
#define IDS_COMPOSE_ERROR_OFFLINE 36687
#define IDS_COMPOSE_FOOTER_FISHFOOD 36688
#define IDS_COMPOSE_EXPERIMENTAL_DISCLAIMER_FOOTER 36689
#define IDS_COMPOSE_REFINEMENTS_EXPERIMENTAL_DISCLAIMER_FOOTER 36690
#define IDS_COMPOSE_FOOTER_FISHFOOD_ON_DEVICE_USED 36691
#define IDS_COMPOSE_FEEDBACK_PLACEHOLDER 36692
#define IDS_CRASH_TITLE 36693
#define IDS_CRASH_CRASH_COUNT_BANNER_FORMAT 36694
#define IDS_CRASH_SHOW_DEVELOPER_DETAILS 36695
#define IDS_CRASH_CAPTURE_TIME_FORMAT 36696
#define IDS_CRASH_REPORT_STATUS 36697
#define IDS_CRASH_REPORT_STATUS_NOT_UPLOADED 36698
#define IDS_CRASH_REPORT_STATUS_PENDING 36699
#define IDS_CRASH_REPORT_STATUS_PENDING_USER_REQUESTED 36700
#define IDS_CRASH_REPORT_STATUS_UPLOADED 36701
#define IDS_CRASH_REPORT_UPLOADED_ID 36702
#define IDS_CRASH_REPORT_UPLOADED_TIME 36703
#define IDS_CRASH_REPORT_LOCAL_ID 36704
#define IDS_CRASH_REPORT_FILE_SIZE 36705
#define IDS_CRASH_BUG_LINK_LABEL 36706
#define IDS_CRASH_NO_CRASHES_MESSAGE 36707
#define IDS_CRASH_DISABLED_HEADER 36708
#define IDS_CRASH_UPLOAD_MESSAGE 36709
#define IDS_CRASH_UPLOAD_NOW_LINK_TEXT 36710
#define IDS_HTTP_POST_WARNING_TITLE 36711
#define IDS_HTTP_POST_WARNING 36712
#define IDS_HTTP_POST_WARNING_RESEND 36713
#define IDS_DOM_DISTILLER_JAVASCRIPT_DISABLED_CONTENT 36714
#define IDS_DOM_DISTILLER_WEBUI_ENTRY_URL 36715
#define IDS_DOM_DISTILLER_WEBUI_ENTRY_ADD 36716
#define IDS_DOM_DISTILLER_WEBUI_ENTRY_ADD_FAILED 36717
#define IDS_DOM_DISTILLER_WEBUI_VIEW_URL 36718
#define IDS_DOM_DISTILLER_WEBUI_VIEW_URL_FAILED 36719
#define IDS_DOM_DISTILLER_WEBUI_REFRESH 36720
#define IDS_DOM_DISTILLER_WEBUI_FETCHING_ENTRIES 36721
#define IDS_DOM_DISTILLER_VIEWER_FAILED_TO_FIND_ARTICLE_TITLE 36722
#define IDS_DOM_DISTILLER_VIEWER_FAILED_TO_FIND_ARTICLE_CONTENT 36723
#define IDS_DOM_DISTILLER_VIEWER_LOADING_TITLE 36724
#define IDS_DOM_DISTILLER_VIEWER_CUSTOMIZE_APPEARANCE 36725
#define IDS_DOM_DISTILLER_VIEWER_FONT_STYLE 36726
#define IDS_DOM_DISTILLER_VIEWER_SANS_SERIF_FONT 36727
#define IDS_DOM_DISTILLER_VIEWER_SERIF_FONT 36728
#define IDS_DOM_DISTILLER_VIEWER_MONOSPACE_FONT 36729
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR 36730
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR_LIGHT 36731
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR_SEPIA 36732
#define IDS_DOM_DISTILLER_VIEWER_PAGE_COLOR_DARK 36733
#define IDS_DOM_DISTILLER_VIEWER_FONT_SIZE 36734
#define IDS_DOM_DISTILLER_VIEWER_FONT_SIZE_SMALL 36735
#define IDS_DOM_DISTILLER_VIEWER_FONT_SIZE_LARGE 36736
#define IDS_DOM_DISTILLER_VIEWER_CLOSE 36737
#define IDS_DOM_DISTILLER_VIEWER_NO_DATA_CONTENT 36738
#define IDS_DOM_DISTILLER_WEBUI_TITLE 36739
#define IDS_DOM_DISTILLER_VIEWER_TITLE_SUFFIX 36740
#define IDS_ENTERPRISE_COPY_PREVENTION_MISSING_LIST_ERROR 36741
#define IDS_ENTERPRISE_COPY_PREVENTION_DISABLE_CONTAINS_WILDCARD_ERROR 36742
#define IDS_ENTERPRISE_COPY_PREVENTION_WARNING_MESSAGE 36743
#define IDS_ENTERPRISE_DATA_CONTROLS_COPY_PREVENTION_WARNING_MESSAGE 36744
#define IDS_DATA_CONTROLS_CLIPBOARD_PASTE_BLOCK_TITLE 36745
#define IDS_DATA_CONTROLS_CLIPBOARD_PASTE_WARN_TITLE 36746
#define IDS_DATA_CONTROLS_CLIPBOARD_COPY_BLOCK_TITLE 36747
#define IDS_DATA_CONTROLS_CLIPBOARD_COPY_WARN_TITLE 36748
#define IDS_DATA_CONTROLS_CLIPBOARD_DRAG_BLOCK_TITLE 36749
#define IDS_DATA_CONTROLS_CLIPBOARD_SHARE_WARN_TITLE 36750
#define IDS_DATA_CONTROLS_CLIPBOARD_ACTION_WARN_TITLE 36751
#define IDS_DATA_CONTROLS_BLOCKED_LABEL 36752
#define IDS_DATA_CONTROLS_WARNED_LABEL 36753
#define IDS_DATA_CONTROLS_WARNED_LABEL_WITH_DOMAIN 36754
#define IDS_DATA_CONTROLS_PASTE_WARN_CONTINUE_BUTTON 36755
#define IDS_DATA_CONTROLS_COPY_WARN_CONTINUE_BUTTON 36756
#define IDS_DATA_CONTROLS_SHARE_WARN_CONTINUE_BUTTON 36757
#define IDS_DATA_CONTROLS_PASTE_WARN_CANCEL_BUTTON 36758
#define IDS_DATA_CONTROLS_COPY_WARN_CANCEL_BUTTON 36759
#define IDS_DATA_CONTROLS_SHARE_WARN_CANCEL_BUTTON 36760
#define IDS_DATA_CONTROLS_BLOCKED_LABEL_WITH_DOMAIN 36761
#define IDS_ERRORPAGE_NET_BUTTON_DETAILS 36762
#define IDS_ERRORPAGE_NET_BUTTON_HIDE_DETAILS 36763
#define IDS_ERRORPAGES_BUTTON_RELOAD 36764
#define IDS_ERRORPAGES_BUTTON_SHOW_SAVED_COPY 36765
#define IDS_ERRORPAGE_FUN_DISABLED 36766
#define IDS_ERRORPAGES_SUGGESTION_RELOAD_REPOST_SUMMARY 36771
#define IDS_ERRORPAGES_SUGGESTION_CHECK_CONNECTION_HEADER 36772
#define IDS_ERRORPAGES_SUGGESTION_CHECK_CONNECTION_BODY 36773
#define IDS_ERRORPAGES_SUGGESTION_SECURE_DNS_CONFIG_HEADER 36774
#define IDS_ERRORPAGES_SUGGESTION_SECURE_DNS_CONFIG_BODY 36775
#define IDS_ERRORPAGES_SUGGESTION_DNS_CONFIG_HEADER 36776
#define IDS_ERRORPAGES_SUGGESTION_DNS_CONFIG_BODY 36777
#define IDS_ERRORPAGES_SUGGESTION_NETWORK_PREDICTION_HEADER 36778
#define IDS_ERRORPAGES_SUGGESTION_FIREWALL_CONFIG_BODY 36779
#define IDS_ERRORPAGES_SUGGESTION_PROXY_CONFIG_HEADER 36780
#define IDS_ERRORPAGES_SUGGESTION_PROXY_CONFIG_BODY 36781
#define IDS_ERRORPAGES_SUGGESTION_CAPTIVE_PORTAL_SIGNIN 36782
#define IDS_ERRORPAGES_SUGGESTION_VIEW_POLICIES_HEADER 36784
#define IDS_ERRORPAGES_SUGGESTION_VIEW_POLICIES_BODY 36785
#define IDS_ERRORPAGES_SUGGESTION_UNSUPPORTED_CIPHER_HEADER 36786
#define IDS_ERRORPAGES_SUGGESTION_UNSUPPORTED_CIPHER_BODY 36787
#define IDS_ERRORPAGES_SUGGESTION_NAVIGATE_TO_ORIGIN 36788
#define IDS_ERRORPAGES_HEADING_NOT_AVAILABLE 36789
#define IDS_ERRORPAGES_HEADING_NETWORK_ACCESS_DENIED 36790
#define IDS_ERRORPAGES_HEADING_INTERNET_DISCONNECTED 36791
#define IDS_ERRORPAGES_HEADING_YOU_ARE_OFFLINE 36792
#define IDS_ERRORPAGES_MESSAGE_IWA_INVALID_WEB_BUNDLE 36793
#define IDS_ERRORPAGES_MESSAGE_IWA_CONNECTION_REFUSED 36794
#define IDS_ERRORPAGES_MESSAGE_IWA_INSTALLED_IN_DEV_MODE 36795
#define IDS_ERRORPAGES_MESSAGE_IWA_PAGE_NOT_FOUND 36796
#define IDS_ERRORPAGES_HEADING_CACHE_READ_FAILURE 36797
#define IDS_ERRORPAGES_HEADING_CONNECTION_INTERRUPTED 36798
#define IDS_ERRORPAGES_HEADING_NOT_FOUND 36799
#define IDS_ERRORPAGES_HEADING_FILE_NOT_FOUND 36800
#define IDS_ERRORPAGES_HEADING_BLOCKED 36801
#define IDS_ERRORPAGES_HEADING_BLOCKED_BY_ADMINISTRATOR 36802
#define IDS_ERRORPAGES_SUMMARY_NOT_AVAILABLE 36803
#define IDS_ERRORPAGES_SUMMARY_TIMED_OUT 36804
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_RESET 36805
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_CLOSED 36806
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_FAILED 36807
#define IDS_ERRORPAGES_SUMMARY_NETWORK_CHANGED 36808
#define IDS_ERRORPAGES_SUMMARY_CONNECTION_REFUSED 36809
#define IDS_ERRORPAGES_SUMMARY_NAME_NOT_RESOLVED 36810
#define IDS_ERRORPAGES_SUMMARY_ICANN_NAME_COLLISION 36811
#define IDS_ERRORPAGES_SUMMARY_ADDRESS_UNREACHABLE 36812
#define IDS_ERRORPAGES_SUMMARY_FILE_ACCESS_DENIED 36813
#define IDS_ERRORPAGES_SUMMARY_NETWORK_ACCESS_DENIED 36814
#define IDS_ERRORPAGES_SUMMARY_PROXY_CONNECTION_FAILED 36815
#define IDS_ERRORPAGES_SUMMARY_CACHE_READ_FAILURE 36816
#define IDS_ERRORPAGES_SUMMARY_NETWORK_IO_SUSPENDED 36817
#define IDS_ERRORPAGES_SUMMARY_NOT_FOUND 36818
#define IDS_ERRORPAGES_SUMMARY_FILE_NOT_FOUND 36819
#define IDS_ERRORPAGES_SUMMARY_TOO_MANY_REDIRECTS 36820
#define IDS_ERRORPAGES_SUMMARY_EMPTY_RESPONSE 36821
#define IDS_ERRORPAGES_SUMMARY_INVALID_RESPONSE 36822
#define IDS_ERRORPAGES_SUMMARY_DNS_PROBE_RUNNING 36823
#define IDS_ERRORPAGES_HEADING_ACCESS_DENIED 36824
#define IDS_ERRORPAGES_HEADING_FILE_ACCESS_DENIED 36825
#define IDS_ERRORPAGES_SUMMARY_FORBIDDEN 36826
#define IDS_ERRORPAGES_SUMMARY_GONE 36827
#define IDS_ERRORPAGES_HEADING_PAGE_NOT_WORKING 36828
#define IDS_ERRORPAGES_SUMMARY_CONTACT_SITE_OWNER 36829
#define IDS_ERRORPAGES_SUMMARY_WEBSITE_CANNOT_HANDLE_REQUEST 36830
#define IDS_ERRORPAGES_SUMMARY_GATEWAY_TIMEOUT 36831
#define IDS_ERRORPAGES_SUMMARY_SSL_SECURITY_ERROR 36832
#define IDS_ERRORPAGES_SUMMARY_SSL_VERSION_OR_CIPHER_MISMATCH 36833
#define IDS_ERRORPAGES_HEADING_INSECURE_CONNECTION 36834
#define IDS_ERRORPAGES_SUMMARY_BAD_SSL_CLIENT_AUTH_CERT 36835
#define IDS_ERRORPAGES_SUMMARY_SSL_CLIENT_AUTH_SIGNATURE_FAILED 36836
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_EXTENSION 36837
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_ADMINISTRATOR 36838
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_SECURITY 36839
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_BY_LOCAL_NETWORK_ACCESS_CHECKS 36840
#define IDS_ERRORPAGES_HTTP_POST_WARNING 36841
#define IDS_ERRORPAGES_SUGGESTION_LIST_HEADER 36842
#define IDS_ERRORPAGES_SUGGESTION_CHECK_CONNECTION_SUMMARY 36843
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_FIREWALL_DNS_SUMMARY 36845
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_FIREWALL_SECURE_DNS_SUMMARY 36846
#define IDS_ERRORPAGES_SUGGESTION_CHECK_FIREWALL_ANTIVIRUS_SUMMARY 36847
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_FIREWALL_SUMMARY 36848
#define IDS_ERRORPAGES_SUGGESTION_CHECK_PROXY_ADDRESS_SUMMARY 36849
#define IDS_ERRORPAGES_SUGGESTION_CONTACT_ADMIN_SUMMARY 36850
#define IDS_ERRORPAGES_SUGGESTION_CONTACT_ADMIN_SUMMARY_STANDALONE 36851
#define IDS_ERRORPAGES_SUGGESTION_LEARNMORE_SUMMARY 36852
#define IDS_ERRORPAGES_SUGGESTION_LEARNMORE_SUMMARY_STANDALONE 36853
#define IDS_ERRORPAGES_SUGGESTION_DELETE_COOKIES_SUMMARY 36854
#define IDS_ERRORPAGES_SUGGESTION_CHECK_HARDWARE_SUMMARY 36858
#define IDS_ERRORPAGES_SUGGESTION_CHECK_WIFI_SUMMARY 36859
#define IDS_ERRORPAGES_SUGGESTION_DISABLE_EXTENSION_SUMMARY 36860
#define IDS_ERRORPAGES_CHECK_TYPO_SUMMARY 36861
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS 36865
#define IDS_ERRORPAGE_DINO_GAME_DESCRIPTION 36866
#define IDS_ERRORPAGE_DINO_ARIA_LABEL 36867
#define IDS_ERRORPAGE_DINO_GAME_START 36868
#define IDS_ERRORPAGE_DINO_GAME_OVER 36869
#define IDS_ERRORPAGE_DINO_HIGH_SCORE 36870
#define IDS_ERRORPAGE_DINO_JUMP 36871
#define IDS_ERRORPAGE_DINO_SLOW_SPEED_TOGGLE 36872
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS_TOUCH 36873
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS_KEYBOARD 36874
#define IDS_ERRORPAGES_GAME_INSTRUCTIONS_HYBRID 36875
#define IDS_ERRORPAGE_DINO_ARIA_LABEL_TOUCH 36876
#define IDS_ERRORPAGE_DINO_ARIA_LABEL_KEYBOARD 36877
#define IDS_ERRORPAGE_DINO_ARIA_LABEL_HYBRID 36878
#define IDS_ERRORPAGES_HEADING_BLOCKED_IN_INCOGNITO_BY_ADMINISTRATOR 36879
#define IDS_ERRORPAGES_SUMMARY_BLOCKED_IN_INCOGNITO_BY_ADMINISTRATOR 36880
#define IDS_FIND_IN_PAGE_ACCESSIBLE_TITLE 36881
#define IDS_FIND_IN_PAGE_COUNT 36882
#define IDS_ACCESSIBLE_FIND_IN_PAGE_COUNT 36883
#define IDS_ACCESSIBLE_FIND_IN_PAGE_NO_RESULTS 36884
#define IDS_FIND_IN_PAGE_PREVIOUS_TOOLTIP 36885
#define IDS_FIND_IN_PAGE_NEXT_TOOLTIP 36886
#define IDS_FIND_IN_PAGE_CLOSE_TOOLTIP 36887
#define IDS_FLAGS_UI_SEARCH_PLACEHOLDER 36888
#define IDS_FLAGS_UI_SEARCH_LABEL 36889
#define IDS_FLAGS_UI_TITLE 36890
#define IDS_FLAGS_UI_PAGE_RESET 36891
#define IDS_FLAGS_UI_PAGE_WARNING 36892
#define IDS_FLAGS_UI_PAGE_WARNING_EXPLANATION 36893
#define IDS_FLAGS_UI_OWNER_WARNING 36894
#define IDS_FLAGS_UI_AVAILABLE_FEATURE 36895
#define IDS_FLAGS_UI_UNAVAILABLE_FEATURE 36896
#define IDS_FLAGS_UI_ENABLED_FEATURE 36897
#define IDS_FLAGS_UI_DISABLED_FEATURE 36898
#define IDS_FLAGS_UI_NO_RESULTS 36899
#define IDS_FLAGS_UI_NOT_AVAILABLE_ON_PLATFORM 36900
#define IDS_FLAGS_UI_RELAUNCH 36901
#define IDS_FLAGS_UI_CLEAR_SEARCH 36902
#define IDS_FLAGS_UI_RESET_ACKNOWLEDGED 36903
#define IDS_FLAGS_UI_EXPERIMENT_ENABLED 36904
#define IDS_FLAGS_UI_SEARCH_RESULTS_SINGULAR 36905
#define IDS_FLAGS_UI_SEARCH_RESULTS_PLURAL 36906
#define IDS_DEPRECATED_FEATURES_SEARCH_PLACEHOLDER 36907
#define IDS_DEPRECATED_FEATURES_TITLE 36908
#define IDS_DEPRECATED_FEATURES_HEADING 36909
#define IDS_DEPRECATED_FEATURES_PAGE_WARNING_EXPLANATION 36910
#define IDS_DEPRECATED_FEATURES_NO_RESULTS 36911
#define IDS_EXIT_FULLSCREEN_MODE 36912
#define IDS_FULLSCREEN_HOLD_TO_EXIT_FULLSCREEN 36913
#define IDS_FULLSCREEN_HOLD_TO_EXIT_FULLSCREEN_WITH_ORIGIN 36914
#define IDS_FULLSCREEN_PRESS_TO_EXIT_FULLSCREEN 36915
#define IDS_FULLSCREEN_PRESS_TO_EXIT_FULLSCREEN_WITH_ORIGIN 36916
#define IDS_FULLSCREEN_PRESS_TO_EXIT_FULLSCREEN_TWO_KEYS 36917
#define IDS_PRESS_TO_EXIT_MOUSELOCK 36918
#define IDS_PRESS_TO_EXIT_MOUSELOCK_WITH_ORIGIN 36919
#define IDS_PRESS_TO_EXIT_MOUSELOCK_TWO_KEYS 36920
#define IDS_FULLSCREEN_HOLD_TO_SEE_DOWNLOADS 36921
#define IDS_FULLSCREEN_PRESS_TO_SEE_DOWNLOADS 36922
#define IDS_FULLSCREEN_PRESS_TO_SEE_DOWNLOADS_AND_EXIT 36923
#define IDS_FULLSCREEN_HOLD_TO_SEE_DOWNLOADS_AND_EXIT 36924
#define IDS_FULLSCREEN_TOUCH_BASED_EXIT_FULLSCREEN_WITH_ORIGIN 36925
#define IDS_FULLSCREEN_TOUCH_BASED_EXIT_FULLSCREEN 36926
#define IDS_TOUCH_BASED_EXIT_MOUSELOCK_WITH_ORIGIN 36927
#define IDS_TOUCH_BASED_EXIT_MOUSELOCK 36928
#define IDS_FULLSCREEN_TOUCH_BASED_INSTRUCTIONS_TO_SEE_DOWNLOADS 36929
#define IDS_FULLSCREEN_TOUCH_BASED_INSTRUCTIONS_TO_SEE_DOWNLOADS_AND_EXIT 36930
#define IDS_GLOBAL_MEDIA_CONTROLS_BACK_TO_TAB 36931
#define IDS_GLOBAL_MEDIA_CONTROLS_DISMISS_ICON_TOOLTIP_TEXT 36932
#define IDS_GLOBAL_MEDIA_CONTROLS_CAST_HEADER_TEXT 36933
#define IDS_GLOBAL_MEDIA_CONTROLS_CLOSE_DEVICE_LIST_TEXT 36934
#define IDS_GLOBAL_MEDIA_CONTROLS_UNKNOWN_SOURCE_TEXT 36935
#define IDS_GLOBAL_MEDIA_CONTROLS_UNKNOWN_DEVICE_TEXT 36936
#define IDS_GLOBAL_MEDIA_CONTROLS_MEDIA_LIVE_TEXT 36937
#define IDS_HEAVY_AD_INTERVENTION_BUTTON_DETAILS 36938
#define IDS_HEAVY_AD_INTERVENTION_HEADING 36939
#define IDS_HEAVY_AD_INTERVENTION_SUMMARY 36940
#define IDS_HEAVY_AD_INTERVENTION_BUTTON_RELOAD 36941
#define IDS_HISTORY_CLUSTERS_ACTION_MENU_DESCRIPTION 36942
#define IDS_HISTORY_CLUSTERS_DELETE_PRIOR_VISITS_CONFIRM_BUTTON 36943
#define IDS_HISTORY_CLUSTERS_DELETE_PRIOR_VISITS_WARNING 36944
#define IDS_HISTORY_CLUSTERS_BY_GROUP_TAB_LABEL 36945
#define IDS_HISTORY_CLUSTERS_BY_DATE_TAB_LABEL 36946
#define IDS_HISTORY_CLUSTERS_CLUSTER_LABEL_SEARCH_TERMS 36947
#define IDS_HISTORY_CLUSTERS_CLUSTER_LABEL_MULTIPLE_HOSTNAMES 36948
#define IDS_HISTORY_CLUSTERS_CLUSTER_LABEL_OTHER_MATCHING_VISITS 36949
#define IDS_HISTORY_CLUSTERS_HIDE_PAGE 36950
#define IDS_HISTORY_CLUSTERS_HIDE_VISITS 36951
#define IDS_HISTORY_CLUSTERS_LOAD_MORE_BUTTON_LABEL 36952
#define IDS_HISTORY_CLUSTERS_NO_RESULTS 36953
#define IDS_HISTORY_CLUSTERS_NO_SEARCH_RESULTS 36954
#define IDS_HISTORY_CLUSTERS_SHOW_SIDE_PANEL 36955
#define IDS_HISTORY_CLUSTERS_OPEN_ALL_IN_TABGROUP 36956
#define IDS_HISTORY_CLUSTERS_OPEN_INCOGNITO 36957
#define IDS_HISTORY_CLUSTERS_OPEN_IN_NEW_TAB 36958
#define IDS_HISTORY_CLUSTERS_OPEN_IN_NEW_WINDOW 36959
#define IDS_HISTORY_CLUSTERS_RELATED_SEARCHES_HEADER 36960
#define IDS_HISTORY_CLUSTERS_REMOVE_ALL_ITEMS 36961
#define IDS_HISTORY_CLUSTERS_REMOVE_PAGE 36962
#define IDS_HISTORY_CLUSTERS_REMOVE_ITEM_TOAST 36963
#define IDS_HISTORY_CLUSTERS_REMOVE_SELECTED_ITEMS 36964
#define IDS_HISTORY_CLUSTERS_SAVED_IN_TABGROUP_LABEL 36965
#define IDS_HISTORY_CLUSTERS_CUT 36966
#define IDS_HISTORY_CLUSTERS_COPY 36967
#define IDS_HISTORY_CLUSTERS_PASTE 36968
#define IDS_HISTORY_CLUSTERS_COPY_LINK 36969
#define IDS_HISTORY_CLUSTERS_SHOW_LESS_BUTTON_LABEL 36970
#define IDS_HISTORY_CLUSTERS_SHOW_MORE_BUTTON_LABEL 36971
#define IDS_HISTORY_ACTION_MENU_DESCRIPTION 36972
#define IDS_HISTORY_ACTOR_TASK_TOOLTIP 36973
#define IDS_HISTORY_ARIA_ROLE_DESCRIPTION 36974
#define IDS_HISTORY_CANCEL_EDITING_BUTTON 36975
#define IDS_HISTORY_DATE_WITH_RELATIVE_TIME 36976
#define IDS_HISTORY_DELETE_PRIOR_VISITS_CONFIRM_BUTTON 36977
#define IDS_HISTORY_DELETE_PRIOR_VISITS_WARNING 36978
#define IDS_HISTORY_DELETE_SELECTED_ENTRIES_BUTTON 36979
#define IDS_HISTORY_ENTRY_ACCESSIBILITY_DELETE 36980
#define IDS_HISTORY_ENTRY_ACCESSIBILITY_LABEL 36981
#define IDS_HISTORY_ENTRY_BOOKMARKED 36982
#define IDS_HISTORY_ENTRY_SUMMARY 36983
#define IDS_HISTORY_FOUND_SEARCH_RESULTS 36984
#define IDS_HISTORY_OTHER_FORMS_OF_HISTORY_GMA_ONLY 36985
#define IDS_HISTORY_OTHER_FORMS_OF_HISTORY_GAA_ONLY 36986
#define IDS_HISTORY_OTHER_FORMS_OF_HISTORY_GMA_AND_GAA 36987
#define IDS_HISTORY_LOADING 36988
#define IDS_HISTORY_MORE_FROM_SITE 36989
#define IDS_HISTORY_NO_RESULTS 36990
#define IDS_HISTORY_NO_SEARCH_RESULTS 36991
#define IDS_HISTORY_OPEN_CLEAR_BROWSING_DATA_DIALOG 36992
#define IDS_HISTORY_OTHER_SESSIONS_COLLAPSE_SESSION 36993
#define IDS_HISTORY_OTHER_SESSIONS_EXPAND_SESSION 36994
#define IDS_HISTORY_OTHER_SESSIONS_HIDE_FOR_NOW 36995
#define IDS_HISTORY_OTHER_SESSIONS_OPEN_ALL 36996
#define IDS_HISTORY_REMOVE_BOOKMARK 36997
#define IDS_HISTORY_REMOVE_PAGE 36998
#define IDS_HISTORY_REMOVE_PAGE_SUCCESS 36999
#define IDS_HISTORY_REMOVE_SELECTED_ITEMS 37000
#define IDS_HISTORY_SEARCH_BUTTON 37001
#define IDS_HISTORY_SEARCH_RESULT 37002
#define IDS_HISTORY_SEARCH_RESULTS 37003
#define IDS_HISTORY_SEARCH_EXACT_MATCH_RESULT 37004
#define IDS_HISTORY_SEARCH_EXACT_MATCH_RESULTS 37005
#define IDS_HISTORY_SEARCH_EMBEDDINGS_MATCH_RESULT 37006
#define IDS_HISTORY_SEARCH_EMBEDDINGS_MATCH_RESULTS 37007
#define IDS_HISTORY_SHOW_HISTORY 37008
#define IDS_HISTORY_SHOW_SIDE_PANEL 37009
#define IDS_HISTORY_SHOWFULLHISTORY_LINK 37010
#define IDS_HISTORY_SOURCE_FILTER_CHIPS_ARIA_LABEL 37011
#define IDS_HISTORY_SOURCE_FILTER_CHIP_ACTOR 37012
#define IDS_HISTORY_SOURCE_FILTER_CHIP_USER 37013
#define IDS_HISTORY_CLOSE_AND_RETURN_TO_PREFIX 37014
#define IDS_HISTORY_START_EDITING_BUTTON 37015
#define IDS_HISTORY_TITLE 37016
#define IDS_HISTORY_UNKNOWN_DEVICE 37017
#define IDS_HISTORY_SYNC_PROMO_TITLE 37018
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGNED_OUT 37019
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGN_IN_PENDING 37020
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGN_IN_PENDING_SYNC_HISTORY_ON 37021
#define IDS_HISTORY_SYNC_PROMO_BODY_SIGNED_IN 37022
#define IDS_HISTORY_EMBEDDINGS_DISCLAIMER 37023
#define IDS_HISTORY_EMBEDDINGS_DISCLAIMER_LOGGING_OFF 37024
#define IDS_HISTORY_EMBEDDINGS_PROMO_LABEL 37025
#define IDS_HISTORY_EMBEDDINGS_PROMO_CLOSE 37026
#define IDS_HISTORY_EMBEDDINGS_PROMO_HEADING 37027
#define IDS_HISTORY_EMBEDDINGS_PROMO_BODY 37028
#define IDS_HISTORY_EMBEDDINGS_ANSWERS_PROMO_HEADING 37029
#define IDS_HISTORY_EMBEDDINGS_ANSWERS_PROMO_BODY 37030
#define IDS_HISTORY_EMBEDDIGNS_PROMO_SETTINGS_LINK_TEXT 37031
#define IDS_HISTORY_EMBEDDINGS_SHOW_BY_ARIA_LABEL 37032
#define IDS_HISTORY_EMBEDDINGS_SHOW_BY_DATE 37033
#define IDS_HISTORY_EMBEDDINGS_SHOW_BY_GROUP 37034
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_1 37035
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_2 37036
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_3 37037
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_1_ARIA_LABEL 37038
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_2_ARIA_LABEL 37039
#define IDS_HISTORY_EMBEDDINGS_SUGGESTION_3_ARIA_LABEL 37040
#define IDS_HISTORY_EMBEDDINGS_HEADING 37041
#define IDS_HISTORY_EMBEDDINGS_HEADING_LOADING 37042
#define IDS_HISTORY_EMBEDDINGS_WITH_ANSWERS_RESULTS_HEADING 37043
#define IDS_HISTORY_EMBEDDINGS_FOOTER 37044
#define IDS_HISTORY_EMBEDDINGS_FEEDBACK_PLACEHOLDER 37045
#define IDS_HISTORY_EMBEDDINGS_IPH_BODY 37046
#define IDS_HISTORY_EMBEDDINGS_IPH_ACTION 37047
#define IDS_HISTORY_EMBEDDINGS_SEARCH_PROMPT 37048
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_1 37049
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_2 37050
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_3 37051
#define IDS_HISTORY_EMBEDDINGS_SEARCH_ANSWERS_ALTERNATIVE_PROMPT_4 37052
#define IDS_HISTORY_EMBEDDINGS_ANSWER_HEADING 37053
#define IDS_HISTORY_EMBEDDINGS_ANSWER_LOADING_HEADING 37054
#define IDS_HISTORY_EMBEDDINGS_ANSWER_SOURCE_VISIT_DATE_LABEL 37055
#define IDS_HISTORY_EMBEDDINGS_ANSWERER_ERROR_UNANSWERABLE 37056
#define IDS_HISTORY_EMBEDDINGS_ANSWERER_ERROR_MODEL_UNAVAILABLE 37057
#define IDS_HISTORY_EMBEDDINGS_ANSWERER_ERROR_TRY_AGAIN 37058
#define IDS_COMPARE_HISTORY_EMPTY 37059
#define IDS_COMPARE_HISTORY_HEADER 37060
#define IDS_COMPARE_HISTORY_INFO 37061
#define IDS_COMPARE_HISTORY_MENU_ARIA_LABEL 37062
#define IDS_COMPARE_HISTORY_MENU_ITEM 37063
#define IDS_COMPARE_HISTORY_REMOVE 37064
#define IDS_COMPARE_HISTORY_ROW 37065
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE 37066
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_IFRAME 37067
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_NONSTANDARD_URL 37068
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_NONSTANDARD_URL_IFRAME 37069
#define IDS_JAVASCRIPT_MESSAGEBOX_TITLE_EXTENSION 37070
#define IDS_JAVASCRIPT_MESSAGEBOX_SUPPRESS_OPTION 37071
#define IDS_BEFOREUNLOAD_MESSAGEBOX_TITLE 37072
#define IDS_BEFOREUNLOAD_APP_MESSAGEBOX_TITLE 37073
#define IDS_BEFOREUNLOAD_MESSAGEBOX_OK_BUTTON_LABEL 37074
#define IDS_BEFOREUNLOAD_MESSAGEBOX_MESSAGE 37075
#define IDS_BEFORERELOAD_MESSAGEBOX_TITLE 37076
#define IDS_BEFORERELOAD_APP_MESSAGEBOX_TITLE 37077
#define IDS_BEFORERELOAD_MESSAGEBOX_OK_BUTTON_LABEL 37078
#define IDS_LIVE_CAPTION_BUBBLE_TITLE 37079
#define IDS_LIVE_CAPTION_BUBBLE_CLOSE 37080
#define IDS_LIVE_CAPTION_BUBBLE_EXPAND 37081
#define IDS_LIVE_CAPTION_BUBBLE_COLLAPSE 37082
#define IDS_LIVE_CAPTION_BUBBLE_BACK_TO_TAB 37083
#define IDS_LIVE_CAPTION_BUBBLE_ERROR 37084
#define IDS_LIVE_CAPTION_BUBBLE_CONTENT_SETTINGS 37085
#define IDS_LIVE_CAPTION_BUBBLE_MEDIA_FOUNDATION_RENDERER_ERROR 37086
#define IDS_LIVE_CAPTION_BUBBLE_MEDIA_FOUNDATION_RENDERER_ERROR_CHECKBOX 37087
#define IDS_LIVE_CAPTION_BUBBLE_APPEAR_SCREENREADER_ANNOUNCEMENT 37088
#define IDS_LIVE_CAPTION_CAPTION_LANGUAGE_AUTODETECTED 37089
#define IDS_LIVE_CAPTION_BUBBLE_SCROLL_BUTTON_SCROLLING 37090
#define IDS_LIVE_CAPTION_BUBBLE_SCROLL_BUTTON_LOCKED 37091
#define IDS_LIVE_CAPTION_DOWNLOAD_PROGRESS 37092
#define IDS_LIVE_CAPTION_TRANSLATION_DOWNLOADING_LANGUAGE_PACKAGES_WITH_PROGRESS 37093
#define IDS_LIVE_CAPTION_INSTALLING 37094
#define IDS_LIVE_CAPTION_INSTALLING_LANGUAGE_PACKAGES 37095
#define IDS_LIVE_CAPTION_LANGUAGE_DOWNLOAD_FAILED 37096
#define IDS_LIVE_CAPTION_TRANSLATING 37097
#define IDS_LOGIN_DIALOG_TITLE 37098
#define IDS_LOGIN_DIALOG_OK_BUTTON_LABEL 37099
#define IDS_LOGIN_DIALOG_AUTHORITY 37100
#define IDS_LOGIN_DIALOG_PROXY_AUTHORITY 37101
#define IDS_LOGIN_DIALOG_NOT_PRIVATE 37102
#define IDS_LOGIN_DIALOG_USERNAME_FIELD 37103
#define IDS_LOGIN_DIALOG_PASSWORD_FIELD 37104
#define IDS_MANAGEMENT_TITLE 37105
#define IDS_MANAGEMENT_TOOLBAR_TITLE 37106
#define IDS_MANAGEMENT_SEARCH_PROMPT 37107
#define IDS_MANAGEMENT_SUBTITLE_MANAGED_BY 37109
#define IDS_MANAGEMENT_NOT_MANAGED_SUBTITLE 37110
#define IDS_MANAGEMENT_SUBTITLE 37111
#define IDS_MANAGEMENT_SUBTITLE_BROWSER_AND_PROFILE_DIFFERENT_MANAGED_BY 37112
#define IDS_MANAGEMENT_SUBTITLE_BROWSER_MANAGED_AND_PROFILE_MANAGED_BY 37113
#define IDS_MANAGEMENT_SUBTITLE_BROWSER_AND_PROFILE_SAME_MANAGED_BY 37114
#define IDS_MANAGEMENT_SUBTITLE_PROFILE_MANAGED_BY 37115
#define IDS_MANAGEMENT_BROWSER_NOTICE 37116
#define IDS_MANAGEMENT_NOT_MANAGED_NOTICE 37117
#define IDS_MANAGEMENT_PROFILE_NOTICE 37118
#define IDS_MANAGEMENT_LEARN_MORE_ACCCESSIBILITY_TEXT 37119
#define IDS_MANAGEMENT_EXTENSION_REPORTING 37175
#define IDS_MANAGEMENT_EXTENSIONS_INSTALLED 37176
#define IDS_MANAGEMENT_EXTENSIONS_INSTALLED_BY 37177
#define IDS_MANAGEMENT_EXTENSIONS_NAME 37178
#define IDS_MANAGEMENT_EXTENSIONS_PERMISSIONS 37179
#define IDS_MANAGEMENT_APPLICATION_REPORTING 37180
#define IDS_MANAGEMENT_APPLICATIONS_INSTALLED 37181
#define IDS_MANAGEMENT_APPLICATIONS_INSTALLED_BY 37182
#define IDS_MANAGEMENT_APPLICATIONS_NAME 37183
#define IDS_MANAGEMENT_APPLICATIONS_PERMISSIONS 37184
#define IDS_MANAGEMENT_APPLICATIONS_RUN_ON_OS_LOGIN 37185
#define IDS_MANAGEMENT_MANAGED_WEBSITES 37186
#define IDS_MANAGEMENT_MANAGED_WEBSITES_EXPLANATION 37187
#define IDS_MANAGEMENT_MANAGED_WEBSITES_BY_EXPLANATION 37188
#define IDS_MANAGEMENT_BROWSER_REPORTING_EXPLANATION 37189
#define IDS_MANAGEMENT_EXTENSION_REPORT_MACHINE_NAME 37190
#define IDS_MANAGEMENT_EXTENSION_REPORT_MACHINE_NAME_ADDRESS 37191
#define IDS_MANAGEMENT_EXTENSION_REPORT_USERNAME 37192
#define IDS_MANAGEMENT_EXTENSION_REPORT_VERSION 37193
#define IDS_MANAGEMENT_EXTENSION_REPORT_EXTENSIONS_PLUGINS 37194
#define IDS_MANAGEMENT_EXTENSION_REPORT_USER_BROWSING_DATA 37195
#define IDS_MANAGEMENT_EXTENSION_REPORT_PERF_CRASH 37196
#define IDS_MANAGEMENT_EXTENSION_REPORT_VISITED_URL 37197
#define IDS_MANAGEMENT_LEGACY_TECH_REPORT 37198
#define IDS_MANAGEMENT_LEGACY_TECH_REPORT_NO_LINK 37199
#define IDS_MANAGEMENT_THREAT_PROTECTION_MORE 37200
#define IDS_MANAGEMENT_FILE_ATTACHED_EVENT 37201
#define IDS_MANAGEMENT_FILE_DOWNLOADED_EVENT 37202
#define IDS_MANAGEMENT_TEXT_ENTERED_EVENT 37203
#define IDS_MANAGEMENT_PAGE_PRINTED_EVENT 37204
#define IDS_MANAGEMENT_FILE_TRANSFER_EVENT 37205
#define IDS_MANAGEMENT_SCREEN_CAPTURE_EVENT 37206
#define IDS_MANAGEMENT_EXTENSION_TELEMETRY_EVENT 37207
#define IDS_MANAGEMENT_FILE_ATTACHED_VISIBLE_DATA 37208
#define IDS_MANAGEMENT_FILE_DOWNLOADED_VISIBLE_DATA 37209
#define IDS_MANAGEMENT_TEXT_ENTERED_VISIBLE_DATA 37210
#define IDS_MANAGEMENT_PAGE_PRINTED_VISIBLE_DATA 37211
#define IDS_MANAGEMENT_FILE_TRANSFER_VISIBLE_DATA 37212
#define IDS_MANAGEMENT_SCREEN_CAPTURE_DATA 37213
#define IDS_MANAGEMENT_EXTENSION_TELEMETRY_VISIBLE_DATA 37214
#define IDS_MANAGEMENT_BROWSER_REPORTING 37215
#define IDS_MANAGEMENT_PROFILE_REPORTING_EXPLANATION 37223
#define IDS_MANAGEMENT_PROFILE_REPORTING_OVERVIEW 37224
#define IDS_MANAGEMENT_PROFILE_REPORTING_USERNAME 37225
#define IDS_MANAGEMENT_PROFILE_REPORTING_BROWSER 37226
#define IDS_MANAGEMENT_PROFILE_REPORTING_POLICY 37227
#define IDS_MANAGEMENT_PROFILE_REPORTING_LEARN_MORE 37228
#define IDS_MANAGEMENT_PROFILE_REPORTING_EXTENSION 37229
#define IDS_MANAGEMENT_DEVICE_SIGNALS_DISCLOSURE 37234
#define IDS_MANAGEMENT_THREAT_PROTECTION 37235
#define IDS_MANAGEMENT_THREAT_PROTECTION_DESCRIPTION 37236
#define IDS_MANAGEMENT_THREAT_PROTECTION_DESCRIPTION_BY 37237
#define IDS_MANAGEMENT_CONNECTORS_EVENT 37238
#define IDS_MANAGEMENT_CONNECTORS_VISIBLE_DATA 37239
#define IDS_MANAGEMENT_ENTERPRISE_REPORTING_EVENT 37240
#define IDS_MANAGEMENT_PAGE_VISITED_EVENT 37241
#define IDS_MANAGEMENT_PAGE_VISITED_VISIBLE_DATA 37242
#define IDS_MANAGEMENT_ENTERPRISE_REPORTING_VISIBLE_DATA 37243
#define IDS_MANAGEMENT_DIALOG_BROWSING_DATA_MANAGEMENT 37244
#define IDS_MANAGEMENT_DIALOG_DEVICE_SIGNALS 37245
#define IDS_MANAGEMENT_DIALOG_PROFILE_MANAGED_BY 37246
#define IDS_MANAGEMENT_DIALOG_THINGS_TO_CONSIDER_SUBTITLE 37247
#define IDS_MANAGED_PROFILE_INTERSTITIAL_TAB_TITLE 37248
#define IDS_MANAGEMENT_BANNER_PROMOTION_TITLE 37249
#define IDS_MANAGEMENT_BANNER_PROMOTION_DESC 37250
#define IDS_MANAGEMENT_BANNER_PROMOTION_BTN 37251
#define IDS_MANAGEMENT_BANNER_ARIA_LABEL 37252
#define IDS_MANAGEMENT_BANNER_NEW_TAB_ARIA_DESCRIPTION 37253
#define IDS_MANAGEMENT_BANNER_DISMISS_ARIA_LABEL 37254
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_PREVIOUS_TRACK 37255
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_SEEK_BACKWARD 37256
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_REPLAY_10 37257
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_PLAY 37258
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_PAUSE 37259
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_FORWARD_10 37260
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_SEEK_FORWARD 37261
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_NEXT_TRACK 37262
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_ENTER_PIP 37263
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_EXIT_PIP 37264
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_MUTE 37265
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_UNMUTE 37266
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_SHOW_DEVICE_LIST 37267
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_HIDE_DEVICE_LIST 37268
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACTION_STOP_CASTING 37269
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_TIME_SCRUBBER 37270
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_ACCESSIBLE_NAME 37271
#define IDS_MEDIA_MESSAGE_CENTER_MEDIA_NOTIFICATION_LABEL 37272
#define IDS_DEFAULT_TAB_TITLE 37273
#define IDS_DOWNLOAD_TAB_TITLE 37274
#define IDS_SAD_TAB_TITLE 37275
#define IDS_SAD_TAB_MESSAGE 37276
#define IDS_SAD_TAB_HELP_MESSAGE 37277
#define IDS_SAD_TAB_HELP_LINK 37278
#define IDS_SAD_TAB_RELOAD_LABEL 37279
#define IDS_SAD_TAB_RELOAD_TITLE 37282
#define IDS_SAD_TAB_OOM_MESSAGE_TABS 37283
#define IDS_SAD_TAB_OOM_MESSAGE_NOTABS 37284
#define IDS_SAD_TAB_RELOAD_TRY 37285
#define IDS_SAD_TAB_RELOAD_INCOGNITO 37286
#define IDS_SAD_TAB_RELOAD_CLOSE_TABS 37287
#define IDS_SAD_TAB_RELOAD_CLOSE_NOTABS 37288
#define IDS_SAD_TAB_RELOAD_RESTART_BROWSER 37289
#define IDS_SAD_TAB_RELOAD_RESTART_DEVICE 37290
#define IDS_SAD_TAB_ERROR_CODE 37292
#define IDS_NEW_TAB_TITLE 37293
#define IDS_NEW_INCOGNITO_TAB_TITLE 37294
#define IDS_INCOGNITO_TAB_LEARN_MORE_ACCESSIBILITY_LABEL 37295
#define IDS_NEW_TAB_OTR_HEADING 37296
#define IDS_NEW_TAB_OTR_DESCRIPTION 37297
#define IDS_NEW_TAB_OTR_LEARN_MORE_LINK 37298
#define IDS_NEW_TAB_OTR_MESSAGE_WARNING 37299
#define IDS_NEW_TAB_UNDO_THUMBNAIL_REMOVE 37300
#define IDS_NEW_TAB_OTR_TITLE 37301
#define IDS_NEW_TAB_OTR_SUBTITLE 37302
#define IDS_NEW_TAB_OTR_SUBTITLE_WITH_READING_LIST 37303
#define IDS_NEW_TAB_OTR_NOT_SAVED 37304
#define IDS_NEW_TAB_OTR_VISIBLE 37305
#define IDS_NEW_TAB_OPENS_HC_ARTICLE_IN_NEW_TAB 37306
#define IDS_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_HINT 37307
#define IDS_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_SUGGESTION_CONTENTS 37308
#define IDS_ACC_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_SUFFIX 37309
#define IDS_ACC_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA 37310
#define IDS_OMNIBOX_PEDAL_MANAGE_PASSWORDS_HINT 37311
#define IDS_OMNIBOX_PEDAL_MANAGE_PASSWORDS_SUGGESTION_CONTENTS 37312
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_PASSWORDS_SUFFIX 37313
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_PASSWORDS 37314
#define IDS_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_HINT 37315
#define IDS_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_SUGGESTION_CONTENTS 37316
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_SUFFIX 37317
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD 37318
#define IDS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_HINT 37319
#define IDS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUGGESTION_CONTENTS 37320
#define IDS_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUFFIX 37321
#define IDS_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO 37322
#define IDS_OMNIBOX_PEDAL_TRANSLATE_HINT 37323
#define IDS_OMNIBOX_PEDAL_TRANSLATE_SUGGESTION_CONTENTS 37324
#define IDS_ACC_OMNIBOX_PEDAL_TRANSLATE_SUFFIX 37325
#define IDS_ACC_OMNIBOX_PEDAL_TRANSLATE 37326
#define IDS_OMNIBOX_PEDAL_UPDATE_CHROME_HINT 37327
#define IDS_OMNIBOX_PEDAL_UPDATE_CHROME_SUGGESTION_CONTENTS 37328
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CHROME_SUFFIX 37329
#define IDS_ACC_OMNIBOX_PEDAL_UPDATE_CHROME 37330
#define IDS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_SUGGESTION_CONTENTS 37331
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_SUFFIX 37332
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK 37333
#define IDS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2_HINT 37334
#define IDS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2_SUGGESTION_CONTENTS 37335
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2_SUFFIX 37336
#define IDS_ACC_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_V2 37337
#define IDS_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS_HINT 37338
#define IDS_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS_SUGGESTION_CONTENTS 37339
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS_SUFFIX 37340
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SECURITY_SETTINGS 37341
#define IDS_OMNIBOX_PEDAL_MANAGE_COOKIES_HINT 37342
#define IDS_OMNIBOX_PEDAL_MANAGE_COOKIES_SUGGESTION_CONTENTS 37343
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_COOKIES_SUFFIX 37344
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_COOKIES 37345
#define IDS_OMNIBOX_PEDAL_MANAGE_ADDRESSES_HINT 37346
#define IDS_OMNIBOX_PEDAL_MANAGE_ADDRESSES_SUGGESTION_CONTENTS 37347
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_ADDRESSES_SUFFIX 37348
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_ADDRESSES 37349
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_HINT 37350
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_SUGGESTION_CONTENTS 37351
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC_SUFFIX 37352
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC 37353
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_HINT_UPDATED 37354
#define IDS_OMNIBOX_PEDAL_MANAGE_SYNC_SUGGESTION_CONTENTS_UPDATED 37355
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC_SUFFIX_UPDATED 37356
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SYNC_UPDATED 37357
#define IDS_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS_HINT 37358
#define IDS_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS_SUGGESTION_CONTENTS 37359
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS_SUFFIX 37360
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_SITE_SETTINGS 37361
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC_HINT 37362
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC_SUGGESTION_CONTENTS 37363
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC_SUFFIX 37364
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_DOC 37365
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET_HINT 37366
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET_SUGGESTION_CONTENTS 37367
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET_SUFFIX 37368
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SHEET 37369
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE_HINT 37370
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE_SUGGESTION_CONTENTS 37371
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE_SUFFIX 37372
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SLIDE 37373
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT_HINT 37374
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT_SUGGESTION_CONTENTS 37375
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT_SUFFIX 37376
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_CALENDAR_EVENT 37377
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE_HINT 37378
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE_SUGGESTION_CONTENTS 37379
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE_SUFFIX 37380
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_SITE 37381
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE_HINT 37382
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE_SUGGESTION_CONTENTS 37383
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE_SUFFIX 37384
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_KEEP_NOTE 37385
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM_HINT 37386
#define IDS_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM_SUGGESTION_CONTENTS 37387
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM_SUFFIX 37388
#define IDS_ACC_OMNIBOX_PEDAL_CREATE_GOOGLE_FORM 37389
#define IDS_OMNIBOX_PEDAL_SEE_CHROME_TIPS_HINT 37390
#define IDS_OMNIBOX_PEDAL_SEE_CHROME_TIPS_SUGGESTION_CONTENTS 37391
#define IDS_ACC_OMNIBOX_PEDAL_SEE_CHROME_TIPS_SUFFIX 37392
#define IDS_ACC_OMNIBOX_PEDAL_SEE_CHROME_TIPS 37393
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT_HINT 37394
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT_SUGGESTION_CONTENTS 37395
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT_SUFFIX 37396
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_ACCOUNT 37397
#define IDS_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD_HINT 37398
#define IDS_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD_SUGGESTION_CONTENTS 37399
#define IDS_ACC_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD_SUFFIX 37400
#define IDS_ACC_OMNIBOX_PEDAL_CHANGE_GOOGLE_PASSWORD 37401
#define IDS_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS_HINT 37402
#define IDS_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS_SUGGESTION_CONTENTS 37403
#define IDS_ACC_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS_SUFFIX 37404
#define IDS_ACC_OMNIBOX_PEDAL_CLOSE_INCOGNITO_WINDOWS 37405
#define IDS_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_HINT 37406
#define IDS_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_SUGGESTION_CONTENTS 37407
#define IDS_ACC_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_SUFFIX 37408
#define IDS_ACC_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME 37409
#define IDS_OMNIBOX_PEDAL_FIND_MY_PHONE_HINT 37410
#define IDS_OMNIBOX_PEDAL_FIND_MY_PHONE_SUGGESTION_CONTENTS 37411
#define IDS_ACC_OMNIBOX_PEDAL_FIND_MY_PHONE_SUFFIX 37412
#define IDS_ACC_OMNIBOX_PEDAL_FIND_MY_PHONE 37413
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY_HINT 37414
#define IDS_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY_SUGGESTION_CONTENTS 37415
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY_SUFFIX 37416
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_GOOGLE_PRIVACY 37417
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_HINT 37418
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_SUGGESTION_CONTENTS 37419
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_SUFFIX 37420
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS 37421
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS_HINT 37422
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS_SUGGESTION_CONTENTS 37423
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS_SUFFIX 37424
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_DOWNLOADS 37425
#define IDS_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_HINT 37426
#define IDS_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_SUGGESTION_CONTENTS 37427
#define IDS_ACC_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_SUFFIX 37428
#define IDS_ACC_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY 37429
#define IDS_OMNIBOX_PEDAL_SHARE_THIS_PAGE_HINT 37430
#define IDS_OMNIBOX_PEDAL_SHARE_THIS_PAGE_SUGGESTION_CONTENTS 37431
#define IDS_ACC_OMNIBOX_PEDAL_SHARE_THIS_PAGE_SUFFIX 37432
#define IDS_ACC_OMNIBOX_PEDAL_SHARE_THIS_PAGE 37433
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY_HINT 37434
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY_SUGGESTION_CONTENTS 37435
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY_SUFFIX 37436
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_ACCESSIBILITY 37437
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS_HINT 37438
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS_SUGGESTION_CONTENTS 37439
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS_SUFFIX 37440
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_CHROME_FONTS 37441
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES_HINT 37442
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES_SUGGESTION_CONTENTS 37443
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES_SUFFIX 37444
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROME_THEMES 37445
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES_HINT 37446
#define IDS_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES_SUGGESTION_CONTENTS 37447
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES_SUFFIX 37448
#define IDS_ACC_OMNIBOX_PEDAL_CUSTOMIZE_SEARCH_ENGINES 37449
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY_HINT 37450
#define IDS_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY_SUGGESTION_CONTENTS 37451
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY_SUFFIX 37452
#define IDS_ACC_OMNIBOX_PEDAL_MANAGE_CHROMEOS_ACCESSIBILITY 37453
#define IDS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_HINT 37454
#define IDS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUGGESTION_CONTENTS 37455
#define IDS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUFFIX 37456
#define IDS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER 37457
#define IDS_ANDROID_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_HINT 37458
#define IDS_ANDROID_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_HINT 37459
#define IDS_ANDROID_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUGGESTION_CONTENTS 37460
#define IDS_ANDROID_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUFFIX 37461
#define IDS_ANDROID_ACC_OMNIBOX_PEDAL_LAUNCH_INCOGNITO 37462
#define IDS_IOS_OMNIBOX_PEDAL_CLEAR_BROWSING_DATA_HINT 37463
#define IDS_IOS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_HINT 37464
#define IDS_IOS_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUGGESTION_CONTENTS 37465
#define IDS_IOS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER_SUFFIX 37466
#define IDS_IOS_ACC_OMNIBOX_PEDAL_SET_CHROME_AS_DEFAULT_BROWSER 37467
#define IDS_IOS_OMNIBOX_PEDAL_UPDATE_CREDIT_CARD_HINT 37468
#define IDS_IOS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_HINT 37469
#define IDS_IOS_OMNIBOX_PEDAL_RUN_CHROME_SAFETY_CHECK_HINT 37470
#define IDS_IOS_OMNIBOX_PEDAL_MANAGE_CHROME_SETTINGS_HINT 37471
#define IDS_IOS_OMNIBOX_PEDAL_VIEW_CHROME_HISTORY_HINT 37472
#define IDS_IOS_OMNIBOX_PEDAL_PLAY_CHROME_DINO_GAME_HINT 37473
#define IDS_IOS_OMNIBOX_PEDAL_LAUNCH_INCOGNITO_SUGGESTION_CONTENTS 37474
#define IDS_IOS_OMNIBOX_PEDAL_MANAGE_PASSWORDS_HINT 37475
#define IDS_AUTOCOMPLETE_SEARCH_DESCRIPTION 37476
#define IDS_AUTOCOMPLETE_ASK_DESCRIPTION 37477
#define IDS_AUTOCOMPLETE_SEARCH_IN_SIDE_PANEL_DESCRIPTION 37478
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_LABEL 37479
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_LABEL_ALT 37480
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_LABEL_ALT2 37481
#define IDS_OMNIBOX_TOOLBELT_LABEL 37482
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_HINT 37483
#define IDS_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_SUGGESTION_CONTENTS 37484
#define IDS_ACC_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION_SUFFIX 37485
#define IDS_ACC_CONTEXTUAL_SEARCH_OPEN_LENS_ACTION 37486
#define IDS_STARTER_PACK_BOOKMARKS_ACTION_HINT 37487
#define IDS_STARTER_PACK_BOOKMARKS_ACTION_SUGGESTION_CONTENTS 37488
#define IDS_ACC_STARTER_PACK_BOOKMARKS_ACTION_SUFFIX 37489
#define IDS_ACC_STARTER_PACK_BOOKMARKS_ACTION 37490
#define IDS_STARTER_PACK_HISTORY_ACTION_HINT 37491
#define IDS_STARTER_PACK_HISTORY_ACTION_SUGGESTION_CONTENTS 37492
#define IDS_ACC_STARTER_PACK_HISTORY_ACTION_SUFFIX 37493
#define IDS_ACC_STARTER_PACK_HISTORY_ACTION 37494
#define IDS_STARTER_PACK_TABS_ACTION_HINT 37495
#define IDS_STARTER_PACK_TABS_ACTION_SUGGESTION_CONTENTS 37496
#define IDS_ACC_STARTER_PACK_TABS_ACTION_SUFFIX 37497
#define IDS_ACC_STARTER_PACK_TABS_ACTION 37498
#define IDS_STARTER_PACK_AI_MODE_ACTION_HINT 37499
#define IDS_STARTER_PACK_AI_MODE_ACTION_SUGGESTION_CONTENTS 37500
#define IDS_ACC_STARTER_PACK_AI_MODE_ACTION_SUFFIX 37501
#define IDS_ACC_STARTER_PACK_AI_MODE_ACTION 37502
#define IDS_EMPTY_KEYWORD_VALUE 37503
#define IDS_EMPTY_STARTER_PACK_AI_MODE_VALUE 37504
#define IDS_LINK_FROM_CLIPBOARD 37505
#define IDS_TEXT_FROM_CLIPBOARD 37506
#define IDS_IMAGE_FROM_CLIPBOARD 37507
#define IDS_SECURE_CONNECTION_EV 37508
#define IDS_SECURE_VERBOSE_STATE 37509
#define IDS_NOT_SECURE_VERBOSE_STATE 37510
#define IDS_DANGEROUS_VERBOSE_STATE 37511
#define IDS_OFFLINE_VERBOSE_STATE 37512
#define IDS_OMNIBOX_EMPTY_HINT 37513
#define IDS_OMNIBOX_EMPTY_HINT_WITH_DSE_NAME 37514
#define IDS_OMNIBOX_EMPTY_ASK_HINT_WITH_DSE_NAME 37515
#define IDS_OMNIBOX_NAVATTACH_GALLERY 37516
#define IDS_OMNIBOX_NAVATTACH_FILES 37517
#define IDS_OMNIBOX_NAVATTACH_TABS 37518
#define IDS_FUSEBOX_ADD_CURRENT_TAB 37519
#define IDS_FUSEBOX_UPLOAD_FAILED 37520
#define IDS_OMNIBOX_CREATE_IMAGE 37521
#define IDS_OMNIBOX_EMPTY_HINT_FOR_IMAGE_GENERATION 37522
#define IDS_FUSEBOX_MODEL_PRO 37523
#define IDS_OMNIBOX_ADDITIONAL_TEXT_DASH_TEMPLATE 37525
#define IDS_OMNIBOX_TAB_SUGGEST_HINT 37526
#define IDS_OMNIBOX_HISTORY_EMBEDDING_HINT 37527
#define IDS_OMNIBOX_FILE 37528
#define IDS_OMNIBOX_READER_MODE 37529
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_BUGANIZER 37530
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_COMMA_SEPARATED_VALUES 37531
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_APPS_SCRIPT 37532
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DOCS 37533
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DRAWINGS 37534
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DRIVE 37535
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_DRIVE_FOLDER 37536
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_FORMS 37537
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_JAMBOARD 37538
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_PHOTOS 37539
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_SITES 37540
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_SHEETS 37541
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_GOOGLE_SLIDES 37542
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_IMAGE_JPEG 37543
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_IMAGE_PNG 37544
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_IMAGE_SVG 37545
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_JIRA 37546
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_JSON 37547
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MARKDOWN 37548
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MS_EXCEL 37549
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MS_POWERPOINT 37550
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_MS_WORD 37551
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_OPEN_DOCUMENT_PRESENTATION 37552
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_OPEN_DOCUMENT_SPREADSHEET 37553
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_OPEN_DOCUMENT_TEXT 37554
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_PDF 37555
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_PLAIN_TEXT 37556
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_RICH_TEXT_FORMAT 37557
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_SALESFORCE 37558
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_SLACK 37559
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_VIDEO_MP4 37560
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_VIDEO_QUICKTIME 37561
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_VIDEO_WEBM 37562
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_ZIP_FILE 37563
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE 37564
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE_WITHOUT_DATE 37565
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE_WITHOUT_OWNER 37566
#define IDS_CONTENT_SUGGESTION_DESCRIPTION_TEMPLATE_WITHOUT_FILE_TYPE_DESCRIPTION 37567
#define IDS_PERSON_SUGGESTION_DESCRIPTION 37568
#define IDS_ACCURACY_CHECK_VERBOSE_STATE 37569
#define IDS_ACC_OMNIBOX_SUGGESTION_IN_GROUP 37570
#define IDS_ACC_OMNIBOX_SUGGESTION_IN_GROUP_WITH_DESCRIPTION 37571
#define IDS_OMNIBOX_HISTORY_CLUSTERS_SEARCH_HINT 37572
#define IDS_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH_HINT 37573
#define IDS_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH_SUGGESTION_CONTENTS 37574
#define IDS_ACC_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH_SUFFIX 37575
#define IDS_ACC_OMNIBOX_ACTION_HISTORY_CLUSTERS_SEARCH 37576
#define IDS_ACC_OMNIBOX_ACTION_IN_SUGGEST_SUFFIX 37577
#define IDS_ACC_OMNIBOX_ACTION_IN_SUGGEST 37578
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_CALL_HINT 37579
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_CALL_CONTENTS 37580
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_DIRECTIONS_HINT 37581
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_DIRECTIONS_CONTENTS 37582
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_REVIEWS_HINT 37583
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_REVIEWS_CONTENTS 37584
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_AIM_HINT 37585
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_AIM_CONTENTS 37586
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_TAB_SWITCH_HINT 37587
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_TAB_SWITCH_CONTENTS 37588
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_WEBSITE_HINT 37589
#define IDS_OMNIBOX_ACTION_IN_SUGGEST_WEBSITE_CONTENTS 37590
#define IDS_ACC_OMNIBOX_ACTION_IN_EXTENSION_SUGGEST_SUFFIX 37591
#define IDS_ACC_SEND_BUTTON_SEARCH_OR_NAVIGATE 37592
#define IDS_ACC_SEND_BUTTON_SEND_TO_AI 37593
#define IDS_ACC_SEND_BUTTON_CREATE_IMAGE 37594
#define IDS_ACC_REMOVE_IMAGE_ATTACHMENT 37595
#define IDS_ACC_REMOVE_ATTACHMENT 37596
#define IDS_ACC_AI_MODE_SELECTED 37597
#define IDS_ACC_CREATE_IMAGE_SELECTED 37598
#define IDS_ACC_AUTOCOMPLETE_HISTORY 37599
#define IDS_ACC_AUTOCOMPLETE_SEARCH_HISTORY 37600
#define IDS_ACC_AUTOCOMPLETE_SEARCH 37601
#define IDS_ACC_AUTOCOMPLETE_SUGGESTED_SEARCH 37602
#define IDS_ACC_AUTOCOMPLETE_SUGGESTED_SEARCH_ENTITY 37603
#define IDS_ACC_AUTOCOMPLETE_QUICK_ANSWER 37604
#define IDS_ACC_AUTOCOMPLETE_BOOKMARK 37605
#define IDS_ACC_AUTOCOMPLETE_CLIPBOARD_IMAGE 37606
#define IDS_ACC_AUTOCOMPLETE_CLIPBOARD_TEXT 37607
#define IDS_ACC_AUTOCOMPLETE_CLIPBOARD_URL 37608
#define IDS_ACC_SEARCH_ICON 37609
#define IDS_ACC_AUTOCOMPLETE_N_OF_M 37610
#define IDS_ACC_TAB_SWITCH_SUFFIX 37611
#define IDS_ACC_TAB_SWITCH_BUTTON_FOCUSED_PREFIX 37612
#define IDS_ACC_TAB_SWITCH_BUTTON 37613
#define IDS_ACC_MULTIPLE_ACTIONS_SUFFIX 37614
#define IDS_ACC_KEYWORD_SUFFIX 37615
#define IDS_ACC_KEYWORD_MODE 37616
#define IDS_ACC_ASK_KEYWORD_MODE 37617
#define IDS_ACC_KEYWORD_MODE_WITH_SHORTCUT 37618
#define IDS_ACC_ASK_KEYWORD_MODE_WITH_SHORTCUT 37619
#define IDS_OMNIBOX_KEYWORD_TEXT_MD 37620
#define IDS_ACC_THUMBS_UP_SUGGESTION_FOCUSED_PREFIX 37621
#define IDS_ACC_THUMBS_UP_SUGGESTION_BUTTON 37622
#define IDS_ACC_THUMBS_DOWN_SUGGESTION_FOCUSED_PREFIX 37623
#define IDS_ACC_THUMBS_DOWN_SUGGESTION_BUTTON 37624
#define IDS_ACC_REMOVE_SUGGESTION_SUFFIX 37625
#define IDS_ACC_REMOVE_SUGGESTION_FOCUSED_PREFIX 37626
#define IDS_ACC_REMOVE_SUGGESTION_BUTTON 37627
#define IDS_ACC_AI_MODE_PLACEHOLDER_TEXT 37628
#define IDS_ACC_AI_MODE_BUTTON_FOCUSED 37629
#define IDS_ACC_CHROME_TIP 37630
#define IDS_ACC_DISMISS_CHROME_TIP_SUFFIX 37631
#define IDS_ACC_DISMISS_CHROME_TIP_FOCUSED_PREFIX 37632
#define IDS_ACC_DISMISS_CHROME_TIP_BUTTON 37633
#define IDS_SEARCH_ENGINES_STARTER_PACK_BOOKMARKS_NAME 37634
#define IDS_SEARCH_ENGINES_STARTER_PACK_BOOKMARKS_KEYWORD 37635
#define IDS_SEARCH_ENGINES_STARTER_PACK_HISTORY_NAME 37636
#define IDS_SEARCH_ENGINES_STARTER_PACK_HISTORY_KEYWORD 37637
#define IDS_SEARCH_ENGINES_STARTER_PACK_TABS_NAME 37638
#define IDS_SEARCH_ENGINES_STARTER_PACK_TABS_KEYWORD 37639
#define IDS_SEARCH_ENGINES_STARTER_PACK_GEMINI_NAME 37640
#define IDS_SEARCH_ENGINES_STARTER_PACK_GEMINI_KEYWORD 37641
#define IDS_SEARCH_ENGINES_STARTER_PACK_PAGE_NAME 37642
#define IDS_SEARCH_ENGINES_STARTER_PACK_PAGE_KEYWORD 37643
#define IDS_SEARCH_ENGINES_STARTER_PACK_AI_MODE_NAME 37644
#define IDS_SEARCH_ENGINES_STARTER_PACK_AI_MODE_KEYWORD 37645
#define IDS_STARTER_PACK_PAGE_KEYWORD_TEXT 37646
#define IDS_STARTER_PACK_PAGE_EMPTY_QUERY_MATCH_TEXT 37647
#define IDS_OMNIBOX_INSTANT_KEYWORD_ASK_TEXT 37648
#define IDS_OMNIBOX_INSTANT_KEYWORD_SEARCH_TEXT 37649
#define IDS_OMNIBOX_SELECTED_KEYWORD_ASK_TEXT 37650
#define IDS_OMNIBOX_TAB_SEARCH_NO_RESULTS_FOUND 37651
#define IDS_OMNIBOX_GEMINI_IPH 37652
#define IDS_OMNIBOX_FEATURED_ENTERPRISE_SITE_SEARCH_IPH 37653
#define IDS_OMNIBOX_FEATURED_ENTERPRISE_SEARCH_AGGREGATOR_IPH 37654
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SETTINGS_PROMO_IPH 37655
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SETTINGS_PROMO_IPH_LINK_TEXT 37656
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_DISCLAIMER_IPH 37657
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_DISCLAIMER_IPH_LINK_TEXT 37658
#define IDS_ACC_OMNIBOX_IPH_LINK_SELECTED 37659
#define IDS_ACC_OMNIBOX_TOOLBELT_NEXT_SUFFIX 37660
#define IDS_OMNIBOX_HISTORY_SCOPE_PROMO_IPH 37661
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SCOPE_PROMO_IPH 37662
#define IDS_OMNIBOX_ONE_LINE_CALCULATOR_SUGGESTION_TEMPLATE 37663
#define IDS_OMNIBOX_HEADER_POPULAR_TOPICS 37664
#define IDS_OMNIBOX_BOOKMARKS_SCOPE_PLACEHOLDER_TEXT 37665
#define IDS_OMNIBOX_HISTORY_SCOPE_PLACEHOLDER_TEXT 37666
#define IDS_OMNIBOX_HISTORY_EMBEDDINGS_SCOPE_PLACEHOLDER_TEXT 37667
#define IDS_OMNIBOX_TABS_SCOPE_PLACEHOLDER_TEXT 37668
#define IDS_OMNIBOX_GEMINI_SCOPE_PLACEHOLDER_TEXT 37669
#define IDS_OMNIBOX_PAGE_SCOPE_PLACEHOLDER_TEXT 37670
#define IDS_OMNIBOX_AI_MODE_SCOPE_PLACEHOLDER_TEXT 37671
#define IDS_OMNIBOX_HUB_OPEN_TABS_HEADER 37672
#define IDS_OMNIBOX_HUB_SEARCH_HEADER 37673
#define IDS_OMNIBOX_HUB_HISTORY_HEADER 37674
#define IDS_OMNIBOX_HUB_TYPED_MATCH_HEADER 37675
#define IDS_PAGE_INFO_SECURE_SUMMARY 37676
#define IDS_PAGE_INFO_MIXED_CONTENT_SUMMARY 37677
#define IDS_PAGE_INFO_MIXED_CONTENT_SUMMARY_SHORT 37678
#define IDS_PAGE_INFO_NOT_SECURE_SUMMARY 37679
#define IDS_PAGE_INFO_NOT_SECURE_SUMMARY_SHORT 37680
#define IDS_PAGE_INFO_SAFE_BROWSING_SUMMARY 37681
#define IDS_PAGE_INFO_EXTENSION_PAGE 37682
#define IDS_PAGE_INFO_VIEW_SOURCE_PAGE 37683
#define IDS_PAGE_INFO_DEVTOOLS_PAGE 37684
#define IDS_PAGE_INFO_READER_MODE_PAGE_SECURE 37685
#define IDS_PAGE_INFO_READER_MODE_PAGE 37686
#define IDS_PAGE_INFO_SAFETY_TIP_MORE_INFO_LINK 37687
#define IDS_PAGE_INFO_SAFETY_TIP_LOOKALIKE_LEAVE_BUTTON 37688
#define IDS_PAGE_INFO_SAFETY_TIP_LOOKALIKE_TITLE 37689
#define IDS_PAGE_INFO_SAFETY_TIP_DESCRIPTION 37690
#define IDS_PAGE_INFO_FILE_PAGE 37691
#define IDS_PAGE_INFO_SECURE_DETAILS 37692
#define IDS_PAGE_INFO_MIXED_CONTENT_DETAILS 37693
#define IDS_PAGE_INFO_LEGACY_TLS_DETAILS 37694
#define IDS_PAGE_INFO_NOT_SECURE_DETAILS 37695
#define IDS_PAGE_INFO_MALWARE_DETAILS 37696
#define IDS_PAGE_INFO_SOCIAL_ENGINEERING_DETAILS 37697
#define IDS_PAGE_INFO_UNWANTED_SOFTWARE_DETAILS 37698
#define IDS_PAGE_INFO_SECURITY_TAB_INSECURE_IDENTITY 37699
#define IDS_PAGE_INFO_CHANGE_PASSWORD_SUMMARY 37700
#define IDS_PAGE_INFO_CHANGE_PASSWORD_SAVED_PASSWORD_SUMMARY 37701
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_SAVED 37702
#define IDS_PAGE_INFO_CHECK_PASSWORDS_BUTTON 37703
#define IDS_PAGE_INFO_INVALID_CERTIFICATE_DESCRIPTION 37704
#define IDS_PAGE_INFO_RESET_INVALID_CERTIFICATE_DECISIONS_BUTTON 37705
#define IDS_PAGE_INFO_HELP_CENTER_LINK 37706
#define IDS_PAGE_INFO_SECURITY_TAB_DEPRECATED_SIGNATURE_ALGORITHM 37707
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_CONNECTION_TEXT 37708
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_INSECURE_CONTENT_ERROR 37709
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_INSECURE_CONTENT_WARNING 37710
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_INSECURE_FORM_WARNING 37711
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTED_SENTENCE_LINK 37712
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTION_DETAILS 37713
#define IDS_PAGE_INFO_SECURITY_TAB_ENCRYPTION_DETAILS_AEAD 37714
#define IDS_PAGE_INFO_SECURITY_TAB_NOT_ENCRYPTED_CONNECTION_TEXT 37715
#define IDS_PAGE_INFO_SECURITY_TAB_SSL_VERSION 37716
#define IDS_PAGE_INFO_SECURITY_TAB_UNKNOWN_PARTY 37717
#define IDS_PAGE_INFO_SECURITY_TAB_WEAK_ENCRYPTION_CONNECTION_TEXT 37718
#define IDS_PAGE_INFO_CERT_INFO_BUTTON 37719
#define IDS_PAGE_INFO_ADDRESS 37720
#define IDS_PAGE_INFO_PARTIAL_ADDRESS 37721
#define IDS_PAGE_INFO_SECURITY_TAB_SECURE_IDENTITY_EV_VERIFIED 37722
#define IDS_PAGE_INFO_CERTIFICATE 37723
#define IDS_PAGE_INFO_CERTIFICATE_VALID_LINK 37724
#define IDS_PAGE_INFO_CERTIFICATE_INVALID_LINK 37725
#define IDS_PAGE_INFO_CERTIFICATE_BUTTON_TEXT 37726
#define IDS_PAGE_INFO_CERTIFICATE_VALID_PARENTHESIZED 37727
#define IDS_PAGE_INFO_CERTIFICATE_INVALID_PARENTHESIZED 37728
#define IDS_PAGE_INFO_CERTIFICATE_IS_VALID 37729
#define IDS_PAGE_INFO_CERTIFICATE_DETAILS 37730
#define IDS_PAGE_INFO_CERTIFICATE_VALID_LINK_TOOLTIP 37731
#define IDS_PAGE_INFO_CERTIFICATE_INVALID_LINK_TOOLTIP 37732
#define IDS_PAGE_INFO_QWAC_STATUS_TITLE 37733
#define IDS_PAGE_INFO_COOKIES 37735
#define IDS_PAGE_INFO_COOKIES_TOOLTIP 37736
#define IDS_PAGE_INFO_BUTTON_TEXT_AUTOMATIC_BY_DEFAULT 37737
#define IDS_PAGE_INFO_BUTTON_TEXT_MUTED_BY_DEFAULT 37738
#define IDS_PAGE_INFO_MENU_ITEM_DEFAULT_ALLOW 37739
#define IDS_PAGE_INFO_MENU_ITEM_DEFAULT_BLOCK 37740
#define IDS_PAGE_INFO_MENU_ITEM_DEFAULT_ASK 37741
#define IDS_PAGE_INFO_MENU_ITEM_ALLOW 37742
#define IDS_PAGE_INFO_MENU_ITEM_BLOCK 37743
#define IDS_PAGE_INFO_MENU_ITEM_ASK 37744
#define IDS_PAGE_INFO_MENU_ITEM_ADS_BLOCK 37745
#define IDS_PAGE_INFO_STATE_TEXT_ALLOWED 37746
#define IDS_PAGE_INFO_STATE_TEXT_ALLOWED_ONCE 37747
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED 37748
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_IN_INCOGNITO 37749
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_IN_GUEST 37750
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_INSECURE 37751
#define IDS_PAGE_INFO_STATE_TEXT_MUTED 37752
#define IDS_PAGE_INFO_STATE_TEXT_ALLOWED_BY_DEFAULT 37753
#define IDS_PAGE_INFO_STATE_TEXT_NOT_ALLOWED_BY_DEFAULT 37754
#define IDS_PAGE_INFO_SELECTOR_TOOLTIP 37755
#define IDS_PAGE_INFO_SELECTOR_STORAGE_ACCESS_TOOLTIP 37756
#define IDS_PAGE_INFO_STATE_TEXT_AR_ASK 37757
#define IDS_PAGE_INFO_STATE_TEXT_AUTO_PICTURE_IN_PICTURE_ASK 37758
#define IDS_PAGE_INFO_STATE_TEXT_AUTOMATIC_DOWNLOADS_ASK 37759
#define IDS_PAGE_INFO_STATE_TEXT_BLUETOOTH_DEVICES_ASK 37760
#define IDS_PAGE_INFO_STATE_TEXT_CAMERA_ASK 37761
#define IDS_PAGE_INFO_STATE_TEXT_CAPTURED_SURFACE_CONTROL_ASK 37762
#define IDS_PAGE_INFO_STATE_TEXT_CAMERA_PAN_TILT_ZOOM_ASK 37763
#define IDS_PAGE_INFO_STATE_TEXT_CLIPBOARD_ASK 37764
#define IDS_PAGE_INFO_STATE_TEXT_FILE_SYSTEM_WRITE_ASK 37765
#define IDS_PAGE_INFO_STATE_TEXT_HAND_TRACKING_ASK 37766
#define IDS_PAGE_INFO_STATE_TEXT_HID_DEVICES_ASK 37767
#define IDS_PAGE_INFO_STATE_TEXT_KEYBOARD_LOCK_ASK 37768
#define IDS_PAGE_INFO_STATE_TEXT_LOCATION_ASK 37769
#define IDS_PAGE_INFO_STATE_TEXT_MIC_ASK 37770
#define IDS_PAGE_INFO_STATE_TEXT_MIDI_SYSEX_ASK 37771
#define IDS_PAGE_INFO_STATE_TEXT_NOTIFICATIONS_ASK 37772
#define IDS_PAGE_INFO_STATE_TEXT_POINTER_LOCK_ASK 37773
#define IDS_PAGE_INFO_STATE_TEXT_MOTION_AND_LIGHT_SENSORS_ASK 37774
#define IDS_PAGE_INFO_STATE_TEXT_MOTION_SENSORS_ASK 37775
#define IDS_PAGE_INFO_STATE_TEXT_USB_ASK 37776
#define IDS_PAGE_INFO_STATE_TEXT_VR_ASK 37777
#define IDS_PAGE_INFO_STATE_TEXT_FONT_ACCESS_ASK 37778
#define IDS_PAGE_INFO_STATE_TEXT_SERIAL_ASK 37779
#define IDS_PAGE_INFO_STATE_TEXT_IDLE_DETECTION_ASK 37780
#define IDS_PAGE_INFO_STATE_TEXT_WINDOW_MANAGEMENT_ASK 37781
#define IDS_PAGE_INFO_STATE_TEXT_BLUETOOTH_SCANNING_ASK 37782
#define IDS_PAGE_INFO_STATE_TEXT_STORAGE_ACCESS_ASK 37783
#define IDS_PAGE_INFO_STATE_TEXT_WEB_APP_INSTALLATION_ASK 37784
#define IDS_PAGE_INFO_STATE_TEXT_WEB_PRINTING_ASK 37785
#define IDS_PAGE_INFO_STATE_TEXT_LOCAL_NETWORK_ACCESS_ASK 37786
#define IDS_PAGE_INFO_STATE_TEXT_LOCAL_NETWORK_ASK 37787
#define IDS_PAGE_INFO_STATE_TEXT_LOOPBACK_NETWORK_ASK 37788
#define IDS_PAGE_INFO_USB_DEVICE_SECONDARY_LABEL 37789
#define IDS_PAGE_INFO_USB_DEVICE_ALLOWED_BY_POLICY_LABEL 37790
#define IDS_PAGE_INFO_DELETE_USB_DEVICE_WITH_NAME 37791
#define IDS_PAGE_INFO_SERIAL_PORT_SECONDARY_LABEL 37792
#define IDS_PAGE_INFO_SERIAL_PORT_ALLOWED_BY_POLICY_LABEL 37793
#define IDS_PAGE_INFO_DELETE_SERIAL_PORT_WITH_NAME 37794
#define IDS_PAGE_INFO_BLUETOOTH_DEVICE_SECONDARY_LABEL 37795
#define IDS_PAGE_INFO_DELETE_BLUETOOTH_DEVICE_WITH_NAME 37796
#define IDS_PAGE_INFO_HID_DEVICE_SECONDARY_LABEL 37797
#define IDS_PAGE_INFO_HID_DEVICE_ALLOWED_BY_POLICY_LABEL 37798
#define IDS_PAGE_INFO_DELETE_HID_DEVICE_WITH_NAME 37799
#define IDS_PAGE_INFO_SMART_CARD_READER_ALLOWED_BY_POLICY_LABEL 37800
#define IDS_PAGE_INFO_SMART_CARD_READER_SECONDARY_LABEL 37801
#define IDS_PAGE_INFO_DELETE_SMART_CARD_READER_WITH_NAME 37802
#define IDS_PAGE_INFO_SITE_SETTINGS_LINK 37803
#define IDS_PAGE_INFO_SITE_SETTINGS_TOOLTIP 37804
#define IDS_PAGE_INFO_CAMERA_SYSTEM_SETTINGS_DESCRIPTION 37807
#define IDS_PAGE_INFO_MICROPHONE_SYSTEM_SETTINGS_DESCRIPTION 37808
#define IDS_PAGE_INFO_LOCATION_SYSTEM_SETTINGS_DESCRIPTION 37809
#define IDS_PAGE_INFO_CLIPBOARD_SYSTEM_SETTINGS_DESCRIPTION 37810
#define IDS_PAGE_INFO_SETTINGS_OF_A_SYSTEM_LINK 37811
#define IDS_PAGE_INFO_PERMISSION_ALLOWED_BY_POLICY 37812
#define IDS_PAGE_INFO_PERMISSION_BLOCKED_BY_POLICY 37813
#define IDS_PAGE_INFO_PERMISSION_ASK_BY_POLICY 37814
#define IDS_PAGE_INFO_PERMISSION_ALLOWED_BY_EXTENSION 37815
#define IDS_PAGE_INFO_PERMISSION_BLOCKED_BY_EXTENSION 37816
#define IDS_PAGE_INFO_PERMISSION_ASK_BY_EXTENSION 37817
#define IDS_PAGE_INFO_PERMISSION_AUTOMATICALLY_BLOCKED 37818
#define IDS_PAGE_INFO_PERMISSION_ADS_SUBTITLE 37819
#define IDS_PAGE_INFO_PERMISSION_MANAGED_BY_POLICY 37820
#define IDS_PAGE_INFO_PERMISSION_MANAGED_BY_EXTENSION 37821
#define IDS_PAGE_INFO_INFOBAR_TEXT 37822
#define IDS_PAGE_INFO_INFOBAR_BUTTON 37823
#define IDS_PAGE_INFO_PERMISSION_USING_NOW 37824
#define IDS_PAGE_INFO_PERMISSION_RECENTLY_USED 37825
#define IDS_PAGE_INFO_PERMISSION_USED_TIME_AGO 37826
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS 37827
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_SYNC 37828
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_SIGNED_IN_NON_SYNC 37829
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_ENTERPRISE 37830
#define IDS_PAGE_INFO_CHANGE_PASSWORD_DETAILS_ENTERPRISE_WITH_ORG_NAME 37831
#define IDS_PAGE_INFO_CHANGE_PASSWORD_BUTTON 37832
#define IDS_PAGE_INFO_PROTECT_ACCOUNT_BUTTON 37833
#define IDS_PAGE_INFO_IGNORE_PASSWORD_WARNING_BUTTON 37834
#define IDS_PAGE_INFO_ALLOWLIST_PASSWORD_REUSE_BUTTON 37835
#define IDS_PAGE_INFO_BILLING_SUMMARY 37836
#define IDS_PAGE_INFO_BILLING_DETAILS 37837
#define IDS_PAGE_INFO_VR_PRESENTING_TEXT 37838
#define IDS_PAGE_INFO_VR_TURN_OFF_BUTTON_TEXT 37839
#define IDS_CERT_INFO_SUBJECT_GROUP 37840
#define IDS_CERT_INFO_ISSUER_GROUP 37841
#define IDS_CERT_INFO_COMMON_NAME_LABEL 37842
#define IDS_CERT_INFO_ORGANIZATION_LABEL 37843
#define IDS_CERT_INFO_ORGANIZATIONAL_UNIT_LABEL 37844
#define IDS_CERT_INFO_SERIAL_NUMBER_LABEL 37845
#define IDS_CERT_INFO_VALIDITY_GROUP 37846
#define IDS_CERT_INFO_ISSUED_ON_LABEL 37847
#define IDS_CERT_INFO_EXPIRES_ON_LABEL 37848
#define IDS_CERT_INFO_FINGERPRINTS_GROUP 37849
#define IDS_CERT_INFO_SHA256_FINGERPRINT_LABEL 37850
#define IDS_CERT_INFO_SHA256_SPKI_FINGERPRINT_LABEL 37851
#define IDS_CERT_DETAILS_EXTENSIONS 37852
#define IDS_CERT_X509_SUBJECT_ALT_NAME 37853
#define IDS_PAGE_INFO_SECURITY_SUBPAGE_BUTTON 37854
#define IDS_PAGE_INFO_SECURITY_SUBPAGE_HEADER 37855
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_BUTTON_TOOLTIP 37856
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_MANAGE_BUTTON 37857
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_MANAGE_BUTTON_TOOLTIP 37858
#define IDS_PAGE_INFO_PERMISSIONS_SUBPAGE_REMEMBER_THIS_SETTING 37859
#define IDS_PAGE_INFO_RESET_PERMISSIONS 37860
#define IDS_PAGE_INFO_ABOUT_THIS_SITE_HEADER 37861
#define IDS_PAGE_INFO_ABOUT_THIS_PAGE_TITLE 37862
#define IDS_PAGE_INFO_ABOUT_THIS_PAGE_DESCRIPTION_PLACEHOLDER 37863
#define IDS_PAGE_INFO_ABOUT_THIS_SITE_TOOLTIP 37864
#define IDS_PAGE_INFO_ABOUT_THIS_PAGE_TOOLTIP 37865
#define IDS_PAGE_INFO_ABOUT_THIS_SITE_SUBPAGE_FROM_LABEL 37866
#define IDS_PAGE_INFO_COOKIES_HEADER 37867
#define IDS_PAGE_INFO_COOKIES_DESCRIPTION 37868
#define IDS_PAGE_INFO_COOKIES_SETTINGS_LINK 37869
#define IDS_PAGE_INFO_BLOCK_THIRD_PARTY_COOKIES_MANAGED_BY_SETTINGS_TOOLTIP 37870
#define IDS_PAGE_INFO_COOKIES_ALLOWED_SITES_COUNT 37871
#define IDS_PAGE_INFO_COOKIES_DIALOG_BUTTON_TITLE 37872
#define IDS_PAGE_INFO_COOKIES_DIALOG_BUTTON_TOOLTIP 37873
#define IDS_PAGE_INFO_RWS_BUTTON_TOOLTIP 37874
#define IDS_PAGE_INFO_RWS_BUTTON_TITLE 37875
#define IDS_PAGE_INFO_RWS_BUTTON_SUBTITLE 37876
#define IDS_PAGE_INFO_COOKIES_SITE_NOT_WORKING_TITLE 37877
#define IDS_PAGE_INFO_TRACKING_PROTECTION_SITE_NOT_WORKING_DESCRIPTION_TEMPORARY 37878
#define IDS_PAGE_INFO_COOKIES_SITE_NOT_WORKING_DESCRIPTION_PERMANENT 37879
#define IDS_PAGE_INFO_COOKIES_THIRD_PARTY_COOKIES_LABEL 37880
#define IDS_PAGE_INFO_TRACKING_PROTECTION_COOKIES_BLOCKED_RESTART_TITLE 37881
#define IDS_PAGE_INFO_TRACKING_PROTECTION_COOKIES_RESTART_DESCRIPTION 37882
#define IDS_PAGE_INFO_TRACKING_PROTECTION_PERMANENT_ALLOWED_TITLE 37883
#define IDS_PAGE_INFO_TRACKING_PROTECTION_COOKIES_PERMANENT_ALLOWED_DESCRIPTION 37884
#define IDS_PAGE_INFO_COOKIE_SYNC_DESCRIPTION 37885
#define IDS_PAGE_INFO_SYNC_SETTINGS_LINK 37886
#define IDS_MERCHANT_TRUST_SIDE_PANEL_TITLE 37887
#define IDS_PAGE_INFO_MERCHANT_TRUST_HEADER 37888
#define IDS_PAGE_INFO_MERCHANT_TRUST_DESCRIPTION 37889
#define IDS_PAGE_INFO_MERCHANT_TRUST_VIEW_ALL_REVIEWS 37890
#define IDS_PAGE_INFO_MERCHANT_TRUST_STAR_RATING_AND_COUNT_A11Y_DESCRIPTION 37891
#define IDS_PAGE_INFO_MERCHANT_TRUST_STAR_RATING_A11Y_DESCRIPTION 37892
#define IDS_PAGE_INFO_MERCHANT_TRUST_REVIEWS_SUMMARY_TITLE 37893
#define IDS_PAGE_INFO_HISTORY 37894
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_TODAY 37895
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_YESTERDAY 37896
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_DAYS 37897
#define IDS_PAGE_INFO_HISTORY_LAST_VISIT_DATE 37898
#define IDS_PAGE_INFO_ENTERPRISE_WARN_SUMMARY 37899
#define IDS_PAGE_INFO_ENTERPRISE_WARN_DETAILS 37900
#define IDS_PAGE_INFO_ENTERPRISE_BLOCK_SUMMARY 37901
#define IDS_PAGE_INFO_ENTERPRISE_BLOCK_DETAILS 37902
#define IDS_PAGE_INFO_AD_PRIVACY_HEADER 37903
#define IDS_PAGE_INFO_AD_PRIVACY_TOOLTIP 37904
#define IDS_PAGE_INFO_AD_PRIVACY_TOPICS_DESCRIPTION 37905
#define IDS_PAGE_INFO_AD_PRIVACY_FLEDGE_DESCRIPTION 37906
#define IDS_PAGE_INFO_AD_PRIVACY_TOPICS_AND_FLEDGE_DESCRIPTION 37907
#define IDS_PAGE_INFO_AD_PRIVACY_SUBPAGE_MANAGE_BUTTON 37908
#define IDS_CERT_OID_PKCS1_RSA_ENCRYPTION 37909
#define IDS_CERT_OID_PKCS1_MD2_WITH_RSA_ENCRYPTION 37910
#define IDS_CERT_OID_PKCS1_MD4_WITH_RSA_ENCRYPTION 37911
#define IDS_CERT_OID_PKCS1_MD5_WITH_RSA_ENCRYPTION 37912
#define IDS_CERT_OID_PKCS1_SHA1_WITH_RSA_ENCRYPTION 37913
#define IDS_CERT_OID_PKCS1_SHA256_WITH_RSA_ENCRYPTION 37914
#define IDS_CERT_OID_PKCS1_SHA384_WITH_RSA_ENCRYPTION 37915
#define IDS_CERT_OID_PKCS1_SHA512_WITH_RSA_ENCRYPTION 37916
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA1_SIGNATURE 37917
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA256_SIGNATURE 37918
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA384_SIGNATURE 37919
#define IDS_CERT_OID_ANSIX962_ECDSA_SHA512_SIGNATURE 37920
#define IDS_CERT_OID_ANSIX962_EC_PUBLIC_KEY 37921
#define IDS_CERT_OID_SECG_EC_SECP256R1 37922
#define IDS_CERT_OID_SECG_EC_SECP384R1 37923
#define IDS_CERT_OID_SECG_EC_SECP521R1 37924
#define IDS_CERT_OID_ML_DSA_44 37925
#define IDS_CERT_OID_ML_DSA_65 37926
#define IDS_CERT_OID_ML_DSA_87 37927
#define IDS_CERT_EKU_ANY_EKU 37928
#define IDS_CERT_EKU_CODE_SIGNING 37929
#define IDS_CERT_EKU_EMAIL_PROTECTION 37930
#define IDS_CERT_EKU_TIME_STAMPING 37931
#define IDS_CERT_X509_AUTH_INFO_ACCESS 37932
#define IDS_CERT_X509_KEY_USAGE_NONREP 37933
#define IDS_CERT_X509_KEY_USAGE_ENCIPHERMENT 37934
#define IDS_CERT_X509_KEY_USAGE_DATA_ENCIPHERMENT 37935
#define IDS_CERT_X509_KEY_USAGE_KEY_AGREEMENT 37936
#define IDS_CERT_X509_KEY_USAGE_CERT_SIGNER 37937
#define IDS_CERT_X509_KEY_USAGE_CRL_SIGNER 37938
#define IDS_CERT_X509_KEY_USAGE_ENCIPHER_ONLY 37939
#define IDS_CERT_X509_KEY_USAGE_DECIPHER_ONLY 37940
#define IDS_CERT_PKIX_CPS_POINTER_QUALIFIER 37941
#define IDS_CERT_PKIX_USER_NOTICE_QUALIFIER 37942
#define IDS_PAINT_PREVIEW_COMPOSITOR_SERVICE_DISPLAY_NAME 37943
#define IDS_LEAK_CHECK_CREDENTIALS 37944
#define IDS_CREDENTIAL_LEAK_TITLE_CHANGE 37945
#define IDS_CREDENTIAL_LEAK_TITLE_CHECK_GPM 37946
#define IDS_CREDENTIAL_LEAK_CHECK_PASSWORDS_MESSAGE_GPM_BRANDED 37947
#define IDS_CREDENTIAL_LEAK_CHANGE_PASSWORD_MESSAGE_GPM_BRANDED 37948
#define IDS_CREDENTIAL_LEAK_CHANGE_AND_CHECK_PASSWORDS_MESSAGE_GPM_BRANDED 37949
#define IDS_CREDENTIAL_LEAK_CHECK_PASSWORDS_MESSAGE_GPM_NON_BRANDED 37950
#define IDS_CREDENTIAL_LEAK_CHANGE_PASSWORD_MESSAGE_GPM_NON_BRANDED 37951
#define IDS_CREDENTIAL_LEAK_CHANGE_AND_CHECK_PASSWORDS_MESSAGE_GPM_NON_BRANDED 37952
#define IDS_PASSWORD_MANAGER_LEAK_HELP_MESSAGE 37955
#define IDS_MANAGE_PASSWORDS_AUTO_SIGNIN_TITLE 37956
#define IDS_PASSWORD_MANAGER_EMPTY_LOGIN 37957
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORDS 37958
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORDS_AND_PASSKEYS 37959
#define IDS_PASSWORD_MANAGER_GENERATE_PASSWORD 37960
#define IDS_PASSWORD_MANAGER_SHOW_PASSWORDS_TAB_TITLE 37961
#define IDS_PASSWORD_MANAGER_DEFAULT_EXPORT_FILENAME 37962
#define IDS_PASSWORD_MANAGER_PASSWORD_FOR_ACCOUNT 37963
#define IDS_PASSWORD_MANAGER_USE_SCREEN_LOCK 37964
#define IDS_PASSWORD_MANAGER_PASSKEY 37965
#define IDS_PASSWORD_MANAGER_USE_GENERIC_DEVICE 37966
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_CHROME_PROFILE 37967
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_ICLOUD_KEYCHAIN 37968
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_GOOGLE_PASSWORD_MANAGER 37969
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_WINDOWS_HELLO 37970
#define IDS_PASSWORD_MANAGER_PASSKEY_FROM_PROVIDER 37971
#define IDS_PASSWORD_MANAGER_PASSWORD_FROM_GOOGLE_PASSWORD_MANAGER 37972
#define IDS_PASSWORD_MANAGER_USE_DIFFERENT_PASSKEY 37973
#define IDS_PASSWORD_MANAGER_USE_PASSKEY_OTHER_DEVICE 37974
#define IDS_PASSWORD_MANAGER_USE_PASSKEY 37975
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_TITLE_LINUX_BRANDED 38000
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_DESCRIPTION_LINUX_BRANDED 38001
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_TITLE_LINUX_NON_BRANDED 38002
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_DESCRIPTION_LINUX_NON_BRANDED 38003
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_ACCEPT_BUTTON_BRANDED 38007
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_ACCEPT_BUTTON_NON_BRANDED 38008
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_CANCEL_BUTTON 38009
#define IDS_PASSWORD_MANAGER_RELAUNCH_CHROME_BUBBLE_NEVER_BUTTON 38010
#define IDS_PASSWORD_MANAGER_MANAGEMENT_BUBBLE_FOOTER_MOVE_PASSWORD 38011
#define IDS_PASSWORD_MANAGER_MANAGEMENT_BUBBLE_LINK_TEXT_MOVE_PASSWORD 38012
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_SUGGESTED_PASSWORDS_SECTION_TITLE 38013
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_ALL_PASSWORDS_SECTION_TITLE 38014
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_FILL_PASSWORD_ENTRY 38015
#define IDS_PASSWORD_MANAGER_MANUAL_FALLBACK_VIEW_DETAILS_ENTRY 38016
#define IDS_PASSWORD_MANAGER_PENDING_STATE 38017
#define IDS_PASSWORD_MANAGER_UI_TROUBLE_SIGNING_IN 38018
#define IDS_PASSWORD_MANAGER_UI_PROACTIVE_RECOVERY_SUGGESTION 38019
#define IDS_PASSWORD_MANAGER_UI_PROACTIVE_RECOVERY_FOOTER_BRANDED 38020
#define IDS_PASSWORD_MANAGER_UI_PROACTIVE_RECOVERY_FOOTER_NON_BRANDED 38021
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_TAG 38022
#define IDS_PAYMENTS_TITLE 38023
#define IDS_PAYMENTS_ERROR_MESSAGE_DIALOG_TITLE 38024
#define IDS_PAYMENTS_METHOD_OF_PAYMENT_LABEL 38025
#define IDS_PAYMENTS_CONTACT_DETAILS_LABEL 38026
#define IDS_PAYMENTS_ADD_CONTACT_DETAILS_LABEL 38027
#define IDS_PAYMENTS_EDIT_CONTACT_DETAILS_LABEL 38028
#define IDS_PAYMENTS_ADD_MORE_INFORMATION 38029
#define IDS_PAYMENTS_ADD_PHONE_NUMBER 38030
#define IDS_PAYMENTS_ADD_RECIPIENT 38031
#define IDS_PAYMENTS_ADD_VALID_ADDRESS 38032
#define IDS_PAYMENTS_ADD_EMAIL 38033
#define IDS_PAYMENTS_ADD_NAME 38034
#define IDS_PAYMENTS_ORDER_SUMMARY_LABEL 38035
#define IDS_PAYMENT_REQUEST_PAYMENT_METHOD_SECTION_NAME 38036
#define IDS_PAYMENT_REQUEST_CONTACT_INFO_SECTION_NAME 38037
#define IDS_PAYMENTS_SHIPPING_SUMMARY_LABEL 38038
#define IDS_PAYMENTS_SHIPPING_ADDRESS_LABEL 38039
#define IDS_PAYMENTS_SHIPPING_OPTION_LABEL 38040
#define IDS_PAYMENTS_DELIVERY_SUMMARY_LABEL 38041
#define IDS_PAYMENTS_DELIVERY_ADDRESS_LABEL 38042
#define IDS_PAYMENTS_DELIVERY_OPTION_LABEL 38043
#define IDS_PAYMENTS_PICKUP_SUMMARY_LABEL 38044
#define IDS_PAYMENTS_PICKUP_ADDRESS_LABEL 38045
#define IDS_PAYMENTS_PICKUP_OPTION_LABEL 38046
#define IDS_PAYMENTS_EDIT_BUTTON 38047
#define IDS_PAYMENTS_PAY_BUTTON 38048
#define IDS_PAYMENTS_CONTINUE_BUTTON 38049
#define IDS_PAYMENTS_ADD_CONTACT 38050
#define IDS_PAYMENTS_ADD_CARD 38051
#define IDS_PAYMENTS_ADD_ADDRESS 38052
#define IDS_PAYMENTS_EDIT_ADDRESS 38053
#define IDS_PAYMENTS_CANCEL_PAYMENT 38054
#define IDS_PAYMENTS_CONFIRM_BUTTON 38055
#define IDS_PAYMENTS_NAME_FIELD_IN_CONTACT_DETAILS 38056
#define IDS_PAYMENTS_PHONE_FIELD_IN_CONTACT_DETAILS 38057
#define IDS_PAYMENTS_EMAIL_FIELD_IN_CONTACT_DETAILS 38058
#define IDS_PAYMENTS_LOADING_MESSAGE 38059
#define IDS_PAYMENTS_PROCESSING_MESSAGE 38060
#define IDS_PAYMENTS_CHECKING_OPTION 38061
#define IDS_PAYMENTS_UPDATED_LABEL 38062
#define IDS_PAYMENTS_ERROR_MESSAGE 38063
#define IDS_PAYMENTS_CARD_AND_ADDRESS_SETTINGS 38064
#define IDS_PAYMENTS_CARD_AND_ADDRESS_SETTINGS_SIGNED_IN 38065
#define IDS_PAYMENTS_CARD_AND_ADDRESS_SETTINGS_SIGNED_OUT 38066
#define IDS_SETTINGS_CAN_MAKE_PAYMENT_TOGGLE_LABEL 38067
#define IDS_PAYMENTS_REQUIRED_FIELD_MESSAGE 38068
#define IDS_PAYMENTS_VALIDATION_INVALID_CREDIT_CARD_EXPIRED 38069
#define IDS_PAYMENTS_VALIDATION_UNSUPPORTED_CREDIT_CARD_TYPE 38070
#define IDS_PAYMENTS_PHONE_INVALID_VALIDATION_MESSAGE 38071
#define IDS_PAYMENTS_EMAIL_INVALID_VALIDATION_MESSAGE 38072
#define IDS_PAYMENTS_CARD_NUMBER_INVALID_VALIDATION_MESSAGE 38073
#define IDS_PAYMENTS_INVALID_ADDRESS 38074
#define IDS_PAYMENTS_BILLING_ADDRESS_REQUIRED 38075
#define IDS_PAYMENTS_MORE_INFORMATION_REQUIRED 38076
#define IDS_PAYMENTS_PHONE_NUMBER_REQUIRED 38077
#define IDS_PAYMENTS_RECIPIENT_REQUIRED 38078
#define IDS_PAYMENTS_EMAIL_REQUIRED 38079
#define IDS_PAYMENTS_NAME_REQUIRED 38080
#define IDS_PREF_EDIT_DIALOG_FIELD_REQUIRED_VALIDATION_MESSAGE 38081
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_SECTION_TOTAL_FORMAT 38082
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_SHEET_TOTAL_FORMAT 38083
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_MORE_ITEMS 38084
#define IDS_PAYMENT_REQUEST_ORDER_SUMMARY_MULTIPLE_CURRENCY_INDICATOR 38085
#define IDS_PAYMENTS_SELECT_SHIPPING_ADDRESS_FOR_SHIPPING_METHODS 38086
#define IDS_PAYMENTS_UNSUPPORTED_SHIPPING_ADDRESS 38087
#define IDS_PAYMENTS_UNSUPPORTED_SHIPPING_OPTION 38088
#define IDS_PAYMENTS_SELECT_DELIVERY_ADDRESS_FOR_DELIVERY_METHODS 38089
#define IDS_PAYMENTS_UNSUPPORTED_DELIVERY_ADDRESS 38090
#define IDS_PAYMENTS_SELECT_PICKUP_ADDRESS_FOR_PICKUP_METHODS 38091
#define IDS_PAYMENTS_UNSUPPORTED_PICKUP_ADDRESS 38092
#define IDS_PAYMENTS_ANDROID_APP_ERROR 38093
#define IDS_PAYMENT_REQUEST_PAYMENT_METHODS_PREVIEW 38095
#define IDS_PAYMENT_REQUEST_SHIPPING_ADDRESSES_PREVIEW 38096
#define IDS_PAYMENT_REQUEST_SHIPPING_OPTIONS_PREVIEW 38097
#define IDS_PAYMENT_REQUEST_CONTACTS_PREVIEW 38098
#define IDS_PAYMENTS_BACK 38099
#define IDS_PAYMENTS_CLOSE 38100
#define IDS_PAYMENTS_EDIT 38101
#define IDS_PAYMENTS_ROW_ACCESSIBLE_NAME_FORMAT 38102
#define IDS_PAYMENTS_ROW_ACCESSIBLE_NAME_SELECTED_FORMAT 38103
#define IDS_PAYMENTS_PROFILE_LABELS_ACCESSIBLE_FORMAT 38104
#define IDS_PAYMENTS_ACCESSIBLE_LABEL_WITH_ERROR 38105
#define IDS_PAYMENTS_ORDER_SUMMARY_ACCESSIBLE_LABEL 38106
#define IDS_PAYMENTS_ITEM_ICON 38107
#define IDS_PAYMENT_HANDLER_SHEET_DESCRIPTION 38108
#define IDS_PAYMENT_HANDLER_SHEET_OPENED_HALF 38109
#define IDS_PAYMENT_HANDLER_SHEET_OPENED_FULL 38110
#define IDS_PAYMENT_HANDLER_SHEET_CLOSED 38111
#define IDS_PAYMENT_HANDLER_ICON 38112
#define IDS_SECURE_PAYMENT_CONFIRMATION_TITLE 38113
#define IDS_SECURE_PAYMENT_CONFIRMATION_INFORM_ONLY_TITLE 38114
#define IDS_SECURE_PAYMENT_CONFIRMATION_VERIFY_BUTTON_LABEL 38115
#define IDS_SECURE_PAYMENT_CONFIRMATION_FOOTNOTE_TEXT 38120
#define IDS_SECURE_PAYMENT_CONFIRMATION_FOOTNOTE_LINK_TEXT 38121
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_TEXT 38122
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_LINK_TEXT 38123
#define IDS_SECURE_PAYMENT_CONFIRMATION_CONFIRM_BUTTON_LABEL 38124
#define IDS_SECURE_PAYMENT_CONFIRMATION_OPT_OUT_AUTHENTICATOR_TEXT 38125
#define IDS_PDF_DOWNLOAD_ORIGINAL 38133
#define IDS_PDF_DOWNLOAD_EDITED 38134
#define IDS_PDF_PRESENT 38135
#define IDS_PDF_NEED_PASSWORD 38136
#define IDS_PDF_PASSWORD_DIALOG_TITLE 38137
#define IDS_PDF_PASSWORD_SUBMIT 38138
#define IDS_PDF_PASSWORD_INVALID 38139
#define IDS_PDF_SIDEBAR_LABEL 38140
#define IDS_PDF_PAGE_LOADING 38141
#define IDS_PDF_ERROR_DIALOG_TITLE 38142
#define IDS_PDF_PAGE_LOAD_FAILED 38143
#define IDS_PDF_PAGE_RELOAD_BUTTON 38144
#define IDS_PDF_BOOKMARKS 38145
#define IDS_PDF_BOOKMARK_EXPAND_ICON_ARIA_LABEL 38146
#define IDS_PDF_PROPERTIES_DIALOG_TITLE 38147
#define IDS_PDF_PROPERTIES_FILE_NAME 38148
#define IDS_PDF_PROPERTIES_FILE_SIZE 38149
#define IDS_PDF_PROPERTIES_TITLE 38150
#define IDS_PDF_PROPERTIES_AUTHOR 38151
#define IDS_PDF_PROPERTIES_SUBJECT 38152
#define IDS_PDF_PROPERTIES_KEYWORDS 38153
#define IDS_PDF_PROPERTIES_CREATED 38154
#define IDS_PDF_PROPERTIES_MODIFIED 38155
#define IDS_PDF_PROPERTIES_APPLICATION 38156
#define IDS_PDF_PROPERTIES_PDF_PRODUCER 38157
#define IDS_PDF_PROPERTIES_PDF_VERSION 38158
#define IDS_PDF_PROPERTIES_PAGE_COUNT 38159
#define IDS_PDF_PROPERTIES_PAGE_SIZE 38160
#define IDS_PDF_PROPERTIES_PAGE_SIZE_VALUE_INCH 38161
#define IDS_PDF_PROPERTIES_PAGE_SIZE_VALUE_MM 38162
#define IDS_PDF_PROPERTIES_PAGE_SIZE_PORTRAIT 38163
#define IDS_PDF_PROPERTIES_PAGE_SIZE_LANDSCAPE 38164
#define IDS_PDF_PROPERTIES_PAGE_SIZE_SQUARE 38165
#define IDS_PDF_PROPERTIES_PAGE_SIZE_VARIABLE 38166
#define IDS_PDF_PROPERTIES_FAST_WEB_VIEW 38167
#define IDS_PDF_PROPERTIES_FAST_WEB_VIEW_NO 38168
#define IDS_PDF_PROPERTIES_FAST_WEB_VIEW_YES 38169
#define IDS_PDF_TOOLTIP_ROTATE_CCW 38170
#define IDS_PDF_ROTATION_STATE_LABEL_0 38171
#define IDS_PDF_ROTATION_STATE_LABEL_90 38172
#define IDS_PDF_ROTATION_STATE_LABEL_180 38173
#define IDS_PDF_ROTATION_STATE_LABEL_270 38174
#define IDS_PDF_TOOLTIP_DOWNLOAD 38175
#define IDS_PDF_TOOLTIP_PRINT 38176
#define IDS_PDF_TOOLTIP_FIT_PAGE 38177
#define IDS_PDF_TOOLTIP_FIT_WIDTH 38178
#define IDS_PDF_TWO_UP_VIEW_ENABLE 38179
#define IDS_PDF_ANNOTATIONS_SHOW_TOGGLE 38180
#define IDS_PDF_ZOOM_TEXT_INPUT_ARIA_LABEL 38181
#define IDS_PDF_TOOLTIP_ZOOM_IN 38182
#define IDS_PDF_TOOLTIP_ZOOM_OUT 38183
#define IDS_PDF_TOOLTIP_THUMBNAILS 38184
#define IDS_PDF_TOOLTIP_DOCUMENT_OUTLINE 38185
#define IDS_PDF_TOOLTIP_ATTACHMENTS 38186
#define IDS_PDF_TOOLTIP_DOWNLOAD_ATTACHMENT 38187
#define IDS_PDF_LABEL_PAGE_NUMBER 38188
#define IDS_PDF_LOADING_TO_A11Y_TREE 38189
#define IDS_PDF_LOADED_TO_A11Y_TREE 38190
#define IDS_PDF_OVERSIZE_ATTACHMENT_WARNING 38191
#define IDS_PDF_PAGE_INDEX 38192
#define IDS_PDF_DOCUMENT_PAGE_COUNT 38193
#define IDS_PDF_THUMBNAIL_PAGE_ARIA_LABEL 38194
#define IDS_PDF_ANNOTATION_PEN 38195
#define IDS_PDF_ANNOTATION_HIGHLIGHTER 38196
#define IDS_PDF_ANNOTATION_ERASER 38197
#define IDS_PDF_ANNOTATION_UNDO 38198
#define IDS_PDF_ANNOTATION_REDO 38199
#define IDS_PDF_ANNOTATION_COLOR_BLACK 38200
#define IDS_PDF_ANNOTATION_COLOR_RED 38201
#define IDS_PDF_ANNOTATION_COLOR_YELLOW 38202
#define IDS_PDF_ANNOTATION_COLOR_GREEN 38203
#define IDS_PDF_ANNOTATION_COLOR_WHITE 38204
#define IDS_PDF_ANNOTATION_COLOR_ORANGE 38205
#define IDS_PDF_ANNOTATION_COLOR_BLUE 38206
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_GREY 38207
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_ORANGE 38208
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_GREEN 38209
#define IDS_PDF_ANNOTATION_COLOR_LIGHT_BLUE 38210
#define IDS_PDF_INK2_DRAW 38211
#define IDS_PDF_INK2_ANNOTATION_TOOL 38212
#define IDS_PDF_INK2_ANNOTATION_SIZE 38213
#define IDS_PDF_INK2_ANNOTATION_COLOR 38214
#define IDS_PDF_INK2_ANNOTATION_SIZE_EXTRA_THIN 38215
#define IDS_PDF_INK2_ANNOTATION_SIZE_THIN 38216
#define IDS_PDF_INK2_ANNOTATION_SIZE_MEDIUM 38217
#define IDS_PDF_INK2_ANNOTATION_SIZE_THICK 38218
#define IDS_PDF_INK2_ANNOTATION_SIZE_EXTRA_THICK 38219
#define IDS_PDF_INK2_ANNOTATION_COLOR_LIGHT_RED 38220
#define IDS_PDF_INK2_ANNOTATION_COLOR_LIGHT_YELLOW 38221
#define IDS_PDF_INK2_ANNOTATION_COLOR_DARK_GREY_1 38222
#define IDS_PDF_INK2_ANNOTATION_COLOR_DARK_GREY_2 38223
#define IDS_PDF_INK2_ANNOTATION_COLOR_RED_1 38224
#define IDS_PDF_INK2_ANNOTATION_COLOR_YELLOW_1 38225
#define IDS_PDF_INK2_ANNOTATION_COLOR_GREEN_1 38226
#define IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_1 38227
#define IDS_PDF_INK2_ANNOTATION_COLOR_BLUE_1 38228
#define IDS_PDF_INK2_ANNOTATION_COLOR_TAN_1 38229
#define IDS_PDF_INK2_ANNOTATION_COLOR_RED_2 38230
#define IDS_PDF_INK2_ANNOTATION_COLOR_YELLOW_2 38231
#define IDS_PDF_INK2_ANNOTATION_COLOR_GREEN_2 38232
#define IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_2 38233
#define IDS_PDF_INK2_ANNOTATION_COLOR_BLUE_2 38234
#define IDS_PDF_INK2_ANNOTATION_COLOR_TAN_2 38235
#define IDS_PDF_INK2_ANNOTATION_COLOR_RED_3 38236
#define IDS_PDF_INK2_ANNOTATION_COLOR_YELLOW_3 38237
#define IDS_PDF_INK2_ANNOTATION_COLOR_GREEN_3 38238
#define IDS_PDF_INK2_ANNOTATION_COLOR_CYAN_3 38239
#define IDS_PDF_INK2_ANNOTATION_COLOR_BLUE_3 38240
#define IDS_PDF_INK2_ANNOTATION_COLOR_TAN_3 38241
#define IDS_PDF_INK2_TEXT_ANNOTATION 38242
#define IDS_PDF_INK2_TEXT_FONT 38243
#define IDS_PDF_INK2_TEXT_FONT_SANS_SERIF 38244
#define IDS_PDF_INK2_TEXT_FONT_SERIF 38245
#define IDS_PDF_INK2_TEXT_FONT_MONOSPACE 38246
#define IDS_PDF_INK2_TEXT_FONT_SIZE 38247
#define IDS_PDF_INK2_TEXT_STYLES 38248
#define IDS_PDF_INK2_TEXT_STYLE_BOLD 38249
#define IDS_PDF_INK2_TEXT_STYLE_ITALIC 38250
#define IDS_PDF_INK2_TEXT_ALIGNMENT 38251
#define IDS_PDF_INK2_TEXT_ALIGN_LEFT 38252
#define IDS_PDF_INK2_TEXT_ALIGN_CENTER 38253
#define IDS_PDF_INK2_TEXT_ALIGN_RIGHT 38254
#define IDS_PDF_INK2_TEXT_COLOR 38255
#define IDS_AX_ROLE_DESCRIPTION_PDF_HIGHLIGHT 38256
#define IDS_AX_ROLE_DESCRIPTION_PDF_POPUP_NOTE 38257
#define IDS_PDF_TOOLTIP_SAVE_TO_DRIVE 38258
#define IDS_SAVE_TO_DRIVE_DIALOG_CANCEL_UPLOAD_BUTTON_LABEL 38259
#define IDS_SAVE_TO_DRIVE_DIALOG_CONNECTION_ERROR_MESSAGE 38260
#define IDS_SAVE_TO_DRIVE_DIALOG_ERROR_TITLE 38261
#define IDS_SAVE_TO_DRIVE_DIALOG_MANAGE_STORAGE_BUTTON_LABEL 38262
#define IDS_SAVE_TO_DRIVE_DIALOG_OPEN_IN_DRIVE_BUTTON_LABEL 38263
#define IDS_SAVE_TO_DRIVE_DIALOG_RETRY_BUTTON_LABEL 38264
#define IDS_SAVE_TO_DRIVE_DIALOG_SESSION_TIMEOUT_ERROR_MESSAGE 38265
#define IDS_SAVE_TO_DRIVE_DIALOG_STORAGE_FULL_ERROR_MESSAGE 38266
#define IDS_SAVE_TO_DRIVE_DIALOG_SUCCESS_MESSAGE 38267
#define IDS_SAVE_TO_DRIVE_DIALOG_SUCCESS_TITLE 38268
#define IDS_SAVE_TO_DRIVE_DIALOG_UNKNOWN_ERROR_MESSAGE 38269
#define IDS_SAVE_TO_DRIVE_DIALOG_UPLOAD_STATUS_DONE 38270
#define IDS_SAVE_TO_DRIVE_DIALOG_UPLOAD_STATUS_WITH_SEPARATOR 38271
#define IDS_SAVE_TO_DRIVE_DIALOG_UPLOADING_TITLE 38272
#define IDS_PDF_OCR_FEATURE_ALERT 38273
#define IDS_PDF_OCR_IN_PROGRESS 38274
#define IDS_PDF_OCR_COMPLETED 38275
#define IDS_PDF_OCR_NO_RESULT 38276
#define IDS_PDF_OCR_POSTAMBLE_PAGE 38277
#define IDS_PDF_SEARCHIFY_IN_PROGRESS 38278
#define IDS_GEOLOCATION_INFOBAR_TEXT 38279
#define IDS_GEOLOCATION_INFOBAR_PERMISSION_FRAGMENT 38317
#define IDS_MOTION_AND_LIGHT_SENSORS_PERMISSION_FRAGMENT 38318
#define IDS_MOTION_SENSORS_PERMISSION_FRAGMENT 38319
#define IDS_NOTIFICATION_PERMISSIONS_FRAGMENT 38320
#define IDS_MIDI_SYSEX_PERMISSION_FRAGMENT 38321
#define IDS_MEDIA_CAPTURE_AUDIO_ONLY_PERMISSION_FRAGMENT 38322
#define IDS_MEDIA_CAPTURE_AUDIO_ONLY_PERMISSION_FRAGMENT_WITH_COUNT 38323
#define IDS_MEDIA_CAPTURE_VIDEO_ONLY_PERMISSION_FRAGMENT 38324
#define IDS_MEDIA_CAPTURE_VIDEO_ONLY_PERMISSION_FRAGMENT_WITH_COUNT 38325
#define IDS_MEDIA_CAPTURE_CAMERA_PAN_TILT_ZOOM_PERMISSION_FRAGMENT 38326
#define IDS_MEDIA_CAPTURE_CAMERA_PAN_TILT_ZOOM_PERMISSION_FRAGMENT_WITH_COUNT 38327
#define IDS_ACCESSIBILITY_EVENTS_PERMISSION_FRAGMENT 38328
#define IDS_CLIPBOARD_PERMISSION_FRAGMENT 38329
#define IDS_VR_PERMISSION_FRAGMENT 38330
#define IDS_AR_PERMISSION_FRAGMENT 38331
#define IDS_HAND_TRACKING_PERMISSION_FRAGMENT 38332
#define IDS_KEYBOARD_LOCK_PERMISSIONS_FRAGMENT 38333
#define IDS_POINTER_LOCK_PERMISSIONS_FRAGMENT 38334
#define IDS_STORAGE_ACCESS_PERMISSION_TWO_ORIGIN_PROMPT_TITLE 38335
#define IDS_STORAGE_ACCESS_PERMISSION_FRAGMENT 38336
#define IDS_STORAGE_ACCESS_PERMISSION_EXPLANATION 38337
#define IDS_STORAGE_ACCESS_PERMISSION_TWO_ORIGIN_EXPLANATION 38338
#define IDS_STORAGE_ACCESS_PERMISSION_TWO_ORIGIN_LINK 38339
#define IDS_WINDOW_MANAGEMENT_PERMISSION_FRAGMENT 38340
#define IDS_FONT_ACCESS_PERMISSION_FRAGMENT 38341
#define IDS_IDLE_DETECTION_PERMISSION_FRAGMENT 38342
#define IDS_IDENTITY_PROVIDER_PERMISSION_FRAGMENT 38343
#define IDS_MULTI_DOWNLOAD_PERMISSION_FRAGMENT 38344
#define IDS_CAPTURED_SURFACE_CONTROL_PERMISSION_FRAGMENT 38345
#define IDS_WEB_APP_INSTALLATION_PERMISSION_FRAGMENT 38346
#define IDS_LOCAL_NETWORK_ACCESS_PERMISSION_FRAGMENT 38347
#define IDS_LOCAL_NETWORK_PERMISSION_FRAGMENT 38348
#define IDS_LOOPBACK_NETWORK_PERMISSION_FRAGMENT 38349
#define IDS_PERMISSION_ALLOW 38350
#define IDS_PERMISSION_DENY 38351
#define IDS_PERMISSION_ALLOW_THIS_TIME 38352
#define IDS_PERMISSION_ALLOW_EVERY_VISIT 38353
#define IDS_PERMISSION_ALLOW_WHILE_VISITING 38354
#define IDS_PERMISSION_DONT_ALLOW 38355
#define IDS_PERMISSION_NEVER_ALLOW 38356
#define IDS_PERMISSION_ALLOW_APPROXIMATE_GEO 38357
#define IDS_PERMISSION_ALLOW_PRECISE_GEO 38358
#define IDS_PERMISSION_ALLOW_PRECISE_GEO_DESCRIPTION 38359
#define IDS_PERMISSION_ALLOW_APPROXIMATE_GEO_DESCRIPTION 38360
#define IDS_PERMISSION_ALLOW_PRECISE_GEO_LONG_DESCRIPTION 38361
#define IDS_PERMISSION_ALLOW_APPROXIMATE_GEO_LONG_DESCRIPTION 38362
#define IDS_BLUETOOTH_DEVICE_CHOOSER_PROMPT 38363
#define IDS_BLUETOOTH_DEVICE_CHOOSER_NO_DEVICES_FOUND_PROMPT 38364
#define IDS_BLUETOOTH_DEVICE_CHOOSER_PAIR_BUTTON_TEXT 38365
#define IDS_BLUETOOTH_DEVICE_CHOOSER_SCANNING_LABEL 38366
#define IDS_BLUETOOTH_DEVICE_CHOOSER_SCANNING_LABEL_TOOLTIP 38367
#define IDS_BLUETOOTH_DEVICE_CHOOSER_ADAPTER_OFF 38368
#define IDS_BLUETOOTH_DEVICE_CHOOSER_TURN_ON_BLUETOOTH_LINK_TEXT 38369
#define IDS_BLUETOOTH_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH_LINK_TEXT 38370
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_WITH_ID 38371
#define IDS_BLUETOOTH_SCANNING_PROMPT 38372
#define IDS_BLUETOOTH_SCANNING_DEVICE_UNKNOWN 38373
#define IDS_BLUETOOTH_SCANNING_PROMPT_NO_DEVICES_FOUND_PROMPT 38374
#define IDS_BLUETOOTH_SCANNING_PROMPT_ALLOW_BUTTON_TEXT 38375
#define IDS_BLUETOOTH_SCANNING_PROMPT_BLOCK_BUTTON_TEXT 38376
#define IDS_DEVICE_CHOOSER_CANCEL_BUTTON_TEXT 38377
#define IDS_DEVICE_CHOOSER_NO_DEVICES_FOUND_PROMPT 38378
#define IDS_USB_DEVICE_CHOOSER_PROMPT 38379
#define IDS_USB_DEVICE_CHOOSER_CONNECT_BUTTON_TEXT 38380
#define IDS_USB_DEVICE_CHOOSER_LOADING_LABEL 38381
#define IDS_USB_DEVICE_CHOOSER_LOADING_LABEL_TOOLTIP 38382
#define IDS_GEOLOCATION_PERMISSION_CHIP 38383
#define IDS_NOTIFICATION_PERMISSIONS_CHIP 38384
#define IDS_MIDI_SYSEX_PERMISSION_CHIP 38385
#define IDS_MEDIA_CAPTURE_AUDIO_ONLY_PERMISSION_CHIP 38386
#define IDS_MEDIA_CAPTURE_VIDEO_ONLY_PERMISSION_CHIP 38387
#define IDS_MEDIA_CAPTURE_VIDEO_AND_AUDIO_PERMISSION_CHIP 38388
#define IDS_CLIPBOARD_PERMISSION_CHIP 38389
#define IDS_SAA_PERMISSION_CHIP 38390
#define IDS_IDLE_DETECTION_PERMISSION_CHIP 38391
#define IDS_KEYBOARD_LOCK_PERMISSION_CHIP 38392
#define IDS_KEYBOARD_AND_POINTER_LOCK_PERMISSION_CHIP 38393
#define IDS_POINTER_LOCK_PERMISSION_CHIP 38394
#define IDS_WEB_APP_INSTALLATION_PERMISSION_CHIP 38395
#define IDS_MOTION_AND_LIGHT_SENSORS_PERMISSION_CHIP 38396
#define IDS_MOTION_SENSORS_PERMISSION_CHIP 38397
#define IDS_AR_PERMISSION_CHIP 38398
#define IDS_PERMISSIONS_AR_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38399
#define IDS_PERMISSIONS_AR_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38400
#define IDS_PERMISSIONS_AR_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38401
#define IDS_VR_PERMISSION_CHIP 38402
#define IDS_PERMISSIONS_VR_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38403
#define IDS_PERMISSIONS_VR_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38404
#define IDS_PERMISSIONS_VR_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38405
#define IDS_HAND_TRACKING_PERMISSION_CHIP 38406
#define IDS_HAND_TRACKING_PERMISSION_BLOCKED_CHIP 38407
#define IDS_PERMISSIONS_HAND_TRACKING_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38408
#define IDS_PERMISSIONS_HAND_TRACKING_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38409
#define IDS_PERMISSIONS_HAND_TRACKING_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38410
#define IDS_GEOLOCATION_PERMISSION_BLOCKED_CHIP 38411
#define IDS_NOTIFICATION_PERMISSIONS_BLOCKED_CHIP 38412
#define IDS_CAPTURED_SURFACE_CONTROL_PERMISSION_CHIP 38413
#define IDS_CAPTURED_SURFACE_CONTROL_PERMISSION_BLOCKED_CHIP 38414
#define IDS_PERMISSIONS_CAPTURED_SURFACE_CONTROL_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38415
#define IDS_PERMISSIONS_CAPTURED_SURFACE_CONTROL_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38416
#define IDS_PERMISSIONS_PERMISSION_ALLOWED_CONFIRMATION 38417
#define IDS_PERMISSIONS_PERMISSION_ALLOWED_ONCE_CONFIRMATION 38418
#define IDS_PERMISSIONS_PERMISSION_NOT_ALLOWED_CONFIRMATION 38419
#define IDS_PERMISSIONS_NOTIFICATION_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38420
#define IDS_PERMISSIONS_NOTIFICATION_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38421
#define IDS_PERMISSIONS_GEOLOCATION_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38422
#define IDS_PERMISSIONS_GEOLOCATION_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38423
#define IDS_PERMISSIONS_GEOLOCATION_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38424
#define IDS_PERMISSIONS_CAMERA_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38425
#define IDS_PERMISSIONS_CAMERA_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38426
#define IDS_PERMISSIONS_CAMERA_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38427
#define IDS_PERMISSIONS_MICROPHONE_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38428
#define IDS_PERMISSIONS_MICROPHONE_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38429
#define IDS_PERMISSIONS_MICROPHONE_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38430
#define IDS_PERMISSIONS_CAMERA_AND_MICROPHONE_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38431
#define IDS_PERMISSIONS_CAMERA_AND_MICROPHONE_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38432
#define IDS_PERMISSIONS_CAMERA_AND_MICROPHONE_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38433
#define IDS_PERMISSIONS_SAA_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38434
#define IDS_PERMISSIONS_SAA_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38435
#define IDS_PERMISSIONS_KEYBOARD_LOCK_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38436
#define IDS_PERMISSIONS_KEYBOARD_LOCK_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38437
#define IDS_PERMISSIONS_POINTER_LOCK_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38438
#define IDS_PERMISSIONS_POINTER_LOCK_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38439
#define IDS_PERMISSIONS_WEB_INSTALL_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38440
#define IDS_PERMISSIONS_WEB_INSTALL_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38441
#define IDS_PERMISSIONS_MOTION_AND_LIGHT_SENSORS_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38442
#define IDS_PERMISSIONS_MOTION_AND_LIGHT_SENSORS_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38443
#define IDS_PERMISSIONS_MOTION_AND_LIGHT_SENSORS_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38444
#define IDS_PERMISSIONS_MOTION_SENSORS_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38445
#define IDS_PERMISSIONS_MOTION_SENSORS_ALLOWED_ONCE_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38446
#define IDS_PERMISSIONS_MOTION_SENSORS_NOT_ALLOWED_CONFIRMATION_SCREENREADER_ANNOUNCEMENT 38447
#define IDS_REQUEST_QUOTA_INFOBAR_TEXT 38451
#define IDS_REQUEST_LARGE_QUOTA_INFOBAR_TEXT 38452
#define IDS_REQUEST_QUOTA_PERMISSION_FRAGMENT 38453
#define IDS_EMBEDDED_PROMPT_ADMIN_BLOCKED 38454
#define IDS_EMBEDDED_PROMPT_ADMIN_ALLOWED 38455
#define IDS_EMBEDDED_PROMPT_PREVIOUSLY_ALLOWED 38456
#define IDS_EMBEDDED_PROMPT_PREVIOUSLY_NOT_ALLOWED 38457
#define IDS_PERMISSION_OFF_FOR_CHROME 38458
#define IDS_PERMISSION_CHROME_NEEDS_PERMISSION 38459
#define IDS_GEOLOCATION_NAME_FRAGMENT 38460
#define IDS_CAMERA_PERMISSION_NAME_FRAGMENT 38461
#define IDS_MICROPHONE_PERMISSION_NAME_FRAGMENT 38462
#define IDS_CAMERA_AND_MICROPHONE_PERMISSION_NAME_FRAGMENT 38463
#define IDS_MACOS_NAME_FRAGMENT 38464
#define IDS_WINDOWS_NAME_FRAGMENT 38465
#define IDS_CHROMEOS_NAME_FRAGMENT 38466
#define IDS_EMBEDDED_PROMPT_OK_LABEL 38468
#define IDS_EMBEDDED_PROMPT_CONTINUE_ALLOWING 38469
#define IDS_EMBEDDED_PROMPT_STOP_ALLOWING 38470
#define IDS_EMBEDDED_PROMPT_OPEN_SYSTEM_SETTINGS 38472
#define IDS_EMBEDDED_PROMPT_CONTINUE_NOT_ALLOWING 38473
#define IDS_PERMISSION_PROMPT_SURVEY_CUSTOM_INVITATION 38474
#define IDS_POLICY_DM_STATUS_SUCCESS 38478
#define IDS_POLICY_DM_STATUS_REQUEST_INVALID 38479
#define IDS_POLICY_DM_STATUS_REQUEST_FAILED 38480
#define IDS_POLICY_DM_STATUS_TEMPORARY_UNAVAILABLE 38481
#define IDS_POLICY_DM_STATUS_HTTP_STATUS_ERROR 38482
#define IDS_POLICY_DM_STATUS_RESPONSE_DECODING_ERROR 38483
#define IDS_POLICY_DM_STATUS_SERVICE_MANAGEMENT_NOT_SUPPORTED 38484
#define IDS_POLICY_DM_STATUS_SERVICE_DEVICE_NOT_FOUND 38485
#define IDS_POLICY_DM_STATUS_SERVICE_MANAGEMENT_TOKEN_INVALID 38486
#define IDS_POLICY_DM_STATUS_SERVICE_ACTIVATION_PENDING 38487
#define IDS_POLICY_DM_STATUS_SERVICE_INVALID_SERIAL_NUMBER 38488
#define IDS_POLICY_DM_STATUS_SERVICE_DEVICE_ID_CONFLICT 38489
#define IDS_POLICY_DM_STATUS_SERVICE_MISSING_LICENSES 38490
#define IDS_POLICY_DM_STATUS_SERVICE_DEPROVISIONED 38491
#define IDS_POLICY_DM_STATUS_SERVICE_POLICY_NOT_FOUND 38492
#define IDS_POLICY_DM_STATUS_UNKNOWN_ERROR 38493
#define IDS_POLICY_DM_STATUS_INVALID_PACKAGED_DEVICE_FOR_KIOSK 38494
#define IDS_POLICY_DM_STATUS_ORG_UNIT_ENROLLMENT_LIMIT_EXCEEDED 38495
#define IDS_POLICY_DM_STATUS_SERVICE_DOMAIN_MISMATCH 38496
#define IDS_POLICY_DM_STATUS_CANNOT_SIGN_REQUEST 38497
#define IDS_POLICY_DM_STATUS_REQUEST_TOO_LARGE 38498
#define IDS_POLICY_DM_STATUS_SERVICE_TOO_MANY_REQUESTS 38499
#define IDS_POLICY_DM_STATUS_SERVICE_DEVICE_NEEDS_RESET 38500
#define IDS_POLICY_DM_STATUS_CONSUMER_ACCOUNT_WITH_PACKAGED_LICENSE 38501
#define IDS_POLICY_DM_STATUS_ENTERPRISE_ACCOUNT_IS_NOT_ELIGIBLE_TO_ENROLL 38502
#define IDS_POLICY_ACTION_BLOCKED_BY_ORGANIZATION 38503
#define IDS_POLICY_ACTION_FORCED_SAVE_TO_CLOUD 38504
#define IDS_POLICY_VALIDATION_OK 38505
#define IDS_POLICY_VALIDATION_BAD_INITIAL_SIGNATURE 38506
#define IDS_POLICY_VALIDATION_BAD_SIGNATURE 38507
#define IDS_POLICY_VALIDATION_ERROR_CODE_PRESENT 38508
#define IDS_POLICY_VALIDATION_PAYLOAD_PARSE_ERROR 38509
#define IDS_POLICY_VALIDATION_WRONG_POLICY_TYPE 38510
#define IDS_POLICY_VALIDATION_WRONG_SETTINGS_ENTITY_ID 38511
#define IDS_POLICY_VALIDATION_BAD_TIMESTAMP 38512
#define IDS_POLICY_VALIDATION_BAD_DM_TOKEN 38513
#define IDS_POLICY_VALIDATION_BAD_DEVICE_ID 38514
#define IDS_POLICY_VALIDATION_BAD_USER 38515
#define IDS_POLICY_VALIDATION_POLICY_PARSE_ERROR 38516
#define IDS_POLICY_VALIDATION_BAD_KEY_VERIFICATION_SIGNATURE 38517
#define IDS_POLICY_VALIDATION_VALUE_WARNING 38518
#define IDS_POLICY_VALIDATION_VALUE_ERROR 38519
#define IDS_POLICY_VALIDATION_UNKNOWN_ERROR 38520
#define IDS_POLICY_STORE_STATUS_OK 38521
#define IDS_POLICY_STORE_STATUS_LOAD_ERROR 38522
#define IDS_POLICY_STORE_STATUS_STORE_ERROR 38523
#define IDS_POLICY_STORE_STATUS_PARSE_ERROR 38524
#define IDS_POLICY_STORE_STATUS_SERIALIZE_ERROR 38525
#define IDS_POLICY_STORE_STATUS_VALIDATION_ERROR 38526
#define IDS_POLICY_STORE_STATUS_BAD_STATE 38527
#define IDS_POLICY_STORE_STATUS_UNKNOWN_ERROR 38528
#define IDS_POLICY_ASSOCIATION_STATE_ACTIVE 38529
#define IDS_POLICY_ASSOCIATION_STATE_UNMANAGED 38530
#define IDS_POLICY_ASSOCIATION_STATE_DEPROVISIONED 38531
#define IDS_POLICY_TYPE_ERROR 38532
#define IDS_POLICY_OUT_OF_RANGE_ERROR 38533
#define IDS_POLICY_VALUE_FORMAT_ERROR 38534
#define IDS_POLICY_INVALID_FILE_EXTENSION_ERROR 38535
#define IDS_POLICY_INVALID_HASH_ERROR 38536
#define IDS_POLICY_INVALID_SELECTION_ERROR 38537
#define IDS_POLICY_PAPER_SIZE_CUSTOM_NO_SIZE_ERROR 38538
#define IDS_POLICY_PAPER_SIZE_NOT_CUSTOM_ERROR 38539
#define IDS_POLICY_INVALID_ACCOUNT_PATTERN_FORMAT_ERROR 38540
#define IDS_POLICY_INVALID_PROTOCOL_ERROR 38541
#define IDS_POLICY_INVALID_ORIGIN_ERROR 38542
#define IDS_POLICY_EMPTY_ORIGIN_LIST_ERROR 38543
#define IDS_POLICY_INVALID_EXTENSION_ID_ERROR 38545
#define IDS_POLICY_INVALID_UPDATE_URL_ERROR 38546
#define IDS_POLICY_URL_PATH_SPECIFIED_ERROR 38547
#define IDS_POLICY_MISSING_VENDOR_ID_ERROR 38548
#define IDS_POLICY_INVALID_NUMBER_OF_URLS_ERROR 38549
#define IDS_POLICY_BRUSCHETTA_UNINSTALLABLE_ERROR 38550
#define IDS_POLICY_CLOUD_SOURCE_ONLY_ERROR 38551
#define IDS_POLICY_CLOUD_USER_ONLY_ERROR 38552
#define IDS_POLICY_CLOUD_MANAGEMENT_ENROLLMENT_ONLY_ERROR 38553
#define IDS_POLICY_DEFAULT_SEARCH_DISABLED 38554
#define IDS_POLICY_NOT_SPECIFIED_ERROR 38555
#define IDS_POLICY_EXTENSION_SETTINGS_ORIGIN_LIMIT_WARNING 38556
#define IDS_POLICY_URL_ALLOW_BLOCK_LIST_MAX_FILTERS_LIMIT_WARNING 38557
#define IDS_POLICY_ERROR_WITH_PATH 38558
#define IDS_POLICY_SCHEMA_VALIDATION_ERROR 38559
#define IDS_POLICY_INVALID_JSON_ERROR 38560
#define IDS_POLICY_INVALID_URL_ERROR 38561
#define IDS_POLICY_URL_NOT_HTTPS_ERROR 38562
#define IDS_POLICY_INVALID_SEARCH_URL_ERROR 38563
#define IDS_POLICY_INVALID_SECURE_DNS_MODE_ERROR 38564
#define IDS_POLICY_SECURE_DNS_TEMPLATES_INVALID_ERROR 38565
#define IDS_POLICY_SECURE_DNS_SALT_INVALID_ERROR 38566
#define IDS_POLICY_SECURE_DNS_SALT_INVALID_SIZE_ERROR 38567
#define IDS_POLICY_SECURE_DNS_TEMPLATES_IRRELEVANT_MODE_ERROR 38568
#define IDS_POLICY_SECURE_DNS_TEMPLATES_INVALID_MODE_ERROR 38569
#define IDS_POLICY_SECURE_DNS_TEMPLATES_UNSET_MODE_ERROR 38570
#define IDS_POLICY_SECURE_DNS_TEMPLATES_NOT_SPECIFIED_ERROR 38571
#define IDS_POLICY_INVALID_PROXY_MODE_ERROR 38572
#define IDS_POLICY_OFF_CWS_URL_ERROR 38574
#define IDS_POLICY_HOMEPAGE_LOCATION_ERROR 38575
#define IDS_POLICY_PROXY_MODE_DISABLED_ERROR 38576
#define IDS_POLICY_PROXY_MODE_AUTO_DETECT_ERROR 38577
#define IDS_POLICY_PROXY_MODE_PAC_URL_ERROR 38578
#define IDS_POLICY_PROXY_MODE_FIXED_SERVERS_ERROR 38579
#define IDS_POLICY_PROXY_MODE_SYSTEM_ERROR 38580
#define IDS_POLICY_PROXY_BOTH_SPECIFIED_ERROR 38581
#define IDS_POLICY_PROXY_NEITHER_SPECIFIED_ERROR 38582
#define IDS_POLICY_PROXY_UNKNOWN_CONDITION 38583
#define IDS_POLICY_PROXY_INVALID_SCHEME_HOST_PORT 38584
#define IDS_POLICY_PROXY_INVALID_PROXY 38585
#define IDS_POLICY_PROXY_INVALID_DESTINATION 38586
#define IDS_POLICY_UNAFFILIATED_USER_ERROR 38587
#define IDS_POLICY_DEVELOPER_TOOLS_EXTENSIONS_CONFLICT_MESSAGE 38588
#define IDS_POLICY_OVERRIDDEN 38589
#define IDS_POLICY_VALUE_DEPRECATED 38590
#define IDS_POLICY_DEPENDENCY_ERROR 38591
#define IDS_POLICY_DEPENDENCY_ERROR_ANY_VALUE 38592
#define IDS_POLICY_IDLE_TIMEOUT_ACTIONS_DEPENDENCY_ERROR 38593
#define IDS_POLICY_USER_IS_NOT_AFFILIATED_ERROR 38594
#define IDS_POLICY_LEVEL_ERROR 38599
#define IDS_POLICY_OK 38600
#define IDS_POLICY_UNSET 38601
#define IDS_POLICY_UNKNOWN 38602
#define IDS_POLICY_PROTO_PARSING_ERROR 38603
#define IDS_POLICY_HEX_COLOR_ERROR 38604
#define IDS_POLICY_SITE_SEARCH_SETTINGS_MAX_PROVIDERS_LIMIT_ERROR 38605
#define IDS_POLICY_SITE_SEARCH_SETTINGS_MAX_FEATURED_PROVIDERS_LIMIT_ERROR 38606
#define IDS_POLICY_SITE_SEARCH_SETTINGS_DUPLICATED_SHORTCUT 38607
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_CONTAINS_SPACE 38608
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_STARTS_WITH_AT 38609
#define IDS_SEARCH_POLICY_SETTINGS_NO_VALID_PROVIDER 38610
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_IS_EMPTY 38611
#define IDS_SEARCH_POLICY_SETTINGS_NAME_IS_EMPTY 38612
#define IDS_SEARCH_POLICY_SETTINGS_URL_IS_EMPTY 38613
#define IDS_SEARCH_POLICY_SETTINGS_URL_DOESNT_SUPPORT_REPLACEMENT 38614
#define IDS_SEARCH_POLICY_SETTINGS_SHORTCUT_EQUALS_DSP_KEYWORD 38615
#define IDS_POLICY_SITE_SEARCH_SETTINGS_SHORTCUT_EQUALS_SEARCH_AGGREGATOR_KEYWORD 38616
#define IDS_SEARCH_POLICY_SETTINGS_URL_NOT_HTTPS 38617
#define IDS_POLICY_DATA_CONTROLS_MUTUALLY_EXCLUSIVE_KEYS 38618
#define IDS_POLICY_DATA_CONTROLS_MUTUALLY_EXCLUSIVE_KEY_SETS 38619
#define IDS_POLICY_DATA_CONTROLS_UNSUPPORTED_CONDITION 38620
#define IDS_POLICY_DATA_CONTROLS_UNSUPPORTED_RESTRICTION 38621
#define IDS_POLICY_DATA_CONTROLS_UNSUPPORTED_LEVEL 38622
#define IDS_POLICY_NTP_SHORTCUTS_MAX_SHORTCUTS_LIMIT_ERROR 38623
#define IDS_POLICY_NTP_SHORTCUTS_NO_VALID_PROVIDER 38624
#define IDS_POLICY_NTP_SHORTCUTS_DUPLICATED_URL 38625
#define IDS_POLICY_NTP_SHORTCUTS_NAME_TOO_LONG 38626
#define IDS_POLICY_NTP_SHORTCUTS_URL_TOO_LONG 38627
#define IDS_POLICY_TITLE 38628
#define IDS_POLICY_FILTER_PLACEHOLDER 38629
#define IDS_POLICY_RELOAD_POLICIES 38630
#define IDS_POLICY_RELOADING_POLICIES 38631
#define IDS_POLICY_RELOAD_POLICIES_DONE 38632
#define IDS_EXPORT_POLICIES_JSON 38633
#define IDS_EXPORT_POLICIES_JSON_DONE 38634
#define IDS_UPLOAD_REPORT 38635
#define IDS_REPORT_UPLOADING 38636
#define IDS_REPORT_UPLOADED 38637
#define IDS_POLICY_STATUS 38638
#define IDS_POLICY_STATUS_DEVICE 38639
#define IDS_POLICY_STATUS_USER 38640
#define IDS_POLICY_STATUS_MACHINE 38641
#define IDS_POLICY_STATUS_ERROR_MANAGED_NO_POLICY 38643
#define IDS_POLICY_STATUS_FLEX_ORG_NO_POLICY 38644
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_DOMAIN 38645
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_TOKEN 38646
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_DEVICE_ID 38647
#define IDS_POLICY_LABEL_MACHINE_ENROLLMENT_MACHINE_NAME 38648
#define IDS_POLICY_LABEL_USERNAME 38649
#define IDS_POLICY_LABEL_GAIA_ID 38650
#define IDS_POLICY_LABEL_CLIENT_ID 38651
#define IDS_POLICY_LABEL_PROFILE_ID 38652
#define IDS_POLICY_LABEL_ASSET_ID 38653
#define IDS_POLICY_LABEL_LOCATION 38654
#define IDS_POLICY_LABEL_DIRECTORY_API_ID 38655
#define IDS_POLICY_LABEL_MANAGED_BY 38656
#define IDS_POLICY_LABEL_TIME_SINCE_LAST_FETCH_ATTEMPT 38657
#define IDS_POLICY_LABEL_TIME_SINCE_LAST_REFRESH 38658
#define IDS_POLICY_LABEL_POLICY_FETCH 38659
#define IDS_POLICY_LABEL_EXTENSION_INSTALL_POLICY_FETCH 38660
#define IDS_POLICY_LABEL_LAST_CLOUD_REPORT_SENT_TIMESTAMP 38661
#define IDS_POLICY_NOT_SPECIFIED 38662
#define IDS_POLICY_LABEL_PUSH_POLICIES 38663
#define IDS_POLICY_PUSH_POLICIES_ON 38664
#define IDS_POLICY_PUSH_POLICIES_OFF 38665
#define IDS_POLICY_NEVER_FETCHED 38666
#define IDS_POLICY_LABEL_REFRESH_INTERVAL 38667
#define IDS_POLICY_LABEL_CONFLICT 38668
#define IDS_POLICY_LABEL_SUPERSEDING 38669
#define IDS_POLICY_LABEL_CONFLICT_VALUE 38670
#define IDS_POLICY_LABEL_SUPERSEDED_VALUE 38671
#define IDS_POLICY_LABEL_ERROR 38672
#define IDS_POLICY_LABEL_DEPRECATED 38673
#define IDS_POLICY_LABEL_FUTURE 38674
#define IDS_POLICY_LABEL_IGNORED 38675
#define IDS_POLICY_LABEL_VALUE 38676
#define IDS_POLICY_LABEL_VERSION 38677
#define IDS_POLICY_LABEL_STATUS 38678
#define IDS_POLICY_LABEL_INFO 38679
#define IDS_POLICY_LABEL_PRECEDENCE 38680
#define IDS_POLICY_SHOW_UNSET 38681
#define IDS_POLICY_NO_POLICIES_SET 38682
#define IDS_POLICY_HEADER_SCOPE 38683
#define IDS_POLICY_HEADER_LEVEL 38684
#define IDS_POLICY_HEADER_NAMESPACE 38685
#define IDS_POLICY_HEADER_NAME 38686
#define IDS_POLICY_HEADER_VALUE 38687
#define IDS_POLICY_HEADER_STATUS 38688
#define IDS_POLICY_HEADER_SOURCE 38689
#define IDS_POLICY_HEADER_WARNING 38690
#define IDS_POLICY_SHOW_MORE 38691
#define IDS_POLICY_SHOW_LESS 38692
#define IDS_POLICY_LEARN_MORE 38693
#define IDS_POLICY_SCOPE_USER 38694
#define IDS_POLICY_SCOPE_ALL_USERS 38695
#define IDS_POLICY_SCOPE_DEVICE 38696
#define IDS_POLICY_LEVEL_RECOMMENDED 38697
#define IDS_POLICY_LEVEL_MANDATORY 38698
#define IDS_POLICY_SOURCE_ENTERPRISE_DEFAULT 38699
#define IDS_POLICY_SOURCE_DEFAULT 38700
#define IDS_POLICY_SOURCE_COMMAND_LINE 38701
#define IDS_POLICY_SOURCE_CLOUD 38702
#define IDS_POLICY_SOURCE_MERGED 38703
#define IDS_POLICY_SOURCE_CLOUD_FROM_ASH 38704
#define IDS_POLICY_SOURCE_RESTRICTED_MANAGED_GUEST_SESSION_OVERRIDE 38705
#define IDS_POLICY_SOURCE_ACTIVE_DIRECTORY 38706
#define IDS_POLICY_SOURCE_PLATFORM 38707
#define IDS_POLICY_SOURCE_DEVICE_LOCAL_ACCOUNT_OVERRIDE 38708
#define IDS_POLICY_RISK_TAG_FULL_ADMIN_ACCESS 38709
#define IDS_POLICY_RISK_TAG_SYSTEM_SECURITY 38710
#define IDS_POLICY_RISK_TAG_WEBSITE_SHARING 38711
#define IDS_POLICY_RISK_TAG_ADMIN_SHARING 38712
#define IDS_POLICY_RISK_TAG_FILTERING 38713
#define IDS_POLICY_RISK_TAG_LOCAL_DATA_ACCESS 38714
#define IDS_POLICY_RISK_TAG_GOOGLE_SHARING 38715
#define IDS_POLICY_SHOW_EXPANDED_STATUS 38716
#define IDS_POLICY_HIDE_EXPANDED_STATUS 38717
#define IDS_POLICY_LIST_MERGING_WRONG_POLICY_TYPE_SPECIFIED 38718
#define IDS_POLICY_DICTIONARY_MERGING_WRONG_POLICY_TYPE_SPECIFIED 38719
#define IDS_POLICY_DICTIONARY_MERGING_POLICY_NOT_ALLOWED 38720
#define IDS_POLICY_CONFLICT_SAME_VALUE 38721
#define IDS_POLICY_CONFLICT_DIFF_VALUE 38722
#define IDS_POLICY_USES_SAME_LOCAL_STATE_AND_PROFILE_PREFS 38723
#define IDS_POLICY_USES_LOCAL_STATE_AND_PROFILE_PREFS 38724
#define IDS_POLICY_MIGRATED_OLD_POLICY 38725
#define IDS_POLICY_MIGRATED_NEW_POLICY 38726
#define IDS_POLICY_BLOCKED 38727
#define IDS_POLICY_INVALID 38728
#define IDS_POLICY_IGNORED_BY_GROUP_MERGING 38729
#define IDS_POLICY_INVALID_VALUE 38730
#define IDS_POLICY_IGNORED_MANDATORY_REPORTING_POLICY 38731
#define IDS_POLICY_IGNORED_CHROME_PROFILE 38732
#define IDS_POLICY_IGNORED_UNAFFILIATED 38733
#define IDS_POLICY_IGNORED_EXTENSION 38734
#define IDS_POLICY_PRECEDENCE_PLATFORM_MACHINE 38735
#define IDS_POLICY_PRECEDENCE_PLATFORM_USER 38736
#define IDS_POLICY_PRECEDENCE_CLOUD_MACHINE 38737
#define IDS_POLICY_PRECEDENCE_CLOUD_USER 38738
#define IDS_POLICY_SPELLCHECK_UNKNOWN_LANGUAGE 38739
#define IDS_POLICY_SPELLCHECK_BLOCKLIST_IGNORE 38740
#define IDS_POLICY_DEFAULT_GEO_POLICY_ARC_CONFLICT 38741
#define IDS_POLICY_LABEL_IS_AFFILIATED 38742
#define IDS_POLICY_IS_AFFILIATED_YES 38743
#define IDS_POLICY_IS_AFFILIATED_NO 38744
#define IDS_POLICY_LABEL_IS_OFFHOURS_ACTIVE 38745
#define IDS_POLICY_OFFHOURS_ACTIVE 38746
#define IDS_POLICY_OFFHOURS_NOT_ACTIVE 38747
#define IDS_POLICY_SIGNIN_PROFILE 38748
#define IDS_POLICY_COPY_VALUE 38749
#define IDS_COPY_POLICIES_JSON 38750
#define IDS_COPY_POLICIES_DONE 38751
#define IDS_VIEW_POLICY_LOGS 38752
#define IDS_POLICY_MORE_ACTIONS 38753
#define IDS_POLICY_TABLE_COLUMN_SORT 38754
#define IDS_POLICY_TABLE_COLUMN_SORT_ASCENDING 38755
#define IDS_POLICY_TABLE_COLUMN_SORT_DESCENDING 38756
#define IDS_POLICY_BANNER_PROMOTION_TITLE 38757
#define IDS_POLICY_BANNER_PROMOTION_DESC 38758
#define IDS_POLICY_BANNER_PROMOTION_BTN 38759
#define IDS_DEVTOOLS_BLOCKED_BY_POLICY 38760
#define IDS_DEVTOOLS_NOT_ALLOWED 38761
#define IDS_POLICY_LOGS_TITLE 38762
#define IDS_POLICY_LOGS_FILTER_PLACEHOLDER 38763
#define IDS_VERSION_INFO 38764
#define IDS_EXPORT_POLICY_LOGS_JSON 38765
#define IDS_REFRESH_POLICY_LOGS 38766
#define IDS_POLICY_TEST_TITLE 38767
#define IDS_POLICY_TEST_RESTART_AND_APPLY 38768
#define IDS_POLICY_TEST_APPLY 38769
#define IDS_POLICY_TEST_IMPORT 38770
#define IDS_POLICY_TEST_DESC 38771
#define IDS_POLICY_TEST_REVERT 38772
#define IDS_POLICY_TEST_TABLE_SCOPE 38773
#define IDS_POLICY_TEST_ADD 38774
#define IDS_POLICY_SELECT_NAME 38775
#define IDS_POLICY_TEST_TABLE_PRESET 38776
#define IDS_LOCAL_TEST_POLICIES_ENABLED 38777
#define IDS_POLICY_TEST_PRESET_CUSTOM 38778
#define IDS_POLICY_TEST_PRESET_LOCAL_MACHINE 38779
#define IDS_POLICY_TEST_PRESET_CLOUD_ACCOUNT 38780
#define IDS_POLICY_TEST_USER_AFFILIATED 38781
#define IDS_CHROME_URLS_DISABLED_PAGE_HEADER 38782
#define IDS_CHROME_URLS_DISABLED_PAGE_TITLE 38783
#define IDS_CHROME_URLS_DISABLED_PAGE_MESSAGE 38784
#define IDS_POLICY_DLP_CLIPBOARD_BLOCKED_ON_PASTE 38785
#define IDS_POLICY_DLP_CLIPBOARD_BLOCKED_ON_COPY_VM 38786
#define IDS_POLICY_DLP_CLIPBOARD_BLOCK_TOAST_BUTTON 38787
#define IDS_POLICY_DLP_ANDROID_APPS 38788
#define IDS_POLICY_DLP_CLIPBOARD_BLOCK_DISMISS_BUTTON 38789
#define IDS_POLICY_DLP_CLIPBOARD_WARN_ON_PASTE 38790
#define IDS_POLICY_DLP_CLIPBOARD_WARN_PROCEED_BUTTON 38791
#define IDS_POLICY_DLP_CLIPBOARD_WARN_ON_COPY_VM 38792
#define IDS_POLICY_DLP_PRINTING_BLOCKED_TITLE 38793
#define IDS_POLICY_DLP_PRINTING_BLOCKED_MESSAGE 38794
#define IDS_POLICY_DLP_PRINTING_WARN_TITLE 38795
#define IDS_POLICY_DLP_PRINTING_WARN_MESSAGE 38796
#define IDS_POLICY_DLP_PRINTING_WARN_CONTINUE_BUTTON 38797
#define IDS_POLICY_DLP_SCREEN_SHARE_BLOCKED_TITLE 38798
#define IDS_POLICY_DLP_SCREEN_SHARE_BLOCKED_MESSAGE 38799
#define IDS_POLICY_DLP_SCREEN_SHARE_PAUSED_TITLE 38800
#define IDS_POLICY_DLP_SCREEN_SHARE_PAUSED_MESSAGE 38801
#define IDS_POLICY_DLP_SCREEN_SHARE_RESUMED_TITLE 38802
#define IDS_POLICY_DLP_SCREEN_SHARE_RESUMED_MESSAGE 38803
#define IDS_POLICY_DLP_SCREEN_CAPTURE_DISABLED_TITLE 38804
#define IDS_POLICY_DLP_SCREEN_CAPTURE_DISABLED_MESSAGE 38805
#define IDS_POLICY_DLP_VIDEO_CAPTURE_STOPPED_TITLE 38806
#define IDS_POLICY_DLP_VIDEO_CAPTURE_STOPPED_MESSAGE 38807
#define IDS_POLICY_DLP_SCREEN_SHARE_WARN_TITLE 38808
#define IDS_POLICY_DLP_SCREEN_SHARE_WARN_MESSAGE 38809
#define IDS_POLICY_DLP_SCREEN_SHARE_WARN_CONTINUE_BUTTON 38810
#define IDS_POLICY_DLP_SCREEN_CAPTURE_WARN_TITLE 38811
#define IDS_POLICY_DLP_SCREEN_CAPTURE_WARN_MESSAGE 38812
#define IDS_POLICY_DLP_SCREEN_CAPTURE_WARN_CONTINUE_BUTTON 38813
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_TITLE 38814
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_MESSAGE 38815
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_CONTINUE_BUTTON 38816
#define IDS_POLICY_DLP_VIDEO_CAPTURE_WARN_CANCEL_BUTTON 38817
#define IDS_POLICY_DLP_FILES_DOWNLOAD_WARN_TITLE 38818
#define IDS_POLICY_DLP_FILES_TRANSFER_WARN_TITLE 38819
#define IDS_POLICY_DLP_FILES_UPLOAD_WARN_TITLE 38820
#define IDS_POLICY_DLP_FILES_MOVE_WARN_TITLE 38821
#define IDS_POLICY_DLP_FILES_COPY_WARN_TITLE 38822
#define IDS_POLICY_DLP_FILES_OPEN_WARN_TITLE 38823
#define IDS_POLICY_DLP_FILES_DOWNLOAD_REVIEW_TITLE 38824
#define IDS_POLICY_DLP_FILES_TRANSFER_REVIEW_TITLE 38825
#define IDS_POLICY_DLP_FILES_UPLOAD_REVIEW_TITLE 38826
#define IDS_POLICY_DLP_FILES_MOVE_REVIEW_TITLE 38827
#define IDS_POLICY_DLP_FILES_COPY_REVIEW_TITLE 38828
#define IDS_POLICY_DLP_FILES_OPEN_REVIEW_TITLE 38829
#define IDS_POLICY_DLP_FILES_DOWNLOAD_WARN_MESSAGE 38830
#define IDS_POLICY_DLP_FILES_TRANSFER_WARN_MESSAGE 38831
#define IDS_POLICY_DLP_FILES_UPLOAD_WARN_MESSAGE 38832
#define IDS_POLICY_DLP_FILES_MOVE_WARN_MESSAGE 38833
#define IDS_POLICY_DLP_FILES_COPY_WARN_MESSAGE 38834
#define IDS_POLICY_DLP_FILES_OPEN_WARN_MESSAGE 38835
#define IDS_POLICY_DLP_FILES_WARN_MESSAGE 38836
#define IDS_POLICY_DLP_FILES_DOWNLOAD_WARN_CONTINUE_BUTTON 38837
#define IDS_POLICY_DLP_FILES_TRANSFER_WARN_CONTINUE_BUTTON 38838
#define IDS_POLICY_DLP_FILES_UPLOAD_WARN_CONTINUE_BUTTON 38839
#define IDS_POLICY_DLP_FILES_MOVE_WARN_CONTINUE_BUTTON 38840
#define IDS_POLICY_DLP_FILES_COPY_WARN_CONTINUE_BUTTON 38841
#define IDS_POLICY_DLP_FILES_OPEN_WARN_CONTINUE_BUTTON 38842
#define IDS_POLICY_DLP_FILES_DESTINATION_REMOVABLE_STORAGE 38843
#define IDS_POLICY_DLP_FILES_REVIEW_BUTTON 38844
#define IDS_POLICY_DLP_FILES_DISMISS_BUTTON 38845
#define IDS_POLICY_DLP_FILES_OK_BUTTON 38846
#define IDS_POLICY_DLP_WARN_CANCEL_BUTTON 38847
#define IDS_POLICY_DLP_CLIPBOARD_BUBBLE_MESSAGE 38848
#define IDS_POLICY_DLP_FROM_YOUR_ADMIN_MESSAGE 38849
#define IDS_POLICY_DLP_FILES_DOWNLOAD_BLOCK_TITLE 38850
#define IDS_POLICY_DLP_FILES_DOWNLOAD_BLOCK_MESSAGE 38851
#define IDS_POLICY_DLP_FILES_UPLOAD_BLOCK_TITLE 38852
#define IDS_POLICY_DLP_FILES_UPLOAD_BLOCK_MESSAGE 38853
#define IDS_POLICY_DLP_FILES_OPEN_BLOCK_TITLE 38854
#define IDS_POLICY_DLP_FILES_OPEN_BLOCK_MESSAGE 38855
#define IDS_POLICY_DLP_FILES_DOWNLOAD_BLOCKED_TITLE 38856
#define IDS_POLICY_DLP_FILES_TRANSFER_BLOCKED_TITLE 38857
#define IDS_POLICY_DLP_FILES_UPLOAD_BLOCKED_TITLE 38858
#define IDS_POLICY_DLP_FILES_MOVE_BLOCKED_TITLE 38859
#define IDS_POLICY_DLP_FILES_COPY_BLOCKED_TITLE 38860
#define IDS_POLICY_DLP_FILES_OPEN_BLOCKED_TITLE 38861
#define IDS_POLICY_DLP_FILES_POLICY_BLOCK_SINGLE_FILE_MESSAGE 38862
#define IDS_POLICY_DLP_FILES_POLICY_BLOCK_MESSAGE 38863
#define IDS_POLICY_DLP_FILES_CONTENT_BLOCK_SINGLE_FILE_MESSAGE 38864
#define IDS_POLICY_DLP_FILES_CONTENT_BLOCK_MESSAGE 38865
#define IDS_POLICY_DLP_FILES_BLOCK_MESSAGE 38866
#define IDS_POLICY_DLP_FILES_DOWNLOAD_JUSTIFICATION_LABEL 38867
#define IDS_POLICY_DLP_FILES_UPLOAD_JUSTIFICATION_LABEL 38868
#define IDS_POLICY_DLP_FILES_COPY_JUSTIFICATION_LABEL 38869
#define IDS_POLICY_DLP_FILES_MOVE_JUSTIFICATION_LABEL 38870
#define IDS_POLICY_DLP_FILES_OPEN_JUSTIFICATION_LABEL 38871
#define IDS_POLICY_DLP_FILES_TRANSFER_JUSTIFICATION_LABEL 38872
#define IDS_POLICY_DLP_FILES_DOWNLOAD_TIMEOUT_TITLE 38873
#define IDS_POLICY_DLP_FILES_TRANSFER_TIMEOUT_TITLE 38874
#define IDS_POLICY_DLP_FILES_UPLOAD_TIMEOUT_TITLE 38875
#define IDS_POLICY_DLP_FILES_MOVE_TIMEOUT_TITLE 38876
#define IDS_POLICY_DLP_FILES_COPY_TIMEOUT_TITLE 38877
#define IDS_POLICY_DLP_FILES_OPEN_TIMEOUT_TITLE 38878
#define IDS_POLICY_DLP_FILES_DOWNLOAD_TIMEOUT_MESSAGE 38879
#define IDS_POLICY_DLP_FILES_TRANSFER_TIMEOUT_MESSAGE 38880
#define IDS_POLICY_DLP_FILES_UPLOAD_TIMEOUT_MESSAGE 38881
#define IDS_POLICY_DLP_FILES_MOVE_TIMEOUT_MESSAGE 38882
#define IDS_POLICY_DLP_FILES_COPY_TIMEOUT_MESSAGE 38883
#define IDS_POLICY_DLP_FILES_OPEN_TIMEOUT_MESSAGE 38884
#define IDS_POLICY_DLP_FILES_LEARN_MORE_ABOUT_DATA_CONTROLS_ACCESSIBLE_NAME 38885
#define IDS_POLICY_DLP_FILES_LEARN_MORE_ABOUT_MALWARE_PROTECTION_ACCESSIBLE_NAME 38886
#define IDS_POLICY_DLP_FILES_LEARN_MORE_ABOUT_SENSITIVE_DATA_PROTECTION_ACCESSIBLE_NAME 38887
#define IDS_POLICY_DLP_FILES_JUSTIFICATION_TEXTAREA_ACCESSIBLE_DESCRIPTION 38888
#define IDS_POLICY_DEVICE_SCHEDULED_REBOOT_TITLE 38889
#define IDS_POLICY_DEVICE_SCHEDULED_REBOOT_MESSAGE 38890
#define IDS_POLICY_REBOOT_BUTTON 38891
#define IDS_POLICY_DEVICE_SCHEDULED_REBOOT_DIALOG_MESSAGE 38892
#define IDS_REBOOT_SCHEDULED_TITLE_MINUTES 38893
#define IDS_REBOOT_SCHEDULED_TITLE_SECONDS 38894
#define IDS_POLICY_DEVICE_POST_REBOOT_TITLE 38895
#define IDS_POLICY_DEVICE_LOCATED_TITLE 38896
#define IDS_POLICY_DEVICE_LOCATED_MESSAGE 38897
#define IDS_POLICY_BROWSING_DATA_DEPENDENCY_APPLIED_INFO 38898
#define IDS_POLICY_BROWSING_DATA_PLATFORM_UNSUPPORTED 38899
#define IDS_POLICY_NOT_SUPPORTED_AS_USER_POLICY_ON_IOS 38900
#define IDS_POLICY_GEN_AI_DEFAULT_SETTINGS_CONTROL_MESSAGE 38901
#define IDS_POLICY_GEN_AI_DEFAULT_SETTINGS_NO_CONTROL_MESSAGE 38902
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_DISPLAY_SOURCE 38903
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_TITLE_PHOTO 38904
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_TITLE_VIDEO 38905
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_TITLE_SCAN 38906
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_MESSAGE_PHOTO 38907
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_MESSAGE_VIDEO 38908
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_MESSAGE_SCAN 38909
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_BUTTON 38910
#define IDS_POLICY_SKYVAULT_CAMERA_SIGN_IN_CANCEL_BUTTON 38911
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DISPLAY_SOURCE 38912
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_CANCEL_BUTTON 38913
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_TITLE 38914
#define IDS_POLICY_SKYVAULT_CAMERA_MULTI_UPLOAD_TITLE 38915
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_ONEDRIVE_MESSAGE 38916
#define IDS_POLICY_SKYVAULT_CAMERA_MULTI_UPLOAD_ONEDRIVE_MESSAGE 38917
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_GOOGLE_DRIVE_MESSAGE 38918
#define IDS_POLICY_SKYVAULT_CAMERA_MULTI_UPLOAD_GOOGLE_DRIVE_MESSAGE 38919
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_TITLE 38920
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_MESSAGE 38921
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_SKIP_CHECKBOX 38922
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_CANCEL_BUTTON 38923
#define IDS_POLICY_SKYVAULT_CAMERA_CANCEL_UPLOAD_CLOSE_BUTTON 38924
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_DONE_TITLE_ONEDRIVE 38925
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_DONE_TITLE_ONEDRIVE 38926
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_DONE_TITLE_ONEDRIVE 38927
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_DONE_TITLE_GOOGLE_DRIVE 38928
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_DONE_TITLE_GOOGLE_DRIVE 38929
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_DONE_TITLE_GOOGLE_DRIVE 38930
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DONE_MESSAGE 38931
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DONE_EDIT_BUTTON 38932
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_DONE_DELETE_BUTTON 38933
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_ERROR_TITLE 38934
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_ERROR_MESSAGE 38935
#define IDS_POLICY_SKYVAULT_CAMERA_PHOTO_UPLOAD_ERROR_RETAKE_BUTTON 38936
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_ERROR_TITLE 38937
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_ERROR_MESSAGE 38938
#define IDS_POLICY_SKYVAULT_CAMERA_VIDEO_UPLOAD_ERROR_RETAKE_BUTTON 38939
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_ERROR_TITLE 38940
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_ERROR_MESSAGE 38941
#define IDS_POLICY_SKYVAULT_CAMERA_SCAN_UPLOAD_ERROR_RETAKE_BUTTON 38942
#define IDS_POLICY_SKYVAULT_CAMERA_UPLOAD_ERROR_DISMISS_BUTTON 38943
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_TITLE 38944
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_BUTTON 38945
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_CANCEL_BUTTON 38946
#define IDS_POLICY_SKYVAULT_DOWNLOAD_SIGN_IN_DISPLAY_SOURCE 38947
#define IDS_POLICY_SKYVAULT_MIGRATION_BANNER 38948
#define IDS_POLICY_SKYVAULT_MISCONFIGURED_POLICY_MESSAGE 38949
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_UPLOAD_TITLE 38950
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_RECORDING_UPLOAD_TITLE 38951
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_UPLOAD_ONEDRIVE_MESSAGE 38952
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_UPLOAD_CANCEL_BUTTON 38953
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_SIGN_IN_TITLE 38954
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_SIGN_IN_BUTTON 38955
#define IDS_POLICY_SKYVAULT_SCREENCAPTURE_SIGN_IN_CANCEL_BUTTON 38956
#define IDS_POLICY_SKYVAULT_CLOUD_PROVIDER_GOOGLE_DRIVE 38957
#define IDS_POLICY_SKYVAULT_CLOUD_PROVIDER_ONEDRIVE 38958
#define IDS_POLICY_SKYVAULT_MIGRATION_PROGRESS_TITLE 38959
#define IDS_POLICY_SKYVAULT_MIGRATION_PROGRESS_MESSAGE 38960
#define IDS_POLICY_SKYVAULT_MIGRATION_COMPLETED_TITLE 38961
#define IDS_POLICY_SKYVAULT_MIGRATION_COMPLETED_MESSAGE 38962
#define IDS_POLICY_SKYVAULT_MIGRATION_COMPLETED_BUTTON 38963
#define IDS_POLICY_SKYVAULT_MIGRATION_CONFIG_ERROR_TITLE 38964
#define IDS_POLICY_SKYVAULT_MIGRATION_CONFIG_ERROR_MESSAGE 38965
#define IDS_POLICY_SKYVAULT_MIGRATION_ERROR_TITLE 38966
#define IDS_POLICY_SKYVAULT_MIGRATION_ERROR_MESSAGE 38967
#define IDS_POLICY_SKYVAULT_MIGRATION_ERROR_BUTTON 38968
#define IDS_POLICY_SKYVAULT_MIGRATION_SIGN_IN_TITLE 38969
#define IDS_POLICY_SKYVAULT_MIGRATION_SIGN_IN_MESSAGE 38970
#define IDS_POLICY_SKYVAULT_MIGRATION_SIGN_IN_BUTTON 38971
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_HOURS 38972
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_HOUR 38973
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_MINUTES 38974
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_TITLE_MINUTE 38975
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_START_MESSAGE 38976
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_START_ON_MESSAGE 38977
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_DONE_MESSAGE 38978
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_NOW_BUTTON 38979
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_IN_HOURS_BUTTON 38980
#define IDS_POLICY_SKYVAULT_MIGRATION_DIALOG_UPLOAD_IN_MINUTES_BUTTON 38981
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_HOURS 38982
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_HOUR 38983
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_MINUTES 38984
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_TITLE_MINUTE 38985
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_START_MESSAGE 38986
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_STORE_MESSAGE 38987
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_DELETE_NOW_BUTTON 38988
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_DELETE_IN_HOURS_BUTTON 38989
#define IDS_POLICY_SKYVAULT_DELETION_DIALOG_DELETE_IN_MINUTES_BUTTON 38990
#define IDS_POLICY_SKYVAULT_DELETION_COMPLETED_TITLE 38991
#define IDS_POLICY_SKYVAULT_DELETION_COMPLETED_MESSAGE 38992
#define IDS_POLICY_SKYVAULT_DELETION_BANNER 38993
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_NO_SPACE 38994
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_FILE_NOT_EXIST 38995
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_ODFS_SIGN_IN 38996
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_NO_INTERNET 38997
#define IDS_POLICY_SKYVAULT_MIGRATION_UPLOAD_ERROR_GENERIC 38998
#define PRINT_PREVIEW_MEDIA_ASME_F_28X40IN 38999
#define PRINT_PREVIEW_MEDIA_ISO_2A0_1189X1682MM 39000
#define PRINT_PREVIEW_MEDIA_ISO_A0_841X1189MM 39001
#define PRINT_PREVIEW_MEDIA_ISO_A0X3_1189X2523MM 39002
#define PRINT_PREVIEW_MEDIA_ISO_A10_26X37MM 39003
#define PRINT_PREVIEW_MEDIA_ISO_A1_594X841MM 39004
#define PRINT_PREVIEW_MEDIA_ISO_A1X3_841X1783MM 39005
#define PRINT_PREVIEW_MEDIA_ISO_A1X4_841X2378MM 39006
#define PRINT_PREVIEW_MEDIA_ISO_A2_420X594MM 39007
#define PRINT_PREVIEW_MEDIA_ISO_A2X3_594X1261MM 39008
#define PRINT_PREVIEW_MEDIA_ISO_A2X4_594X1682MM 39009
#define PRINT_PREVIEW_MEDIA_ISO_A2X5_594X2102MM 39010
#define PRINT_PREVIEW_MEDIA_ISO_A3_297X420MM 39011
#define PRINT_PREVIEW_MEDIA_ISO_A3_EXTRA_322X445MM 39012
#define PRINT_PREVIEW_MEDIA_ISO_A3X3_420X891MM 39013
#define PRINT_PREVIEW_MEDIA_ISO_A3X4_420X1189MM 39014
#define PRINT_PREVIEW_MEDIA_ISO_A3X5_420X1486MM 39015
#define PRINT_PREVIEW_MEDIA_ISO_A3X6_420X1783MM 39016
#define PRINT_PREVIEW_MEDIA_ISO_A3X7_420X2080MM 39017
#define PRINT_PREVIEW_MEDIA_ISO_A4_210X297MM 39018
#define PRINT_PREVIEW_MEDIA_ISO_A4_EXTRA_235_5X322_3MM 39019
#define PRINT_PREVIEW_MEDIA_ISO_A4_TAB_225X297MM 39020
#define PRINT_PREVIEW_MEDIA_ISO_A4X3_297X630MM 39021
#define PRINT_PREVIEW_MEDIA_ISO_A4X4_297X841MM 39022
#define PRINT_PREVIEW_MEDIA_ISO_A4X5_297X1051MM 39023
#define PRINT_PREVIEW_MEDIA_ISO_A4X6_297X1261MM 39024
#define PRINT_PREVIEW_MEDIA_ISO_A4X7_297X1471MM 39025
#define PRINT_PREVIEW_MEDIA_ISO_A4X8_297X1682MM 39026
#define PRINT_PREVIEW_MEDIA_ISO_A4X9_297X1892MM 39027
#define PRINT_PREVIEW_MEDIA_ISO_A5_148X210MM 39028
#define PRINT_PREVIEW_MEDIA_ISO_A5_EXTRA_174X235MM 39029
#define PRINT_PREVIEW_MEDIA_ISO_A6_105X148MM 39030
#define PRINT_PREVIEW_MEDIA_ISO_A7_74X105MM 39031
#define PRINT_PREVIEW_MEDIA_ISO_A8_52X74MM 39032
#define PRINT_PREVIEW_MEDIA_ISO_A9_37X52MM 39033
#define PRINT_PREVIEW_MEDIA_ISO_B0_1000X1414MM 39034
#define PRINT_PREVIEW_MEDIA_ISO_B10_31X44MM 39035
#define PRINT_PREVIEW_MEDIA_ISO_B1_707X1000MM 39036
#define PRINT_PREVIEW_MEDIA_ISO_B2_500X707MM 39037
#define PRINT_PREVIEW_MEDIA_ISO_B3_353X500MM 39038
#define PRINT_PREVIEW_MEDIA_ISO_B4_250X353MM 39039
#define PRINT_PREVIEW_MEDIA_ISO_B5_176X250MM 39040
#define PRINT_PREVIEW_MEDIA_ISO_B5_EXTRA_201X276MM 39041
#define PRINT_PREVIEW_MEDIA_ISO_B6C4_125X324MM 39042
#define PRINT_PREVIEW_MEDIA_ISO_B6_125X176MM 39043
#define PRINT_PREVIEW_MEDIA_ISO_B7_88X125MM 39044
#define PRINT_PREVIEW_MEDIA_ISO_B8_62X88MM 39045
#define PRINT_PREVIEW_MEDIA_ISO_B9_44X62MM 39046
#define PRINT_PREVIEW_MEDIA_ISO_C0_917X1297MM 39047
#define PRINT_PREVIEW_MEDIA_ISO_C10_28X40MM 39048
#define PRINT_PREVIEW_MEDIA_ISO_C1_648X917MM 39049
#define PRINT_PREVIEW_MEDIA_ISO_C2_458X648MM 39050
#define PRINT_PREVIEW_MEDIA_ISO_C3_324X458MM 39051
#define PRINT_PREVIEW_MEDIA_ISO_C4_229X324MM 39052
#define PRINT_PREVIEW_MEDIA_ISO_C5_162X229MM 39053
#define PRINT_PREVIEW_MEDIA_ISO_C6C5_114X229MM 39054
#define PRINT_PREVIEW_MEDIA_ISO_C6_114X162MM 39055
#define PRINT_PREVIEW_MEDIA_ISO_C7C6_81X162MM 39056
#define PRINT_PREVIEW_MEDIA_ISO_C7_81X114MM 39057
#define PRINT_PREVIEW_MEDIA_ISO_C8_57X81MM 39058
#define PRINT_PREVIEW_MEDIA_ISO_C9_40X57MM 39059
#define PRINT_PREVIEW_MEDIA_ISO_DL_110X220MM 39060
#define PRINT_PREVIEW_MEDIA_ISO_ID_1_53_98X85_6MM 39061
#define PRINT_PREVIEW_MEDIA_ISO_RA0_860X1220MM 39062
#define PRINT_PREVIEW_MEDIA_ISO_RA1_610X860MM 39063
#define PRINT_PREVIEW_MEDIA_ISO_RA2_430X610MM 39064
#define PRINT_PREVIEW_MEDIA_ISO_RA3_305X430MM 39065
#define PRINT_PREVIEW_MEDIA_ISO_RA4_215X305MM 39066
#define PRINT_PREVIEW_MEDIA_ISO_SRA0_900X1280MM 39067
#define PRINT_PREVIEW_MEDIA_ISO_SRA1_640X900MM 39068
#define PRINT_PREVIEW_MEDIA_ISO_SRA2_450X640MM 39069
#define PRINT_PREVIEW_MEDIA_ISO_SRA3_320X450MM 39070
#define PRINT_PREVIEW_MEDIA_ISO_SRA4_225X320MM 39071
#define PRINT_PREVIEW_MEDIA_JIS_B0_1030X1456MM 39072
#define PRINT_PREVIEW_MEDIA_JIS_B1_728X1030MM 39073
#define PRINT_PREVIEW_MEDIA_JIS_B2_515X728MM 39074
#define PRINT_PREVIEW_MEDIA_JIS_B3_364X515MM 39075
#define PRINT_PREVIEW_MEDIA_JIS_B4_257X364MM 39076
#define PRINT_PREVIEW_MEDIA_JIS_B5_182X257MM 39077
#define PRINT_PREVIEW_MEDIA_JIS_B6_128X182MM 39078
#define PRINT_PREVIEW_MEDIA_JIS_B7_91X128MM 39079
#define PRINT_PREVIEW_MEDIA_JIS_B8_64X91MM 39080
#define PRINT_PREVIEW_MEDIA_JIS_B9_45X64MM 39081
#define PRINT_PREVIEW_MEDIA_JIS_B10_32X45MM 39082
#define PRINT_PREVIEW_MEDIA_JIS_EXEC_216X330MM 39083
#define PRINT_PREVIEW_MEDIA_JPN_CHOU2_111_1X146MM 39084
#define PRINT_PREVIEW_MEDIA_JPN_CHOU3_120X235MM 39085
#define PRINT_PREVIEW_MEDIA_JPN_CHOU4_90X205MM 39086
#define PRINT_PREVIEW_MEDIA_JPN_CHOU40_90X225MM 39087
#define PRINT_PREVIEW_MEDIA_JPN_HAGAKI_100X148MM 39088
#define PRINT_PREVIEW_MEDIA_JPN_KAHU_240X322_1MM 39089
#define PRINT_PREVIEW_MEDIA_JPN_KAKU1_270X382MM 39090
#define PRINT_PREVIEW_MEDIA_JPN_KAKU2_240X332MM 39091
#define PRINT_PREVIEW_MEDIA_JPN_KAKU3_216X277MM 39092
#define PRINT_PREVIEW_MEDIA_JPN_KAKU4_197X267MM 39093
#define PRINT_PREVIEW_MEDIA_JPN_KAKU5_190X240MM 39094
#define PRINT_PREVIEW_MEDIA_JPN_KAKU7_142X205MM 39095
#define PRINT_PREVIEW_MEDIA_JPN_KAKU8_119X197MM 39096
#define PRINT_PREVIEW_MEDIA_JPN_OUFUKU_148X200MM 39097
#define PRINT_PREVIEW_MEDIA_JPN_YOU4_105X235MM 39098
#define PRINT_PREVIEW_MEDIA_JPN_YOU6_98X190MM 39099
#define PRINT_PREVIEW_MEDIA_NA_10X11_10X11IN 39100
#define PRINT_PREVIEW_MEDIA_NA_10X13_10X13IN 39101
#define PRINT_PREVIEW_MEDIA_NA_10X14_10X14IN 39102
#define PRINT_PREVIEW_MEDIA_NA_10X15_10X15IN 39103
#define PRINT_PREVIEW_MEDIA_NA_11X12_11X12IN 39104
#define PRINT_PREVIEW_MEDIA_NA_11X15_11X15IN 39105
#define PRINT_PREVIEW_MEDIA_NA_12X19_12X19IN 39106
#define PRINT_PREVIEW_MEDIA_NA_5X7_5X7IN 39107
#define PRINT_PREVIEW_MEDIA_NA_6X9_6X9IN 39108
#define PRINT_PREVIEW_MEDIA_NA_7X9_7X9IN 39109
#define PRINT_PREVIEW_MEDIA_NA_9X11_9X11IN 39110
#define PRINT_PREVIEW_MEDIA_NA_A2_4_375X5_75IN 39111
#define PRINT_PREVIEW_MEDIA_NA_ARCH_A_9X12IN 39112
#define PRINT_PREVIEW_MEDIA_NA_ARCH_B_12X18IN 39113
#define PRINT_PREVIEW_MEDIA_NA_ARCH_C_18X24IN 39114
#define PRINT_PREVIEW_MEDIA_NA_ARCH_D_24X36IN 39115
#define PRINT_PREVIEW_MEDIA_NA_ARCH_E_36X48IN 39116
#define PRINT_PREVIEW_MEDIA_NA_ARCH_E2_26X38IN 39117
#define PRINT_PREVIEW_MEDIA_NA_ARCH_E3_27X39IN 39118
#define PRINT_PREVIEW_MEDIA_NA_B_PLUS_12X19_17IN 39119
#define PRINT_PREVIEW_MEDIA_NA_C5_6_5X9_5IN 39120
#define PRINT_PREVIEW_MEDIA_NA_C_17X22IN 39121
#define PRINT_PREVIEW_MEDIA_NA_D_22X34IN 39122
#define PRINT_PREVIEW_MEDIA_NA_EDP_11X14IN 39123
#define PRINT_PREVIEW_MEDIA_NA_EUR_EDP_12X14IN 39124
#define PRINT_PREVIEW_MEDIA_NA_E_34X44IN 39125
#define PRINT_PREVIEW_MEDIA_NA_EXECUTIVE_7_25X10_5IN 39126
#define PRINT_PREVIEW_MEDIA_NA_FANFOLD_EUR_8_5X12IN 39127
#define PRINT_PREVIEW_MEDIA_NA_FANFOLD_US_11X14_875IN 39128
#define PRINT_PREVIEW_MEDIA_NA_FOOLSCAP_8_5X13IN 39129
#define PRINT_PREVIEW_MEDIA_NA_F_44X68IN 39130
#define PRINT_PREVIEW_MEDIA_NA_GOVT_LEGAL_8X13IN 39131
#define PRINT_PREVIEW_MEDIA_NA_GOVT_LETTER_8X10IN 39132
#define PRINT_PREVIEW_MEDIA_NA_INDEX_3X5_3X5IN 39133
#define PRINT_PREVIEW_MEDIA_NA_INDEX_4X6_4X6IN 39134
#define PRINT_PREVIEW_MEDIA_NA_INDEX_4X6_EXT_6X8IN 39135
#define PRINT_PREVIEW_MEDIA_NA_INDEX_5X8_5X8IN 39136
#define PRINT_PREVIEW_MEDIA_NA_INVOICE_5_5X8_5IN 39137
#define PRINT_PREVIEW_MEDIA_NA_LEDGER_11X17IN 39138
#define PRINT_PREVIEW_MEDIA_NA_LEGAL_8_5X14IN 39139
#define PRINT_PREVIEW_MEDIA_NA_LEGAL_EXTRA_9_5X15IN 39140
#define PRINT_PREVIEW_MEDIA_NA_LETTER_8_5X11IN 39141
#define PRINT_PREVIEW_MEDIA_NA_LETTER_EXTRA_9_5X12IN 39142
#define PRINT_PREVIEW_MEDIA_NA_LETTER_PLUS_8_5X12_69IN 39143
#define PRINT_PREVIEW_MEDIA_NA_MONARCH_3_875X7_5IN 39144
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_9_3_875X8_875IN 39145
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_10_4_125X9_5IN 39146
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_11_4_5X10_375IN 39147
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_12_4_75X11IN 39148
#define PRINT_PREVIEW_MEDIA_NA_NUMBER_14_5X11_5IN 39149
#define PRINT_PREVIEW_MEDIA_NA_OFICIO_8_5X13_4IN 39150
#define PRINT_PREVIEW_MEDIA_NA_PERSONAL_3_625X6_5IN 39151
#define PRINT_PREVIEW_MEDIA_NA_QUARTO_8_5X10_83IN 39152
#define PRINT_PREVIEW_MEDIA_NA_SUPER_A_8_94X14IN 39153
#define PRINT_PREVIEW_MEDIA_NA_SUPER_B_13X19IN 39154
#define PRINT_PREVIEW_MEDIA_NA_WIDE_FORMAT_30X42IN 39155
#define PRINT_PREVIEW_MEDIA_OE_12X16_12X16IN 39156
#define PRINT_PREVIEW_MEDIA_OE_14X17_14X17IN 39157
#define PRINT_PREVIEW_MEDIA_OE_18X22_18X22IN 39158
#define PRINT_PREVIEW_MEDIA_OE_A2PLUS_17X24IN 39159
#define PRINT_PREVIEW_MEDIA_OE_BUSINESS_CARD_2X3_5IN 39160
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_10R_10X12IN 39161
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_12R_12X15IN 39162
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_14X18_14X18IN 39163
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_16R_16X20IN 39164
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_20R_20X24IN 39165
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_22R_22X29_5IN 39166
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_22X28_22X28IN 39167
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_24R_24X31_5IN 39168
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_24X30_24X30IN 39169
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_30R_30X40IN 39170
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_L_3_5X5IN 39171
#define PRINT_PREVIEW_MEDIA_OE_PHOTO_S8R_8X12IN 39172
#define PRINT_PREVIEW_MEDIA_OE_SQUARE_PHOTO_4X4IN 39173
#define PRINT_PREVIEW_MEDIA_OE_SQUARE_PHOTO_5X5IN 39174
#define PRINT_PREVIEW_MEDIA_OM_16K_184X260MM 39175
#define PRINT_PREVIEW_MEDIA_OM_16K_195X270MM 39176
#define PRINT_PREVIEW_MEDIA_OM_BUSINESS_CARD_55X85MM 39177
#define PRINT_PREVIEW_MEDIA_OM_BUSINESS_CARD_55X91MM 39178
#define PRINT_PREVIEW_MEDIA_OM_CARD_54X86MM 39179
#define PRINT_PREVIEW_MEDIA_OM_DAI_PA_KAI_275X395MM 39180
#define PRINT_PREVIEW_MEDIA_OM_DSC_PHOTO_89X119MM 39181
#define PRINT_PREVIEW_MEDIA_OM_FOLIO_210X330MM 39182
#define PRINT_PREVIEW_MEDIA_OM_FOLIO_SP_215X315MM 39183
#define PRINT_PREVIEW_MEDIA_OM_INVITE_220X220MM 39184
#define PRINT_PREVIEW_MEDIA_OM_ITALIAN_110X230MM 39185
#define PRINT_PREVIEW_MEDIA_OM_JUURO_KU_KAI_198X275MM 39186
#define PRINT_PREVIEW_MEDIA_OM_LARGE_PHOTO_200X300 39187
#define PRINT_PREVIEW_MEDIA_OM_MEDIUM_PHOTO_130X180MM 39188
#define PRINT_PREVIEW_MEDIA_OM_PA_KAI_267X389MM 39189
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_30X40_300X400MM 39190
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_30X45_300X450MM 39191
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_35X46_350X460MM 39192
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_40X60_400X600MM 39193
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_50X75_500X750MM 39194
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_50X76_500X760MM 39195
#define PRINT_PREVIEW_MEDIA_OM_PHOTO_60X90_600X900MM 39196
#define PRINT_PREVIEW_MEDIA_OM_SQUARE_PHOTO_89X89MM 39197
#define PRINT_PREVIEW_MEDIA_OM_WIDE_PHOTO_100X200MM 39198
#define PRINT_PREVIEW_MEDIA_OM_SMALL_PHOTO_100X150MM 39199
#define PRINT_PREVIEW_MEDIA_PRC_16K_146X215MM 39200
#define PRINT_PREVIEW_MEDIA_PRC_1_102X165MM 39201
#define PRINT_PREVIEW_MEDIA_PRC_2_102X176MM 39202
#define PRINT_PREVIEW_MEDIA_PRC_32K_97X151MM 39203
#define PRINT_PREVIEW_MEDIA_PRC_4_110X208MM 39204
#define PRINT_PREVIEW_MEDIA_PRC_6_120X320MM 39205
#define PRINT_PREVIEW_MEDIA_PRC_7_160X230MM 39206
#define PRINT_PREVIEW_MEDIA_PRC_8_120X309MM 39207
#define PRINT_PREVIEW_MEDIA_ROC_16K_7_75X10_75IN 39208
#define PRINT_PREVIEW_MEDIA_ROC_8K_10_75X15_5IN 39209
#define PRINT_PREVIEW_MEDIA_DIMENSIONS_INCHES 39210
#define PRINT_PREVIEW_MEDIA_DIMENSIONS_MM 39211
#define PRINT_PREVIEW_MEDIA_NAME_WITH_DIMENSIONS_INCHES 39212
#define PRINT_PREVIEW_MEDIA_NAME_WITH_DIMENSIONS_MM 39213
#define IDS_PRINT_COMPOSITOR_SERVICE_DISPLAY_NAME 39215
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_TITLE 39619
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_1 39620
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_2 39621
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_3 39622
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_EXPAND_LABEL 39623
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_DESCRIPTION_4 39624
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_BULLET_1 39625
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_BULLET_2 39626
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_BULLET_3 39627
#define IDS_PRIVACY_SANDBOX_M1_CONSENT_LEARN_MORE_LINK 39628
#define IDS_SETTINGS_TOPICS_PAGE_TITLE 39629
#define IDS_SETTINGS_TOPICS_PAGE_TOGGLE_LABEL 39630
#define IDS_SETTINGS_TOPICS_PAGE_TOGGLE_SUB_LABEL_V2 39631
#define IDS_SETTINGS_TOPICS_PAGE_DISCLAIMER_DESKTOP 39632
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_CANONICAL 39633
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_DISABLED 39634
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_EMPTY_TEXT_V2 39635
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_DESCRIPTION_EMPTY_TEXT_HEADING 39636
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_DESCRIPTION_EMPTY_TEXT_V2 39637
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_DESCRIPTION_EMPTY_TEXT_HEADING 39638
#define IDS_SETTINGS_TOPICS_PAGE_BLOCK_TOPIC 39639
#define IDS_SETTINGS_TOPICS_PAGE_BLOCK_TOPIC_A11Y_LABEL 39640
#define IDS_SETTINGS_TOPICS_PAGE_ALLOW_TOPIC 39641
#define IDS_SETTINGS_TOPICS_PAGE_ALLOW_TOPIC_A11Y_LABEL 39642
#define IDS_SETTINGS_TOPICS_PAGE_UNBLOCK_TOPIC_A11Y_LABEL 39643
#define IDS_SETTINGS_TOPICS_PAGE_FOOTER_CANONICAL 39644
#define IDS_SETTINGS_TOPICS_PAGE_FIRST_LEVEL_TOPIC_DESCRIPTOR 39645
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_TITLE 39646
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_BODY 39647
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_CLANK_TITLE 39648
#define IDS_SETTINGS_MANAGE_TOPICS_DIALOG_CLANK_BODY 39649
#define IDS_SETTINGS_MANAGE_TOPICS_PAGE_DESCRIPTION 39650
#define IDS_SETTINGS_MANAGE_TOPICS_PAGE_LEARN_MORE_LINK 39651
#define IDS_SETTINGS_MANAGE_TOPICS_PAGE_DESCRIPTION_LEARN_MORE_ARIA_LABEL 39652
#define IDS_SETTINGS_UNBLOCK_TOPIC_TOAST_BODY 39653
#define IDS_SETTINGS_UNBLOCK_TOPIC_TOAST_BUTTON_TEXT 39654
#define IDS_SETTINGS_FLEDGE_PAGE_FOOTER_V2 39655
#define IDS_SETTINGS_UNBLOCK_TOPIC_BUTTON_TEXT_V2 39656
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_HEADING_NEW 39657
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_DESCRIPTION_NEW 39658
#define IDS_SETTINGS_TOPICS_PAGE_MANAGE_TOPICS_HEADING 39659
#define IDS_SETTINGS_TOPICS_PAGE_MANAGE_TOPICS_DESCRIPTION 39660
#define IDS_SETTINGS_TOPICS_PAGE_MANAGE_TOPICS_EXPLANATION 39661
#define IDS_SETTINGS_TOPICS_PAGE_ACTIVE_TOPICS_HEADING 39662
#define IDS_SETTINGS_TOPICS_PAGE_ACTIVE_TOPICS_DESCRIPTION 39663
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_STATUS_LABEL 39664
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_LAST_UPDATE_TIME_LABEL 39665
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_LAST_UPDATE_SOURCE_LABEL 39666
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_LAST_UPDATE_TEXT_LABEL 39667
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_UPDATE_SOURCE_SETTINGS 39668
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_UPDATE_SOURCE_DEFAULT 39669
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_UPDATE_SOURCE_CONFIRMATION 39670
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_ACTIVE 39671
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_INACTIVE 39672
#define IDS_PRIVACY_SANDBOX_TOPICS_CONSENT_NOT_REQUIRED 39673
#define IDS_PRIVACY_SANDBOX_TOPICS_INVALID_TOPIC 39674
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_1 39675
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_2 39676
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_3 39677
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_4 39678
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_5 39679
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_6 39680
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_7 39681
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_8 39682
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_9 39683
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_10 39684
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_11 39685
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_12 39686
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_13 39687
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_14 39688
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_15 39689
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_16 39690
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_17 39691
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_18 39692
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_19 39693
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_20 39694
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_21 39695
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_22 39696
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_23 39697
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_24 39698
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_25 39699
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_26 39700
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_27 39701
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_28 39702
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_29 39703
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_30 39704
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_31 39705
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_32 39706
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_33 39707
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_34 39708
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_35 39709
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_36 39710
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_37 39711
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_38 39712
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_39 39713
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_40 39714
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_41 39715
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_42 39716
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_43 39717
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_44 39718
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_45 39719
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_46 39720
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_47 39721
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_48 39722
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_49 39723
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_50 39724
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_51 39725
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_52 39726
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_53 39727
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_54 39728
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_55 39729
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_56 39730
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_57 39731
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_58 39732
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_59 39733
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_60 39734
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_61 39735
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_62 39736
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_63 39737
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_64 39738
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_65 39739
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_66 39740
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_67 39741
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_68 39742
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_69 39743
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_70 39744
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_71 39745
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_72 39746
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_73 39747
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_74 39748
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_75 39749
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_76 39750
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_77 39751
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_78 39752
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_79 39753
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_80 39754
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_81 39755
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_82 39756
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_83 39757
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_84 39758
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_85 39759
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_86 39760
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_87 39761
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_88 39762
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_89 39763
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_90 39764
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_91 39765
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_92 39766
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_93 39767
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_94 39768
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_95 39769
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_96 39770
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_97 39771
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_98 39772
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_99 39773
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_100 39774
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_101 39775
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_102 39776
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_103 39777
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_104 39778
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_105 39779
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_106 39780
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_107 39781
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_108 39782
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_109 39783
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_110 39784
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_111 39785
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_112 39786
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_113 39787
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_114 39788
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_115 39789
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_116 39790
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_117 39791
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_118 39792
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_119 39793
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_120 39794
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_121 39795
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_122 39796
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_123 39797
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_124 39798
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_125 39799
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_126 39800
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_127 39801
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_128 39802
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_129 39803
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_130 39804
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_131 39805
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_132 39806
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_133 39807
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_134 39808
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_135 39809
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_136 39810
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_137 39811
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_138 39812
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_139 39813
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_140 39814
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_141 39815
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_142 39816
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_143 39817
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_144 39818
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_145 39819
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_146 39820
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_147 39821
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_148 39822
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_149 39823
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_150 39824
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_151 39825
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_152 39826
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_153 39827
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_154 39828
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_155 39829
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_156 39830
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_157 39831
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_158 39832
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_159 39833
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_160 39834
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_161 39835
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_162 39836
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_163 39837
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_164 39838
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_165 39839
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_166 39840
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_167 39841
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_168 39842
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_169 39843
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_170 39844
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_171 39845
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_172 39846
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_173 39847
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_174 39848
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_175 39849
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_176 39850
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_177 39851
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_178 39852
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_179 39853
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_180 39854
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_181 39855
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_182 39856
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_183 39857
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_184 39858
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_185 39859
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_186 39860
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_187 39861
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_188 39862
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_189 39863
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_190 39864
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_191 39865
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_192 39866
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_193 39867
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_194 39868
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_195 39869
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_196 39870
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_197 39871
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_198 39872
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_199 39873
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_200 39874
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_201 39875
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_202 39876
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_203 39877
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_204 39878
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_205 39879
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_206 39880
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_207 39881
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_208 39882
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_209 39883
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_210 39884
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_211 39885
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_212 39886
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_213 39887
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_214 39888
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_215 39889
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_216 39890
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_217 39891
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_218 39892
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_219 39893
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_220 39894
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_221 39895
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_222 39896
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_223 39897
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_224 39898
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_225 39899
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_226 39900
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_227 39901
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_228 39902
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_229 39903
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_230 39904
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_231 39905
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_232 39906
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_233 39907
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_234 39908
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_235 39909
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_236 39910
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_237 39911
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_238 39912
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_239 39913
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_240 39914
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_241 39915
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_242 39916
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_243 39917
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_244 39918
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_245 39919
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_246 39920
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_247 39921
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_248 39922
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_249 39923
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_250 39924
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_251 39925
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_252 39926
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_253 39927
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_254 39928
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_255 39929
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_256 39930
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_257 39931
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_258 39932
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_259 39933
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_260 39934
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_261 39935
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_262 39936
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_263 39937
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_264 39938
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_265 39939
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_266 39940
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_267 39941
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_268 39942
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_269 39943
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_270 39944
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_271 39945
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_272 39946
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_273 39947
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_274 39948
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_275 39949
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_276 39950
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_277 39951
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_278 39952
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_279 39953
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_280 39954
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_281 39955
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_282 39956
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_283 39957
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_284 39958
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_285 39959
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_286 39960
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_287 39961
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_288 39962
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_289 39963
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_290 39964
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_291 39965
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_292 39966
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_293 39967
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_294 39968
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_295 39969
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_296 39970
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_297 39971
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_298 39972
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_299 39973
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_300 39974
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_301 39975
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_302 39976
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_303 39977
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_304 39978
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_305 39979
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_306 39980
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_307 39981
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_308 39982
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_309 39983
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_310 39984
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_311 39985
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_312 39986
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_313 39987
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_314 39988
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_315 39989
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_316 39990
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_317 39991
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_318 39992
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_319 39993
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_320 39994
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_321 39995
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_322 39996
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_323 39997
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_324 39998
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_325 39999
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_326 40000
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_327 40001
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_328 40002
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_329 40003
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_330 40004
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_331 40005
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_332 40006
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_333 40007
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_334 40008
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_335 40009
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_336 40010
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_337 40011
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_338 40012
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_339 40013
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_340 40014
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_341 40015
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_342 40016
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_343 40017
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_344 40018
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_345 40019
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_346 40020
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_347 40021
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_348 40022
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V1_TOPIC_ID_349 40023
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_350 40024
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_351 40025
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_352 40026
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_353 40027
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_354 40028
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_355 40029
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_356 40030
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_357 40031
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_358 40032
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_359 40033
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_360 40034
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_361 40035
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_362 40036
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_363 40037
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_364 40038
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_365 40039
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_366 40040
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_367 40041
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_368 40042
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_369 40043
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_370 40044
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_371 40045
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_372 40046
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_373 40047
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_374 40048
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_375 40049
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_376 40050
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_377 40051
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_378 40052
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_379 40053
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_380 40054
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_381 40055
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_382 40056
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_383 40057
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_384 40058
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_385 40059
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_386 40060
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_387 40061
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_388 40062
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_389 40063
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_390 40064
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_391 40065
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_392 40066
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_393 40067
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_394 40068
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_395 40069
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_396 40070
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_397 40071
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_398 40072
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_399 40073
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_400 40074
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_401 40075
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_402 40076
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_403 40077
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_404 40078
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_405 40079
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_406 40080
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_407 40081
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_408 40082
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_409 40083
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_410 40084
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_411 40085
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_412 40086
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_413 40087
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_414 40088
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_415 40089
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_416 40090
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_417 40091
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_418 40092
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_419 40093
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_420 40094
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_421 40095
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_422 40096
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_423 40097
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_424 40098
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_425 40099
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_426 40100
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_427 40101
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_428 40102
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_429 40103
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_430 40104
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_431 40105
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_432 40106
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_433 40107
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_434 40108
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_435 40109
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_436 40110
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_437 40111
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_438 40112
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_439 40113
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_440 40114
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_441 40115
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_442 40116
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_443 40117
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_444 40118
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_445 40119
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_446 40120
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_447 40121
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_448 40122
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_449 40123
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_450 40124
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_451 40125
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_452 40126
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_453 40127
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_454 40128
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_455 40129
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_456 40130
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_457 40131
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_458 40132
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_459 40133
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_460 40134
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_461 40135
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_462 40136
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_463 40137
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_464 40138
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_465 40139
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_466 40140
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_467 40141
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_468 40142
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_469 40143
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_470 40144
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_471 40145
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_472 40146
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_473 40147
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_474 40148
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_475 40149
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_476 40150
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_477 40151
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_478 40152
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_479 40153
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_480 40154
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_481 40155
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_482 40156
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_483 40157
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_484 40158
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_485 40159
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_486 40160
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_487 40161
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_488 40162
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_489 40163
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_490 40164
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_491 40165
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_492 40166
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_493 40167
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_494 40168
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_495 40169
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_496 40170
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_497 40171
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_498 40172
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_499 40173
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_500 40174
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_501 40175
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_502 40176
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_503 40177
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_504 40178
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_505 40179
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_506 40180
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_507 40181
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_508 40182
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_509 40183
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_510 40184
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_511 40185
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_512 40186
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_513 40187
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_514 40188
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_515 40189
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_516 40190
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_517 40191
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_518 40192
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_519 40193
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_520 40194
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_521 40195
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_522 40196
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_523 40197
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_524 40198
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_525 40199
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_526 40200
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_527 40201
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_528 40202
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_529 40203
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_530 40204
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_531 40205
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_532 40206
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_533 40207
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_534 40208
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_535 40209
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_536 40210
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_537 40211
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_538 40212
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_539 40213
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_540 40214
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_541 40215
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_542 40216
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_543 40217
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_544 40218
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_545 40219
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_546 40220
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_547 40221
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_548 40222
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_549 40223
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_550 40224
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_551 40225
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_552 40226
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_553 40227
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_554 40228
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_555 40229
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_556 40230
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_557 40231
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_558 40232
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_559 40233
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_560 40234
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_561 40235
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_562 40236
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_563 40237
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_564 40238
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_565 40239
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_566 40240
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_567 40241
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_568 40242
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_569 40243
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_570 40244
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_571 40245
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_572 40246
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_573 40247
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_574 40248
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_575 40249
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_576 40250
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_577 40251
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_578 40252
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_579 40253
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_580 40254
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_581 40255
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_582 40256
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_583 40257
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_584 40258
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_585 40259
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_586 40260
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_587 40261
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_588 40262
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_589 40263
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_590 40264
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_591 40265
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_592 40266
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_593 40267
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_594 40268
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_595 40269
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_596 40270
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_597 40271
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_598 40272
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_599 40273
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_600 40274
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_601 40275
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_602 40276
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_603 40277
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_604 40278
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_605 40279
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_606 40280
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_607 40281
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_608 40282
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_609 40283
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_610 40284
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_611 40285
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_612 40286
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_613 40287
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_614 40288
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_615 40289
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_616 40290
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_617 40291
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_618 40292
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_619 40293
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_620 40294
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_621 40295
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_622 40296
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_623 40297
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_624 40298
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_625 40299
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_626 40300
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_627 40301
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_628 40302
#define IDS_PRIVACY_SANDBOX_TOPICS_TAXONOMY_V2_TOPIC_ID_629 40303
#define IDS_REGISTER_PROTOCOL_HANDLER_TOOLTIP 40304
#define IDS_REGISTER_PROTOCOL_HANDLER_MAILTO_NAME 40305
#define IDS_REGISTER_PROTOCOL_HANDLER_WEBCAL_NAME 40306
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM 40307
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM_REPLACE 40308
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM_FRAGMENT 40309
#define IDS_REGISTER_PROTOCOL_HANDLER_CONFIRM_REPLACE_FRAGMENT 40310
#define IDS_REGISTER_PROTOCOL_HANDLER_ACCEPT 40311
#define IDS_REGISTER_PROTOCOL_HANDLER_DENY 40312
#define IDS_REGISTER_PROTOCOL_HANDLER_IGNORE 40313
#define IDS_CONFIRM_PROTOCOL_HANDLER_TITLE 40314
#define IDS_CONFIRM_PROTOCOL_HANDLER_MESSAGE 40315
#define IDS_CONFIRM_PROTOCOL_HANDLER_MESSAGE_WITH_INITIATING_ORIGIN 40316
#define IDS_CONFIRM_PROTOCOL_HANDLER_REMEMBER 40317
#define IDS_RESET_PASSWORD_TITLE 40318
#define IDS_RESET_PASSWORD_WARNING_HEADING 40319
#define IDS_RESET_PASSWORD_WARNING_HEADING_V2 40320
#define IDS_RESET_PASSWORD_WARNING_HEADING_WITH_ORG_NAME 40321
#define IDS_RESET_PASSWORD_HEADING 40322
#define IDS_RESET_PASSWORD_WARNING_EXPLANATION_PARAGRAPH 40323
#define IDS_RESET_PASSWORD_WARNING_EXPLANATION_PARAGRAPH_V2 40324
#define IDS_RESET_PASSWORD_WARNING_EXPLANATION_PARAGRAPH_WITH_ORG_NAME 40325
#define IDS_RESET_PASSWORD_BUTTON 40326
#define IDS_RESET_PASSWORD_LEARN_MORE 40327
#define IDS_RESET_PASSWORD_EXPLANATION_PARAGRAPH 40328
#define IDS_RESET_PASSWORD_EXPLANATION_PARAGRAPH_WITH_ORG_NAME 40329
#define IDS_SAVED_TAB_GROUPS_CREATION_JUST_NOW 40330
#define IDS_SAVED_TAB_GROUPS_CREATION_MINUTES_AGO_FORMAT 40331
#define IDS_SAVED_TAB_GROUPS_CREATION_HOURS_AGO_FORMAT 40332
#define IDS_SAVED_TAB_GROUPS_CREATION_DAYS_AGO_FORMAT 40333
#define IDS_SAVED_TAB_GROUPS_CREATION_MONTHS_AGO_FORMAT 40334
#define IDS_SAVED_TAB_GROUPS_CREATION_YEARS_AGO_FORMAT 40335
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_SUBTITLE 40336
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_SUBTITLE_NON_EEA 40337
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_CHANGE_DEFAULT_ENGINE 40338
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_CONFIRMATION_TOAST_LABEL 40339
#define IDS_SEARCH_ENGINE_CHOICE_SETTINGS_ENTRY_POINT_SUBTITLE 40340
#define IDS_SEARCH_ENGINE_CHOICE_BUTTON_TITLE 40341
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_TITLE 40342
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE 40343
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE_INFO_LINK 40344
#define IDS_SEARCH_ENGINE_CHOICE_PAGE_SUBTITLE_INFO_LINK_A11Y_LABEL 40345
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_TITLE 40352
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_BODY_FIRST_PARAGRAPH 40353
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_BODY_SECOND_PARAGRAPH 40354
#define IDS_SEARCH_ENGINE_CHOICE_INFO_DIALOG_BODY_THIRD_PARAGRAPH 40355
#define IDS_SEARCH_ENGINE_FALLBACK_MARKETING_SNIPPET 40356
#define IDS_SEARCH_ENGINE_CHOICE_MORE_BUTTON 40357
#define IDS_SEARCH_ENGINE_CHOICE_CONTINUE_BUTTON 40358
#define IDS_SEARCH_ENGINE_CHOICE_CHEVRON_A11Y_LABEL 40359
#define IDS_SEARCH_ENGINE_CHOICE_LIST_A11Y_LABEL 40360
#define IDS_SEARCH_ENGINE_CHOICE_GUEST_SESSION_CHECKBOX 40361
#define IDS_SSL_OPEN_DETAILS_BUTTON 40362
#define IDS_SSL_CLOSE_DETAILS_BUTTON 40363
#define IDS_CAPTIVE_PORTAL_AUTHORIZATION_DIALOG_NAME 40364
#define IDS_CAPTIVE_PORTAL_HEADING_WIRED 40365
#define IDS_CAPTIVE_PORTAL_HEADING_WIFI 40366
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_WIRED 40367
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_WIFI 40368
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_WIFI_SSID 40369
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_NO_LOGIN_URL_WIRED 40370
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_NO_LOGIN_URL_WIFI 40371
#define IDS_CAPTIVE_PORTAL_PRIMARY_PARAGRAPH_NO_LOGIN_URL_WIFI_SSID 40372
#define IDS_CAPTIVE_PORTAL_BUTTON_OPEN_LOGIN_PAGE 40373
#define IDS_MITM_SOFTWARE_HEADING 40374
#define IDS_MITM_SOFTWARE_PRIMARY_PARAGRAPH_ENTERPRISE 40375
#define IDS_MITM_SOFTWARE_PRIMARY_PARAGRAPH_NONENTERPRISE 40376
#define IDS_MITM_SOFTWARE_EXPLANATION_ENTERPRISE 40377
#define IDS_MITM_SOFTWARE_EXPLANATION_NONENTERPRISE 40378
#define IDS_MITM_SOFTWARE_EXPLANATION 40379
#define IDS_LOOKALIKE_URL_TITLE 40380
#define IDS_LOOKALIKE_URL_HEADING 40381
#define IDS_LOOKALIKE_URL_IGNORE 40382
#define IDS_LOOKALIKE_URL_CONTINUE 40383
#define IDS_LOOKALIKE_URL_PRIMARY_PARAGRAPH 40384
#define IDS_LOOKALIKE_URL_HEADING_NO_SUGGESTED_URL 40385
#define IDS_LOOKALIKE_URL_PRIMARY_PARAGRAPH_NO_SUGGESTED_URL 40386
#define IDS_LOOKALIKE_URL_BACK_TO_SAFETY 40387
#define IDS_LOOKALIKE_URL_CLOSE_PAGE 40388
#define IDS_ENTERPRISE_BLOCK_TITLE 40389
#define IDS_ENTERPRISE_BLOCK_HEADING 40390
#define IDS_ENTERPRISE_BLOCK_PRIMARY_PARAGRAPH 40391
#define IDS_ENTERPRISE_BLOCK_PRIMARY_PARAGRAPH_CUSTOM_MESSAGE 40392
#define IDS_ENTERPRISE_BLOCK_GO_BACK 40393
#define IDS_ENTERPRISE_WARN_TITLE 40394
#define IDS_ENTERPRISE_WARN_HEADING 40395
#define IDS_ENTERPRISE_WARN_PRIMARY_PARAGRAPH 40396
#define IDS_ENTERPRISE_WARN_PRIMARY_PARAGRAPH_CUSTOM_MESSAGE 40397
#define IDS_ENTERPRISE_WARN_GO_BACK 40398
#define IDS_ENTERPRISE_WARN_CONTINUE_TO_SITE 40399
#define IDS_ENTERPRISE_INTERSTITIALS_LEARN_MORE_ACCCESSIBILITY_TEXT 40400
#define IDS_CLOCK_ERROR_TITLE 40401
#define IDS_CLOCK_ERROR_AHEAD_HEADING 40402
#define IDS_CLOCK_ERROR_BEHIND_HEADING 40403
#define IDS_CLOCK_ERROR_UPDATE_DATE_AND_TIME 40404
#define IDS_CLOCK_ERROR_PRIMARY_PARAGRAPH 40405
#define IDS_CLOCK_ERROR_EXPLANATION 40406
#define IDS_SSL_V2_TITLE 40407
#define IDS_SSL_V2_HEADING 40408
#define IDS_SSL_V2_PRIMARY_PARAGRAPH 40409
#define IDS_SSL_OVERRIDABLE_SAFETY_BUTTON 40410
#define IDS_SSL_OVERRIDABLE_CLOSE_PAGE_BUTTON 40411
#define IDS_SSL_OVERRIDABLE_PROCEED_PARAGRAPH 40412
#define IDS_SSL_RELOAD 40413
#define IDS_SSL_NONOVERRIDABLE_PINNED 40414
#define IDS_SSL_NONOVERRIDABLE_HSTS 40415
#define IDS_SSL_NONOVERRIDABLE_REVOKED 40416
#define IDS_SSL_NONOVERRIDABLE_MORE 40417
#define IDS_SSL_NONOVERRIDABLE_INVALID 40418
#define IDS_SAFEBROWSING_V3_TITLE 40419
#define IDS_SAFEBROWSING_V3_OPEN_DETAILS_BUTTON 40420
#define IDS_SAFEBROWSING_V3_CLOSE_DETAILS_BUTTON 40421
#define IDS_SAFEBROWSING_OVERRIDABLE_SAFETY_BUTTON 40422
#define IDS_SAFEBROWSING_HEADING 40423
#define IDS_MALWARE_V3_PRIMARY_PARAGRAPH 40424
#define IDS_MALWARE_V3_EXPLANATION_PARAGRAPH 40425
#define IDS_MALWARE_V3_PROCEED_PARAGRAPH 40426
#define IDS_SAFE_BROWSING_SCOUT_REPORTING_AGREE 40427
#define IDS_SAFE_BROWSING_ENHANCED_PROTECTION_MESSAGE 40428
#define IDS_HARMFUL_V3_PRIMARY_PARAGRAPH 40429
#define IDS_HARMFUL_V3_EXPLANATION_PARAGRAPH 40430
#define IDS_HARMFUL_V3_PROCEED_PARAGRAPH 40431
#define IDS_PHISHING_V4_PRIMARY_PARAGRAPH 40432
#define IDS_PHISHING_V4_EXPLANATION_PARAGRAPH 40433
#define IDS_PHISHING_V4_PROCEED_PARAGRAPH 40434
#define IDS_MALWARE_WEBVIEW_HEADING 40435
#define IDS_MALWARE_WEBVIEW_EXPLANATION_PARAGRAPH 40436
#define IDS_PHISHING_WEBVIEW_HEADING 40437
#define IDS_PHISHING_WEBVIEW_EXPLANATION_PARAGRAPH 40438
#define IDS_HARMFUL_WEBVIEW_HEADING 40439
#define IDS_HARMFUL_WEBVIEW_EXPLANATION_PARAGRAPH 40440
#define IDS_BILLING_WEBVIEW_HEADING 40441
#define IDS_BILLING_WEBVIEW_EXPLANATION_PARAGRAPH 40442
#define IDS_SUPERVISED_USER_URL_BLOCKED_MESSAGE 40443
#define IDS_SUPERVISED_USER_LEARN_MORE 40444
#define IDS_CONNECTION_HELP_SHOW_MORE 40445
#define IDS_CONNECTION_HELP_SHOW_LESS 40446
#define IDS_CONNECTION_HELP_TITLE 40447
#define IDS_CONNECTION_HELP_HEADING 40448
#define IDS_CONNECTION_HELP_GENERAL_HELP 40449
#define IDS_CONNECTION_HELP_SPECIFIC_ERROR_HEADING 40450
#define IDS_CONNECTION_HELP_CONNECTION_NOT_PRIVATE_TITLE 40451
#define IDS_CONNECTION_HELP_CONNECT_TO_NETWORK_TITLE 40452
#define IDS_CONNECTION_HELP_INCORRECT_CLOCK_TITLE 40453
#define IDS_CONNECTION_HELP_CONNECTION_NOT_PRIVATE_DETAILS 40454
#define IDS_CONNECTION_HELP_CONNECT_TO_NETWORK_DETAILS 40455
#define IDS_CONNECTION_HELP_INCORRECT_CLOCK_DETAILS 40456
#define IDS_BILLING_TITLE 40459
#define IDS_BILLING_HEADING 40460
#define IDS_BILLING_PRIMARY_PARAGRAPH 40461
#define IDS_BILLING_PRIMARY_BUTTON 40462
#define IDS_BILLING_PROCEED_BUTTON 40463
#define IDS_BLOCKED_INTERCEPTION_HEADING 40464
#define IDS_KNOWN_INTERCEPTION_TITLE 40465
#define IDS_KNOWN_INTERCEPTION_HEADER 40466
#define IDS_KNOWN_INTERCEPTION_BODY1 40467
#define IDS_KNOWN_INTERCEPTION_BODY2 40468
#define IDS_KNOWN_INTERCEPTION_INFOBAR_HEADING 40469
#define IDS_KNOWN_INTERCEPTION_INFOBAR_BUTTON_TEXT 40470
#define IDS_LEGACY_TLS_HEADING 40471
#define IDS_LEGACY_TLS_PRIMARY_PARAGRAPH 40472
#define IDS_LEGACY_TLS_EXPLANATION 40473
#define IDS_INSECURE_FORM_TITLE 40474
#define IDS_INSECURE_FORM_HEADING 40475
#define IDS_INSECURE_FORM_PRIMARY_PARAGRAPH 40476
#define IDS_INSECURE_FORM_BACK_BUTTON 40477
#define IDS_INSECURE_FORM_SUBMIT_BUTTON 40478
#define IDS_HTTPS_ONLY_MODE_TITLE 40479
#define IDS_HTTPS_ONLY_MODE_HEADING 40480
#define IDS_HTTPS_ONLY_MODE_PRIMARY_PARAGRAPH 40481
#define IDS_HTTPS_ONLY_BALANCED_MODE_HEADING 40482
#define IDS_HTTPS_ONLY_BALANCED_MODE_PRIMARY_PARAGRAPH 40483
#define IDS_HTTPS_ONLY_MODE_WITH_ADVANCED_PROTECTION_PRIMARY_PARAGRAPH 40484
#define IDS_HTTPS_ONLY_MODE_WITH_SITE_ENGAGEMENT_PRIMARY_PARAGRAPH 40486
#define IDS_HTTPS_ONLY_MODE_FOR_TYPICALLY_SECURE_BROWSING_PRIMARY_PARAGRAPH 40487
#define IDS_HTTPS_ONLY_MODE_FOR_INCOGNITO_PRIMARY_PARAGRAPH 40488
#define IDS_HTTPS_ONLY_MODE_BACK_BUTTON 40489
#define IDS_HTTPS_ONLY_MODE_SUBMIT_BUTTON 40490
#define IDS_ABH_PROMPT_TITLE 40491
#define IDS_ABH_PROMPT_BALANCED_MODE_FIRST_ITEM_TEXT 40492
#define IDS_ABH_PROMPT_BALANCED_MODE_SECOND_ITEM_TEXT 40493
#define IDS_ABH_PROMPT_SECONDARY_TEXT 40494
#define IDS_ABH_PROMPT_LEARN_MORE_LINK 40495
#define IDS_ABH_PROMPT_SITE_ENGAGEMENT_PRIMARY_PARAGRAPH 40496
#define IDS_ABH_PROMPT_TYPICALLY_SECURE_BROWSING_PRIMARY_PARAGRAPH 40497
#define IDS_ABH_PROMPT_INCOGNITO_PRIMARY_PARAGRAPH 40498
#define IDS_ABH_PROMPT_ADVANCED_PROTECTION_PRIMARY_PARAGRAPH 40499
#define IDS_SHARING_DEVICE_TYPE_COMPUTER 40500
#define IDS_SHARING_DEVICE_TYPE_DEVICE 40501
#define IDS_SHARING_DEVICE_TYPE_PHONE 40502
#define IDS_SHARING_DEVICE_TYPE_TABLET 40503
#define IDS_SEND_TAB_PUSH_NOTIFICATION_TITLE_DEAULT_DEVICE_NAME 40504
#define IDS_SEND_TAB_PUSH_NOTIFICATION_TITLE_USER_GIVEN_DEVICE_NAME 40505
#define IDS_SEND_TAB_PUSH_NOTIFICATION_BODY 40506
#define IDS_SEND_TAB_PUSH_NOTIFICATION_PLACEHOLDER_TITLE 40507
#define IDS_SEND_TAB_PUSH_NOTIFICATION_PLACEHOLDER_BODY 40508
#define IDS_SEND_TAB_RECEIVE_TOAST_FOREGROUND 40509
#define IDS_SEND_TAB_RECEIVE_TOAST_BACKGROUND 40510
#define IDS_SEND_TAB_RECEIVE_TOAST_BACKGROUND_ACTION_BUTTON 40511
#define IDS_SEND_TAB_TO_SELF_POST_SEND_SUCCESS_TOAST 40512
#define IDS_SITE_SETTINGS_TYPE_ADS 40513
#define IDS_SITE_SETTINGS_TYPE_ADS_MID_SENTENCE 40514
#define IDS_SITE_SETTINGS_TYPE_ANTI_ABUSE 40515
#define IDS_SITE_SETTINGS_TYPE_AR 40516
#define IDS_SITE_SETTINGS_TYPE_AR_MID_SENTENCE 40517
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_DOWNLOADS 40518
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_DOWNLOADS_MID_SENTENCE 40519
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_FULLSCREEN 40520
#define IDS_SITE_SETTINGS_TYPE_AUTOMATIC_FULLSCREEN_MID_SENTENCE 40521
#define IDS_SITE_SETTINGS_TYPE_AUTO_PICTURE_IN_PICTURE 40522
#define IDS_SITE_SETTINGS_TYPE_AUTO_PICTURE_IN_PICTURE_MID_SENTENCE 40523
#define IDS_SITE_SETTINGS_TYPE_BACKGROUND_SYNC 40524
#define IDS_SITE_SETTINGS_TYPE_BACKGROUND_SYNC_MID_SENTENCE 40525
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_DEVICES 40526
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_DEVICES_MID_SENTENCE 40527
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_SCANNING 40528
#define IDS_SITE_SETTINGS_TYPE_BLUETOOTH_SCANNING_MID_SENTENCE 40529
#define IDS_SITE_SETTINGS_TYPE_CAMERA 40530
#define IDS_SITE_SETTINGS_TYPE_CAMERA_MID_SENTENCE 40531
#define IDS_SITE_SETTINGS_TYPE_CAMERA_WITH_COUNT 40532
#define IDS_SITE_SETTINGS_TYPE_CAMERA_PAN_TILT_ZOOM 40533
#define IDS_SITE_SETTINGS_TYPE_CAMERA_PAN_TILT_ZOOM_MID_SENTENCE 40534
#define IDS_SITE_SETTINGS_TYPE_CAMERA_PAN_TILT_ZOOM_WITH_COUNT 40535
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL 40536
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_MID_SENTENCE 40537
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_SHARED_TABS 40538
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_SHARED_TABS_MID_SENTENCE 40539
#define IDS_SITE_SETTINGS_TYPE_CAPTURED_SURFACE_CONTROL_SUB_MENU 40540
#define IDS_SITE_SETTINGS_TYPE_CLIPBOARD 40541
#define IDS_SITE_SETTINGS_TYPE_CLIPBOARD_MID_SENTENCE 40542
#define IDS_SITE_SETTINGS_TYPE_COOKIES 40543
#define IDS_SITE_SETTINGS_TYPE_COOKIES_MID_SENTENCE 40544
#define IDS_SITE_SETTINGS_TYPE_FEDERATED_IDENTITY_API 40545
#define IDS_SITE_SETTINGS_TYPE_FEDERATED_IDENTITY_API_MID_SENTENCE 40546
#define IDS_SITE_SETTINGS_TYPE_HAND_TRACKING 40547
#define IDS_SITE_SETTINGS_TYPE_HAND_TRACKING_MID_SENTENCE 40548
#define IDS_SITE_SETTINGS_TYPE_IDLE_DETECTION 40549
#define IDS_SITE_SETTINGS_TYPE_IDLE_DETECTION_MID_SENTENCE 40550
#define IDS_SITE_SETTINGS_TYPE_JAVASCRIPT 40551
#define IDS_SITE_SETTINGS_TYPE_JAVASCRIPT_MID_SENTENCE 40552
#define IDS_SITE_SETTINGS_TYPE_JAVASCRIPT_OPTIMIZER 40553
#define IDS_SITE_SETTINGS_TYPE_LOCATION 40554
#define IDS_SITE_SETTINGS_TYPE_LOCATION_MID_SENTENCE 40555
#define IDS_SITE_SETTINGS_TYPE_MIC 40556
#define IDS_SITE_SETTINGS_TYPE_MIC_MID_SENTENCE 40557
#define IDS_SITE_SETTINGS_TYPE_MIC_WITH_COUNT 40558
#define IDS_SITE_SETTINGS_TYPE_MIDI_SYSEX 40559
#define IDS_SITE_SETTINGS_TYPE_MIDI_SYSEX_MID_SENTENCE 40560
#define IDS_SITE_SETTINGS_TYPE_MOTION_AND_LIGHT_SENSORS 40561
#define IDS_SITE_SETTINGS_TYPE_MOTION_AND_LIGHT_SENSORS_MID_SENTENCE 40562
#define IDS_SITE_SETTINGS_TYPE_MOTION_SENSORS 40563
#define IDS_SITE_SETTINGS_TYPE_MOTION_SENSORS_MID_SENTENCE 40564
#define IDS_SITE_SETTINGS_TYPE_NFC 40565
#define IDS_SITE_SETTINGS_TYPE_NFC_MID_SENTENCE 40566
#define IDS_SITE_SETTINGS_TYPE_NOTIFICATIONS 40567
#define IDS_SITE_SETTINGS_TYPE_NOTIFICATIONS_MID_SENTENCE 40568
#define IDS_SITE_SETTINGS_TYPE_POPUPS_REDIRECTS 40569
#define IDS_SITE_SETTINGS_TYPE_POPUPS_REDIRECTS_MID_SENTENCE 40570
#define IDS_SITE_SETTINGS_TYPE_PROTECTED_MEDIA_ID 40571
#define IDS_SITE_SETTINGS_TYPE_PROTECTED_MEDIA_ID_MID_SENTENCE 40572
#define IDS_SITE_SETTINGS_TYPE_SOUND 40573
#define IDS_SITE_SETTINGS_TYPE_SOUND_MID_SENTENCE 40574
#define IDS_SITE_SETTINGS_TYPE_USB_DEVICES 40575
#define IDS_SITE_SETTINGS_TYPE_USB_DEVICES_MID_SENTENCE 40576
#define IDS_SITE_SETTINGS_TYPE_VR 40577
#define IDS_SITE_SETTINGS_TYPE_VR_MID_SENTENCE 40578
#define IDS_SITE_SETTINGS_TYPE_STORAGE_ACCESS 40579
#define IDS_SITE_SETTINGS_TYPE_STORAGE_ACCESS_MID_SENTENCE 40580
#define IDS_SITE_SETTINGS_TYPE_FILE_SYSTEM_ACCESS_WRITE 40581
#define IDS_SITE_SETTINGS_TYPE_FILE_SYSTEM_ACCESS_WRITE_MID_SENTENCE 40582
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK_ACCESS 40583
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK_ACCESS_MID_SENTENCE 40584
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK 40585
#define IDS_SITE_SETTINGS_TYPE_LOCAL_NETWORK_MID_SENTENCE 40586
#define IDS_SITE_SETTINGS_TYPE_LOOPBACK_NETWORK 40587
#define IDS_SITE_SETTINGS_TYPE_LOOPBACK_NETWORK_MID_SENTENCE 40588
#define IDS_SITE_SETTINGS_TYPE_WINDOW_MANAGEMENT 40589
#define IDS_SITE_SETTINGS_TYPE_WINDOW_MANAGEMENT_MID_SENTENCE 40590
#define IDS_SITE_SETTINGS_TYPE_FONT_ACCESS 40591
#define IDS_SITE_SETTINGS_TYPE_FONT_ACCESS_MID_SENTENCE 40592
#define IDS_SITE_SETTINGS_TYPE_HANDLERS 40593
#define IDS_SITE_SETTINGS_TYPE_HANDLERS_MID_SENTENCE 40594
#define IDS_SITE_SETTINGS_TYPE_HID_DEVICES 40595
#define IDS_SITE_SETTINGS_TYPE_HID_DEVICES_MID_SENTENCE 40596
#define IDS_SITE_SETTINGS_TYPE_IMAGES 40597
#define IDS_SITE_SETTINGS_TYPE_IMAGES_MID_SENTENCE 40598
#define IDS_SITE_SETTINGS_TYPE_INSECURE_CONTENT 40599
#define IDS_SITE_SETTINGS_TYPE_INSECURE_CONTENT_MID_SENTENCE 40600
#define IDS_SITE_SETTINGS_TYPE_KEYBOARD_LOCK 40601
#define IDS_SITE_SETTINGS_TYPE_KEYBOARD_LOCK_MID_SENTENCE 40602
#define IDS_SITE_SETTINGS_TYPE_PAYMENT_HANDLER 40603
#define IDS_SITE_SETTINGS_TYPE_PAYMENT_HANDLER_MID_SENTENCE 40604
#define IDS_SITE_SETTINGS_TYPE_PDF_DOCUMENTS 40605
#define IDS_SITE_SETTINGS_TYPE_POINTER_LOCK 40606
#define IDS_SITE_SETTINGS_TYPE_POINTER_LOCK_MID_SENTENCE 40607
#define IDS_SITE_SETTINGS_TYPE_SERIAL_PORTS 40608
#define IDS_SITE_SETTINGS_TYPE_SERIAL_PORTS_MID_SENTENCE 40609
#define IDS_SITE_SETTINGS_TYPE_ZOOM_LEVELS 40611
#define IDS_SITE_SETTINGS_TYPE_ZOOM_LEVELS_MID_SENTENCE 40612
#define IDS_SITE_SETTINGS_TYPE_WEB_APP_INSTALLATION 40613
#define IDS_SITE_SETTINGS_TYPE_WEB_APP_INSTALLATION_MID_SENTENCE 40614
#define IDS_SITE_SETTINGS_TYPE_WEB_PRINTING 40615
#define IDS_SITE_SETTINGS_TYPE_WEB_PRINTING_MID_SENTENCE 40616
#define IDS_SITE_SETTINGS_TYPE_PERFORMANCE 40617
#define IDS_SITE_SETTINGS_TYPE_PERFORMANCE_SUBLABEL 40618
#define IDS_SITE_SETTINGS_TYPE_OFFER_WRITING_HELP 40619
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_HEADER 40620
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_HEADER_V2 40621
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_MESSAGE_BODY 40622
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_MESSAGE_BODY_ALT 40623
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_MESSAGE_BODY_V2 40624
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_LEARN_MORE 40625
#define IDS_STS_IPH_PROMPT_FIRST_TIME_ADDING_CONTEXT_TURN_ON 40626
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_HEADER 40627
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_HEADER_ALT 40628
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_HEADER_V2 40629
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_MESSAGE_BODY 40630
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_MESSAGE_BODY_ALT 40631
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_MESSAGE_BODY_V2 40632
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_LEARN_MORE 40633
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_TURN_ON 40634
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_NOT_NOW 40635
#define IDS_STS_IPH_PROMPT_TURN_ON_FOR_ALL_THREADS_GO_TO_SETTINGS 40636
#define IDS_STS_CONTEXT_REMINDER_USED_FOLLOWING_TABS 40637
#define IDS_STS_CONTEXT_REMINDER_EXCLUDE_SITES 40638
#define IDS_STS_CONTEXT_REMINDER_MANAGE 40639
#define IDS_STS_CONSIDERING_RELEVANT_OPEN_TABS 40640
#define IDS_STS_CONTEXT_REMINDER_CHANGE_IN_SETTINGS 40641
#define IDS_STS_SETTINGS_OPTION_1_SHARE_OPEN_TABS_FOR_EVERY_THREAD 40642
#define IDS_STS_SETTINGS_OPTION_1_SHARE_OPEN_TABS_FOR_EVERY_THREAD_V2 40643
#define IDS_STS_SETTINGS_OPTION_1_SHARE_OPEN_TABS_BY_DEFAULT 40644
#define IDS_STS_SETTINGS_OPTION_1_CHOOSE_HOW_RELEVANT_OPEN_TABS_CAN_BE_USED_V2 40645
#define IDS_STS_SETTINGS_OPTION_1_LEARN_MORE 40646
#define IDS_STS_SETTINGS_OPTION_1_WHEN_ON 40647
#define IDS_STS_SETTINGS_OPTION_1_RELEVANT_OPEN_TABS_ARE_USED_TO_PERSONALIZE 40648
#define IDS_STS_SETTINGS_OPTION_1_YOU_CAN_EASILY_ASK_QUESTIONS 40649
#define IDS_STS_SETTINGS_OPTION_1_THINGS_TO_CONSIDER 40650
#define IDS_STS_SETTINGS_OPTION_1_SENDS_YOUR_OPEN_TABS 40651
#define IDS_STS_SETTINGS_OPTION_1_SEEN_BY_HUMAN_REVIEWERS 40652
#define IDS_STS_SETTINGS_OPTION_1_SITE_EXCLUSIONS 40653
#define IDS_STS_SETTINGS_OPTION_1_NEVER_SHARE_THESE_SITES 40654
#define IDS_STS_SETTINGS_OPTION_1_SITES_ADDED_HERE_WONT_BE_REFERENCED 40655
#define IDS_STS_SETTINGS_OPTION_1_SITES_ADDED_HERE_WONT_BE_REFERENCED_V2 40656
#define IDS_STS_OPTION_2_SHARE_OPEN_TABS_FOR_EVERY_THREAD 40657
#define IDS_STS_OPTION_2_CHOOSE_HOW_RELEVANT_OPEN_TABS_CAN_BE_USED 40658
#define IDS_STS_OPTION_2_LEARN_MORE 40659
#define IDS_STS_OPTION_2_DO_NOT_SHARE_AUTOMATICALLY 40660
#define IDS_STS_OPTION_2_DO_NOT_SHARE_AUTOMATICALLY_DETAIL 40661
#define IDS_STS_OPTION_2_SHARE_AUTOMATICALLY 40662
#define IDS_STS_OPTION_2_SHARE_AUTOMATICALLY_DETAIL 40663
#define IDS_STS_OPTION_2_SITE_EXCLUSIONS 40664
#define IDS_STS_OPTION_2_SITES_ADDED_HERE_WONT_BE_REFERENCED 40665
#define IDS_STS_SETTINGS_ENTRYPOINT_AI_MODE_SEARCH 40666
#define IDS_STS_SETTINGS_ENTRYPOINT_GOOGLE_SEARCH_AI_MODE 40667
#define IDS_STS_SETTINGS_ENTRYPOINT_GET_RESPONSES_WITH_CONTEXT 40668
#define IDS_STS_SETTINGS_ENTRYPOINT_LEARN_MORE 40669
#define IDS_STS_MEGAPLUS_SHARE_RELEVANT_OPEN_TABS 40670
#define IDS_STS_CONTEXT_MENU_TOGGLE_LABEL 40671
#define IDS_STS_THREAD_PROMO_CARD_ALWAYS_SHARE_RELEVANT_OPEN_TABS 40672
#define IDS_STS_THREAD_PROMO_CARD_MESSAGE_BODY 40673
#define IDS_SMS_INFOBAR_TITLE 40674
#define IDS_SMS_INFOBAR_STATUS_SMS_RECEIVED 40675
#define IDS_SMS_INFOBAR_STATUS_SMS_RECEIVED_FROM_EMBEDDED_FRAME 40676
#define IDS_SMS_INFOBAR_BUTTON_OK 40677
#define IDS_CERT_ERROR_NO_SUBJECT_ALTERNATIVE_NAMES_DETAILS 40678
#define IDS_CERT_ERROR_COMMON_NAME_INVALID_DETAILS 40679
#define IDS_CERT_ERROR_COMMON_NAME_INVALID_DESCRIPTION 40680
#define IDS_CERT_ERROR_EXPIRED_DETAILS 40681
#define IDS_CERT_ERROR_EXPIRED_DESCRIPTION 40682
#define IDS_CERT_ERROR_NOT_YET_VALID_DETAILS 40683
#define IDS_CERT_ERROR_NOT_YET_VALID_DESCRIPTION 40684
#define IDS_CERT_ERROR_NOT_VALID_AT_THIS_TIME_DETAILS 40685
#define IDS_CERT_ERROR_NOT_VALID_AT_THIS_TIME_DESCRIPTION 40686
#define IDS_CERT_ERROR_AUTHORITY_INVALID_DESCRIPTION 40687
#define IDS_CERT_ERROR_CONTAINS_ERRORS_DETAILS 40688
#define IDS_CERT_ERROR_CONTAINS_ERRORS_DESCRIPTION 40689
#define IDS_CERT_ERROR_UNABLE_TO_CHECK_REVOCATION_DETAILS 40690
#define IDS_CERT_ERROR_UNABLE_TO_CHECK_REVOCATION_DESCRIPTION 40691
#define IDS_CERT_ERROR_NO_REVOCATION_MECHANISM_DETAILS 40692
#define IDS_CERT_ERROR_NO_REVOCATION_MECHANISM_DESCRIPTION 40693
#define IDS_CERT_ERROR_REVOKED_CERT_DETAILS 40694
#define IDS_CERT_ERROR_REVOKED_CERT_DESCRIPTION 40695
#define IDS_CERT_ERROR_INVALID_CERT_DETAILS 40696
#define IDS_CERT_ERROR_INVALID_CERT_DESCRIPTION 40697
#define IDS_CERT_ERROR_WEAK_SIGNATURE_ALGORITHM_DETAILS 40698
#define IDS_CERT_ERROR_WEAK_SIGNATURE_ALGORITHM_DESCRIPTION 40699
#define IDS_CERT_ERROR_WEAK_KEY_DETAILS 40700
#define IDS_CERT_ERROR_WEAK_KEY_DESCRIPTION 40701
#define IDS_CERT_ERROR_NAME_CONSTRAINT_VIOLATION_DETAILS 40702
#define IDS_CERT_ERROR_NAME_CONSTRAINT_VIOLATION_DESCRIPTION 40703
#define IDS_CERT_ERROR_VALIDITY_TOO_LONG_DETAILS 40704
#define IDS_CERT_ERROR_VALIDITY_TOO_LONG_DESCRIPTION 40705
#define IDS_CERT_ERROR_NON_UNIQUE_NAME_DETAILS 40706
#define IDS_CERT_ERROR_NON_UNIQUE_NAME_DESCRIPTION 40707
#define IDS_CERT_ERROR_UNKNOWN_ERROR_DETAILS 40708
#define IDS_CERT_ERROR_UNKNOWN_ERROR_DESCRIPTION 40709
#define IDS_CERT_ERROR_SUMMARY_PINNING_FAILURE_DETAILS 40710
#define IDS_CERT_ERROR_SUMMARY_PINNING_FAILURE_DESCRIPTION 40711
#define IDS_CERT_ERROR_CERTIFICATE_TRANSPARENCY_REQUIRED_DETAILS 40712
#define IDS_CERT_ERROR_CERTIFICATE_TRANSPARENCY_REQUIRED_DESCRIPTION 40713
#define IDS_SSL_ERROR_OBSOLETE_VERSION_DETAILS 40714
#define IDS_SSL_ERROR_OBSOLETE_VERSION_DESCRIPTION 40715
#define IDS_CERT_ERROR_AUTHORITY_INVALID_DETAILS 40716
#define IDS_CERT_ERROR_AUTHORITY_INVALID_DETAILS_V2 40717
#define IDS_ALWAYS_ALLOW_ADS 40718
#define IDS_BLOCKED_ADS_PROMPT_EXPLANATION 40719
#define IDS_BLOCKED_ADS_PROMPT_TITLE 40720
#define IDS_BLOCK_INTERSTITIAL_TITLE 40727
#define IDS_CHILD_BLOCK_INTERSTITIAL_HEADER 40728
#define IDS_BLOCK_INTERSTITIAL_HEADER_ACCESS_REQUESTS_DISABLED 40729
#define IDS_CHILD_BLOCK_INTERSTITIAL_MESSAGE_V2 40730
#define IDS_SUPERVISED_USER_INTERSTITIAL_MESSAGE_BLOCK_ALL 40731
#define IDS_SUPERVISED_USER_INTERSTITIAL_MESSAGE_SAFE_SITES 40732
#define IDS_SUPERVISED_USER_INTERSTITIAL_MESSAGE_MANUAL 40733
#define IDS_CHILD_BLOCK_INTERSTITIAL_MESSAGE_NOT_SIGNED_IN 40734
#define IDS_REQUEST_SENT_OK 40735
#define IDS_BLOCK_INTERSTITIAL_ASK_IN_PERSON_BUTTON 40736
#define IDS_BLOCK_INTERSTITIAL_ASK_IN_PERSON_INSTEAD_BUTTON 40737
#define IDS_BLOCK_INTERSTITIAL_ASK_IN_A_MESSAGE_BUTTON 40738
#define IDS_CHILD_BLOCK_INTERSTITIAL_WAITING_APPROVAL_MESSAGE 40739
#define IDS_CHILD_BLOCK_INTERSTITIAL_WAITING_APPROVAL_DESCRIPTION_SINGLE_PARENT 40740
#define IDS_CHILD_BLOCK_INTERSTITIAL_WAITING_APPROVAL_DESCRIPTION_MULTI_PARENT 40741
#define IDS_CHILD_BLOCK_INTERSTITIAL_REQUEST_FAILED_MESSAGE_SINGLE_PARENT 40742
#define IDS_CHILD_BLOCK_INTERSTITIAL_REQUEST_FAILED_MESSAGE_MULTI_PARENT 40743
#define IDS_BLOCK_INTERSTITIAL_SHOW_DETAILS 40744
#define IDS_BLOCK_INTERSTITIAL_HIDE_DETAILS 40745
#define IDS_GENERIC_SITE_BLOCK_HEADER 40746
#define IDS_SUPERVISED_USER_BLOCK_HEADER 40747
#define IDS_CHILD_BLOCK_MESSAGE_DEFAULT_SINGLE_PARENT 40748
#define IDS_CHILD_BLOCK_MESSAGE_DEFAULT_MULTI_PARENT 40749
#define IDS_SUPERVISED_USER_BLOCK_MESSAGE_SAFE_SITES 40750
#define IDS_CHILD_BLOCK_MESSAGE_MANUAL_SINGLE_PARENT 40751
#define IDS_CHILD_BLOCK_MESSAGE_MANUAL_MULTI_PARENT 40752
#define IDS_SUPERVISED_USER_VERIFY_PAGE_TAB_TITLE 40753
#define IDS_SUPERVISED_USER_VERIFY_PAGE_PRIMARY_HEADING 40754
#define IDS_SUPERVISED_USER_VERIFY_PAGE_PRIMARY_PARAGRAPH 40755
#define IDS_SUPERVISED_USER_VERIFY_PAGE_PRIMARY_BUTTON 40756
#define IDS_SUPERVISED_USER_VERIFY_PAGE_SUBFRAME_YOUTUBE_HEADING 40757
#define IDS_SUPERVISED_USER_VERIFY_PAGE_SUBFRAME_BLOCKED_SITE_HEADING 40758
#define IDS_PARENT_WEBSITE_APPROVAL_BLOCK_ALL_URL 40759
#define IDS_PARENT_WEBSITE_APPROVAL_SAFE_SITES_URL 40760
#define IDS_PARENT_WEBSITE_APPROVAL_MANUAL_URL 40761
#define IDS_PARENT_WEBSITE_APPROVAL_DIALOG_A11Y_NAME 40762
#define IDS_PARENTAL_LOCAL_APPROVAL_DIALOG_GENERIC_ERROR_TITLE 40763
#define IDS_PARENTAL_LOCAL_APPROVAL_DIALOG_GENERIC_ERROR_DESCRIPTION 40764
#define IDS_PARENTAL_LOCAL_APPROVAL_DIALOG_GENERIC_ERROR_BACK_BUTTON 40765
#define IDS_PARENTAL_LOCAL_APPROVAL_SNACKBAR_GENERIC_ERROR_TITLE 40766
#define IDS_PARENTAL_LOCAL_APPROVAL_SNACKBAR_GENERIC_ERROR_BACK_BUTTON 40767
#define IDS_SYNC_BASIC_ENCRYPTION_DATA 40771
#define IDS_SYNC_DATATYPE_AUTOFILL 40772
#define IDS_SYNC_DATATYPE_BOOKMARKS 40773
#define IDS_SYNC_DATATYPE_PASSWORDS 40774
#define IDS_SYNC_DATATYPE_PASSWORDS_AND_PASSKEYS 40775
#define IDS_SYNC_DATATYPE_PREFERENCES 40776
#define IDS_SYNC_DATATYPE_TABS 40777
#define IDS_SYNC_DATATYPE_TYPED_URLS 40778
#define IDS_SYNC_DATATYPE_HISTORY_AND_TABS 40779
#define IDS_SYNC_DATATYPE_READING_LIST 40780
#define IDS_SYNC_EMPTY_PASSPHRASE_ERROR 40781
#define IDS_SYNC_ENCRYPTION_SECTION_TITLE 40782
#define IDS_SYNC_FULL_ENCRYPTION_DATA 40783
#define IDS_SYNC_LOGIN_SETTING_UP 40784
#define IDS_SYNC_PASSPHRASE_LABEL 40785
#define IDS_SYNC_PASSPHRASE_MISMATCH_ERROR 40786
#define IDS_SYNC_ENTER_PASSPHRASE_BODY_WITH_DATE 40787
#define IDS_SYNC_ENTER_PASSPHRASE_BODY 40788
#define IDS_BULK_UPLOAD_SUBTITLE 40789
#define IDS_BULK_UPLOAD_BOOKMARK_FOLDER_SUBTITLE 40790
#define IDS_TAB_GROUP_COLOR_GREY 40791
#define IDS_TAB_GROUP_COLOR_BLUE 40792
#define IDS_TAB_GROUP_COLOR_RED 40793
#define IDS_TAB_GROUP_COLOR_YELLOW 40794
#define IDS_TAB_GROUP_COLOR_MAGENTA 40795
#define IDS_TAB_GROUP_COLOR_GREEN 40796
#define IDS_TAB_GROUP_COLOR_PINK 40797
#define IDS_TAB_GROUP_COLOR_LIME 40798
#define IDS_TAB_GROUP_COLOR_PURPLE 40799
#define IDS_TAB_GROUP_COLOR_CYAN 40800
#define IDS_TAB_GROUP_COLOR_ORANGE 40801
#define IDS_TAB_RESUME_DECORATORS_VISITED_X_AGO 40802
#define IDS_TAB_RESUME_DECORATORS_VISITED_RECENTLY 40803
#define IDS_TAB_RESUME_DECORATORS_FREQUENTLY_VISITED 40804
#define IDS_TAB_RESUME_DECORATORS_CONTINUE_READING 40805
#define IDS_TAB_RESUME_DECORATORS_MOST_RECENT 40806
#define IDS_TAB_RESUME_DECORATORS_TIME_OF_DAY 40807
#define IDS_TAB_RESUME_DECORATORS_VISITED_X_AGO_IOS 40808
#define IDS_TAB_RESUME_DECORATORS_VISITED_RECENTLY_IOS 40809
#define IDS_TAB_RESUME_DECORATORS_FREQUENTLY_VISITED_IOS 40810
#define IDS_TAB_RESUME_DECORATORS_MOST_RECENT_IOS 40811
#define IDS_TAB_RESUME_N_MINUTES_AGO_NARROW 40812
#define IDS_TAB_RESUME_N_HOURS_AGO_NARROW 40813
#define IDS_TRANSLATE_NOTIFICATION_UNDO 40829
#define IDS_TRANSLATE_DETECTED_LANGUAGE 40830
#define IDS_BOOKMARK_BAR_UNDO 40831
#define IDS_BOOKMARK_BAR_REDO 40832
#define IDS_BOOKMARK_BAR_UNDO_ADD 40833
#define IDS_BOOKMARK_BAR_REDO_ADD 40834
#define IDS_BOOKMARK_BAR_UNDO_DELETE 40835
#define IDS_BOOKMARK_BAR_REDO_DELETE 40836
#define IDS_BOOKMARK_BAR_UNDO_EDIT 40837
#define IDS_BOOKMARK_BAR_REDO_EDIT 40838
#define IDS_BOOKMARK_BAR_UNDO_MOVE 40839
#define IDS_BOOKMARK_BAR_REDO_MOVE 40840
#define IDS_BOOKMARK_BAR_UNDO_REORDER 40841
#define IDS_BOOKMARK_BAR_REDO_REORDER 40842
#define IDS_IMPORTED_FROM_SAFARI_FOLDER 40843
#define IDS_IMPORTED_FOLDER 40844
#define IDS_CLOSE_TUTORIAL 40845
#define IDS_CLOSE_PROMO 40846
#define IDS_HELP_BUBBLE 40847
#define IDS_PROMO_DISMISS_BUTTON 40848
#define IDS_PROMO_SNOOZE_BUTTON 40849
#define IDS_PROMO_SHOW_TUTORIAL_BUTTON 40850
#define IDS_TUTORIAL_RESTART_TUTORIAL 40851
#define IDS_PROMO_LEARN_MORE_BUTTON 40852
#define IDS_TUTORIAL_CLOSE_TUTORIAL 40853
#define IDS_TUTORIAL_NEXT_BUTTON 40854
#define IDS_PROMO_MANAGE_BUTTON 40855
#define IDS_VERSION_UI_TITLE 40856
#define IDS_VERSION_UI_OFFICIAL 40857
#define IDS_VERSION_UI_UNOFFICIAL 40858
#define IDS_VERSION_UI_32BIT 40859
#define IDS_VERSION_UI_64BIT 40860
#define IDS_VERSION_UI_REVISION 40865
#define IDS_VERSION_UI_OS 40866
#define IDS_VERSION_UI_USER_AGENT 40868
#define IDS_VERSION_UI_COMMAND_LINE 40869
#define IDS_VERSION_UI_COPY_LABEL 40873
#define IDS_VERSION_UI_COPY_NOTICE 40874
#define IDS_VERSION_UI_EXECUTABLE_PATH 40875
#define IDS_VERSION_UI_PROFILE_PATH 40876
#define IDS_VERSION_UI_MODULE_PATH 40877
#define IDS_VERSION_UI_USER_DATA_PATH 40878
#define IDS_VERSION_UI_PATH_NOTFOUND 40879
#define IDS_VERSION_UI_VARIATIONS 40880
#define IDS_VERSION_UI_VARIATIONS_SOURCE_NAME 40881
#define IDS_VERSION_UI_VARIATIONS_SEED_NAME 40882
#define IDS_VERSION_UI_VARIATIONS_CMD 40883
#define IDS_VERSION_UI_COPY_VARIATIONS_LABEL 40884
#define IDS_VERSION_UI_COPY_VARIATIONS_NOTICE 40885
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_TITLE 40890
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_NO_THANKS_BUTTON 40891
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_TURN_ON_BUTTON 40892
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_LEARN_MORE 40893
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_SUBTITLE_DESCRIPTION 40894
#define IDS_WALLET_WALLETABLE_PASS_CONSENT_DIALOG_SUBTITLE_ACTION 40895
#define IDS_WALLET_WALLETABLE_PASS_SAVE_LOYALTY_CARD_DIALOG_TITLE 40896
#define IDS_WALLET_WALLETABLE_PASS_SAVE_EVENT_TICKET_DIALOG_TITLE 40897
#define IDS_WALLET_WALLETABLE_PASS_SAVE_TRANSPORT_TICKET_DIALOG_TITLE 40898
#define IDS_WALLET_WALLETABLE_PASS_SAVE_BOARDING_PASS_DIALOG_TITLE 40899
#define IDS_WALLET_WALLETABLE_PASS_GOOGLE_WALLET_TITLE 40900
#define IDS_WALLET_WALLETABLE_PASS_SAVE_DIALOG_SUBTITLE 40901
#define IDS_WALLET_WALLETABLE_PASS_SAVE_DIALOG_NO_THANKS_BUTTON 40902
#define IDS_WALLET_WALLETABLE_PASS_SAVE_DIALOG_SAVE_BUTTON 40903
#define IDS_WALLET_WALLETABLE_PASS_LOYALTY_CARD_ISSUER_ATTRIBUTE_NAME 40904
#define IDS_WALLET_WALLETABLE_PASS_LOYALTY_CARD_MEMBER_ID_ATTRIBUTE_NAME 40905
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_EVENT_NAME_ATTRIBUTE_NAME 40906
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_ISSUER_ATTRIBUTE_NAME 40907
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_VENUE_ATTRIBUTE_NAME 40908
#define IDS_WALLET_WALLETABLE_PASS_EVENT_PASS_DATE_ATTRIBUTE_NAME 40909
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_OPERATOR_ATTRIBUTE_NAME 40910
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_TRIP_ATTRIBUTE_NAME 40911
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_TRIP_VALUE 40912
#define IDS_WALLET_WALLETABLE_PASS_TRANSPORT_TICKET_DATE_ATTRIBUTE_NAME 40913
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_AIRLINE_ATTRIBUTE_NAME 40914
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_FLIGHT_CODE_ATTRIBUTE_NAME 40915
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_TRIP_ATTRIBUTE_NAME 40916
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_TRIP_VALUE 40917
#define IDS_WALLET_WALLETABLE_PASS_BOARDING_PASS_DATE_ATTRIBUTE_NAME 40918
#define IDS_COLLABORATION_SIGNIN_TITLE 40919
#define IDS_COLLABORATION_SIGNIN_DESCRIPTION 40920
#define IDS_COLLABORATION_SIGNIN_BOTTOM_SHEET_TITLE 40921
#define IDS_COLLABORATION_SIGNIN_BOTTOM_SHEET_DESCRIPTION 40922
#define IDS_COLLABORATION_SIGNIN_SYNC_DISMISS 40923
#define IDS_COLLABORATION_SYNC_TITLE 40924
#define IDS_COLLABORATION_SYNC_DESCRIPTION 40925
#define IDS_COLLABORATION_ONE_GROUP_REMOVED_NOTIFICATION 40926
#define IDS_COLLABORATION_ONE_UNNAMED_GROUP_REMOVED_NOTIFICATION 40927
#define IDS_COLLABORATION_TWO_GROUPS_REMOVED_NOTIFICATION 40928
#define IDS_COLLABORATION_SEVERAL_GROUPS_REMOVED_NOTIFICATION 40929
#define IDS_COLLABORATION_RECENT_ACTIVITY_MENU_OPTION 40930
#define IDS_COLLABORATION_SOMETHING_WENT_WRONG_HEADER 40931
#define IDS_COLLABORATION_SOMETHING_WENT_WRONG_BODY 40932
#define IDS_COLLABORATION_LINK_FAILED_HEADER 40933
#define IDS_COLLABORATION_LINK_FAILED_BODY 40934
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_HEADER 40935
#define IDS_COLLABORATION_SHARE_BUTTON_CHROME_OUT_OF_DATE_ERROR_DIALOG_BODY 40936
#define IDS_COLLABORATION_JOIN_BUTTON_CHROME_OUT_OF_DATE_ERROR_DIALOG_BODY 40937
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_UPDATE_BUTTON 40938
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_NOT_NOW_BUTTON 40939
#define IDS_COLLABORATION_CHROME_OUT_OF_DATE_ERROR_DIALOG_CONTINUE_BODY 40940
#define IDS_COLLABORATION_SIGNED_OUT_HEADER 40941
#define IDS_COLLABORATION_SIGNED_OUT_BODY 40942
#define IDS_COLLABORATION_SIGNED_OUT_POSITIVE_BUTTON 40943
#define IDS_COLLABORATION_GROUP_IS_FULL_DESCRIPTION 40944
#define IDS_COLLABORATION_GROUP_IS_FULL_ERROR_DIALOG_HEADER 40945
#define IDS_COLLABORATION_GROUP_IS_FULL_ERROR_DIALOG_BODY 40946
#define IDS_COLLABORATION_ENTREPRISE_SIGNIN_DISABLED_HEADER 40947
#define IDS_COLLABORATION_ENTREPRISE_SIGNIN_DISABLED_BODY 40948
#define IDS_COLLABORATION_ENTREPRISE_SIGNIN_DISABLED_SYNC_HISTORY_BODY 40949
#define IDS_COLLABORATION_ENTREPRISE_SYNC_DISABLED_HEADER 40950
#define IDS_COLLABORATION_ENTREPRISE_SYNC_DISABLED_BODY 40951
#define IDS_COLLABORATION_ENTREPRISE_TABS_SYNC_DISABLED_BODY 40952
#define IDS_COLLABORATION_ENTREPRISE_GROUP_CLOSED_HEADER 40953
#define IDS_COLLABORATION_ENTREPRISE_GROUP_CLOSED_BODY 40954
#define IDS_COLLABORATION_ENTREPRISE_SHARING_OFF_HEADER 40955
#define IDS_COLLABORATION_ENTREPRISE_SHARING_OFF_BODY 40956
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_PANEL_OUT_OF_DATE_MESSAGE_CELL_TEXT 40960
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_AVAILABLE_AGAIN_IPH_MESSAGE 40961
#define IDS_DATA_SHARING_RECENT_ACTIVITY_USER_SELF 40962
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_ADDED 40963
#define IDS_DATA_SHARING_RECENT_ACTIVITY_MEMBER_ADDED_THIS_TAB 40964
#define IDS_DATA_SHARING_RECENT_ACTIVITY_MEMBER_CHANGED_THIS_TAB 40965
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_REMOVED 40966
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_UPDATED 40967
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_GROUP_NAME_UPDATED 40968
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TAB_GROUP_COLOR_UPDATED 40969
#define DATA_SHARING_GROUP_LABEL_NEW_ACTIVITY 40970
#define IDS_DATA_SHARING_RECENT_ACTIVITY_USER_JOINED_GROUP 40971
#define IDS_DATA_SHARING_RECENT_ACTIVITY_USER_LEFT_GROUP 40972
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TIME_DELTA 40973
#define IDS_DATA_SHARING_RECENT_ACTIVITY_SEPARATOR 40974
#define IDS_DATA_SHARING_RECENT_ACTIVITY_DESCRIPTION_FULL 40975
#define IDS_DATA_SHARING_RECENT_ACTIVITY_EMPTY 40976
#define IDS_DATA_SHARING_RECENT_ACTIVITY_JUST_NOW 40977
#define IDS_DATA_SHARING_RECENT_ACTIVITY_UNKNOWN_USER 40978
#define IDS_DATA_SHARING_SHARED_TAB_GROUPS_ACTIVITY 40979
#define IDS_DATA_SHARING_TOAST_TAB_REMOVED 40980
#define IDS_DATA_SHARING_TOAST_TAB_UPDATED 40981
#define IDS_DATA_SHARING_TOAST_TAB_REMOVED_ACTION 40982
#define IDS_DATA_SHARING_TOAST_NEW_MEMBER 40983
#define IDS_DATA_SHARING_TOAST_NEW_MEMBER_MULTIPLE_MEMBERS 40984
#define IDS_DATA_SHARING_TOAST_NEW_MEMBER_ACTION 40985
#define IDS_DATA_SHARING_TOAST_BLOCK_LEAVE 40986
#define IDS_DATA_SHARING_TOAST_BLOCK_LEAVE_MULTIPLE_GROUPS 40987
#define IDS_DATA_SHARING_TAB_GROUP_DEFAULT_TITLE_TABS_COUNT 40988
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_COMMENTS_TITLE 40989
#define IDS_COLLABORATION_SHARED_TAB_GROUPS_COMMENTS_TITLE_WITH_NAME 40990
#define IDS_CONTEXTUAL_CUEING_MENU_DISMISS 40991
#define IDS_CONTEXTUAL_CUEING_MENU_EDIT_PROMPT 40992
#define IDS_CONTEXTUAL_CUEING_MENU_SUGGESTION_SETTINGS 40993
#define IDS_CONTEXTUAL_CUEING_SETTINGS_PAGE_TITLE 40994
#define IDS_CONTEXTUAL_CUEING_SETTINGS_PAGE_SUBLABEL 40995
#define IDS_CONTEXTUAL_CUEING_SETTINGS_TOGGLE_LABEL 40996
#define IDS_CONTEXTUAL_CUEING_SETTINGS_TOGGLE_SUBLABEL 40997
#define IDS_CONTEXTUAL_CUEING_SETTINGS_WHEN_ON_1 40998
#define IDS_CONTEXTUAL_CUEING_SETTINGS_WHEN_ON_2 40999
#define IDS_CONTEXTUAL_CUEING_SETTINGS_CONSIDER_1 41000
#define IDS_CONTEXTUAL_CUEING_SETTINGS_CONSIDER_2 41001
#define IDS_CONTEXTUAL_CUEING_SETTINGS_CONSIDER_2_LINK 41002
#define IDS_CONTEXTUAL_TASKS_CONTEXTUAL_TASKS_TITLE 41003
#define IDS_CONTEXTUAL_TASKS_ENTRY_POINT_TOOLTIP 41004
#define IDS_CONTEXTUAL_TASKS_AI_MODE_TITLE 41005
#define IDS_CONTEXTUAL_TASKS_MENU_OPEN_IN_NEW_TAB 41006
#define IDS_CONTEXTUAL_TASKS_MENU_MY_ACTIVITY 41007
#define IDS_CONTEXTUAL_TASKS_MENU_HELP 41008
#define IDS_CONTEXTUAL_TASKS_SOURCES_MENU_TITLE 41009
#define IDS_CONTEXTUAL_TASKS_SOURCES_MENU_TABS_HEADER 41010
#define IDS_CONTEXTUAL_TASKS_SOURCES_MENU_IMAGES_HEADER 41011
#define IDS_CONTEXTUAL_TASKS_SOURCES_MENU_FILES_HEADER 41012
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_TITLE 41013
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_DESCRIPTION 41014
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_LEARN_MORE 41015
#define IDS_CONTEXTUAL_TASKS_FIRST_RUN_EXPERIENCE_ACCEPT_BUTTON 41016
#define IDS_CONTEXTUAL_TASKS_CONTINUE_THREAD_MESSAGE 41017
#define IDS_CONTEXTUAL_TASKS_REOPEN_TABS_BUTTON_TEXT 41018
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_RECENT_TABS 41019
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_ADD_IMAGES 41020
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_ADD_FILES 41021
#define IDS_CONTEXTUAL_TASKS_AI_SIDE_PANEL_TOOL_TIP 41022
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_MOST_RECENT_TABS 41023
#define IDS_CONTEXTUAL_TASKS_CONTEXT_MENU_GEMINI_MODELS 41024
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_NEW_THREAD_TOOL_TIP 41025
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_HISTORY_TOOL_TIP 41026
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_CONTEXT_TOOL_TIP 41027
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_MORE_OPTIONS_TOOL_TIP 41028
#define IDS_CONTEXTUAL_TASKS_SIDE_PANEL_CLOSE_TOOL_TIP 41029
#define IDS_CONTEXTUAL_TASKS_TOOLBAR_CLOSE_TAB_TOOL_TIP 41030
#define IDS_CONTEXTUAL_TASKS_ADD_TAB_CONTEXT_ERROR_TOAST 41031
#define IDS_CONTEXTUAL_TASKS_CANNOT_SHARE_TAB_TOOL_TIP 41032
#define IDS_CONTEXTUAL_TASKS_OAUTH_ERROR_DIALOG_TITLE 41033
#define IDS_CONTEXTUAL_TASKS_OAUTH_ERROR_DIALOG_BODY 41034
#define IDS_CONTEXTUAL_TASKS_OAUTH_ERROR_DIALOG_RELOAD_BUTTON 41035
#define IDS_AI_MODE_FRIENDLY_ZERO_STATE_TITLE 41036
#define IDS_AI_MODE_FRIENDLY_ZERO_STATE_TITLE_WITHOUT_NAME 41037
#define IDS_CONTEXTUAL_TASKS_COMPOSEBOX_PLACEHOLDER_TEXT 41038
#define IDS_CONTEXTUAL_TASKS_THREAD_CLOSED 41039
#define IDS_CANCEL 41099
#define IDS_CONTINUE 41100
#define IDS_CLOSE 41101
#define IDS_CLEAR 41102
#define IDS_DONE 41103
#define IDS_LEARN_MORE 41104
#define IDS_LEARN_MORE_MAYBE_TITLE_CASE 41105
#define IDS_OK 41106
#define IDS_RELOAD 41107
#define IDS_ADD 41108
#define IDS_MOVE 41109
#define IDS_REMOVE 41110
#define IDS_OPEN 41111
#define IDS_RESTORE 41112
#define IDS_SAVE 41113
#define IDS_MENU 41114
#define IDS_INSTALL 41115
#define IDS_UPDATE 41116
#define IDS_NO_THANKS 41119
#define IDS_NOT_NOW 41120
#define IDS_TURN_OFF 41121
#define IDS_PLUGIN_NOT_SUPPORTED 41122
#define IDS_PRINT 41123
#define IDS_RECENT_TABS 41124
#define IDS_RECENTLY_CLOSED 41125
#define IDS_YOUR_DEVICES 41126
#define IDS_CHOOSE 41127
#define IDS_ACCNAME_BACK 41128
#define IDS_ACCNAME_FORWARD 41129
#define IDS_ACCNAME_OK 41130
#define IDS_ACCNAME_CANCEL 41131
#define IDS_ACCNAME_DONE 41132
#define IDS_ACCNAME_SAVE 41133
#define IDS_ACCNAME_CLOSE 41134
#define IDS_ACCNAME_OPEN 41135
#define IDS_ACCNAME_OPEN_IN_NEW_TAB 41136
#define IDS_ACCNAME_PREVIOUS 41137
#define IDS_ACCNAME_NEXT 41138
#define IDS_ACCNAME_LOCATION 41139
#define IDS_ACCNAME_TAB_LIST 41140
#define IDS_UTILITY_PROCESS_JSON_PARSER_NAME 41141
#define IDS_SESSION_CRASHED_VIEW_RESTORE_BUTTON 41142
#define IDS_SESSION_CRASHED_VIEW_STARTUP_PAGES_BUTTON 41143
#define IDS_OPTIONS_ADVANCED_SECTION_TITLE_PRIVACY 41144
#define IDS_OPTIONS_ADVANCED_SECTION_TITLE_SAFETY_CHECK 41145
#define IDS_CONTENT_BOOKMARK_PARSER_SERVICE_DISPLAY_NAME 41146
#define IDS_PATCH_SERVICE_DISPLAY_NAME 41147
#define IDS_PASSWORD_MANAGER_CSV_PASSWORD_PARSER_SERVICE_DISPLAY_NAME 41148
#define IDS_UNZIP_SERVICE_DISPLAY_NAME 41149
#define IDS_INTERNAL_DEBUG_PAGES_DISABLED_HEADING 41150
#define IDS_SEND_TAB_TO_SELF_DEVICE_LAST_UPDATE_DAYS 41151
#define IDS_SEND_TAB_TO_SELF_DEVICE_ACTIVE_NOW 41152
#define IDS_SEND_TAB_TO_SELF_DEVICE_ACTIVE_MINUTES 41153
#define IDS_SEND_TAB_TO_SELF_DEVICE_ACTIVE_HOURS 41154

// ---------------------------------------------------------------------------
// From extensions_strings.h:

#define IDS_EXTENSION_BAD_FILE_ENCODING 46470
#define IDS_EXTENSION_CANT_GET_ABSOLUTE_PATH 46471
#define IDS_EXTENSION_CONTAINS_PRIVATE_KEY 46472
#define IDS_EXTENSION_CRX_EXISTS 46473
#define IDS_EXTENSION_CONTENT_SCRIPT_FILE_TOO_LARGE 46474
#define IDS_EXTENSION_CONTENT_SCRIPT_FILE_BAD_JS_MIME_TYPE 46475
#define IDS_EXTENSION_CONTENT_SCRIPT_FILE_BAD_CSS_MIME_TYPE 46476
#define IDS_EXTENSION_DIRECTORY_NO_EXISTS 46477
#define IDS_EXTENSION_ERROR_WHILE_SIGNING 46478
#define IDS_EXTENSION_FAILED_DURING_PACKAGING 46479
#define IDS_EXTENSION_LOAD_ABOUT_PAGE_FAILED 46480
#define IDS_EXTENSION_LOAD_BACKGROUND_SCRIPT_FAILED 46481
#define IDS_EXTENSION_LOAD_BACKGROUND_PAGE_FAILED 46482
#define IDS_EXTENSION_LOAD_CSS_FAILED 46483
#define IDS_EXTENSION_LOAD_JAVASCRIPT_FAILED 46484
#define IDS_EXTENSION_LOAD_OPTIONS_PAGE_FAILED 46485
#define IDS_EXTENSION_LOCALES_NO_DEFAULT_LOCALE_SPECIFIED 46486
#define IDS_EXTENSION_MANIFEST_UNREADABLE 46487
#define IDS_EXTENSION_MANIFEST_INVALID 46488
#define IDS_EXTENSION_PACKAGE_IMAGE_ERROR 46489
#define IDS_EXTENSION_PACKAGE_UNZIP_ERROR 46490
#define IDS_EXTENSION_PRIVATE_KEY_EXISTS 46491
#define IDS_EXTENSION_PRIVATE_KEY_FAILED_TO_READ 46492
#define IDS_EXTENSION_PRIVATE_KEY_FAILED_TO_EXPORT 46493
#define IDS_EXTENSION_PRIVATE_KEY_FAILED_TO_OUTPUT 46494
#define IDS_EXTENSION_PRIVATE_KEY_INVALID 46495
#define IDS_EXTENSION_PRIVATE_KEY_NO_EXISTS 46496
#define IDS_EXTENSION_PRIVATE_KEY_INVALID_PATH 46497
#define IDS_EXTENSION_PRIVATE_KEY_INVALID_FORMAT 46498
#define IDS_EXTENSION_PUBLIC_KEY_FAILED_TO_EXPORT 46499
#define IDS_EXTENSION_SHARING_VIOLATION 46500
#define IDS_EXTENSION_CANT_INSTALL_POLICY_BLOCKED 46501
#define IDS_EXTENSION_CANT_MODIFY_POLICY_REQUIRED 46502
#define IDS_EXTENSION_CANT_UNINSTALL_POLICY_REQUIRED 46503
#define IDS_EXTENSION_MANIFEST_VERSION_NOT_SUPPORTED 46504
#define IDS_EXTENSION_CANT_INSTALL_BLOCKED_BY_RISK_SCORE 46505
#define IDS_EXTENSION_CANT_INSTALL_BLOCKED_BY_CATEGORY 46506
#define IDS_EXTENSION_CANT_INSTALL_BLOCKED_BY_POLICY_FALLBACK 46507
#define IDS_DEVICE_NAME_WITH_PRODUCT_SERIAL 46508
#define IDS_DEVICE_NAME_WITH_PRODUCT_UNKNOWN_VENDOR 46509
#define IDS_DEVICE_NAME_WITH_PRODUCT_UNKNOWN_VENDOR_SERIAL 46510
#define IDS_DEVICE_NAME_WITH_PRODUCT_VENDOR 46511
#define IDS_DEVICE_NAME_WITH_PRODUCT_VENDOR_SERIAL 46512
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_UNKNOWN_VENDOR 46513
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_UNKNOWN_VENDOR_SERIAL 46514
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_VENDOR 46515
#define IDS_DEVICE_NAME_WITH_UNKNOWN_PRODUCT_VENDOR_SERIAL 46516
#define IDS_DEVICE_PERMISSIONS_PROMPT_SINGLE_SELECTION 46517
#define IDS_DEVICE_PERMISSIONS_PROMPT_MULTIPLE_SELECTION 46518
#define IDS_CAMERA_FACING_USER 46519
#define IDS_CAMERA_FACING_ENVIRONMENT 46520
#define IDS_EXTENSION_USB_DEVICE_PRODUCT_NAME_AND_VENDOR 46521
#define IDS_EXTENSION_TASK_MANAGER_APPVIEW_TAG_PREFIX 46522
#define IDS_EXTENSION_TASK_MANAGER_EXTENSIONOPTIONS_TAG_PREFIX 46523
#define IDS_EXTENSION_TASK_MANAGER_MIMEHANDLERVIEW_TAG_PREFIX 46524
#define IDS_EXTENSION_TASK_MANAGER_WEBVIEW_TAG_PREFIX 46525
#define IDS_EXTENSION_WARNINGS_NETWORK_DELAY 46526
#define IDS_EXTENSION_WARNINGS_DOWNLOAD_FILENAME_CONFLICT 46527
#define IDS_EXTENSION_WARNING_RELOAD_TOO_FREQUENT 46528
#define IDS_EXTENSION_WARNING_RULESET_FAILED_TO_LOAD 46529
#define IDS_EXTENSION_WARNING_ENABLED_RULE_COUNT_EXCEEDED 46530
#define IDS_EXTENSION_IS_BLOCKLISTED 46531
#define IDS_APP_CANT_DOWNGRADE_VERSION 46532
#define IDS_EXTENSION_CANT_DOWNGRADE_VERSION 46533
#define IDS_EXTENSION_MOVE_DIRECTORY_TO_PROFILE_FAILED 46534
#define IDS_EXTENSION_INSTALL_DEPENDENCY_OLD_VERSION 46535
#define IDS_EXTENSION_INSTALL_DEPENDENCY_NOT_SHARED_MODULE 46536
#define IDS_EXTENSION_INSTALL_DEPENDENCY_NOT_ALLOWLISTED 46537
#define IDS_EXTENSION_INSTALL_DISALLOWED_ON_SITE 46538
#define IDS_EXTENSION_INSTALL_GALLERY_ONLY 46539
#define IDS_EXTENSION_INSTALL_INCORRECT_APP_CONTENT_TYPE 46540
#define IDS_EXTENSION_INSTALL_INCORRECT_INSTALL_HOST 46541
#define IDS_EXTENSION_INSTALL_KIOSK_MODE_ONLY 46542
#define IDS_EXTENSION_INSTALL_NOT_ENABLED 46543
#define IDS_EXTENSION_OVERLAPPING_WEB_EXTENT 46544
#define IDS_EXTENSION_INSTALL_PROCESS_CRASHED 46545
#define IDS_EXTENSION_INSTALL_UNEXPECTED_ID 46546
#define IDS_EXTENSION_INSTALL_UNEXPECTED_VERSION 46547
#define IDS_EXTENSION_PACKAGE_ERROR_CODE 46548
#define IDS_EXTENSION_PACKAGE_ERROR_MESSAGE 46549
#define IDS_EXTENSION_PACKAGE_INSTALL_ERROR 46550
#define IDS_EXTENSION_WEBGL_NOT_SUPPORTED 46551
#define IDS_EXTENSION_WEB_STORE_TITLE 46552
#define IDS_EXTENSIONS_LOAD_ERROR_ALERT_HEADING 46553
#define IDS_EXTENSIONS_LOAD_ERROR_MESSAGE 46554
#define IDS_WEBSTORE_DOWNLOAD_ACCESS_DENIED 46555
#define IDS_EXTENSIONS_SUPERVISED_USER_PARENTAL_PERMISSION_FAILURE 46556
#define IDS_EXTENSIONS_SUPERVISED_USER_BLOCKED_BY_PARENT 46557
#define IDS_EXTENSION_PROMPT_MESSAGE_FROM_ADMIN 46558

// ---------------------------------------------------------------------------
// From generated_resources.h:

#define IDS_ACCESS_CODE_CAST_ACCESS_CODE_MESSAGE 1800
#define IDS_ACCESS_CODE_CAST_BACK 1801
#define IDS_ACCESS_CODE_CAST_CAST 1802
#define IDS_ACCESS_CODE_CAST_CONNECT 1803
#define IDS_ACCESS_CODE_CAST_DIALOG_TITLE 1804
#define IDS_ACCESS_CODE_CAST_ENTER_CHARACTER 1805
#define IDS_ACCESS_CODE_CAST_ERROR_ACCESS_CODE 1806
#define IDS_ACCESS_CODE_CAST_ERROR_DIFFERENT_NETWORK 1807
#define IDS_ACCESS_CODE_CAST_ERROR_NETWORK 1808
#define IDS_ACCESS_CODE_CAST_ERROR_PERMISSION 1809
#define IDS_ACCESS_CODE_CAST_ERROR_TOO_MANY_REQUESTS 1810
#define IDS_ACCESS_CODE_CAST_ERROR_UNKNOWN 1811
#define IDS_ACCESS_CODE_CAST_ERROR_PROFILE_SYNC 1812
#define IDS_ACCESS_CODE_CAST_INPUT_ARIA_LABEL 1813
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_DAYS 1814
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_HOURS 1815
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_MONTHS 1816
#define IDS_ACCESS_CODE_CAST_MANAGED_FOOTNOTE_YEARS 1817
#define IDS_ACCESS_CODE_CAST_SUBMIT 1818
#define IDS_ACCESS_CODE_CAST_USE_CAMERA 1819
#define IDS_HANDOFF_TAKE_OVER_TASK_LABEL 1820
#define IDS_HANDOFF_GIVE_TASK_BACK_LABEL 1821
#define IDS_HANDOFF_TAKE_OVER_TASK_A11Y_LABEL 1822
#define IDS_HANDOFF_GIVE_TASK_BACK_A11Y_LABEL 1823
#define IDS_TASK_IN_PROGRESS_TOAST_BODY 1824
#define IDS_ACTOR_TASK_NUDGE_CHECK_TASK_LABEL 1825
#define IDS_ACTOR_TASK_NUDGE_TASK_COMPLETE_LABEL 1826
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_TAB_CLOSED_SUBTITLE 1827
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_CHECK_TASK_SUBTITLE 1828
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_ACTING_TASK_SUBTITLE 1829
#define IDS_ACTOR_TASK_LIST_BUBBLE_A11Y_LABEL 1830
#define IDS_ACTOR_TASK_INDICATOR_TOOLTIP 1831
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_PAUSED_TASK_SUBTITLE 1832
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_COMPLETED_TASK_SUBTITLE 1833
#define IDR_ACTOR_TASK_LIST_BUBBLE_ROW_FAILED_TASK_SUBTITLE 1834
#define IDS_TOOLTIP_TAB_ALERT_STATE_ACTOR_ACCESSING 1835
#define IDS_TAB_AX_LABEL_ACTOR_ACCESSING 1836
#define IDS_ACTOR_PIP_WORKING_STATUS 1837
#define IDS_ACTOR_PIP_PAUSED_STATUS 1838
#define IDS_ACTOR_PIP_NEEDS_ATTENTION_STATUS 1839
#define IDS_ACTOR_PIP_COMPLETE_STATUS 1840
#define IDS_ACTOR_OVERLAY_SNACKBAR_MESSAGE 1841
#define IDS_GLIC_BUTTON_STATUS_REVIEW 1842
#define IDS_GLIC_BUTTON_STATUS_DONE 1843
#define IDS_ACTOR_NOTIFICATION_TITLE_WORKING_ON_TASK 1844
#define IDS_ACTOR_NOTIFICATION_TITLE_CHECK_YOUR_TASK 1845
#define IDS_ACTOR_NOTIFICATION_TITLE_TASK_PAUSED 1846
#define IDS_ACTOR_NOTIFICATION_TITLE_TASK_INTERRUPTED 1847
#define IDS_ACTOR_NOTIFICATION_TITLE_TASK_COMPLETE 1848
#define IDS_ACTOR_NOTIFICATION_BUTTON_VIEW_TASK 1849
#define IDS_ACTOR_NOTIFICATION_BUTTON_PAUSE_TASK 1850
#define IDS_ACTOR_NOTIFICATION_BUTTON_RESUME_TASK 1851
#define IDS_ACTOR_NOTIFICATION_BODY_WORKING 1852
#define IDS_ACTOR_NOTIFICATION_BODY_USER_INPUT 1853
#define IDS_ACTOR_NOTIFICATION_BODY_PAUSED 1854
#define IDS_ACTOR_NOTIFICATION_BODY_COMPLETE 1855
#define IDS_ACTOR_NOTIFICATION_BODY_INTERRUPTED 1856
#define IDS_PEEK_STATE_ACTING 1857
#define IDS_PEEK_STATE_PAUSED 1858
#define IDS_PEEK_STATE_WAITING 1859
#define IDS_PEEK_STATE_VIEW_BUTTON_LABEL 1860
#define IDS_APP_MANAGEMENT_CAMERA 1861
#define IDS_APP_MANAGEMENT_LOCATION 1862
#define IDS_APP_MANAGEMENT_MICROPHONE 1863
#define IDS_APP_MANAGEMENT_NOTIFICATIONS 1864
#define IDS_APP_MANAGEMENT_PERMISSIONS 1866
#define IDS_APP_MANAGEMENT_PERMISSIONS_WITH_ORIGIN 1867
#define IDS_APP_MANAGEMENT_MORE_SETTINGS 1868
#define IDS_APP_MANAGEMENT_WINDOW 1869
#define IDS_APP_MANAGEMENT_UNINSTALL_APP 1870
#define IDS_APP_MANAGEMENT_RUN_ON_OS_LOGIN 1871
#define IDS_APP_MANAGEMENT_POLICY_APP_POLICY_STRING 1872
#define IDS_APP_MANAGEMENT_INTENT_SETTINGS_TITLE 1873
#define IDS_APP_MANAGEMENT_INTENT_SHARING_APP_OPEN 1874
#define IDS_APP_MANAGEMENT_INTENT_SHARING_BROWSER_OPEN 1875
#define IDS_APP_MANAGEMENT_INTENT_SHARING_TAB_EXPLANATION 1876
#define IDS_APP_MANAGEMENT_INTENT_SETTINGS_DIALOG_TITLE 1877
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_CHANGE_BUTTON 1878
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TITLE 1879
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_1_APP 1880
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_2_APPS 1881
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_3_APPS 1882
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_4_APPS 1883
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_DIALOG_TEXT_5_OR_MORE_APPS 1884
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_1_APP 1885
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_2_APPS 1886
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_3_APPS 1887
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_4_APPS 1888
#define IDS_APP_MANAGEMENT_INTENT_OVERLAP_WARNING_TEXT_5_OR_MORE_APPS 1889
#define IDS_APP_MANAGEMENT_APP_VERSION_TITLE 1890
#define IDS_APP_MANAGEMENT_APP_SIZE_TITLE 1891
#define IDS_APP_MANAGEMENT_APP_DATA_SIZE_TITLE 1892
#define IDS_APP_MANAGEMENT_FILE_HANDLING_HEADER 1893
#define IDS_APP_MANAGEMENT_FILE_HANDLING_OVERFLOW_DIALOG_TITLE 1894
#define IDS_APP_MANAGEMENT_FILE_HANDLING_SET_DEFAULTS_LINK 1895
#define IDS_APP_MANAGEMENT_FILE_HANDLING_TYPES 1896
#define IDS_APP_MANAGEMENT_APP_CONTENT_TITLE 1897
#define IDS_APP_MANAGEMENT_APP_CONTENT_SUBTITLE 1898
#define IDS_APP_MANAGEMENT_APP_CONTENT_DIALOG_SUBTITLE 1899
#define IDS_APP_MANAGEMENT_IS_SUB_APP_PERMISSION_EXPLANATION 1900
#define IDS_APP_MANAGEMENT_HAS_SUB_APPS_PERMISSION_EXPLANATION 1901
#define IDS_BOOKMARK_GROUP_FROM_FIREFOX 1904
#define IDS_BOOKMARK_GROUP_FROM_SAFARI 1905
#define IDS_BOOKMARK_GROUP 1906
#define IDS_UNNAMED_BOOKMARK_BUTTON_ACCESSIBLE_NAME 1907
#define IDS_BOOKMARK_BAR_SHOW_APPS_SHORTCUT 1908
#define IDS_BOOKMARK_BAR_SHOW_TAB_GROUPS 1909
#define IDS_BOOKMARK_BAR_SHOW_READING_LIST 1910
#define IDS_BOOKMARK_BAR_SHOW_MANAGED_BOOKMARKS_DEFAULT_NAME 1911
#define IDS_BOOKMARK_BAR_SHOW_MANAGED_BOOKMARKS 1912
#define IDS_BOOKMARK_BAR_APPS_SHORTCUT_NAME 1913
#define IDS_BOOKMARK_BAR_APPS_SHORTCUT_TOOLTIP 1914
#define IDS_BOOKMARK_BAR_OVERFLOW_BUTTON_TOOLTIP 1915
#define IDS_BOOKMARK_BAR_OPEN_ALL 1916
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT 1917
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT_NEW_WINDOW 1918
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT_INCOGNITO 1919
#define IDS_BOOKMARK_BAR_OPEN_ALL_COUNT_NEW_TAB_GROUP 1920
#define IDS_BOOKMARK_BAR_OPEN_IN_NEW_TAB 1921
#define IDS_BOOKMARK_BAR_OPEN_IN_NEW_WINDOW 1922
#define IDS_BOOKMARK_BAR_OPEN_INCOGNITO 1923
#define IDS_BOOKMARK_BAR_OPEN_IN_SPLIT_VIEW 1924
#define IDS_BOOKMARK_BAR_EDIT 1925
#define IDS_BOOKMARK_BAR_RENAME_FOLDER 1926
#define IDS_BOOKMARK_BAR_REMOVE 1927
#define IDS_BOOKMARK_BAR_ADD_NEW_BOOKMARK 1928
#define IDS_BOOKMARK_BAR_NEW_FOLDER 1929
#define IDS_SHOW_BOOKMARK_BAR 1930
#define IDS_HIDE_BOOKMARK_BAR 1931
#define IDS_BOOKMARK_BAR_SHOULD_OPEN_ALL 1932
#define IDS_BOOKMARK_BAR_ALREADY_CREATED_GROUP 1933
#define IDS_BOOKMARK_BAR_REPLACE_OR_CREATE_NEW_GROUP_TITLE 1934
#define IDS_BOOKMARK_BAR_CREATE_NEW_GROUP_BUTTON 1935
#define IDS_BOOKMARK_BAR_REPLACE_OLD_GROUP_BUTTON 1936
#define IDS_BOOKMARK_BUBBLE_PAGE_BOOKMARKED 1937
#define IDS_BOOKMARK_BUBBLE_PAGE_BOOKMARK 1938
#define IDS_BOOKMARK_BUBBLE_EDIT_BOOKMARK 1939
#define IDS_BOOKMARK_BUBBLE_NAME_LABEL 1940
#define IDS_BOOKMARK_BUBBLE_SAVED_TO 1941
#define IDS_BOOKMARK_AX_BUBBLE_NAME_LABEL 1942
#define IDS_BOOKMARK_BUBBLE_FOLDER_LABEL 1943
#define IDS_BOOKMARK_AX_BUBBLE_FOLDER_LABEL 1944
#define IDS_BOOKMARK_BUBBLE_OPTIONS 1945
#define IDS_BOOKMARK_BUBBLE_CHOOSER_ANOTHER_FOLDER 1946
#define IDS_BOOKMARK_DICE_PROMO_SYNC_MESSAGE 1947
#define IDS_BOOKMARK_VERIFY_PROMO_SUBTITLE 1948
#define IDS_BOOKMARK_PROMO_TITLE 1953
#define IDS_BOOKMARK_EDITOR_NAME_LABEL 1954
#define IDS_BOOKMARK_AX_EDITOR_NAME_LABEL 1955
#define IDS_BOOKMARK_AX_EDITOR_URL_LABEL 1957
#define IDS_BOOKMARK_EDITOR_URL_LABEL 1958
#define IDS_BOOKMARK_EDITOR_CONFIRM_DELETE 1959
#define IDS_TAB_GROUP_TO_BOOKMARK_FOLDER_SUBTITLE 1960
#define IDS_BOOKMARK_EDITOR_NEW_FOLDER_BUTTON 1961
#define IDS_BOOKMARK_EDITOR_NEW_FOLDER_MENU_ITEM 1962
#define IDS_BOOKMARK_FOLDER_EDITOR_WINDOW_TITLE 1963
#define IDS_BOOKMARK_FOLDER_EDITOR_WINDOW_TITLE_NEW 1964
#define IDS_UNNAMED_BOOKMARK_FOLDER 1965
#define IDS_BOOKMARK_ALL_TABS_DIALOG_TITLE 1966
#define IDS_TAB_GROUP_TO_BOOKMARK_FOLDER_TITLE 1967
#define IDS_BOOKMARK_MANAGER_TITLE 1968
#define IDS_BOOKMARK_MANAGER_SEARCH_BUTTON 1969
#define IDS_BOOKMARK_MANAGER 1970
#define IDS_BOOKMARK_MANAGER_ORGANIZE_MENU 1971
#define IDS_BOOKMARK_MANAGER_INVALID_URL 1972
#define IDS_EXPORT_BOOKMARKS_DEFAULT_FILENAME 1973
#define IDS_BOOKMARK_MANAGER_ADD_BOOKMARK_TITLE 1974
#define IDS_BOOKMARK_MANAGER_ADD_FOLDER_TITLE 1975
#define IDS_BOOKMARK_MANAGER_CLEAR_SEARCH 1976
#define IDS_BOOKMARK_MANAGER_EMPTY_LIST 1977
#define IDS_BOOKMARK_MANAGER_EMPTY_UNMODIFIABLE_LIST 1978
#define IDS_BOOKMARK_MANAGER_FOLDER_LABEL 1979
#define IDS_BOOKMARK_MANAGER_FOLDER_RENAME_TITLE 1980
#define IDS_BOOKMARK_MANAGER_FOLDER_LIST_CHANGED 1981
#define IDS_BOOKMARK_MANAGER_LIST_AX_LABEL 1982
#define IDS_BOOKMARK_MANAGER_MENU_ADD_BOOKMARK 1983
#define IDS_BOOKMARK_MANAGER_MENU_ADD_FOLDER 1984
#define IDS_BOOKMARK_MANAGER_MENU_CUT 1985
#define IDS_BOOKMARK_MANAGER_MENU_COPY 1986
#define IDS_BOOKMARK_MANAGER_MENU_PASTE 1987
#define IDS_BOOKMARK_MANAGER_MENU_EXPORT 1988
#define IDS_BOOKMARK_MANAGER_MENU_HELP_CENTER 1989
#define IDS_BOOKMARK_MANAGER_MENU_IMPORT 1990
#define IDS_BOOKMARK_MANAGER_MENU_IMPORT_BEGAN 1991
#define IDS_BOOKMARK_MANAGER_MENU_IMPORT_ENDED 1992
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL 1993
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_WITH_COUNT 1994
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_WINDOW 1995
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_WINDOW_WITH_COUNT 1996
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_INCOGNITO 1997
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_INCOGNITO_WITH_COUNT 1998
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_TAB_GROUP 1999
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_ALL_NEW_TAB_GROUP_WITH_COUNT 2000
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_NEW_TAB 2001
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_NEW_WINDOW 2002
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_INCOGNITO 2003
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_NEW_TAB_GROUP 2004
#define IDS_BOOKMARK_MANAGER_MENU_OPEN_IN_SPLIT_VIEW 2005
#define IDS_BOOKMARK_MANAGER_MENU_RENAME 2006
#define IDS_BOOKMARK_MANAGER_MENU_SHOW_IN_FOLDER 2007
#define IDS_BOOKMARK_MANAGER_MENU_SORT 2008
#define IDS_BOOKMARK_MANAGER_MORE_ACTIONS 2009
#define IDS_BOOKMARK_MANAGER_MORE_ACTIONS_AX_LABEL 2010
#define IDS_BOOKMARK_MANAGER_MORE_ACTIONS_MULTI_AX_LABEL 2011
#define IDS_BOOKMARK_MANAGER_OPEN_DIALOG_TITLE 2012
#define IDS_BOOKMARK_MANAGER_OPEN_DIALOG_CONFIRM 2013
#define IDS_BOOKMARK_MANAGER_ITEMS_SELECTED 2014
#define IDS_BOOKMARK_MANAGER_ITEMS_UNSELECTED 2015
#define IDS_BOOKMARK_MANAGER_SIDEBAR_AX_LABEL 2016
#define IDS_BOOKMARK_MANAGER_TOAST_FOLDER_SORTED 2017
#define IDS_BOOKMARK_MANAGER_TOAST_ITEM_DELETED 2018
#define IDS_BOOKMARK_MANAGER_TOAST_ITEMS_DELETED 2019
#define IDS_BOOKMARK_MANAGER_TOAST_ITEM_COPIED 2020
#define IDS_BOOKMARK_MANAGER_TOAST_ITEMS_COPIED 2021
#define IDS_BOOKMARKS_MENU 2022
#define IDS_BOOKMARKS_AND_LISTS_MENU 2023
#define IDS_SHOW_BOOKMARK_SIDE_PANEL 2024
#define IDS_BOOKMARK_THIS_TAB 2025
#define IDS_BOOKMARK_ALL_TABS 2026
#define IDS_BOOKMARKS_LIST_TITLE 2027
#define IDS_TOOLTIP_STARRED 2028
#define IDS_BOOKMARK_SCREEN_READER_CREATED 2029
#define IDS_BOOKMARK_SCREEN_READER_FOLDER_CREATED 2030
#define IDS_BOOKMARK_SCREEN_READER_REORDERED 2031
#define IDS_BOOKMARK_SCREEN_READER_MOVED 2032
#define IDS_TOOLTIP_TAB_ALERT_STATE_GLIC_ACCESSING 2033
#define IDS_TOOLTIP_TAB_ALERT_STATE_GLIC_SHARING 2034
#define IDS_TOOLTIP_GLIC_CLOSE 2035
#define IDS_TAB_AX_LABEL_GLIC_ACCESSING 2036
#define IDS_TAB_AX_LABEL_GLIC_SHARING 2037
#define IDS_GLIC_PROMO_BODY 2038
#define IDS_GLIC_STATUS_ICON_MENU_CUSTOMIZE_KEYBOARD_SHORTCUT 2039
#define IDS_GLIC_STATUS_ICON_MENU_EXIT 2040
#define IDS_GLIC_STATUS_ICON_MENU_SETTINGS 2041
#define IDS_GLIC_OS_WIDGET_TOGGLE_HELP_BUBBLE 2042
#define IDS_GLIC_OS_WIDGET_KEYBOARD_SHORTCUT_HELP_BUBBLE 2043
#define IDS_GLIC_OFFLINE_NOTICE_HEADER 2044
#define IDS_GLIC_OFFLINE_NOTICE_ACTION 2045
#define IDS_GLIC_OFFLINE_NOTICE_ACTION_BUTTON 2046
#define IDS_GLIC_UNRESPONSIVE_MESSAGE 2047
#define IDS_GLIC_ERROR_NOTICE_HEADER 2048
#define IDS_GLIC_ERROR_NOTICE 2049
#define IDS_GLIC_ERROR_NOTICE_ACTION_BUTTON 2050
#define IDS_GLIC_SHOW_ERROR_BUTTON 2051
#define IDS_GLIC_NOTICE_CLOSE_BUTTON_LABEL 2052
#define IDS_GLIC_SIGN_IN_NOTICE_HEADER 2053
#define IDS_GLIC_SIGN_IN_NOTICE 2054
#define IDS_GLIC_SIGN_IN_NOTICE_ACTION_BUTTON 2055
#define IDS_GLIC_INELIGIBLE_PROFILE_NOTICE_HEADER 2056
#define IDS_GLIC_INELIGIBLE_PROFILE_NOTICE_ACTION_BUTTON 2057
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE 2058
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE_WITH_LINK 2059
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE_CLOSE_BUTTON 2060
#define IDS_GLIC_DISABLED_BY_ADMIN_NOTICE_HEADER 2061
#define IDS_SETTINGS_GLIC_ROW_SUBLABEL 2062
#define IDS_SETTINGS_GLIC_POLICY_DISABLED_MESSAGE 2063
#define IDS_SETTINGS_GLIC_PREFERENCES_SECTION 2064
#define IDS_SETTINGS_GLIC_PERMISSIONS_SECTION 2065
#define IDS_SETTINGS_GLIC_BUTTON_TOGGLE 2066
#define IDS_SETTINGS_GLIC_BUTTON_TOGGLE_SUBLABEL 2067
#define IDS_SETTINGS_GLIC_OS_WIDGET_TOGGLE 2068
#define IDS_SETTINGS_GLIC_OS_WIDGET_TOGGLE_SHORTCUTS_ONLY 2069
#define IDS_SETTINGS_GLIC_OS_WIDGET_TOGGLE_SUBLABEL 2070
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT 2071
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_EDIT_LABEL 2072
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_CLEAR_LABEL 2073
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_SUBLABEL 2074
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_LEARN_MORE_LABEL 2075
#define IDS_SETTINGS_GLIC_KEYBOARD_SHORTCUT_LEARN_MORE_ARIA_LABEL 2076
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_LEARN_MORE_ARIA_LABEL 2077
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_LEARN_MORE_ARIA_LABEL 2078
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT 2079
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_EDIT_LABEL 2080
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_CLEAR_LABEL 2081
#define IDS_SETTINGS_GLIC_NAVIGATION_SHORTCUT_SUBLABEL 2082
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT 2083
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_EDIT_LABEL 2084
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_CLEAR_LABEL 2085
#define IDS_SETTINGS_GLIC_SELECTION_SHORTCUT_SUBLABEL 2086
#define IDS_SETTINGS_GLIC_CLOSED_CAPTIONING 2087
#define IDS_SETTINGS_GLIC_CLOSED_CAPTIONING_SUBLABEL 2088
#define IDS_SETTINGS_GLIC_KEEP_SIDEPANEL_OPEN_ON_NEW_TABS 2089
#define IDS_SETTINGS_GLIC_PERMISSIONS_LOCATION_TOGGLE 2090
#define IDS_SETTINGS_GLIC_PERMISSIONS_LOCATION_TOGGLE_SUBLABEL 2091
#define IDS_SETTINGS_GLIC_PERMISSIONS_LOCATION_TOGGLE_SUBLABEL_DATA_PROTECTED 2092
#define IDS_SETTINGS_GLIC_PERMISSIONS_MICROPHONE_TOGGLE 2093
#define IDS_SETTINGS_GLIC_PERMISSIONS_MICROPHONE_TOGGLE_SUBLABEL 2094
#define IDS_SETTINGS_GLIC_PERMISSIONS_MICROPHONE_TOGGLE_SUBLABEL_DATA_PROTECTED 2095
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_TOGGLE 2096
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_TOGGLE_SUBLABEL 2097
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_TOGGLE_SUBLABEL_DATA_PROTECTED 2098
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_TOGGLE 2099
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_TOGGLE_SUBLABEL 2100
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_TOGGLE_SUBLABEL_DATA_PROTECTED 2101
#define IDS_SETTINGS_GLIC_PERMISSIONS_ACTIVITY_BUTTON 2102
#define IDS_SETTINGS_GLIC_PERMISSIONS_ACTIVITY_BUTTON_SUBLABEL 2103
#define IDS_SETTINGS_GLIC_PERMISSIONS_ACTIVITY_BUTTON_URL 2104
#define IDS_SETTINGS_GLIC_EXTENSIONS_BUTTON 2105
#define IDS_SETTINGS_GLIC_EXTENSIONS_BUTTON_SUBLABEL 2106
#define IDS_SETTINGS_GLIC_EXTENSIONS_BUTTON_URL 2107
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_WHEN_ON_1 2108
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_CONSIDER_1 2109
#define IDS_SETTINGS_GLIC_PERMISSIONS_TAB_ACCESS_CONSIDER_1_LEARN_MORE_LABEL 2110
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_WHEN_ON_1 2111
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_WHEN_ON_2 2112
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_WHEN_ON_2_NO_LIVE 2113
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_CONSIDER_1 2114
#define IDS_SETTINGS_GLIC_PERMISSIONS_DEFAULT_TAB_ACCESS_CONSIDER_2 2115
#define IDS_SETTINGS_GLIC_PERSONAL_CONTEXT_LABEL 2116
#define IDS_SETTINGS_GLIC_PERSONAL_CONTEXT 2117
#define IDS_SETTINGS_GLIC_INSTRUCTIONS_BUTTON 2118
#define IDS_SETTINGS_GLIC_INSTRUCTIONS_BUTTON_SUBLABEL 2119
#define IDS_SETTINGS_GLIC_EXPERIMENTAL_TRIGGERING_TOGGLE 2120
#define IDS_SETTINGS_GLIC_PERMISSIONS_CHROME_WEB_ACTUATION_TOGGLE 2121
#define IDS_SETTINGS_GLIC_PERMISSIONS_CHROME_WEB_ACTUATION_TOGGLE_SUBLABEL 2122
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_WHEN_ON_1 2123
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_WHEN_ON_2 2124
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_CONSIDER_1 2125
#define IDS_SETTINGS_GLIC_PERMISSIONS_WEB_ACTUATION_TOGGLE_CONSIDER_2 2126
#define IDS_SETTINGS_GLIC_ACTOR_LOGIN_PERMISSIONS_SECTION_TITLE 2127
#define IDS_SETTINGS_GLIC_ACTOR_LOGIN_PERMISSIONS_SECTION_SUBLABEL 2128
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_PAGE_TITLE 2129
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_OFFLINE_WARNING 2130
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_PAGE_DESCRIPTION 2131
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_NO_SITES 2132
#define IDS_SETTINGS_GLIC_REVOKE_ACTOR_LOGIN_PERMISSION_ARIA_LABEL 2133
#define IDS_SETTINGS_GLIC_REMOVE_ACTOR_LOGIN_DIALOG_TITLE 2134
#define IDS_SETTINGS_GLIC_REMOVE_ACTOR_LOGIN_DIALOG_DESCRIPTION 2135
#define IDS_SETTINGS_GLIC_LOGIN_PERMISSIONS_REMOVE_ERROR 2136
#define IDS_GLIC_PIN 2137
#define IDS_GLIC_UNPIN 2138
#define IDS_GLIC_SCREEN_PICKER_REQUESTER 2139
#define IDS_GLIC_SCREEN_PICKER_HEADLINE 2140
#define IDS_GLIC_SCREEN_PICKER_DESCRIPTION 2141
#define IDS_GLIC_SCREEN_PICKER_CTA 2142
#define IDS_GLIC_INACTIVE_VIEW_CARD_TEXT 2143
#define IDS_GLIC_WINDOW_TITLE 2144
#define IDS_GLIC_WINDOW_TITLE_FIRST_LOAD 2145
#define IDS_GLIC_WINDOW_FIRST_FOCUS_LOST_ANNOUNCEMENT 2146
#define IDS_TASK_MANAGER_GLIC_RENDERER_PREFIX 2147
#define IDS_TAB_CXMENU_GLIC_START_SHARE 2148
#define IDS_TAB_CXMENU_GLIC_STOP_SHARE 2149
#define IDS_TAB_CXMENU_GLIC_SHARE_LIMIT 2150
#define IDS_TAB_CXMENU_GLIC_CREATE_NEW_CHAT 2151
#define IDS_TAB_CXMENU_GLIC_UNSHARE 2152
#define IDS_GLIC_BUTTON_CXMENU_UNPIN 2153
#define IDS_GLIC_SETTING_LABEL 2154
#define IDS_GLIC_BUTTON_ENTRYPOINT_LABEL 2155
#define IDS_GLIC_BUTTON_ENTRYPOINT_PINNED_LABEL 2156
#define IDS_GLIC_BUTTON_ENTRYPOINT_ASK_GEMINI_LABEL 2157
#define IDS_GLIC_BUTTON_ENTRYPOINT_BROWSE_LABEL 2158
#define IDS_GLIC_BUTTON_ENTRYPOINT_ASK_ABOUT_THIS_PAGE_LABEL 2159
#define IDS_CONTENT_CONTEXT_GLICSHAREIMAGE 2160
#define IDS_GLIC_CONTEXT_MENU_SUMMARIZE_PAGE_WITH_GEMINI 2161
#define IDS_GLIC_SUMMARIZE_PAGE_PROMPT 2162
#define IDS_GLIC_PROMO_CONFIRM 2163
#define IDS_GLIC_TRYIT_TITLE 2164
#define IDS_GLIC_TRYIT_BODY 2165
#define IDS_GLIC_SHORTCUT_IPH_TEXT_TEMPLATE 2166
#define IDS_GLIC_SHORTCUT_IPH_TEXT 2167
#define IDS_GLIC_SHORTCUT_IPH_SCREENREADER 2168
#define IDS_GLIC_SELECTION_ASK_ABOUT 2169
#define IDS_GLIC_SELECTION_TELL_ME_ABOUT 2170
#define IDS_EDUCATIONAL_TIP_GLIC_TITLE 2171
#define IDS_EDUCATIONAL_TIP_GLIC_DESCRIPTION 2172
#define IDS_EDUCATIONAL_TIP_GLIC_BUTTON 2173
#define IDS_EDUCATIONAL_TIP_GLIC_DISMISS_BUTTON 2174
#define IDS_TAB_BOTTOM_SHEET_RESIZING_VIEW_TEXT 2175
#define IDS_GLOBAL_MEDIA_CONTROLS_ICON_TOOLTIP_TEXT 2176
#define IDS_GLOBAL_MEDIA_CONTROLS_DEVICES_LABEL_WITH_COLON 2177
#define IDS_GLOBAL_MEDIA_CONTROLS_DEVICES_LABEL 2178
#define IDS_GLOBAL_MEDIA_CONTROLS_STOP_CASTING_BUTTON_LABEL 2179
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION 2180
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_SHOW_LANGUAGE 2181
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_DOWNLOAD_PROGRESS 2182
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_DOWNLOAD_ERROR 2183
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_CAPTION_DOWNLOAD_ERROR_REBOOT_REQUIRED 2184
#define IDS_GLOBAL_MEDIA_CONTROLS_CAPTION_SETTINGS 2185
#define IDS_GLOBAL_MEDIA_CONTROLS_LIVE_TRANSLATE_TARGET_LANGUAGE_ACCNAME 2186
#define IDS_GLOBAL_MEDIA_CONTROLS_DIALOG_NAME 2187
#define IDS_GLOBAL_MEDIA_CONTROLS_CONTROL_CAST_SESSIONS_PROMO 2188
#define IDS_GMC_LOCAL_MEDIA_CAST_SESSIONS_PROMO 2189
#define IDS_GMC_LOCAL_MEDIA_CAST_START_PROMO 2190
#define IDS_MEDIA_TOOLBAR_CONTEXT_REPORT_CAST_ISSUE 2191
#define IDS_MEDIA_TOOLBAR_CONTEXT_SHOW_OTHER_SESSIONS 2192
#define IDS_MEDIA_PREVIEW_CAMERA_ACCESSIBLE_NAME 2193
#define IDS_MEDIA_PREVIEW_VIDEO_STREAM_ACCESSIBLE_NAME 2194
#define IDS_MEDIA_PREVIEW_NO_CAMERAS_FOUND 2195
#define IDS_MEDIA_PREVIEW_NO_CAMERAS_FOUND_COMBOBOX 2196
#define IDS_MEDIA_PREVIEW_VIDEO_STREAM_PREVIEW_BADGE 2197
#define IDS_MEDIA_PREVIEW_MIC_ACCESSIBLE_NAME 2198
#define IDS_MEDIA_PREVIEW_AUDIO_STREAM_ACCESSIBLE_NAME 2199
#define IDS_MEDIA_PREVIEW_NO_MICS_FOUND 2200
#define IDS_MEDIA_PREVIEW_NO_MICS_FOUND_COMBOBOX 2201
#define IDS_MEDIA_PREVIEW_SYSTEM_DEFAULT_MIC 2202
#define IDS_MEDIA_PREVIEW_SYSTEM_DEFAULT_MIC_PARENTHETICAL 2203
#define IDS_MEDIA_PREVIEW_ANNOUNCE_SELECTED_DEVICE_CHANGE 2204
#define IDS_MEDIA_ROUTER_ICON_TOOLTIP_TEXT 2205
#define IDS_MEDIA_ROUTER_MENU_ITEM_TITLE 2206
#define IDS_MEDIA_ROUTER_PRESENTATION_CAST_MODE 2207
#define IDS_MEDIA_ROUTER_DESKTOP_MIRROR_CAST_MODE 2208
#define IDS_MEDIA_ROUTER_TAB_MIRROR_CAST_MODE 2209
#define IDS_MEDIA_ROUTER_ALTERNATIVE_SOURCES_BUTTON 2210
#define IDS_MEDIA_ROUTER_ABOUT 2211
#define IDS_MEDIA_ROUTER_HELP 2212
#define IDS_MEDIA_ROUTER_ALWAYS_SHOW_TOOLBAR_ACTION 2213
#define IDS_MEDIA_ROUTER_SHOWN_BY_POLICY 2214
#define IDS_MEDIA_ROUTER_TOGGLE_MEDIA_REMOTING 2215
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT_WITH_HOSTNAME 2216
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT 2217
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT_FOR_DESKTOP 2218
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_TIMEOUT_FOR_TAB 2219
#define IDS_MEDIA_ROUTER_ISSUE_UNABLE_TO_CAST_DESKTOP 2220
#define IDS_MEDIA_ROUTER_ISSUE_TAB_AUDIO_NOT_SUPPORTED 2221
#define IDS_MEDIA_ROUTER_ISSUE_DESKTOP_AUDIO_NOT_SUPPORTED 2222
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_USER_PENDING_AUTHORIZATION 2224
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_USER_NOT_ALLOWED 2225
#define IDS_MEDIA_ROUTER_ISSUE_CREATE_ROUTE_NOTIFICATION_DISABLED 2226
#define IDS_MEDIA_ROUTER_ISSUE_FAILED_TO_CAST 2227
#define IDS_MEDIA_ROUTER_ISSUE_CANNOT_TERMINATE 2228
#define IDS_MEDIA_ROUTER_STATUS_LOOKING_FOR_DEVICES 2229
#define IDS_MEDIA_ROUTER_STATUS_NO_DEVICES_FOUND 2230
#define IDS_MEDIA_ROUTER_NO_DEVICES_FOUND_BUTTON 2231
#define IDS_MEDIA_ROUTER_DESTINATION_MISSING 2232
#define IDS_MEDIA_ROUTER_LOCAL_DISCOVERY_PERMISSION_REJECTED_BUTTON 2233
#define IDS_MEDIA_ROUTER_LOCAL_DISCOVERY_PERMISSION_REJECTED_LABEL 2234
#define IDS_MEDIA_ROUTER_LOCAL_DISCOVERY_PERMISSION_REJECTED_LINK 2235
#define IDS_MEDIA_ROUTER_SINK_AVAILABLE 2236
#define IDS_MEDIA_ROUTER_SINK_CONNECTING 2237
#define IDS_MEDIA_ROUTER_SINK_DISCONNECTING 2238
#define IDS_MEDIA_ROUTER_SINK_PAUSED 2239
#define IDS_MEDIA_ROUTER_STOP_CASTING 2240
#define IDS_MEDIA_ROUTER_SOURCE_NOT_SUPPORTED 2241
#define IDS_MEDIA_ROUTER_AVAILABLE_SPECIFIC_SITES 2242
#define IDS_MEDIA_ROUTER_CASTING_DESKTOP 2243
#define IDS_MEDIA_ROUTER_CASTING_TAB 2244
#define IDS_MEDIA_ROUTER_PRESENTATION_ROUTE_DESCRIPTION 2245
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE 2246
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE_GENERIC_ACCESSIBLE_NAME 2247
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE_SCREEN_ACCESSIBLE_NAME 2248
#define IDS_MEDIA_ROUTER_SINK_VIEW_PAUSE_TAB_ACCESSIBLE_NAME 2249
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME 2250
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME_GENERIC_ACCESSIBLE_NAME 2251
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME_SCREEN_ACCESSIBLE_NAME 2252
#define IDS_MEDIA_ROUTER_SINK_VIEW_RESUME_TAB_ACCESSIBLE_NAME 2253
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP 2254
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP_GENERIC_ACCESSIBLE_NAME 2255
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP_SCREEN_ACCESSIBLE_NAME 2256
#define IDS_MEDIA_ROUTER_SINK_VIEW_STOP_TAB_ACCESSIBLE_NAME 2257
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_TITLE 2258
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_BODY_TEXT 2259
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_CHECKBOX 2260
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_OPTIMIZE_BUTTON 2261
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_CANCEL_BUTTON 2262
#define IDS_MEDIA_ROUTER_REMOTING_DIALOG_CANCEL_BUTTON_MACOS 2263
#define IDS_MEDIA_ROUTER_CAST_TO_MEETING_DEPRECATED 2264
#define IDS_MEDIA_ROUTER_CAST_TO_MEETING_REMOVED 2265
#define IDS_MEDIA_ROUTER_WIRED_DISPLAY_SINK_NAME 2266
#define IDS_MEDIA_ROUTER_FEEDBACK_TITLE 2267
#define IDS_MEDIA_ROUTER_FEEDBACK_NA 2268
#define IDS_MEDIA_ROUTER_FEEDBACK_FORM_DESCRIPTION 2269
#define IDS_MEDIA_ROUTER_FEEDBACK_HEADER 2270
#define IDS_MEDIA_ROUTER_FEEDBACK_YOUR_ANSWER 2271
#define IDS_MEDIA_ROUTER_FEEDBACK_REQUIRED 2272
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_QUESTION 2273
#define IDS_MEDIA_ROUTER_FEEDBACK_PROMPT 2274
#define IDS_MEDIA_ROUTER_FEEDBACK_MIRRORING_QUALITY_SUBHEADING 2275
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_SMOOTHNESS 2276
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_QUALITY 2277
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_QUALITY 2278
#define IDS_MEDIA_ROUTER_FEEDBACK_CONTENT_QUESTION 2279
#define IDS_MEDIA_ROUTER_FEEDBACK_ADDITIONAL_COMMENTS 2280
#define IDS_MEDIA_ROUTER_FEEDBACK_ALLOW_CONTACT_BY_EMAIL 2281
#define IDS_MEDIA_ROUTER_FEEDBACK_YOUR_EMAIL_ADDRESS 2282
#define IDS_MEDIA_ROUTER_FEEDBACK_EMAIL_FIELD 2283
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_BUTTON 2284
#define IDS_MEDIA_ROUTER_FEEDBACK_DISCARD_CONFIRMATION 2285
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_BUG_OR_ERROR 2286
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_FEATURE_REQUEST 2287
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_PROJECTION_QUALITY 2288
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_DISCOVERY 2289
#define IDS_MEDIA_ROUTER_FEEDBACK_TYPE_OTHER 2290
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_FREEZES 2291
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_JERKY 2292
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_STUTTER 2293
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_SMOOTH 2294
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_PERFECT 2295
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_UNWATCHABLE 2296
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_POOR 2297
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_ACCEPTABLE 2298
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_GOOD 2299
#define IDS_MEDIA_ROUTER_FEEDBACK_VIDEO_GREAT 2300
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_UNINTELLIGIBLE 2301
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_POOR 2302
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_ACCEPTABLE 2303
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_GOOD 2304
#define IDS_MEDIA_ROUTER_FEEDBACK_AUDIO_PERFECT 2305
#define IDS_MEDIA_ROUTER_FEEDBACK_SENDING 2306
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_FAIL 2307
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_SUCCESS 2308
#define IDS_MEDIA_ROUTER_FEEDBACK_RESENDING 2309
#define IDS_MEDIA_ROUTER_FEEDBACK_LOGS_HEADER 2310
#define IDS_MEDIA_ROUTER_FEEDBACK_FINE_LOGS_WARNING 2311
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_LOGS_HTML 2312
#define IDS_MEDIA_ROUTER_FEEDBACK_SEND_LOGS 2313
#define IDS_MEDIA_ROUTER_FEEDBACK_PRIVACY_DATA_USAGE 2314
#define IDS_MEDIA_ROUTER_FEEDBACK_SETUP_VISIBILITY_QUESTION 2315
#define IDS_MEDIA_ROUTER_FEEDBACK_YES 2316
#define IDS_MEDIA_ROUTER_FEEDBACK_NO 2317
#define IDS_MEDIA_ROUTER_FEEDBACK_DID_NOT_TRY 2318
#define IDS_MEDIA_ROUTER_FEEDBACK_SOFTWARE_QUESTION 2319
#define IDS_MEDIA_ROUTER_FEEDBACK_UNKNOWN 2320
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_QUESTION 2321
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_SAME_WIFI 2322
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_DIFFERENT_WIFI 2323
#define IDS_MEDIA_ROUTER_FEEDBACK_NETWORK_WIRED_PC 2324
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_CAST_SCREEN 2325
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_PAUSED 2326
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_SCREEN_CAN_PAUSE 2327
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_SCREEN_PAUSED 2328
#define IDS_MEDIA_ROUTER_NOTIFICATION_MESSAGE_TAB_CAN_PAUSE 2329
#define IDS_MEDIA_ROUTER_NOTIFICATION_TITLE 2330
#define IDS_MEDIA_ROUTER_NOTIFICATION_TITLE_UNKNOWN 2331
#define IDS_AVATAR_BUTTON_GUEST 2332
#define IDS_AVATAR_BUTTON_GUEST_TOOLTIP 2333
#define IDS_GUEST_BUBBLE_ACCESSIBLE_TITLE 2334
#define IDS_INCOGNITO_BUBBLE_ACCESSIBLE_TITLE 2335
#define IDS_AVATAR_BUTTON_INCOGNITO 2336
#define IDS_AVATAR_BUTTON_INCOGNITO_TOOLTIP 2337
#define IDS_AVATAR_BUTTON_SYNC_ERROR 2338
#define IDS_AVATAR_BUTTON_SYNC_ERROR_TOOLTIP 2339
#define IDS_AVATAR_BUTTON_SYNC_PAUSED 2340
#define IDS_AVATAR_BUTTON_SYNC_ERROR_BOOKMARKS_LIMIT_EXCEEDED 2341
#define IDS_AVATAR_BUTTON_SIGNIN_PAUSED 2342
#define IDS_AVATAR_BUTTON_WORK 2343
#define IDS_AVATAR_BUTTON_SCHOOL 2344
#define IDS_AVATAR_BUTTON_GREETING 2345
#define IDS_AVATAR_BUTTON_PASSKEYS_ERROR_UNLOCK 2346
#define IDS_AVATAR_BUTTON_PASSKEYS_ERROR_GET 2347
#define IDS_AVATAR_BUTTON_PASSKEYS_ERROR_VERIFY 2348
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_DESCRIPTION_UNLOCK 2349
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_DESCRIPTION_GET 2350
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_DESCRIPTION_VERIFY 2351
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_BUTTON_UNLOCK 2352
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_BUTTON_GET 2353
#define IDS_PROFILE_MENU_PASSKEYS_ERROR_BUTTON_VERIFY 2354
#define IDS_PROFILES_MENU_NAME 2355
#define IDS_PROFILES_ADD_PROFILE_LABEL 2357
#define IDS_PROFILES_PROFILE_BUBBLE_ACCESSIBLE_TITLE 2358
#define IDS_PROFILES_EXIT_PROFILE_BUTTON 2359
#define IDS_PROFILES_ACCOUNT_REMOVAL_TITLE 2360
#define IDS_PROFILES_SYNC_COMPLETE_TITLE 2361
#define IDS_PROFILES_DICE_SIGNIN_BUTTON 2362
#define IDS_EXTENSIONS_EXPLICIT_SIGNIN_BUTTON 2363
#define IDS_PROFILES_DICE_WEB_ONLY_SIGNIN_BUTTON 2364
#define IDS_PROFILES_DICE_SIGNIN_FIRST_ACCOUNT_BUTTON 2365
#define IDS_PROFILES_DICE_SIGNIN_FIRST_ACCOUNT_BUTTON_NO_NAME 2366
#define IDS_PROFILES_DICE_SYNC_DISABLED_TITLE 2367
#define IDS_PROFILES_DASHER_FEATURE_DISABLED_TITLE 2368
#define IDS_PROFILES_DICE_SYNC_PAUSED_TITLE 2369
#define IDS_PROFILES_SIGNIN_PROMO 2370
#define IDS_AI_SIGNIN_PROMO_TITLE 2371
#define IDS_AI_VERIFY_PROMO_SUBTITLE 2372
#define IDS_PROFILES_VERIFY_ACCOUNT_BUTTON 2373
#define IDS_PROFILE_MENU_SIGNIN_PROMO_DESCRIPTION 2374
#define IDS_PROFILE_MENU_SIGNIN_PROMO_DESCRIPTION_WITH_BOOKMARKS 2375
#define IDS_PROFILE_MENU_PROFILE_IDENTIFIER_WITH_SEPARATOR 2376
#define IDS_PROFILE_MENU_PROFILE_MANAGED_HEADER 2377
#define IDS_GUEST_PROFILE_MENU_CLOSE_X_WINDOWS_BUTTON 2378
#define IDS_INCOGNITO_PROFILE_MENU_CLOSE_X_WINDOWS_BUTTON 2379
#define IDS_PROFILES_PROFILE_MANAGE_ACCOUNTS_BUTTON 2380
#define IDS_PROFILES_PROFILE_HIDE_MANAGE_ACCOUNTS_BUTTON 2381
#define IDS_PROFILE_MENU_OPEN_GUEST_PROFILE 2382
#define IDS_PROFILE_MENU_CLOSE_PROFILE_X_WINDOWS_BUTTON 2383
#define IDS_PROFILES_OPEN_SYNC_SETTINGS_BUTTON 2384
#define IDS_PROFILE_MENU_CUSTOMIZE_PROFILE_BUTTON 2385
#define IDS_PROFILE_MENU_OPEN_ACCOUNT_SETTINGS 2386
#define IDS_PROFILE_MENU_AUTOFILL_SETTINGS_BUTTON 2387
#define IDS_PROFILE_MENU_BATCH_UPLOAD_BUTTON 2388
#define IDS_PROFILES_MANAGED_BY 2389
#define IDS_PROFILES_MANAGE_PROFILES_BUTTON_TOOLTIP 2390
#define IDS_PROFILES_CUSTOMIZE_PROFILE_BUTTON_TOOLTIP 2391
#define IDS_PROFILES_GUEST_PROFILE_NAME 2392
#define IDS_DEFAULT_PROFILE_NAME 2393
#define IDS_LEGACY_DEFAULT_PROFILE_NAME 2394
#define IDS_NEW_NUMBERED_PROFILE_NAME 2395
#define IDS_SINGLE_PROFILE_DISPLAY_NAME 2396
#define IDS_GUEST_PROFILE_NAME 2397
#define IDS_DEFAULT_AVATAR_NAME_8 2398
#define IDS_DEFAULT_AVATAR_NAME_9 2399
#define IDS_DEFAULT_AVATAR_NAME_10 2400
#define IDS_DEFAULT_AVATAR_NAME_11 2401
#define IDS_DEFAULT_AVATAR_NAME_12 2402
#define IDS_DEFAULT_AVATAR_NAME_13 2403
#define IDS_DEFAULT_AVATAR_NAME_14 2404
#define IDS_DEFAULT_AVATAR_NAME_15 2405
#define IDS_DEFAULT_AVATAR_NAME_16 2406
#define IDS_DEFAULT_AVATAR_NAME_17 2407
#define IDS_DEFAULT_AVATAR_NAME_18 2408
#define IDS_DEFAULT_AVATAR_NAME_19 2409
#define IDS_DEFAULT_AVATAR_NAME_20 2410
#define IDS_DEFAULT_AVATAR_NAME_21 2411
#define IDS_DEFAULT_AVATAR_NAME_22 2412
#define IDS_DEFAULT_AVATAR_NAME_23 2413
#define IDS_DEFAULT_AVATAR_NAME_24 2414
#define IDS_DEFAULT_AVATAR_NAME_25 2415
#define IDS_DEFAULT_AVATAR_NAME_26 2416
#define IDS_DEFAULT_AVATAR_LABEL_0 2417
#define IDS_DEFAULT_AVATAR_LABEL_1 2418
#define IDS_DEFAULT_AVATAR_LABEL_2 2419
#define IDS_DEFAULT_AVATAR_LABEL_3 2420
#define IDS_DEFAULT_AVATAR_LABEL_4 2421
#define IDS_DEFAULT_AVATAR_LABEL_5 2422
#define IDS_DEFAULT_AVATAR_LABEL_6 2423
#define IDS_DEFAULT_AVATAR_LABEL_7 2424
#define IDS_DEFAULT_AVATAR_LABEL_8 2425
#define IDS_DEFAULT_AVATAR_LABEL_9 2426
#define IDS_DEFAULT_AVATAR_LABEL_10 2427
#define IDS_DEFAULT_AVATAR_LABEL_11 2428
#define IDS_DEFAULT_AVATAR_LABEL_12 2429
#define IDS_DEFAULT_AVATAR_LABEL_13 2430
#define IDS_DEFAULT_AVATAR_LABEL_14 2431
#define IDS_DEFAULT_AVATAR_LABEL_15 2432
#define IDS_DEFAULT_AVATAR_LABEL_16 2433
#define IDS_DEFAULT_AVATAR_LABEL_17 2434
#define IDS_DEFAULT_AVATAR_LABEL_18 2435
#define IDS_DEFAULT_AVATAR_LABEL_19 2436
#define IDS_DEFAULT_AVATAR_LABEL_20 2437
#define IDS_DEFAULT_AVATAR_LABEL_21 2438
#define IDS_DEFAULT_AVATAR_LABEL_22 2439
#define IDS_DEFAULT_AVATAR_LABEL_23 2440
#define IDS_DEFAULT_AVATAR_LABEL_24 2441
#define IDS_DEFAULT_AVATAR_LABEL_25 2442
#define IDS_DEFAULT_AVATAR_LABEL_26 2443
#define IDS_DEFAULT_AVATAR_LABEL_27 2444
#define IDS_DEFAULT_AVATAR_LABEL_28 2445
#define IDS_DEFAULT_AVATAR_LABEL_29 2446
#define IDS_DEFAULT_AVATAR_LABEL_30 2447
#define IDS_DEFAULT_AVATAR_LABEL_31 2448
#define IDS_DEFAULT_AVATAR_LABEL_32 2449
#define IDS_DEFAULT_AVATAR_LABEL_33 2450
#define IDS_DEFAULT_AVATAR_LABEL_34 2451
#define IDS_DEFAULT_AVATAR_LABEL_35 2452
#define IDS_DEFAULT_AVATAR_LABEL_36 2453
#define IDS_DEFAULT_AVATAR_LABEL_37 2454
#define IDS_DEFAULT_AVATAR_LABEL_38 2455
#define IDS_DEFAULT_AVATAR_LABEL_39 2456
#define IDS_DEFAULT_AVATAR_LABEL_40 2457
#define IDS_DEFAULT_AVATAR_LABEL_41 2458
#define IDS_DEFAULT_AVATAR_LABEL_42 2459
#define IDS_DEFAULT_AVATAR_LABEL_43 2460
#define IDS_DEFAULT_AVATAR_LABEL_44 2461
#define IDS_DEFAULT_AVATAR_LABEL_45 2462
#define IDS_DEFAULT_AVATAR_LABEL_46 2463
#define IDS_DEFAULT_AVATAR_LABEL_47 2464
#define IDS_DEFAULT_AVATAR_LABEL_48 2465
#define IDS_DEFAULT_AVATAR_LABEL_49 2466
#define IDS_DEFAULT_AVATAR_LABEL_50 2467
#define IDS_DEFAULT_AVATAR_LABEL_51 2468
#define IDS_DEFAULT_AVATAR_LABEL_52 2469
#define IDS_DEFAULT_AVATAR_LABEL_53 2470
#define IDS_DEFAULT_AVATAR_LABEL_54 2471
#define IDS_DEFAULT_AVATAR_LABEL_55 2472
#define IDS_PROFILES_LOCAL_PROFILE_STATE 2473
#define IDS_PROFILES_CREATE_BUTTON_LABEL 2474
#define IDS_PROFILES_MANAGE_BUTTON_LABEL 2475
#define IDS_PROFILES_DEFAULT_NAME 2476
#define IDS_SYNC_LOGIN_NAME_PROHIBITED 2477
#define IDS_SIGN_IN_LOGIN_NAME_PROHIBITED 2478
#define IDS_SUPERVISED_USER_NOT_ALLOWED_BY_POLICY 2479
#define IDS_SYNC_USER_NAME_IN_USE_ERROR 2480
#define IDS_SYNC_USER_NAME_IN_USE_BY_ERROR 2481
#define IDS_SCREEN_LOCK_SIGN_OUT 2482
#define IDS_PROFILE_CUSTOMIZATION_DONE_BUTTON_LABEL 2488
#define IDS_PROFILE_CUSTOMIZATION_THEME_PICKER_LABEL 2489
#define IDS_PROFILE_CUSTOMIZATION_WELCOME 2490
#define IDS_PROFILE_CUSTOMIZATION_INPUT_LABEL 2491
#define IDS_PROFILE_CUSTOMIZATION_INPUT_TITLE 2492
#define IDS_PROFILE_CUSTOMIZATION_INPUT_PLACEHOLDER 2493
#define IDS_PROFILE_CUSTOMIZATION_INPUT_ERROR_MESSAGE 2494
#define IDS_PROFILE_CUSTOMIZATION_SKIP_BUTTON_LABEL 2495
#define IDS_PROFILE_CUSTOMIZATION_DELETE_PROFILE_BUTTON_LABEL 2496
#define IDS_PROFILE_CUSTOMIZATION_LOCAL_PROFILE_CREATION_TITLE 2497
#define IDS_PROFILE_CUSTOMIZATION_AVATAR_SELECTION_BACK_BUTTON_LABEL 2498
#define IDS_ENTERPRISE_PROFILE_WELCOME_TITLE 2499
#define IDS_ENTERPRISE_PROFILE_WELCOME_ACCOUNT_MANAGED_BY 2500
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_MANAGED_STRICT_SEPARATION 2501
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_MANAGED_SEPARATION 2502
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_SEPARATION_DEVICE_MANAGED 2503
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_SEPARATION_ACCOUNT_MANAGED 2504
#define IDS_ENTERPRISE_PROFILE_WELCOME_PROFILE_SEPARATION_DEVICE_MANAGED_BY 2505
#define IDS_ENTERPRISE_PROFILE_WELCOME_ACCOUNT_EMAIL_MANAGED_BY 2506
#define IDS_ENTERPRISE_PROFILE_WELCOME_DEVICE_MANAGED_BY 2507
#define IDS_ENTERPRISE_PROFILE_WELCOME_DEVICE_MANAGED 2508
#define IDS_ENTERPRISE_WELCOME_PROFILE_REQUIRED_TITLE 2509
#define IDS_ENTERPRISE_WELCOME_PROFILE_SETUP_TITLE 2510
#define IDS_ENTERPRISE_WELCOME_PROFILE_WILL_BE_MANAGED_TITLE 2511
#define IDS_ENTERPRISE_PROFILE_WELCOME_CREATE_PROFILE_BUTTON 2512
#define IDS_ENTERPRISE_PROFILE_WELCOME_LINK_DATA_CHECKBOX 2513
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_SCHOOL_TITLE 2514
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_WORK_TITLE 2515
#define IDS_ENTERPRISE_WELCOME_PROFILE_OIDC_DISCLOSURE_TITLE 2516
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_TITLE 2517
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_ENFORCED_SUBTITLE 2518
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_SUBTITLE 2519
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_SUBTITLE 2520
#define IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_KNOWN_DOMAIN_SUBTITLE 2521
#define IDS_ENTERPRISE_WELCOME_PROFILE_INFORMATION_TITLE 2522
#define IDS_ENTERPRISE_WELCOME_DEVICE_INFORMATION_TITLE 2523
#define IDS_ENTERPRISE_WELCOME_DEVICE_INFORMATION_DETAILS 2524
#define IDS_ENTERPRISE_PROFILE_WELCOME_BACK 2525
#define IDS_ENTERPRISE_OIDC_WELCOME_PROCESSING_SUBTITLE 2526
#define IDS_ENTERPRISE_OIDC_WELCOME_LONG_PROCESSING_SUBTITLE 2527
#define IDS_ENTERPRISE_OIDC_WELCOME_SUCCESS_TITLE 2528
#define IDS_ENTERPRISE_OIDC_WELCOME_SUCCESS_SUBTITLE 2529
#define IDS_ENTERPRISE_OIDC_WELCOME_TIMEOUT_TITLE 2530
#define IDS_ENTERPRISE_OIDC_WELCOME_TIMEOUT_SUBTITLE 2531
#define IDS_ENTERPRISE_OIDC_WELCOME_TIMEOUT_RETRY_LABEL 2532
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_TITLE 2533
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_SUBTITLE 2534
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_NO_SIGNIN_TITLE 2535
#define IDS_ENTERPRISE_OIDC_WELCOME_ERROR_NO_SIGNIN_SUBTITLE 2536
#define IDS_ENTERPRISE_VALUE_PROPOSITION_CONSUMER_SUBTITLE 2537
#define IDS_ENTERPRISE_VALUE_PROPOSITION_CONSUMER_SUBTITLE_WITH_BOOKMARKS 2538
#define IDS_ENTERPRISE_VALUE_PROPOSITION_SCHOOL_SUBTITLE 2539
#define IDS_ENTERPRISE_VALUE_PROPOSITION_WORK_SUBTITLE 2540
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_WORK_TITLE 2541
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_SCHOOL_TITLE 2542
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_ALREADY_SIGNED_IN_TITLE 2543
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_CONSUMER_TITLE 2544
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_SCHOOL_CHOICE 2545
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_WORK_CHOICE 2546
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_ALREADY_SIGNED_IN_CHOICE 2547
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_SCHOOL_NOT_RECOMMENDED 2548
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_WORK_NOT_RECOMMENDED 2549
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_DETAILS 2550
#define IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_ALREADY_SIGNED_IN_DETAILS 2551
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WORK_CHOICE 2552
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_SCHOOL_CHOICE 2553
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_ALREADY_SIGNED_IN_CHOICE 2554
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_CHOICE_DETAILS 2555
#define IDS_BROWSING_HISTORY_COUNT 2556
#define IDS_BOOKMARKS_COUNT 2557
#define IDS_EXTENSIONS_COUNT 2558
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_THREE_COUNTS_CHOICE_DETAILS 2559
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_TWO_COUNTS_CHOICE_DETAILS 2560
#define IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_ONE_COUNT_CHOICE_DETAILS 2561
#define IDS_ACCNAME_YOUR_AVATAR 2562
#define IDS_ACCNAME_ENTERPRISE_ORGANIZATION_ICON 2563
#define IDS_SUPERVISED_USER_PROFILE_SIGNIN_IPH_TITLE 2564
#define IDS_SUPERVISED_USER_PROFILE_SIGNIN_IPH_TEXT 2565
#define IDS_MANAGED_BY_PARENT_A11Y 2566
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_KIDS_BODY 2567
#define IDS_PROFILE_PICKER_ADD_SPACE_BUTTON 2568
#define IDS_PROFILE_PICKER_BROWSE_AS_GUEST_BUTTON 2569
#define IDS_PROFILE_PICKER_BACK_BUTTON_ARIA_LABEL 2570
#define IDS_PROFILE_PICKER_BACK_BUTTON_SIGN_IN_LABEL 2571
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_KEEP_WORK_AND_LIFE_SEPARATE 2572
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_GOT_ANOTHER_GOOGLE_ACCOUNT 2573
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_KEEP_TASKS_SEPARATE 2574
#define IDS_PROFILE_PICKER_MAIN_VIEW_TITLE_SHARING_A_COMPUTER 2575
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_SHARING_A_COMPUTER 2576
#define IDS_PROFILE_PICKER_MAIN_VIEW_SUBTITLE_KEEP_EVERYTHING_IN_CHROME 2577
#define IDS_PROFILE_PICKER_PROFILE_CARD_NEEDS_SIGNIN_PROMPT 2578
#define IDS_PROFILE_PICKER_PROFILE_CARD_LABEL_SUPERVISED 2579
#define IDS_PROFILE_PICKER_PROFILE_CARD_LABEL 2580
#define IDS_PROFILE_PICKER_PROFILE_CARD_INPUT_LABEL 2581
#define IDS_PROFILE_PICKER_PROFILE_MORE_ACTIONS_ARIA_LABEL 2582
#define IDS_PROFILE_PICKER_PROFILE_MENU_REMOVE_TEXT 2583
#define IDS_PROFILE_PICKER_PROFILE_MENU_REMOVE_CONFIRM 2584
#define IDS_PROFILE_PICKER_PROFILE_MENU_CUSTOMIZE_TEXT 2585
#define IDS_PROFILE_PICKER_PROFILE_MENU_INCOGNITO_TEXT 2586
#define IDS_PROFILE_PICKER_ASK_ON_STARTUP 2587
#define IDS_PROFILE_PICKER_OPEN_ALL_PROFILES_BUTTON 2588
#define IDS_PROFILE_PICKER_REMOVE_WARNING_LOCAL_PROFILE_TITLE 2589
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_ALLOWED_TITLE 2590
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_ALLOWED_BODY 2591
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_WRONG_ACCOUNT_TITLE 2592
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_WRONG_ACCOUNT_BODY 2593
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_TIMEOUT_TITLE 2594
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_TIMEOUT_BODY 2595
#define IDS_PROFILE_PICKER_FORCE_SIGN_IN_ERROR_DIALOG_NOT_SUPPORTED_BY_GLIC_FLOW_TITLE 2596
#define IDS_PROFILE_PICKER_REMOVE_WARNING_HISTORY 2597
#define IDS_PROFILE_PICKER_REMOVE_WARNING_PASSWORDS 2598
#define IDS_PROFILE_PICKER_REMOVE_WARNING_BOOKMARKS 2599
#define IDS_PROFILE_PICKER_REMOVE_WARNING_AUTOFILL 2600
#define IDS_PROFILE_PICKER_REMOVE_WARNING_CALCULATING 2601
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_SIGNIN_BUTTON_LABEL 2602
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_NOT_NOW_BUTTON_LABEL 2603
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_DONT_SIGN_IN_BUTTON_LABEL 2604
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_STAY_SIGNED_OUT_BUTTON_LABEL 2605
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_LOCAL_PROFILE_CREATION_CUSTOMIZE_AVATAR_BUTTON_LABEL 2606
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_LOCAL_PROFILE_CREATION_AVATAR_TEXT 2607
#define IDS_PROFILE_PICKER_TAKE_A_TOUR_BUTTON_LABEL 2608
#define IDS_PROFILE_PICKER_IPH_NEXT_BUTTON_LABEL 2609
#define IDS_PROFILE_PICKER_IPH_DONE_BUTTON_LABEL 2610
#define IDS_PROFILE_PICKER_IPH_FOR_PROFILES_TITLE 2611
#define IDS_PROFILE_PICKER_IPH_FOR_ADD_PROFILE_TITLE 2612
#define IDS_PROFILE_PICKER_IPH_FOR_CUSTOMIZE_PROFILE_TITLE 2613
#define IDS_PROFILE_PICKER_IPH_FOR_CUSTOMIZE_PROFILE_TEXT 2614
#define IDS_PROFILE_PICKER_PROFILE_SWITCH_SWITCH_BUTTON_LABEL 2615
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_DEVICE_MANAGED_BY_DESCRIPTION 2616
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_DEVICE_MANAGED_DESCRIPTION 2617
#define IDS_PROFILE_PICKER_REMOVE_WARNING_LOCAL_PROFILE 2618
#define IDS_PROFILE_PICKER_REMOVE_WARNING_SIGNED_IN_PROFILE_TITLE 2619
#define IDS_PROFILE_PICKER_REMOVE_WARNING_SIGNED_IN_PROFILE 2620
#define IDS_PROFILE_PICKER_REMOVE_WARNING_SIGNED_IN_PROFILE_SIGN_IN_AS 2621
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_PROFILE_TYPE_CHOICE_SUBTITLE_UNO 2622
#define IDS_PROFILE_PICKER_PROFILE_CREATION_FLOW_PROFILE_TYPE_CHOICE_SUBTITLE_UNO_BOOKMARKS 2623
#define IDS_FRE_SIGN_IN_SUBTITLE_0 2624
#define IDS_FRE_SIGN_IN_SUBTITLE_1 2625
#define IDS_FRE_DEVICES_CARD_TITLE 2626
#define IDS_FRE_DEVICES_CARD_DESCRIPTION 2627
#define IDS_FRE_SECURITY_CARD_TITLE 2628
#define IDS_FRE_SECURITY_CARD_DESCRIPTION 2629
#define IDS_FRE_BACKUP_CARD_TITLE 2630
#define IDS_UNO_FRE_BACKUP_CARD_DESCRIPTION 2631
#define IDS_UNO_FRE_BACKUP_CARD_DESCRIPTION_WITH_PASSWORDS 2632
#define IDS_UNO_FRE_REFRESH_BACKUP_CARD_DESCRIPTION_WITH_PASSWORDS 2633
#define IDS_FRE_DECLINE_SIGN_IN_BUTTON_TITLE 2634
#define IDS_FRE_STAY_SIGNED_OUT_BUTTON_TITLE 2635
#define IDS_FRE_ACCEPT_SIGN_IN_BUTTON_TITLE 2636
#define IDS_FRE_CREATE_ACCOUNT_DESCRIPTION 2637
#define IDS_FRE_SIGN_IN_CELEBRATION_WELCOME_TITLE 2638
#define IDS_FRE_MANAGED_DESCRIPTION 2639
#define IDS_FRE_MANAGED_BY_DESCRIPTION 2640
#define IDS_FRE_NATIVE_TOOLBAR_DONT_SIGN_IN_BUTTON_LABEL 2641
#define IDS_FRE_NEXT_BUTTON_TITLE 2642
#define IDS_FRE_DEFAULT_BROWSER_TITLE_NEW 2643
#define IDS_FRE_DEFAULT_BROWSER_SUBTITLE 2644
#define IDS_FRE_DEFAULT_BROWSER_SET_AS_DEFAULT 2645
#define IDS_FRE_DEFAULT_BROWSER_SKIP 2646
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_SET_AS_DEFAULT 2647
#define IDS_FRE_REFRESH_DEFAULT_BROWSER_NO_THANKS 2648
#define IDS_BATCH_UPLOAD_TITLE 2649
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_ITEMS_WITH_DEDUPLICATION 2650
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS_WITH_DEDUPLICATION 2651
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS_COMBO_WITH_DEDUPLICATION 2652
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS_WITH_DEDUPLICATION 2653
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS_COMBO_WITH_DEDUPLICATION 2654
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_ITEMS 2655
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS 2656
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_PASSWORDS_COMBO 2657
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS 2658
#define IDS_BATCH_UPLOAD_SUBTITLE_DESCRIPTION_BOOKMARKS_COMBO 2659
#define IDS_BATCH_UPLOAD_SECTION_TITLE_PASSWORDS 2660
#define IDS_BATCH_UPLOAD_SECTION_TITLE_BOOKMARKS 2661
#define IDS_BATCH_UPLOAD_SECTION_TITLE_READING_LIST 2662
#define IDS_BATCH_UPLOAD_SECTION_TITLE_ADDRESSES 2663
#define IDS_BATCH_UPLOAD_SECTION_TITLE_EXTENSIONS 2664
#define IDS_BATCH_UPLOAD_SECTION_TITLE_THEMES_WITH_DESCRIPTION 2665
#define IDS_BATCH_UPLOAD_SAVE_TO_ACCOUNT_OK_BUTTON_LABEL 2666
#define IDS_BATCH_UPLOAD_AVATAR_BUTTON_SAVING_TO_ACCOUNT 2667
#define IDS_BATCH_UPLOAD_LAST_ITEM_SELECTED_SCREEN_READER 2668
#define IDS_BATCH_UPLOAD_SCREEN_READER_ITEM_COUNT_SELECTED 2669
#define IDS_BATCH_UPLOAD_SCREEN_READER_SELECT_ALL 2670
#define IDS_BATCH_UPLOAD_PROMO_TITLE 2671
#define IDS_BATCH_UPLOAD_PROMO_TITLE_OK_BUTTON_LABEL 2672
#define IDS_BATCH_UPLOAD_PROMO_SUBTITLE_BOOKMARKS 2673
#define IDS_BATCH_UPLOAD_PROMO_SUBTITLE_BOOKMARKS_COMBO 2674
#define IDS_BATCH_UPLOAD_PROMO_SUBTITLE_ITEMS_WITH_LINK 2675
#define IDS_SIGNOUT_CONFIRMATION_EXTENSIONS_SECTION_TITLE 2676
#define IDS_SIGNOUT_CONFIRMATION_EXTENSIONS_SECTION_TOOLTIP 2677
#define IDS_SIGNOUT_CONFIRMATION_UNSYNCED_DATA_WITH_ACCOUNT_EXTENSIONS 2678
#define IDS_HISTORY_SYNC_OPT_IN_TITLE 2679
#define IDS_HISTORY_SYNC_OPT_IN_SUBTITLE 2680
#define IDS_HISTORY_SYNC_OPT_IN_SUBTITLE_WITH_EMAIL 2681
#define IDS_HISTORY_SYNC_OPT_IN_DESCRIPTION 2682
#define IDS_HISTORY_SYNC_OPT_IN_ACCEPT_BUTTON 2683
#define IDS_HISTORY_SYNC_OPT_IN_REJECT_BUTTON 2684
#define IDS_TABS_DISABLED_ERROR_DESCRIPTION 2685
#define IDS_AVATAR_BUTTON_SYNC_HISTORY 2686
#define IDS_AVATAR_BUTTON_SYNC_PROMO 2687
#define IDS_AVATAR_BUTTON_BATCH_UPLOAD_PROMO 2688
#define IDS_AVATAR_BUTTON_BATCH_UPLOAD_PROMO_WITH_BOOKMARK_CLEANUP_PROMO 2689
#define IDS_PROFILE_MENU_SYNC_PROMO_SYNC_HISTORY_DESCRIPTION 2690
#define IDS_PROFILE_MENU_SYNC_PROMO_BUTTON_LABEL 2691
#define IDS_PROFILE_MENU_DESCRIPTION_WITH_SYNC_PROMO 2692
#define IDS_PROFILE_MENU_BUTTON_LABEL_WITH_SYNC_PROMO 2693
#define IDS_PROFILE_MENU_PROMO_DESCRIPTION_WITH_BATCH_UPLOAD 2694
#define IDS_PROFILE_MENU_PROMO_BUTTON_WITH_BATCH_UPLOAD 2695
#define IDS_PROFILE_MENU_PROMO_DESCRIPTION_WITH_BATCH_UPLOAD_BOOKMARK_CLEANUP 2696
#define IDS_SIGN_IN_BENEFITS_IPH_TEXT 2697
#define IDS_SIGN_IN_BENEFITS_WITHOUT_BOOKMARKS_AND_EXTENSIONS_IPH_TEXT 2698
#define IDS_TYPE_A_SHORTCUT 2699
#define IDS_SHORTCUT_SET 2700
#define IDS_SHORTCUT_NOT_SET 2701
#define IDS_SHORTCUT_INCLUDE_START_MODIFIER 2702
#define IDS_SHORTCUT_TOO_MANY_MODIFIERS 2703
#define IDS_SHORTCUT_NEED_CHARACTER 2704
#define IDS_SHORTCUT_CLEAR 2705
#define IDS_SETTINGS_EMPTY_STRING 7526
#define IDS_SETTINGS_CONTINUE 7527
#define IDS_SETTINGS_GOT_IT 7528
#define IDS_SETTINGS_MORE_ACTIONS 7529
#define IDS_SETTINGS_MORE_ACTIONS_BUTTON_ARIA_LABEL 7530
#define IDS_SETTINGS_OPENS_IN_NEW_TAB 7531
#define IDS_SETTINGS_SEND_FEEDBACK_ROLE_DESCRIPTION 7532
#define IDS_SETTINGS_COLUMN_HEADING_WHEN_ON 7533
#define IDS_SETTINGS_COLUMN_HEADING_CONSIDER 7534
#define IDS_SETTINGS_COLUMN_HEADING_WHEN_USED 7535
#define IDS_RELAUNCH_CONFIRMATION_DIALOG_BODY 7536
#define IDS_SETTINGS_ABOUT_PAGE_BROWSER_VERSION 7537
#define IDS_SETTINGS_ABOUT_PAGE_LEARN_MORE_UPDATE_ERRORS 7538
#define IDS_SETTINGS_ABOUT_PAGE_LEARN_MORE_SYSTEM_REQUIREMENTS 7539
#define IDS_SETTINGS_ABOUT_PAGE_RELAUNCH 4583
#define IDS_SETTINGS_ACCESSIBILITY 7546
#define IDS_SETTINGS_ACCESSIBILITY_WEB_STORE 7547
#define IDS_SETTINGS_MORE_FEATURES_LINK 7548
#define IDS_SETTINGS_MORE_FEATURES_LINK_DESCRIPTION 7549
#define IDS_SETTINGS_ACCESSIBLE_IMAGE_LABELS_TITLE 7550
#define IDS_SETTINGS_ACCESSIBLE_IMAGE_LABELS_SUBTITLE 7551
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOAD_COMPLETE 7552
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOAD_ERROR 7553
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOAD_PROGRESS 7554
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_DOWNLOADING 7555
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_TITLE 7556
#define IDS_SETTINGS_MAIN_NODE_ANNOTATIONS_SUBTITLE 7557
#define IDS_SETTINGS_AX_TREE_FIXING_TITLE 7558
#define IDS_SETTINGS_AX_TREE_FIXING_SUBTITLE 7559
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_CAPTION_TITLE 7560
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_TRANSLATE_TITLE 7561
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_TRANSLATE_SUBTITLE 7562
#define IDS_SETTINGS_CAPTIONS_ENABLE_LIVE_CAPTION_SUBTITLE 7563
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_PROGRESS 7564
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_COMPLETE 7565
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_ERROR 7566
#define IDS_SETTINGS_CAPTIONS_LIVE_CAPTION_DOWNLOAD_ERROR_REBOOT_REQUIRED 7567
#define IDS_SETTINGS_CAPTIONS_MASK_OFFENSIVE_WORDS_TITLE 7568
#define IDS_SETTINGS_ENABLE_CARET_BROWSING_TITLE 7569
#define IDS_SETTINGS_ENABLE_CARET_BROWSING_SUBTITLE 7570
#define IDS_SETTINGS_ACCESSIBILITY_FOCUS_HIGHLIGHT_DESCRIPTION 5306
#define IDS_SETTINGS_OVERSCROLL_HISTORY_NAVIGATION_TITLE 5238
#define IDS_SETTINGS_OVERSCROLL_HISTORY_NAVIGATION_SUBTITLE 7571
#define IDS_SETTINGS_ACCESSIBILITY_TOAST_FREQUENCY_TITLE 7572
#define IDS_SETTINGS_ACCESSIBILITY_TOAST_FREQUENCY_DESCRIPTION 7573
#define IDS_SETTINGS_APPEARANCE 7574
#define IDS_SETTINGS_CUSTOM_WEB_ADDRESS 7575
#define IDS_SETTINGS_ENTER_CUSTOM_WEB_ADDRESS 7576
#define IDS_SETTINGS_HOME_BUTTON_DISABLED 7577
#define IDS_SETTINGS_THEMES 7578
#define IDS_SETTINGS_GTK_THEME 7579
#define IDS_SETTINGS_USE_GTK_THEME 7580
#define IDS_SETTINGS_QT_THEME 7581
#define IDS_SETTINGS_USE_QT_THEME 7582
#define IDS_SETTINGS_CLASSIC_THEME 7583
#define IDS_SETTINGS_USE_CLASSIC_THEME 7584
#define IDS_SETTINGS_RESET_TO_DEFAULT 7585
#define IDS_SETTINGS_CUSTOMIZE_TOOLBAR 7587
#define IDS_SETTINGS_RESET_TOOLBAR_TO_DEFAULT 7588
#define IDS_SETTINGS_CHROME_COLORS 7589
#define IDS_SETTINGS_COLOR_SCHEME_MODE 7590
#define IDS_SETTINGS_SHOW_HOME_BUTTON 7591
#define IDS_SETTINGS_SHOW_BOOKMARKS_BAR 7592
#define IDS_SETTINGS_SHOW_TAB_SEARCH_BUTTON 7593
#define IDS_SETTINGS_SHOW_PROJECTS_PANEL_BUTTON 7594
#define IDS_SETTINGS_SHOW_EVERYTHING_MENU_BUTTON 7595
#define IDS_SETTINGS_TAB_STRIP_POSITION 7596
#define IDS_SETTINGS_VERTICAL_TABS_EXPAND_ON_HOVER 7597
#define IDS_SETTINGS_ALLOW_SPLIT_VIEW_DRAG_AND_DROP 7598
#define IDS_SETTINGS_SHOW_TAB_GROUPS_IN_BOOKMARKS_BAR 7599
#define IDS_SETTINGS_AUTO_PIN_NEW_TAB_GROUPS 7600
#define IDS_SETTINGS_HOVER_CARD_TITLE 7601
#define IDS_SETTINGS_SHOW_HOVER_CARD_IMAGES 7602
#define IDS_SETTINGS_SHOW_HOVER_CARD_MEMORY_USAGE 7603
#define IDS_SETTINGS_SHOW_HOVER_CARD_MEMORY_USAGE_STANDALONE 7604
#define IDS_SETTINGS_SIDE_PANEL_POSITION 7605
#define IDS_SETTINGS_TAB_SEARCH_POSITION 7606
#define IDS_SETTINGS_UI_FEATURE_ALIGN_LEFT 7607
#define IDS_SETTINGS_UI_FEATURE_ALIGN_RIGHT 7608
#define IDS_SETTINGS_UI_FEATURE_ALIGN_SIDE 7609
#define IDS_SETTINGS_UI_FEATURE_ALIGN_TOP 7610
#define IDS_SETTINGS_HOME_PAGE_NTP 7611
#define IDS_SETTINGS_CHANGE_HOME_PAGE 7612
#define IDS_SETTINGS_ADVANCED 7615
#define IDS_SETTINGS_BASIC 7616
#define IDS_SETTINGS_MENU_BUTTON_LABEL 7617
#define IDS_SETTINGS_MENU_EXTENSIONS_LINK_TOOLTIP 7618
#define IDS_SETTINGS_SEARCH_PROMPT 7619
#define IDS_SETTINGS_SEARCH_NO_RESULTS_HELP 7620
#define IDS_SETTINGS_SETTINGS 7621
#define IDS_SETTINGS_ALT_PAGE_TITLE 7622
#define IDS_SETTINGS_SUBPAGE_BUTTON 7623
#define IDS_SETTINGS_RESTART 7624
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION 7625
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION_TITLE 7626
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION_WITH_DISABLE_AND_MANAGE_OPTION 7627
#define IDS_SETTINGS_CONTROLLED_BY_EXTENSION_WITH_MANAGE_OPTION 7628
#define IDS_SETTINGS_CLEAR 7629
#define IDS_SETTINGS_CUSTOM 7630
#define IDS_SETTINGS_DELETE 7631
#define IDS_SETTINGS_EDIT 7632
#define IDS_SETTINGS_END_TIME 7633
#define IDS_SETTINGS_NOT_VALID 7634
#define IDS_SETTINGS_NOT_VALID_WEB_ADDRESS 7635
#define IDS_SETTINGS_NOT_VALID_WEB_ADDRESS_FOR_CONTENT_TYPE 7636
#define IDS_SETTINGS_INPUT_MAX_LENGTH_DESCRIPTION 7637
#define IDS_SETTINGS_RETRY 7638
#define IDS_SETTINGS_SLIDER_MIN_MAX_ARIA_ROLE_DESCRIPTION 7639
#define IDS_SETTINGS_START_TIME 7640
#define IDS_PASSWORDS_PAGE_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7641
#define IDS_PASSWORDS_PAGE_COPY_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7642
#define IDS_PASSWORDS_PAGE_EDIT_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7643
#define IDS_PASSWORDS_PAGE_EXPORT_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7644
#define IDS_PASSWORDS_PAGE_DELETE_ALL_DATA_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7645
#define IDS_SETTINGS_AUTOFILL_AND_PASSWORDS 7646
#define IDS_SETTINGS_YOUR_SAVED_INFO 7647
#define IDS_IDENTITY_DOCS_SUBMENU_OPTION 7648
#define IDS_TRAVEL_SUBMENU_OPTION 7649
#define IDS_SETTINGS_YOUR_SAVED_INFO_DESCRIPTION 7650
#define IDS_SETTINGS_YOUR_SAVED_INFO_AUTOFILL_SETTINGS_LABEL 7651
#define IDS_SETTINGS_YOUR_SAVED_INFO_AUTOFILL_SETTINGS_DESCRIPTION 7652
#define IDS_SETTINGS_RELATED_SERVICES_TITLE 7653
#define IDS_PASSWORDS_PAGE_IMPORT_AUTHENTICATION_PROMPT_BIOMETRIC_SUFFIX 7654
#define IDS_SETTINGS_GOOGLE_PAYMENTS 7655
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_ADD_TITLE 7656
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_EDIT_TITLE 7657
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_COUNTRY 7658
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_PHONE 7659
#define IDS_SETTINGS_AUTOFILL_ADDRESSES_EMAIL 7660
#define IDS_SETTINGS_AUTOFILL_DETAIL 7661
#define IDS_SETTINGS_AUTOFILL_DROPDOWN_NO_OPTION_SELECTED 7662
#define IDS_SETTINGS_AUTOFILL_CARD_DESCRIPTION 7663
#define IDS_SETTINGS_AUTOFILL_CARD_A11Y_LABELED 7664
#define IDS_SETTINGS_AUTOFILL_CARD_EXP_DATE_A11Y_LABELED 7665
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_ADDRESS 7666
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_CREDIT_CARD 7667
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_CREDIT_CARD_WITH_CVC 7668
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_HOME_ADDRESS 7669
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_WORK_ADDRESS 7670
#define IDS_AUTOFILL_ADD_VIRTUAL_CARD 7671
#define IDS_AUTOFILL_REMOVE_VIRTUAL_CARD 7672
#define IDS_AUTOFILL_EDIT_SERVER_CREDIT_CARD 7673
#define IDS_AUTOFILL_EDIT_SERVER_CREDIT_CARD_IN_WALLET 7674
#define IDS_AUTOFILL_VIRTUAL_CARD_TURNED_ON_LABEL 7675
#define IDS_AUTOFILL_VIRTUAL_CARD_UNENROLL_DIALOG_TITLE 7676
#define IDS_AUTOFILL_VIRTUAL_CARD_UNENROLL_DIALOG_LABEL 7677
#define IDS_AUTOFILL_VIRTUAL_CARD_UNENROLL_DIALOG_CONFIRM_BUTTON_LABEL 7678
#define IDS_SETTINGS_ADDRESS_REMOVE 7679
#define IDS_SETTINGS_ADDRESS_REMOVE_CONFIRMATION_TITLE 7680
#define IDS_SETTINGS_ADDRESS_REMOVED_MESSAGE 7681
#define IDS_SETTINGS_EDIT_CREDIT_CARD_TITLE 7682
#define IDS_SETTINGS_LOCAL_CARD_REMOVE_CONFIRMATION_TITLE 7683
#define IDS_SETTINGS_LOCAL_PAYMENT_METHOD_REMOVE_CONFIRMATION_DESCRIPTION 7684
#define IDS_SETTINGS_PAYMENTS_MANAGE_CREDIT_CARDS 7685
#define IDS_SETTINGS_GOOGLE_WALLET 7686
#define IDS_SETTINGS_PAYMENTS_MANAGE_LOYALTY_CARDS_AND_PAYMENT_METHODS 7687
#define IDS_SETTINGS_REMOTE_WALLET_PASSES_LINK_LABEL 7688
#define IDS_SETTINGS_PAYMENTS_SAVED_TO_THIS_DEVICE_ONLY 7689
#define IDS_SETTINGS_CREDIT_AND_DEBIT_CARD_TITLE 7690
#define IDS_SETTINGS_ADD_CREDIT_CARD_TITLE 7691
#define IDS_SETTINGS_REMOTE_PAYMENT_METHODS_LINK_LABEL 7692
#define IDS_SETTINGS_REMOTE_PAYMENT_METHODS_WALLET_LINK_LABEL 7693
#define IDS_SETTINGS_NAME_ON_CREDIT_CARD 7694
#define IDS_SETTINGS_CREDIT_CARD_NUMBER 7695
#define IDS_SETTINGS_CREDIT_CARD_EXPIRATION_DATE 7696
#define IDS_SETTINGS_CREDIT_CARD_EXPIRATION_MONTH 7697
#define IDS_SETTINGS_CREDIT_CARD_EXPIRATION_YEAR 7698
#define IDS_SETTINGS_CREDIT_CARD_EXPIRED 7699
#define IDS_SETTINGS_CREDIT_CARD_NICKNAME 7700
#define IDS_SETTINGS_CREDIT_CARD_NICKNAME_INVALID 7701
#define IDS_SETTINGS_CREDIT_CARD_CVC_TITLE 7702
#define IDS_SETTINGS_CREDIT_CARD_CVC_IMAGE_TITLE 7703
#define IDS_SETTINGS_CREDIT_CARD_CVC_IMAGE_TITLE_AMEX 7704
#define IDS_SETTINGS_CREDIT_CARD_CVC_PLACEHOLDER 7705
#define IDS_SETTINGS_ADD_PAYMENT_METHODS 7706
#define IDS_SETTINGS_ADD_PAYMENT_METHOD_CREDIT_OR_DEBIT_CARD 7707
#define IDS_SETTINGS_ADD_PAYMENT_METHOD_IBAN 7708
#define IDS_SETTINGS_IBAN_SAVED_TO_THIS_DEVICE_ONLY 7709
#define IDS_SETTINGS_IBAN_INVALID_VALIDATION_MESSAGE 7710
#define IDS_IBAN_NICKNAME 7711
#define IDS_SETTINGS_AUTOFILL_MORE_ACTIONS_FOR_IBAN 7712
#define IDS_SETTINGS_AUTOFILL_A11Y_IBAN_DESCRIPTION 7713
#define IDS_SETTINGS_ADD_IBAN_TITLE 7714
#define IDS_SETTINGS_EDIT_IBAN_TITLE 7715
#define IDS_SETTINGS_IBAN_EDIT 7716
#define IDS_SETTINGS_LOCAL_IBAN_REMOVE_CONFIRMATION_TITLE 7717
#define IDS_SETTINGS_PASSWORD_MANAGER 7718
#define IDS_SETTINGS_PASSWORD_MANAGER_DESCRIPTION 7719
#define IDS_SETTINGS_PAYMENT_METHODS_NONE 7720
#define IDS_AUTOFILL_PASSKEYS_TITLE 7721
#define IDS_SETTINGS_PASSKEYS_LENGTH_ERROR 7722
#define IDS_SETTINGS_PASSKEYS_SITE_LABEL 7723
#define IDS_SETTINGS_PASSKEYS_DIALOG_TITLE 7724
#define IDS_SETTINGS_PASSKEYS_EDIT_DIALOG_FOOTNOTE 7725
#define IDS_SETTINGS_ADDRESS_NONE 7726
#define IDS_SETTINGS_PASSWORDS_LEAK_DETECTION_LABEL 7727
#define IDS_SETTINGS_PASSWORDS_LEAK_DETECTION_SIGNED_OUT_ENABLED_DESC 7728
#define IDS_SETTINGS_CHECK_PASSWORDS_PROGRESS 7729
#define IDS_SETTINGS_COMPROMISED_PASSWORDS_COUNT 7730
#define IDS_SETTINGS_COMPROMISED_PASSWORDS_COUNT_SHORT 7731
#define IDS_SETTINGS_WEAK_PASSWORDS_COUNT_SHORT 7732
#define IDS_SETTINGS_REUSED_PASSWORDS_COUNT_SHORT 7733
#define IDS_SETTINGS_AUTOFILL_AI_WHEN_ON_SAVED_INFO 7734
#define IDS_SETTINGS_AUTOFILL_AI_ENTITY_INSTANCES_HEADER 7735
#define IDS_SETTINGS_AUTOFILL_AI_ENTITY_INSTANCES_NONE 7736
#define IDS_SETTINGS_AUTOFILL_AI_MORE_ACTIONS_FOR_ENTITY_INSTANCE 7737
#define IDS_SETTINGS_AUTOFILL_AI_DELETE_ENTITY_INSTANCE_DIALOG_TEXT 7738
#define IDS_SETTINGS_AUTOFILL_AI_ACCESSIBILITY_LABEL_MONTH_DROPDOWN 7739
#define IDS_SETTINGS_AUTOFILL_AI_ACCESSIBILITY_LABEL_DAY_DROPDOWN 7740
#define IDS_SETTINGS_AUTOFILL_AI_ACCESSIBILITY_LABEL_YEAR_DROPDOWN 7741
#define IDS_SETTINGS_AUTOFILL_AI_MONTH_DROPDOWN_NO_OPTION_SELECTED 7742
#define IDS_SETTINGS_AUTOFILL_AI_DAY_DROPDOWN_NO_OPTION_SELECTED 7743
#define IDS_SETTINGS_AUTOFILL_AI_YEAR_DROPDOWN_NO_OPTION_SELECTED 7744
#define IDS_SETTINGS_AUTOFILL_AI_ADD_OR_EDIT_DIALOG_DATE_VALIDATION_ERROR 7745
#define IDS_SETTINGS_AUTOFILL_AI_ADD_OR_EDIT_DIALOG_VALIDATION_ERROR 7746
#define IDS_AUTOFILL_AI_ADD_OR_EDIT_DIALOG_REQUIRED_FIELD_ERROR 7747
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TOGGLE_LABEL 7748
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TOGGLE_SUB_LABEL 7749
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_WHEN_ON_SAVED_INFO 7750
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_WHEN_ON_NOTIFICATIONS 7751
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TO_CONSIDER_DATA_USAGE 7752
#define IDS_SETTINGS_WALLETABLE_PASS_DETECTION_TO_CONSIDER_DATA_STORAGE 7753
#define IDS_SETTINGS_PASSWORD_SHOW_PASSWORD_A11Y 7765
#define IDS_SETTINGS_PASSWORD_HIDE_PASSWORD_A11Y 7766
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_EDIT 7767
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_REMOVE 7768
#define IDS_SETTINGS_HOME_ADDRESS_REMOVE_CONFIRMATION_DIALOG_TITLE 7769
#define IDS_SETTINGS_WORK_ADDRESS_REMOVE_CONFIRMATION_DIALOG_TITLE 7770
#define IDS_SETTINGS_NAME_EMAIL_ADDRESS_REMOVE_CONFIRMATION_DIALOG_TITLE 7771
#define IDS_SETTINGS_HOME_ADDRESS_REMOVE_CONFIRMATION_DIALOG_NOTICE 7772
#define IDS_SETTINGS_WORK_ADDRESS_REMOVE_CONFIRMATION_DIALOG_NOTICE 7773
#define IDS_SETTINGS_NAME_EMAIL_ADDRESS_REMOVE_CONFIRMATION_DIALOG_NOTICE 7774
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_REMOVE_CONFIRMATION_DIALOG_ACTION_OK 7775
#define IDS_SETTINGS_HOME_AND_WORK_ADDRESS_REMOVED_MESSAGE 7776
#define IDS_SETTINGS_NAME_EMAIL_ADDRESS_REMOVED_MESSAGE 7777
#define IDS_SETTINGS_DEFAULT_BROWSER 7778
#define IDS_SETTINGS_DEFAULT_BROWSER_MAKE_DEFAULT_BUTTON 7779
#define IDS_SETTINGS_CLEAR_PERIOD_TITLE 7780
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC 7781
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC_ERROR 7782
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC_PASSPHRASE_ERROR 7783
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_WITH_SYNC_PAUSED 7784
#define IDS_SETTINGS_CLEAR_BROWSING_HISTORY 7785
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC 7786
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC_WITH_EXCEPTION 7787
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC_SUPERVISED_PROFILE 7788
#define IDS_SETTINGS_CLEAR_COOKIES_AND_SITE_DATA_SUMMARY_BASIC_SIGNED_IN_PROFILE 7789
#define IDS_SETTINGS_CLEAR_BROWSING_HISTORY_SUMMARY 7790
#define IDS_SETTINGS_CLEAR_BROWSING_HISTORY_SUMMARY_SIGNED_IN_NO_LINK 7791
#define IDS_SETTINGS_CLEAR_GOOGLE_SEARCH_HISTORY_GOOGLE_DSE 7792
#define IDS_SETTINGS_CLEAR_GOOGLE_SEARCH_HISTORY_NON_GOOGLE_DSE 7793
#define IDS_SETTINGS_CLEAR_DOWNLOAD_HISTORY 7794
#define IDS_SETTINGS_CLEAR_CACHE 7795
#define IDS_SETTINGS_CLEAR_COOKIES 7796
#define IDS_SETTINGS_CLEAR_PASSWORDS 7797
#define IDS_SETTINGS_CLEAR_FORM_DATA 7798
#define IDS_SETTINGS_CLEAR_HOSTED_APP_DATA 7799
#define IDS_SETTINGS_CLEAR_PERIOD_15_MIN 7800
#define IDS_SETTINGS_CLEAR_PERIOD_15_MINUTES 7801
#define IDS_SETTINGS_CLEAR_PERIOD_HOUR 7802
#define IDS_SETTINGS_CLEAR_PERIOD_24_HOURS 7803
#define IDS_SETTINGS_CLEAR_PERIOD_7_DAYS 7804
#define IDS_SETTINGS_CLEAR_PERIOD_FOUR_WEEKS 7805
#define IDS_SETTINGS_CLEAR_PERIOD_EVERYTHING 7806
#define IDS_SETTINGS_NOTIFICATION_WARNING 7807
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_SHOW_MORE 7808
#define IDS_SETTINGS_CLEAR_BROWSING_DATA_MORE 7809
#define IDS_SETTINGS_MANAGE_IN_YOUR_GEMINI_APPS_ACTIVITY 7810
#define IDS_SETTINGS_GEMINI_APPS_ACTIVITY 7811
#define IDS_SETTINGS_DELETE_DATA_FROM_DEVICE 7812
#define IDS_SETTINGS_DELETION_CONFIRMATION_TOAST_LABEL 7813
#define IDS_SETTINGS_DELETION_CONFIRMATION_ALL_TIME_TOAST_LABEL 7814
#define IDS_SETTINGS_SEARCH_GEMINI_PASSWORDS_OTHER_DATA_SUB_LABEL 7815
#define IDS_SETTINGS_DOWNLOADS 7816
#define IDS_SETTINGS_DOWNLOAD_LOCATION 7817
#define IDS_SETTINGS_CHANGE_DOWNLOAD_LOCATION 7818
#define IDS_SETTINGS_PROMPT_FOR_DOWNLOAD 7819
#define IDS_SETTINGS_OPEN_FILE_TYPES_AUTOMATICALLY 7820
#define IDS_SETTINGS_DOWNLOADS_SHOW_WHEN_FINISHED 7821
#define IDS_SETTINGS_ON_STARTUP 7822
#define IDS_SETTINGS_ON_STARTUP_OPEN_NEW_TAB 7823
#define IDS_SETTINGS_ON_STARTUP_CONTINUE 7824
#define IDS_SETTINGS_ON_STARTUP_OPEN_SPECIFIC 7825
#define IDS_SETTINGS_ON_STARTUP_CONTINUE_AND_OPEN_SPECIFIC 7826
#define IDS_SETTINGS_ON_STARTUP_USE_CURRENT 7827
#define IDS_SETTINGS_ON_STARTUP_ADD_NEW_PAGE 7828
#define IDS_SETTINGS_ON_STARTUP_EDIT_PAGE 7829
#define IDS_SETTINGS_ON_STARTUP_SITE_URL 7830
#define IDS_SETTINGS_ON_STARTUP_REMOVE 7831
#define IDS_SETTINGS_ON_STARTUP_PAGE_TOOLTIP 7832
#define IDS_SETTINGS_INVALID_URL 7833
#define IDS_SETTINGS_URL_TOOL_LONG 7834
#define IDS_SETTINGS_PERFORMANCE_PAGE_TITLE 7835
#define IDS_SETTINGS_PERFORMANCE_GENERAL_PAGE_TITLE 7836
#define IDS_SETTINGS_PERFORMANCE_MEMORY_PAGE_TITLE 7837
#define IDS_SETTINGS_PERFORMANCE_SPEED_PAGE_TITLE 7838
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_SETTING 7839
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_HEURISTICS_LABEL 7840
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_RECOMMENDED_BADGE 7841
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_ON_TIMER_LABEL 7842
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_RADIO_GROUP_ARIA_LABEL 7843
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_CHOOSE_DISCARD_TIME_ARIA_LABEL 7844
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_CONSERVATIVE_LABEL 7845
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_MEDIUM_LABEL 7846
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_AGGRESSIVE_LABEL 7847
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_CONSERVATIVE_DESCRIPTION 7848
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_MEDIUM_DESCRIPTION 7849
#define IDS_SETTINGS_PERFORMANCE_MEMORY_SAVER_MODE_AGGRESSIVE_DESCRIPTION 7850
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_BUTTON_ARIA_LABEL 7851
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_SAVE_BUTTON_ARIA_LABEL 7852
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_HEADER 7853
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_DESCRIPTION 7854
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADDITIONAL_SITES 7855
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_CURRENT_TABS 7856
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_CURRENT_TABS_EMPTY 7857
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_MANUAL 7858
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ACTIVE_SITE_ARIA_DESCRIPTION 7859
#define IDS_SETTINGS_PERFORMANCE_TAB_DISCARDING_EXCEPTIONS_ADD_DIALOG_HELP 7860
#define IDS_SETTINGS_PERFORMANCE_BATTERY_PAGE_TITLE 7861
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_SETTING 7862
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_ON_BATTERY_LABEL 7863
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_BELOW_THRESHOLD_LABEL 7864
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_RADIO_GROUP_ARIA_LABEL 7865
#define IDS_SETTINGS_PERFORMANCE_BATTERY_SAVER_MODE_LINK_OS_SETTING_DESCRIPTION 7866
#define IDS_SETTINGS_PERFORMANCE_DISCARD_RING_TREATMENT_ENABLED_LABEL 7867
#define IDS_SETTINGS_PERFORMANCE_DISCARD_RING_TREATMENT_ENABLED_DESCRIPTION_WITH_LEARN_LINK 7868
#define IDS_SETTINGS_PERFORMANCE_TAB_HOVER_PREVIEW_CARD_LINK_TITLE 7869
#define IDS_SETTINGS_PERFORMANCE_TAB_HOVER_PREVIEW_CARD_LINK_SUBTITLE 7870
#define IDS_SETTINGS_PERFORMANCE_INTERVENTION_NOTIFICATION_ENABLED_LABEL 7871
#define IDS_SETTINGS_PERFORMANCE_INTERVENTION_NOTIFICATION_ENABLED_DESCRIPTION 7872
#define IDS_SETTINGS_LANGUAGES_PAGE_TITLE 7873
#define IDS_SETTINGS_LANGUAGES_CARD_TITLE 7874
#define IDS_SETTINGS_LANGUAGE_SEARCH 7875
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_MOVE_TO_TOP 7876
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_MOVE_UP 7877
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_MOVE_DOWN 7878
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_LIST_REMOVE 7879
#define IDS_SETTINGS_LANGUAGES_LANGUAGES_ADD 7880
#define IDS_SETTINGS_LANGUAGES_MANAGE_LANGUAGES_TITLE 7881
#define IDS_SETTINGS_LANGUAGES_NO_LANGUAGES_ADDED 7882
#define IDS_SETTINGS_LANGUAGES_EXPAND_ACCESSIBILITY_LABEL 7883
#define IDS_SETTINGS_LANGUAGES_PREFERRED_LANGUAGES_HEADER 7884
#define IDS_SETTINGS_LANGUAGES_PREFERRED_LANGUAGES_DESC 7885
#define IDS_SETTINGS_LANGUAGES_OFFER_TO_ENABLE_TRANSLATE 7886
#define IDS_SETTINGS_LANGUAGES_OFFER_TO_ENABLE_TRANSLATE_SUBLABEL 7887
#define IDS_SETTINGS_LANGUAGES_TRANSLATE_TARGET 7888
#define IDS_SETTINGS_LANGUAGES_MANAGED_DIALOG_TITLE 7889
#define IDS_SETTINGS_LANGUAGES_MANAGED_DIALOG_BODY 7890
#define IDS_SETTINGS_LANGUAGES_ADD_ARIA_LABEL 7891
#define IDS_SETTINGS_LANGUAGES_REMOVE_AUTOMATIC_ARIA_LABEL 7892
#define IDS_SETTINGS_LANGUAGES_REMOVE_NEVER_ARIA_LABEL 7893
#define IDS_SETTINGS_TRANSLATE_PAGE_TITLE 7894
#define IDS_SETTINGS_TARGET_TRANSLATE_LABEL 7895
#define IDS_SETTINGS_LANGUAGES_AUTOMATIC_TRANSLATE 7896
#define IDS_SETTINGS_LANGUAGES_AUTOMATIC_TRANSLATE_ADD_ARIA_LABEL 7897
#define IDS_SETTINGS_LANGUAGES_NEVER_LANGUAGES 7898
#define IDS_SETTINGS_LANGUAGES_NEVER_TRANSLATE_ADD_ARIA_LABEL 7899
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_TITLE 7900
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_BASIC_LABEL 7901
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_ENHANCED_LABEL 7902
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_ENHANCED_DESCRIPTION 7903
#define IDS_SETTINGS_LANGUAGES_OFFER_TO_ENABLE_SPELL_CHECK 7904
#define IDS_SETTING_LANGUAGES_SPELL_CHECK_DISABLED_REASON 7905
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_LANGUAGES_LIST_TITLE 7906
#define IDS_SETTINGS_LANGUAGES_SPELL_CHECK_MANAGE 7907
#define IDS_SETTINGS_LANGUAGES_EDIT_DICTIONARY_TITLE 7908
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD 7909
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD_BUTTON 7910
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD_DUPLICATE_ERROR 7911
#define IDS_SETTINGS_LANGUAGES_ADD_DICTIONARY_WORD_LENGTH_ERROR 7912
#define IDS_SETTINGS_LANGUAGES_DELETE_DICTIONARY_WORD_BUTTON 7913
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_WORDS 7914
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_WORDS_NONE 7915
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_DOWNLOAD_FAILED 7916
#define IDS_SETTINGS_LANGUAGES_DICTIONARY_DOWNLOAD_FAILED_HELP 7917
#define IDS_SETTINGS_PRELOAD_PAGES_TITLE 7920
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_TITLE 7921
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_EXPAND_A11Y_LABEL 7922
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_SUMMARY 7923
#define IDS_SETTINGS_PRELOAD_PAGES_STANDARD_PRELOADING_WHEN_ON_BULLET_ONE 7924
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_TITLE 7925
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_SUMMARY 7926
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_EXPAND_A11Y_LABEL 7927
#define IDS_SETTINGS_PRELOAD_PAGES_EXTENDED_PRELOADING_WHEN_ON_BULLET_ONE 7928
#define IDS_SETTINGS_PRIVACY 7929
#define IDS_SETTINGS_PRIVACY_V2 7930
#define IDS_SETTINGS_PRIVACY_MORE 7931
#define IDS_SETTINGS_AI_COMPOSE_SUBLABEL_V2 7933
#define IDS_SETTINGS_OFFER_WRITING_HELP_TOGGLE_LABEL 7934
#define IDS_SETTINGS_OFFER_WRITING_HELP_TOGGLE_SUB_LABEL 7935
#define IDS_SETTINGS_OFFER_WRITING_HELP_ENABLED_SUB_LABEL 7936
#define IDS_SETTINGS_OFFER_WRITING_HELP_DISABLED_SUB_LABEL 7937
#define IDS_SETTINGS_OFFER_WRITING_HELP_DISABLED_SITES_LABEL_V2 7938
#define IDS_SETTINGS_OFFER_WRITING_HELP_NO_DISABLED_SITES 7939
#define IDS_SETTINGS_OFFER_WRITING_HELP_REMOVE_SITE_ARIA_LABEL 7940
#define IDS_SETTINGS_COMPOSE_SETTING_LINK_A11Y 7941
#define IDS_SETTINGS_COMPOSE_WHEN_ON_WRITING_HELP 7942
#define IDS_SETTINGS_COMPOSE_WHEN_ON_WRITING_EXAMPLES 7943
#define IDS_SETTINGS_COMPOSE_WHEN_ON_WRITING_REFERENCES 7944
#define IDS_SETTINGS_COMPOSE_CONSIDER_DATA 7945
#define IDS_SETTINGS_ANTI_ABUSE_ENABLED_SUB_LABEL 7946
#define IDS_SETTINGS_ANTI_ABUSE_DISABLED_SUB_LABEL 7947
#define IDS_SETTINGS_ANTI_ABUSE_DESCRIPTION 7948
#define IDS_SETTINGS_ANTI_ABUSE_WHEN_ON_SECTION_ONE 7949
#define IDS_SETTINGS_ANTI_ABUSE_WHEN_ON_SECTION_TWO 7950
#define IDS_SETTINGS_ANTI_ABUSE_WHEN_ON_SECTION_THREE 7951
#define IDS_SETTINGS_ANTI_ABUSE_THINGS_TO_CONSIDER_SECTION_ONE 7952
#define IDS_SETTINGS_PRIVACY_SANDBOX_TITLE 7953
#define IDS_SETTINGS_PRIVACY_SANDBOX_COOKIES_DIALOG 7954
#define IDS_SETTINGS_PRIVACY_SANDBOX_COOKIES_DIALOG_MORE 7955
#define IDS_SETTINGS_AD_PRIVACY_LINK_ROW_LABEL 7956
#define IDS_SETTINGS_AD_PRIVACY_LINK_ROW_SUB_LABEL 7957
#define IDS_SETTINGS_AD_PRIVACY_RESTRICTED_LINK_ROW_SUB_LABEL 7958
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TITLE 7959
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TOPICS_LINK_ROW_LABEL 7960
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TOPICS_LINK_ROW_SUB_LABEL_ENABLED 7961
#define IDS_SETTINGS_AD_PRIVACY_PAGE_TOPICS_LINK_ROW_SUB_LABEL_DISABLED 7962
#define IDS_SETTINGS_AD_PRIVACY_PAGE_FLEDGE_LINK_ROW_LABEL 7963
#define IDS_SETTINGS_AD_PRIVACY_PAGE_FLEDGE_LINK_ROW_SUB_LABEL_ENABLED 7964
#define IDS_SETTINGS_AD_PRIVACY_PAGE_FLEDGE_LINK_ROW_SUB_LABEL_DISABLED 7965
#define IDS_SETTINGS_AD_PRIVACY_PAGE_AD_MEASUREMENT_LINK_ROW_LABEL 7966
#define IDS_SETTINGS_AD_PRIVACY_PAGE_AD_MEASUREMENT_LINK_ROW_SUB_LABEL_ENABLED 7967
#define IDS_SETTINGS_AD_PRIVACY_PAGE_AD_MEASUREMENT_LINK_ROW_SUB_LABEL_DISABLED 7968
#define IDS_SETTINGS_TOPICS_PAGE_CURRENT_TOPICS_REGION_A11Y_DESCRIPTION 7969
#define IDS_SETTINGS_TOPICS_PAGE_BLOCKED_TOPICS_REGION_A11Y_DESCRIPTION 7970
#define IDS_SETTINGS_TOPICS_PAGE_FOOTER_V2 7971
#define IDS_SETTINGS_FLEDGE_PAGE_TITLE 7972
#define IDS_SETTINGS_FLEDGE_PAGE_TOGGLE_LABEL 7973
#define IDS_SETTINGS_FLEDGE_PAGE_TOGGLE_SUB_LABEL 7974
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_HEADING 7975
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION 7976
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_LEARN_MORE 7977
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_DISABLED 7978
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_EMPTY 7979
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_REGION_A11Y_DESCRIPTION 7980
#define IDS_SETTINGS_FLEDGE_PAGE_SEE_ALL_SITES_LABEL 7981
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCK_SITE 7982
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCK_SITE_A11Y_LABEL 7983
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_HEADING 7984
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_DESCRIPTION 7985
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_DESCRIPTION_EMPTY 7986
#define IDS_SETTINGS_FLEDGE_PAGE_BLOCKED_SITES_REGION_A11Y_DESCRIPTION 7987
#define IDS_SETTINGS_FLEDGE_PAGE_ALLOW_SITE 7988
#define IDS_SETTINGS_FLEDGE_PAGE_ALLOW_SITE_A11Y_LABEL 7989
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_HEADING 7990
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_BULLET_1 7991
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_BULLET_2 7992
#define IDS_SETTINGS_FLEDGE_PAGE_LEARN_MORE_BULLET_3 7993
#define IDS_SETTINGS_FLEDGE_PAGE_CURRENT_SITES_DESCRIPTION_LEARN_MORE_A11Y_LABEL 7994
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_TITLE 7995
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_TOGGLE_LABEL 7996
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_TOGGLE_SUB_LABEL 7997
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_ENABLED_BULLET_1 7998
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_ENABLED_BULLET_2 7999
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_ENABLED_BULLET_3 8000
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_CONSIDER_BULLET_1 8001
#define IDS_SETTINGS_AD_MEASUREMENT_PAGE_CONSIDER_BULLET_2 8002
#define IDS_SETTINGS_PRIVACY_GUIDE_LABEL 8003
#define IDS_SETTINGS_PRIVACY_GUIDE_SUBLABEL 8004
#define IDS_SETTINGS_PRIVACY_GUIDE_PROMO_HEADER 8005
#define IDS_SETTINGS_PRIVACY_GUIDE_PROMO_START_BUTTON 8006
#define IDS_SETTINGS_PRIVACY_GUIDE_BACK_TO_SETTINGS_ARIA_LABEL 8007
#define IDS_SETTINGS_PRIVACY_GUIDE_BACK_TO_SETTINGS_ARIA_ROLE_DESC 8008
#define IDS_SETTINGS_PRIVACY_GUIDE_BACK_BUTTON 8009
#define IDS_SETTINGS_PRIVACY_GUIDE_STEPS 8010
#define IDS_SETTINGS_PRIVACY_GUIDE_NEXT_BUTTON 8011
#define IDS_SETTINGS_PRIVACY_GUIDE_WELCOME_CARD_HEADER 8012
#define IDS_SETTINGS_PRIVACY_GUIDE_WELCOME_CARD_SUB_HEADER 8013
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_HEADER 8014
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_SUB_HEADER 8015
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_SUB_HEADER_NO_LINKS 8016
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_LEAVE_BUTTON 8017
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_PRIVACY_SANDBOX_LABEL 8018
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_PRIVACY_SANDBOX_SUB_LABEL_AD_TOPICS 8019
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_WAA_LABEL 8020
#define IDS_SETTINGS_PRIVACY_GUIDE_COMPLETION_CARD_AI_SETTINGS_LABEL 8021
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_CARD_HEADER 8022
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_FEATURE_DESCRIPTION1 8023
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_FEATURE_DESCRIPTION2 8024
#define IDS_SETTINGS_PRIVACY_GUIDE_MSBB_PRIVACY_DESCRIPTION1 8025
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_CARD_HEADER 8026
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_AND_TABS_SYNC_CARD_HEADER 8027
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_SETTING_LABEL 8028
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_AND_TABS_SYNC_SETTING_LABEL 8029
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_FEATURE_DESCRIPTION1 8030
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_AND_TABS_SYNC_FEATURE_DESCRIPTION1 8031
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_FEATURE_DESCRIPTION2 8032
#define IDS_SETTINGS_PRIVACY_GUIDE_HISTORY_SYNC_PRIVACY_DESCRIPTION1 8033
#define IDS_SETTINGS_PRIVACY_GUIDE_COOKIES_CARD_HEADER 8034
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_HEADER 8035
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_ENHANCED_PROTECTION_PRIVACY_DESCRIPTION1 8036
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_ENHANCED_PROTECTION_PRIVACY_DESCRIPTION2 8037
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_ENHANCED_PROTECTION_PRIVACY_DESCRIPTION3 8038
#define IDS_SETTINGS_PRIVACY_GUIDE_SAFE_BROWSING_CARD_STANDARD_PROTECTION_FEATURE_DESCRIPTION1 8039
#define IDS_SETTINGS_SAFETY_CHECK_ICON_INFO_ARIA_LABEL 8042
#define IDS_SETTINGS_SAFETY_CHECK_ICON_WARNING_ARIA_LABEL 8043
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW 8044
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_ALLOW_AGAIN_ARIA_LABEL 8045
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_ALLOW_AGAIN_LABEL 8046
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_PRIMARY_LABEL 8047
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_SECONDARY_LABEL 8048
#define IDS_SETTINGS_SAFETY_HUB_REVOKED_PERMISSIONS_SECONDARY_LABEL 8049
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_TOAST_BULK_LABEL 8050
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_TOAST_LABEL 8051
#define IDS_SETTINGS_SAFETY_CHECK_UNUSED_SITE_PERMISSIONS_SETTING_LABEL 8052
#define IDS_SETTINGS_SAFETY_CHECK_UPDATES_DISABLED_BY_ADMIN 8053
#define IDS_SETTINGS_SAFETY_CHECK_PASSWORDS_PRIMARY_LABEL 8054
#define IDS_SETTINGS_SAFETY_CHECK_PASSWORDS_FEATURE_UNAVAILABLE 8055
#define IDS_SETTINGS_SAFETY_CHECK_SAFE_BROWSING_ENABLED 8056
#define IDS_SETTINGS_SAFETY_CHECK_SAFE_BROWSING_ENABLED_STANDARD 8057
#define IDS_SETTINGS_SAFETY_CHECK_SAFE_BROWSING_ENABLED_STANDARD_AVAILABLE_ENHANCED 8058
#define IDS_SETTINGS_SAFETY_CHECK_SAFE_BROWSING_ENABLED_ENHANCED 8059
#define IDS_SETTINGS_SAFETY_CHECK_EXTENSIONS_SAFE 8060
#define IDS_SETTINGS_SAFETY_CHECK_EXTENSIONS_BLOCKLISTED_OFF 8061
#define IDS_SETTINGS_SAFETY_CHECK_EXTENSIONS_BLOCKLISTED_ON_USER 8062
#define IDS_SETTINGS_SAFETY_CHECK_EXTENSIONS_BLOCKLISTED_ON_ADMIN 8063
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_EXTENSIONS 8064
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_IGNORED_TOAST_LABEL 8065
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_BLOCKED_TOAST_LABEL 8066
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_RESET_TOAST_LABEL 8067
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_COUNT_LABEL 8068
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_DONT_ALLOW_LABEL 8069
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_DONT_ALLOW_ARIA_LABEL 8070
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_IGNORE_LABEL 8071
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_IGNORE_ARIA_LABEL 8072
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_RESET_LABEL 8073
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_RESET_ARIA_LABEL 8074
#define IDS_SETTINGS_SAFETY_CHECK_REVIEW_NOTIFICATION_PERMISSIONS_MORE_ACTIONS_ARIA_LABEL 8075
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_BLOCK_ALL_LABEL 8076
#define IDS_SETTINGS_SAFETY_CHECK_NOTIFICATION_PERMISSION_REVIEW_BLOCK_ALL_TOAST_LABEL 8077
#define IDS_SETTINGS_SAFETY_CHECK_TOAST_UNDO_BUTTON_LABEL 8078
#define IDS_SETTINGS_NETWORK_PREDICTION_ENABLED_DESC 8079
#define IDS_SETTINGS_SAFEBROWSING_ENABLEPROTECTION 8080
#define IDS_SETTINGS_SAFEBROWSING_ENABLEPROTECTION_DESC 8081
#define IDS_SETTINGS_SAFEBROWSING_ENABLE_REPORTING_DESC 8082
#define IDS_SETTINGS_SAFEBROWSING_SECTION_LABEL 8083
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED 8084
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_DESC_UPDATED 8085
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_EXPAND_ACCESSIBILITY_LABEL 8086
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_ONE 8087
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_THREE 8088
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_FOUR 8089
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_BULLET_FIVE 8090
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_TWO 8091
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_THREE 8092
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_WHEN_ON_BULLET_FOUR 8093
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_THINGS_TO_CONSIDER_BULLET_ONE 8094
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_THINGS_TO_CONSIDER_BULLET_TWO 8095
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_THINGS_TO_CONSIDER_BULLET_THREE 8096
#define IDS_SETTINGS_SAFEBROWSING_STANDARD 8097
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_DESC 8098
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_EXPAND_ACCESSIBILITY_LABEL 8101
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_BULLET_ONE 8102
#define IDS_SETTINGS_SAFEBROWSING_STANDARD_HELP_IMPROVE 8103
#define IDS_SETTINGS_SAFEBROWSING_NONE 8104
#define IDS_SETTINGS_SAFEBROWSING_NONE_DESC 8105
#define IDS_SETTINGS_SAFEBROWSING_DISABLE_DIALOG_TITLE 8106
#define IDS_SETTINGS_SAFEBROWSING_DISABLE_DIALOG_DESC 8107
#define IDS_SETTINGS_SAFEBROWSING_DISABLE_DIALOG_CONFIRM 8108
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK 8109
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK_DIALOG_TITLE 8110
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK_DIALOG_TEXT 8111
#define IDS_SETTINGS_ENABLE_DO_NOT_TRACK_DIALOG_LEARN_MORE_ACCESSIBILITY_LABEL 8112
#define IDS_SETTINGS_PERMISSIONS 8113
#define IDS_SETTINGS_PERMISSIONS_DESCRIPTION 8114
#define IDS_SETTINGS_SECURITY 8115
#define IDS_SETTINGS_SECURITY_DESCRIPTION 8116
#define IDS_SETTINGS_ADVANCED_PROTECTION_PROGRAM 8117
#define IDS_SETTINGS_ADVANCED_PROTECTION_PROGRAM_DESC 8118
#define IDS_SETTINGS_SECURITY_BUNDLE_TOAST_FOR_USER_OPTED_INTO_ENHANCED_BUNDLE 8119
#define IDS_SETTINGS_SECURITY_BUNDLE_RESET_TO_DEFAULTS_BUTTON_LABEL 8120
#define IDS_SETTINGS_SECURITY_TITLE 8121
#define IDS_SETTINGS_SECURITY_STANDARD_BUNDLE_TITLE 8122
#define IDS_SETTINGS_SECURITY_ENHANCED_BUNDLE_TITLE 8123
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_TITLE 8124
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_DESCRIPTION 8125
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_TITLE 8126
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_SUBTITLE 8127
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_WHAT_IT_DOES_HEADING 8128
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_WHAT_IT_DOES_CONTENT 8129
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_STANDARD_HOW_IT_WORKS_HEADING 8130
#define IDS_SETTINGS_SECURITY_BUNDLE_STANDARD_BULLET_ONE 8131
#define IDS_SETTINGS_SECURITY_BUNDLE_STANDARD_BULLET_TWO 8132
#define IDS_SETTINGS_SECURITY_BUNDLE_STANDARD_BULLET_THREE 8133
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_ENHANCED_TITLE 8134
#define IDS_SETTINGS_SECURITY_SAFE_BROWSING_ENHANCED_SUBTITLE 8135
#define IDS_SETTINGS_SECURITY_BUNDLE_ENHANCED_BULLET_TWO 8136
#define IDS_SETTINGS_SECURITY_BUNDLE_ENHANCED_BULLET_THREE 8137
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_ENHANCED 8138
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_ENHANCED_CUSTOM 8139
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_ENHANCED_STRICT 8140
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_STANDARD 8141
#define IDS_SETTINGS_SECURITY_FEATURE_ROW_STATE_OFF 8142
#define IDS_SETTINGS_SECURITY_ACCOUNT_AND_NETWORK_SECTION_TITLE 8143
#define IDS_SETTINGS_SECURITY_ADVANCED_PROTECTION_PROGRAM_LABEL 8144
#define IDS_SETTINGS_SECURITY_PASSWORDS_LEAK_DETECTION_TITLE 8145
#define IDS_SETTINGS_SECURITY_SECURE_DNS_TITLE 8146
#define IDS_SETTINGS_SECURITY_SECURE_DNS_DESCRIPTION 8147
#define IDS_SETTINGS_SECURITY_SECURE_DNS_DEFAULT 8148
#define IDS_SETTINGS_SECURITY_SECURE_DNS_FALLBACK 8149
#define IDS_SETTINGS_SECURITY_SECURE_DNS_CUSTOM 8150
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_TITLE 8151
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_DESCRIPTION 8152
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_UNRECOGNIZED_SITES 8153
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_STRICT_FOR_ALL_SITES 8154
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_STRICT_FOR_ALL_SITES_DESCRIPTION 8155
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_MANAGE_SITE_EXCEPTIONS 8156
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_GUARDRAILS_MANAGE_SITE_EXCEPTIONS_DESCRIPTION 8157
#define IDS_SETTINGS_SECURE_CONNECTIONS_SECTION_TITLE 8158
#define IDS_SETTINGS_HTTPS_ONLY_MODE 8159
#define IDS_SETTINGS_HTTPS_ONLY_MODE_DESCRIPTION 8160
#define IDS_SETTINGS_HTTPS_ONLY_MODE_DESCRIPTION_ADVANCED_PROTECTION 8161
#define IDS_SETTINGS_HTTPS_FIRST_MODE_TITLE 8162
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DESCRIPTION 8163
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DESCRIPTION_ADVANCED_PROTECTION 8164
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_FULL_LABEL 8165
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_INCOGNITO_LABEL 8166
#define IDS_SETTINGS_HTTPS_FIRST_MODE_DISABLED_LABEL 8167
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_STRICT_LABEL 8168
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_STRICT_SUBLABEL 8169
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_BALANCED_LABEL 8170
#define IDS_SETTINGS_HTTPS_FIRST_MODE_ENABLED_BALANCED_SUBLABEL 8171
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_TOGGLE_LABEL 8172
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_TOGGLE_SUBLABEL 8173
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_BALANCED_LABEL 8174
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_BALANCED_SUBLABEL 8175
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_STRICT_LABEL 8176
#define IDS_SETTINGS_SECURITY_HTTPS_FIRST_MODE_STRICT_SUBLABEL 8177
#define IDS_SETTINGS_MANAGE_CERTIFICATES 8178
#define IDS_SETTINGS_MANAGE_CERTIFICATES_DESCRIPTION 8179
#define IDS_SETTINGS_MANAGE_DEVICE_CERTIFICATES 8180
#define IDS_SETTINGS_MANAGE_DEVICE_CERTIFICATES_DESCRIPTION 8181
#define IDS_SETTINGS_MANAGE 8182
#define IDS_SETTINGS_SECURE_DNS 8183
#define IDS_SETTINGS_AUTOMATIC_MODE_DESCRIPTION 8185
#define IDS_SETTINGS_SECURE_DNS_DROPDOWN_ACCESSIBILITY_LABEL 8186
#define IDS_SETTINGS_SECURE_DROPDOWN_MODE_DESCRIPTION 8187
#define IDS_SETTINGS_SECURE_DROPDOWN_MODE_PRIVACY_POLICY 8188
#define IDS_SETTINGS_SECURE_DNS_DISABLED_FOR_MANAGED_ENVIRONMENT 8189
#define IDS_SETTINGS_SECURE_DNS_DISABLED_FOR_PARENTAL_CONTROL 8190
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_DESCRIPTION 8191
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_PLACEHOLDER 8192
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_FORMAT_ERROR 8193
#define IDS_SETTINGS_SECURE_DNS_CUSTOM_CONNECTION_ERROR 8194
#define IDS_SETTINGS_SECURITY_JAVASCRIPT_OPTIMIZATION_LINK_TITLE 8195
#define IDS_SETTINGS_CONTENT_SETTINGS 8196
#define IDS_SETTINGS_SITE_SETTINGS 8197
#define IDS_SETTINGS_SITE_SETTINGS_DESCRIPTION 8198
#define IDS_SETTINGS_CLEAR_DATA 8199
#define IDS_SETTINGS_CLEARING_DATA 8200
#define IDS_SETTINGS_CLEARED_DATA 8201
#define IDS_SETTINGS_CLEAR_BROWSING_DATA 8202
#define IDS_SETTINGS_CLEAR_DATA_DESCRIPTION 8203
#define IDS_SETTINGS_TITLE_AND_COUNT 8204
#define IDS_SETTINGS_SYNC_AND_GOOGLE_SERVICES_PRIVACY_DESC_UNIFIED_CONSENT 8205
#define IDS_SETTINGS_SEARCH_AGGREGATOR_PREF 8206
#define IDS_SETTINGS_RECENT_PERMISSIONS_NO_CHANGES 8207
#define IDS_SETTINGS_RECENT_PERMISSIONS_ALLOWED_ONE_ITEM 8208
#define IDS_SETTINGS_RECENT_PERMISSIONS_ALLOWED_TWO_ITEMS 8209
#define IDS_SETTINGS_RECENT_PERMISSIONS_ALLOWED_MORE_THAN_TWO_ITEMS 8210
#define IDS_SETTINGS_RECENT_PERMISSIONS_AUTOMATICALLY_BLOCKED_ONE_ITEM 8211
#define IDS_SETTINGS_RECENT_PERMISSIONS_AUTOMATICALLY_BLOCKED_TWO_ITEMS 8212
#define IDS_SETTINGS_RECENT_PERMISSIONS_AUTOMATICALLY_BLOCKED_MORE_THAN_TWO_ITEMS 8213
#define IDS_SETTINGS_RECENT_PERMISSIONS_BLOCKED_ONE_ITEM 8214
#define IDS_SETTINGS_RECENT_PERMISSIONS_BLOCKED_TWO_ITEMS 8215
#define IDS_SETTINGS_RECENT_PERMISSIONS_BLOCKED_MORE_THAN_TWO_ITEMS 8216
#define IDS_SETTINGS_RESET_PROMPT_TITLE 8217
#define IDS_SETTINGS_RESET 8218
#define IDS_SETTINGS_RESET_SETTINGS_TRIGGER 8219
#define IDS_SETTINGS_RESET_AUTOMATED_DIALOG_TITLE 8220
#define IDS_SETTINGS_RESET_BANNER_TEXT 8221
#define IDS_SETTINGS_RESET_BANNER_RESET_BUTTON_TEXT 8222
#define IDS_SETTINGS_RESET_LEARN_MORE_ACCESSIBILITY_TEXT 8223
#define IDS_SETTINGS_RESET_AUTOMATED_DIALOG_V2_TITLE 8224
#define IDS_SETTINGS_RESET_AUTOMATED_DIALOG_V2_BODY 8225
#define IDS_SETTINGS_RESET_PINNED_TABS 8226
#define IDS_SETTINGS_RESET_EXTENSIONS 8227
#define IDS_SETTINGS_RESET_HOMEPAGE 8228
#define IDS_SETTINGS_RESET_DSE 8229
#define IDS_SETTINGS_SEARCH 8232
#define IDS_SETTINGS_DEFAULT_SEARCH 8233
#define IDS_SETTINGS_SEARCH_EXPLANATION_ACCESSIBILITY_LABEL 8234
#define IDS_SETTINGS_SEARCH_MANAGE_SEARCH_ENGINES 8235
#define IDS_SETTINGS_SEARCH_MANAGE_SEARCH_ENGINES_AND_SITE_SEARCH 8236
#define IDS_SETTINGS_SEARCH_MANAGE_SEARCH_ENGINES_EXPLANATION 8237
#define IDS_SETTINGS_SEARCH_SITE_SEARCH 8238
#define IDS_SETTINGS_SEARCH_ACTIVE_SHORTCUTS 8239
#define IDS_SETTINGS_SEARCH_ACTIVE_SHORTCUTS_EXPLANATION 8240
#define IDS_SETTINGS_SEARCH_INACTIVE_SHORTCUTS 8241
#define IDS_SETTINGS_SEARCH_INACTIVE_SHORTCUTS_EXPLANATION 8242
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES 8243
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_ACTIVE_SHORTCUTS 8244
#define IDS_SETTINGS_SEARCH_EXTENSION_ENGINES_INACTIVE_SHORTCUTS 8245
#define IDS_SETTINGS_SEARCH_KEYBOARD_KEY_TITLE 8246
#define IDS_SETTINGS_SEARCH_KEYBOARD_KEY_DESCRIPTION 8247
#define IDS_SETTINGS_SEARCH_ACTIVATE 8248
#define IDS_SETTINGS_SEARCH_DEACTIVATE 8249
#define IDS_SETTINGS_SEARCH_ACTIVATE_SHORTCUT 8250
#define IDS_SETTINGS_SEARCH_DEACTIVATE_SHORTCUT 8251
#define IDS_SETTINGS_SEARCH_DISABLE_EXTENSION 8252
#define IDS_SETTINGS_SEARCH_MANAGE_EXTENSION 8253
#define IDS_SETTINGS_SEARCH_NO_SITE_SHORTCUTS 8254
#define IDS_SETTINGS_SEARCH_NO_FEATURE_SHORTCUTS 8255
#define IDS_SETTINGS_SEARCH_ENGINES 8256
#define IDS_SETTINGS_SEARCH_ENGINES_PAGE_EXPLANATION 8257
#define IDS_SETTINGS_SEARCH_ENGINES_SEARCH 8258
#define IDS_SETTINGS_SEARCH_ENGINES_SUBTITLE_FOR_POLICY 8259
#define IDS_SETTINGS_SEARCH_ENGINES_ADD_SITE_SEARCH 8260
#define IDS_SETTINGS_SEARCH_ENGINES_EDIT_SEARCH_ENGINE 8261
#define IDS_SETTINGS_SEARCH_ENGINES_VIEW_SEARCH_ENGINE 8262
#define IDS_SETTINGS_SEARCH_ENGINES_EDIT_SITE_SEARCH 8263
#define IDS_SETTINGS_SEARCH_ENGINES_VIEW_SITE_SEARCH 8264
#define IDS_SETTINGS_SEARCH_ENGINES_DELETE_CONFIRMATION_TITLE 8265
#define IDS_SETTINGS_SEARCH_ENGINES_DELETE_CONFIRMATION_DESCRIPTION 8266
#define IDS_SETTINGS_SEARCH_ENGINES_DELETE_CONFIRMATION_DESCRIPTION_FOR_POLICY 8267
#define IDS_SETTINGS_SEARCH_ENGINES_SEARCH_ENGINES 8268
#define IDS_SETTINGS_SEARCH_ENGINES_SEARCH_ENGINES_EXPLANATION 8269
#define IDS_SETTINGS_SEARCH_ENGINES_SITE_SEARCH 8270
#define IDS_SETTINGS_SEARCH_ENGINES_SITE_SEARCH_EXPLANATION 8271
#define IDS_SETTINGS_SEARCH_ENGINES_SITE_SEARCH_EXPLANATION_STARTER_PACK 8272
#define IDS_SETTINGS_SEARCH_ENGINES_NO_SITES_ADDED 8273
#define IDS_SETTINGS_SEARCH_ENGINES_INACTIVE_SHORTCUTS 8274
#define IDS_SETTINGS_SEARCH_ENGINES_NO_OTHER_ENGINES 8275
#define IDS_SETTINGS_SEARCH_ENGINES_EXTENSION_ENGINES 8276
#define IDS_SETTINGS_SEARCH_ENGINES_EXTENSION_ENGINES_EXPLANATION 8277
#define IDS_SETTINGS_SEARCH_ENGINES_NAME 8278
#define IDS_SETTINGS_SEARCH_ENGINES_SHORTCUT 8279
#define IDS_SETTINGS_SEARCH_ENGINES_QUERY_URL 8280
#define IDS_SETTINGS_SEARCH_ENGINES_QUERY_URL_EXPLANATION 8281
#define IDS_SETTINGS_SEARCH_ENGINES_MAKE_DEFAULT 8282
#define IDS_SETTINGS_SEARCH_ENGINES_ACTIVATE 8283
#define IDS_SETTINGS_SEARCH_ENGINES_DEACTIVATE 8284
#define IDS_SETTINGS_SEARCH_ENGINES_VIEW_DETAILS 8285
#define IDS_SETTINGS_SEARCH_ENGINES_MANAGE_EXTENSION 8286
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_TITLE 8287
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_DESCRIPTION 8288
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_DESCRIPTION_STARTER_PACK 8289
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_SPACE_OR_TAB 8290
#define IDS_SETTINGS_SEARCH_ENGINES_KEYBOARD_SHORTCUTS_TAB 8291
#define IDS_SETTINGS_SEARCH_ENGINES_ADDITIONAL_SITES 8292
#define IDS_SETTINGS_SEARCH_ENGINES_ADDITIONAL_INACTIVE_SITES 8293
#define IDS_SETTINGS_SEARCH_ENGINES_MORE_ACTIONS_ARIA_LABEL 8294
#define IDS_SETTINGS_SEARCH_ENGINES_ACTIVATE_BUTTON_ARIA_LABEL 8295
#define IDS_SETTINGS_SEARCH_ENGINES_ADD_SITE_SEARCH_BUTTON_ARIA_LABEL 8296
#define IDS_SETTINGS_SEARCH_ENGINES_EDIT_SEARCH_ENGINE_BUTTON_ARIA_LABEL 8297
#define IDS_SETTINGS_EXCEPTIONS_EMBEDDED_ON_HOST 8298
#define IDS_SETTINGS_EXCEPTIONS_EMBEDDED_ON_ANY_HOST 8299
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES 8300
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_DESCRIPTION 8301
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_FILTER 8302
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SEARCH 8303
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT 8304
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT_METHOD_MOST_VISITED 8305
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT_METHOD_STORAGE 8306
#define IDS_SETTINGS_SITE_SETTINGS_ALL_SITES_SORT_METHOD_NAME 8307
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_HEADER 8308
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_EDIT_HEADER 8309
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_REMOVE_GRANT_LABEL 8310
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_REMOVE_GRANTS 8311
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_VIEW_HEADER 8312
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_SITE_LIST_VIEW_SITE_DETAILS 8313
#define IDS_SETTINGS_SITE_SETTINGS_SITE_ENTRY_PARTITIONED_LABEL 8314
#define IDS_SETTINGS_SITE_SETTINGS_SITE_REPRESENTATION_SEPARATOR 8315
#define IDS_SETTINGS_SITE_SETTINGS_DEFAULT_BEHAVIOR 8316
#define IDS_SETTINGS_SITE_SETTINGS_DEFAULT_BEHAVIOR_DESCRIPTION 8317
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_DEFAULT_BEHAVIOR_DESC 8318
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_DESC 8319
#define IDS_SETTINGS_SITE_SETTINGS_CUSTOMIZED_BEHAVIORS 8320
#define IDS_SETTINGS_SITE_SETTINGS_CUSTOMIZED_BEHAVIORS_DESCRIPTION 8321
#define IDS_SETTINGS_SITE_SETTINGS_CUSTOMIZED_BEHAVIORS_DESCRIPTION_SHORT 8322
#define IDS_SETTINGS_SITE_SETTINGS_ADS_DESCRIPTION 8323
#define IDS_SETTINGS_SITE_SETTINGS_ADS_ALLOWED 8324
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCKED 8325
#define IDS_SETTINGS_SITE_SETTINGS_ADS_ALLOWED_EXCEPTIONS 8326
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCKED_EXCEPTIONS 8327
#define IDS_SETTINGS_SITE_SETTINGS_AR_DESCRIPTION 8328
#define IDS_SETTINGS_SITE_SETTINGS_AR_ALLOWED 8329
#define IDS_SETTINGS_SITE_SETTINGS_AR_BLOCKED 8330
#define IDS_SETTINGS_SITE_SETTINGS_AR_ALLOWED_EXCEPTIONS 8331
#define IDS_SETTINGS_SITE_SETTINGS_AR_BLOCKED_EXCEPTIONS 8332
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_DESCRIPTION 8333
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_ASK 8334
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_BLOCKED 8335
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_ALLOWED_EXCEPTIONS 8336
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DOWNLOADS_BLOCKED_EXCEPTIONS 8337
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_DESCRIPTION 8338
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_ALLOWED 8339
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_BLOCKED 8340
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_ALLOWED_EXCEPTIONS 8341
#define IDS_SETTINGS_SITE_SETTINGS_AUTO_PICTURE_IN_PICTURE_BLOCKED_EXCEPTIONS 8342
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_DESCRIPTION 8343
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_ALLOWED 8344
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_BLOCKED 8345
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_BLOCKED_SUB_LABEL 8346
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_ALLOWED_EXCEPTIONS 8347
#define IDS_SETTINGS_SITE_SETTINGS_BACKGROUND_SYNC_BLOCKED_EXCEPTIONS 8348
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_DEVICES_DESCRIPTION 8349
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_DEVICES_ASK 8350
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_DEVICES_BLOCKED 8351
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_DESCRIPTION 8352
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_ASK 8353
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_BLOCKED 8354
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_ALLOWED_EXCEPTIONS 8355
#define IDS_SETTINGS_SITE_SETTINGS_CAPTURED_SURFACE_CONTROL_BLOCKED_EXCEPTIONS 8356
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_DESCRIPTION 8357
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_ASK 8358
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED 8359
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED_SUB_LABEL 8360
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_ALLOWED_EXCEPTIONS 8361
#define IDS_SETTINGS_SITE_SETTINGS_CAMERA_BLOCKED_EXCEPTIONS 8362
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_DESCRIPTION 8363
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_ASK 8364
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_BLOCKED 8365
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_ALLOWED_EXCEPTIONS 8366
#define IDS_SETTINGS_SITE_SETTINGS_CLIPBOARD_BLOCKED_EXCEPTIONS 8367
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_DESCRIPTION 8368
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_ASK 8369
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_BLOCKED 8370
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_ALLOWED_EXCEPTIONS 8371
#define IDS_SETTINGS_SITE_SETTINGS_DEVICE_USE_BLOCKED_EXCEPTIONS 8372
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_DESCRIPTION 8373
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_ALLOWED 8374
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_BLOCKED 8375
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_ALLOWED_EXCEPTIONS 8376
#define IDS_SETTINGS_SITE_SETTINGS_FEDERATED_IDENTITY_API_BLOCKED_EXCEPTIONS 8377
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_DESCRIPTION 8378
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_ASK 8379
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_BLOCKED 8380
#define IDS_SETTINGS_SITE_SETTINGS_FILE_SYSTEM_WRITE_BLOCKED_EXCEPTIONS 8381
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_DESCRIPTION 8382
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_ASK 8383
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_BLOCKED 8384
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_ALLOWED_EXCEPTIONS 8385
#define IDS_SETTINGS_SITE_SETTINGS_FONTS_BLOCKED_EXCEPTIONS 8386
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_FULLSCREEN_DESCRIPTION 8387
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_FULLSCREEN_ALLOWED_EXCEPTIONS 8388
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_FULLSCREEN_BLOCKED_EXCEPTIONS 8389
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_DESCRIPTION 8390
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_ALLOWED_EXCEPTIONS 8391
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_BLOCKED_EXCEPTIONS 8392
#define IDS_SETTINGS_SITE_SETTINGS_HID_DEVICES_DESCRIPTION 8393
#define IDS_SETTINGS_SITE_SETTINGS_HID_DEVICES_ASK 8394
#define IDS_SETTINGS_SITE_SETTINGS_HID_DEVICES_BLOCKED 8395
#define IDS_SITE_SETTINGS_SMART_CARD_READERS 8396
#define IDS_SITE_SETTINGS_SMART_CARD_READERS_DESCRIPTION 8397
#define IDS_SITE_SETTINGS_SMART_CARDS_DEFAULT_DESCRIPTION 8398
#define IDS_SITE_SETTINGS_SMART_CARDS_ASK 8399
#define IDS_SITE_SETTINGS_SMART_CARDS_BLOCKED 8400
#define IDS_SITE_SETTINGS_NO_SMART_CARD_READERS_FOUND 8401
#define IDS_SITE_SETTINGS_RESET_SMART_CARD_CONFIRMATION 8402
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_DESCRIPTION 8403
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_ALLOWED 8404
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_BLOCKED 8405
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_BLOCKED_SUB_LABEL 8406
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_ALLOWED_EXCEPTIONS 8407
#define IDS_SETTINGS_SITE_SETTINGS_IMAGES_BLOCKED_EXCEPTIONS 8408
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_DESCRIPTION 8409
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_ALLOWED_EXCEPTIONS 8410
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_BLOCKED_EXCEPTIONS 8411
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_DESCRIPTION 8412
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_ALLOWED 8413
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_BLOCKED 8414
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_ALLOWED_EXCEPTIONS 8415
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_BLOCKED_EXCEPTIONS 8416
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_ALLOWED 8417
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED 8418
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_UNFAMILIAR_SITES 8419
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_UNFAMILIAR_SITES_SUB_LABEL 8420
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_UNFAMILIAR_SITES_SAFE_BROWSING_OFF_SUB_LABEL 8421
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_ALLOWED_EXCEPTIONS 8422
#define IDS_SETTINGS_SITE_SETTINGS_JAVASCRIPT_OPTIMIZER_BLOCKED_EXCEPTIONS 8423
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_DESCRIPTION 8424
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_ASK 8425
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_BLOCKED 8426
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_ALLOWED_EXCEPTIONS 8427
#define IDS_SETTINGS_SITE_SETTINGS_KEYBOARD_LOCK_BLOCKED_EXCEPTIONS 8428
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_DESCRIPTION 8429
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_ASK 8430
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED 8431
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED_SUB_LABEL 8432
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_ALLOWED_EXCEPTIONS 8433
#define IDS_SETTINGS_SITE_SETTINGS_LOCATION_BLOCKED_EXCEPTIONS 8434
#define IDS_SETTINGS_SITE_SETTINGS_MIC_DESCRIPTION 8435
#define IDS_SETTINGS_SITE_SETTINGS_MIC_ASK 8436
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED 8437
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED_SUB_LABEL 8438
#define IDS_SETTINGS_SITE_SETTINGS_MIC_ALLOWED_EXCEPTIONS 8439
#define IDS_SETTINGS_SITE_SETTINGS_MIC_BLOCKED_EXCEPTIONS 8440
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_DESCRIPTION 8441
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_ASK 8442
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_BLOCKED 8443
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_ALLOWED_EXCEPTIONS 8444
#define IDS_SETTINGS_SITE_SETTINGS_MIDI_BLOCKED_EXCEPTIONS 8445
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_DESCRIPTION 8446
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_ALLOWED 8447
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_ASK 8448
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_BLOCKED 8449
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_BLOCKED_SUB_LABEL 8450
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_ALLOWED_EXCEPTIONS 8451
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_AND_LIGHT_SENSORS_BLOCKED_EXCEPTIONS 8452
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_DESCRIPTION 8453
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_ALLOWED 8454
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_ASK 8455
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_BLOCKED 8456
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_BLOCKED_SUB_LABEL 8457
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_ALLOWED_EXCEPTIONS 8458
#define IDS_SETTINGS_SITE_SETTINGS_MOTION_SENSORS_BLOCKED_EXCEPTIONS 8459
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_DESCRIPTION 8460
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_ALLOWED 8461
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_PARTIAL 8462
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_PARTIAL_SUB_LABEL 8463
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_ASK_STATE 8464
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_QUIET 8465
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_CPSS 8466
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_LOUD 8467
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSION_TITLE 8468
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_BLOCKED 8469
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_BLOCKED_SUB_LABEL 8470
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_ALLOWED_EXCEPTIONS 8471
#define IDS_SETTINGS_SITE_SETTINGS_NOTIFICATIONS_BLOCKED_EXCEPTIONS 8472
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_DESCRIPTION 8473
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_ALLOWED 8474
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_BLOCKED 8475
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_ALLOWED_EXCEPTIONS 8476
#define IDS_SETTINGS_SITE_SETTINGS_PAYMENT_HANDLERS_BLOCKED_EXCEPTIONS 8477
#define IDS_SETTINGS_SITE_SETTINGS_PDFS_DESCRIPTION 8478
#define IDS_SETTINGS_SITE_SETTINGS_PDFS_ALLOWED 8479
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_DESCRIPTION 8480
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_ALLOWED 8481
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_BLOCKED 8482
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_ALLOWED_EXCEPTIONS 8483
#define IDS_SETTINGS_SITE_SETTINGS_POINTER_LOCK_BLOCKED_EXCEPTIONS 8484
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_DESCRIPTION 8485
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_ALLOWED 8486
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_BLOCKED 8487
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_ALLOWED_EXCEPTIONS 8488
#define IDS_SETTINGS_SITE_SETTINGS_POPUPS_BLOCKED_EXCEPTIONS 8489
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_DESCRIPTION 8490
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_ALLOWED 8491
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_BLOCKED 8492
#define IDS_SETTINGS_SITE_SETTINGS_PROTECTED_CONTENT_BLOCKED_SUB_LABEL 8493
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_DESCRIPTION 8501
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_ALLOWED 8502
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_BLOCKED 8503
#define IDS_SETTINGS_SITE_SETTINGS_PROTOCOL_HANDLERS_BLOCKED_EXCEPTIONS 8504
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_DESCRIPTION 8505
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_ASK 8506
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_BLOCKED 8507
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_DESCRIPTION 8508
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_ALLOWED 8509
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_BLOCKED 8510
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_BLOCKED_SUB_LABEL 8511
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_ALLOWED_EXCEPTIONS 8512
#define IDS_SETTINGS_SITE_SETTINGS_SOUND_BLOCKED_EXCEPTIONS 8513
#define IDS_SETTINGS_SITE_SETTINGS_USB_DESCRIPTION 8514
#define IDS_SETTINGS_SITE_SETTINGS_USB_ASK 8515
#define IDS_SETTINGS_SITE_SETTINGS_USB_BLOCKED 8516
#define IDS_SETTINGS_SITE_SETTINGS_VR_DESCRIPTION 8517
#define IDS_SETTINGS_SITE_SETTINGS_VR_ASK 8518
#define IDS_SETTINGS_SITE_SETTINGS_VR_BLOCKED 8519
#define IDS_SETTINGS_SITE_SETTINGS_VR_ALLOWED_EXCEPTIONS 8520
#define IDS_SETTINGS_SITE_SETTINGS_VR_BLOCKED_EXCEPTIONS 8521
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_DESCRIPTION 8522
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_ASK 8523
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_BLOCK 8524
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_ALLOWED_EXCEPTIONS 8525
#define IDS_SETTINGS_SITE_SETTINGS_WEB_APP_INSTALLATION_BLOCKED_EXCEPTIONS 8526
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_DESCRIPTION 8527
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_ASK 8528
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_BLOCK 8529
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_ALLOWED_EXCEPTIONS 8530
#define IDS_SETTINGS_SITE_SETTINGS_WEB_PRINTING_BLOCKED_EXCEPTIONS 8531
#define IDS_SETTINGS_SITE_SETTINGS_ZOOM_LEVELS_DESCRIPTION 8532
#define IDS_SETTINGS_SITE_SETTINGS_AR_ASK 8533
#define IDS_SETTINGS_SITE_SETTINGS_AR_BLOCK 8534
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_ASK 8535
#define IDS_SETTINGS_SITE_SETTINGS_HAND_TRACKING_BLOCK 8536
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_DESCRIPTION 8537
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_ASK 8538
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_BLOCK 8539
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_ALLOWED_EXCEPTIONS 8540
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ACCESS_BLOCKED_EXCEPTIONS 8541
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_DESCRIPTION 8542
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ASK 8543
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_BLOCK 8544
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_ALLOWED_EXCEPTIONS 8545
#define IDS_SETTINGS_SITE_SETTINGS_LOCAL_NETWORK_BLOCKED_EXCEPTIONS 8546
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_DESCRIPTION 8547
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_ASK 8548
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_BLOCK 8549
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_ALLOWED_EXCEPTIONS 8550
#define IDS_SETTINGS_SITE_SETTINGS_LOOPBACK_NETWORK_BLOCKED_EXCEPTIONS 8551
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_DESCRIPTION 8552
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_TITLE 8553
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_LINK_ROW_LABEL 8554
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_LINK_ROW_SUB_LABEL_ENABLED 8555
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_LINK_ROW_SUB_LABEL_DISABLED 8556
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_ALLOW_RADIO_LABEL 8557
#define IDS_SETTINGS_THIRD_PARTY_COOKIES_PAGE_BLOCK_RADIO_LABEL 8558
#define IDS_SETTINGS_COOKIES_RELATED_WEBSITE_SETS_TOGGLE_LABEL 8559
#define IDS_SETTINGS_COOKIES_RELATED_WEBSITE_SETS_TOGGLE_SUB_LABEL 8560
#define IDS_SETTINGS_COOKIES_ALL_SITES_LINK 8561
#define IDS_SETTINGS_TRACKING_PROTECTION_ADVANCED_LABEL 8562
#define IDS_SETTINGS_TRACKING_PROTECTION_DO_NOT_TRACK_TOGGLE_SUB_LABEL 8563
#define IDS_SETTINGS_TRACKING_PROTECTION_SITES_ALLOWED_COOKIES_TITLE 8564
#define IDS_SETTINGS_TRACKING_PROTECTION_SITES_ALLOWED_COOKIES_DESCRIPTION 8565
#define IDS_SETTINGS_SITE_SETTINGS_APP_PROTOCOL_HANDLERS 8566
#define IDS_SETTINGS_SITE_SETTINGS_APP_ALLOWED_PROTOCOL_HANDLERS_DESCRIPTION 8567
#define IDS_SETTINGS_SITE_SETTINGS_APP_DISALLOWED_PROTOCOL_HANDLERS_DESCRIPTION 8568
#define IDS_SETTINGS_SITE_SETTINGS_INSECURE_CONTENT_BLOCK 8569
#define IDS_SETTINGS_SITE_SETTINGS_PDF_DOWNLOAD_PDFS 8570
#define IDS_SETTINGS_SITE_SETTINGS_RECENT_ACTIVITY 8571
#define IDS_SETTINGS_SITE_SETTINGS_SERIAL_PORTS_ASK_RECOMMENDED 8572
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_ZOOM_LEVEL 8573
#define IDS_SETTINGS_SITE_SETTINGS_ASK_BEFORE_SENDING 8574
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATICALLY_BLOCKED_NOTIFICATIONS 8575
#define IDS_SETTINGS_SITE_SETTINGS_SHOW_BLOCKED_NOTIFICATIONS_INDICATOR 8576
#define IDS_SETTINGS_SITE_SETTINGS_HANDLERS_ASK_RECOMMENDED 8577
#define IDS_SETTINGS_SITE_SETTINGS_HANDLERS_BLOCKED 8578
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_DESCRIPTION 8579
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_ASK 8580
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_BLOCKED 8581
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_ASK_EXCEPTIONS 8582
#define IDS_SETTINGS_SITE_SETTINGS_WINDOW_MANAGEMENT_BLOCKED_EXCEPTIONS 8583
#define IDS_SETTINGS_SITE_SETTINGS_BLOCKED 8584
#define IDS_SETTINGS_SITE_SETTINGS_ALLOW 8585
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK 8586
#define IDS_SETTINGS_SITE_SETTINGS_SESSION_ONLY 8587
#define IDS_SETTINGS_SITE_SETTINGS_ASK_DEFAULT_MENU 8588
#define IDS_SETTINGS_SITE_SETTINGS_ALLOW_DEFAULT_MENU 8589
#define IDS_SETTINGS_SITE_SETTINGS_AUTOMATIC_DEFAULT_MENU 8590
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK_DEFAULT_MENU 8591
#define IDS_SETTINGS_SITE_SETTINGS_ACTION_BLOCK_ON_UNFAMILIAR_SITES_DEFAULT_MENU 8592
#define IDS_SETTINGS_SITE_SETTINGS_MUTE_DEFAULT_MENU 8593
#define IDS_SETTINGS_SITE_SETTINGS_ALLOW_MENU 8594
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK_MENU 8595
#define IDS_SETTINGS_SITE_SETTINGS_ASK_MENU 8596
#define IDS_SETTINGS_SITE_SETTINGS_MUTE_MENU 8597
#define IDS_SETTINGS_SITE_SETTINGS_RESET_MENU 8598
#define IDS_SETTINGS_SITE_SETTINGS_RESET_FROM_LIST_A11Y 8599
#define IDS_SETTINGS_SITE_SETTINGS_VIEW_FROM_LIST_A11Y 8600
#define IDS_SETTINGS_SITE_SETTINGS_SESSION_ONLY_MENU 8601
#define IDS_SETTINGS_SITE_SETTINGS_USAGE 8602
#define IDS_SETTINGS_SITE_SETTINGS_USAGE_NONE 8603
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSIONS 8604
#define IDS_SETTINGS_SITE_SETTINGS_PERMISSIONS_MORE 8605
#define IDS_SETTINGS_SITE_SETTINGS_CONTENT 8606
#define IDS_SETTINGS_SITE_SETTINGS_CONTENT_MORE 8607
#define IDS_SETTINGS_SITE_SETTINGS_ALLOWLISTED 8608
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCK_BLOCKLISTED_SINGULAR 8609
#define IDS_SETTINGS_SITE_SETTINGS_ADS_BLOCK_NOT_BLOCKLISTED_SINGULAR 8610
#define IDS_SETTINGS_SITE_SETTINGS_SOURCE_KILL_SWITCH 8611
#define IDS_SETTINGS_SITE_SETTINGS_SOURCE_INSECURE_ORIGIN 8612
#define IDS_SETTINGS_SITE_SETTINGS_RESET_BUTTON 8613
#define IDS_SETTINGS_SITE_SETTINGS_DELETE 8614
#define IDS_SETTINGS_SITE_SETTINGS_THIRD_PARTY_COOKIES_EXCEPTION_LABEL 8615
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_DIALOG_TITLE 8616
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_DIALOG_TITLE 8617
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_LEARN_MORE 8618
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_LEARN_MORE_ACCESSIBILITY 8619
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_ALL_STORAGE_DESCRIPTION 8620
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_DISPLAYED_STORAGE_DESCRIPTION 8621
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_LABEL 8622
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_LABEL 8623
#define IDS_SETTINGS_SITE_SETTINGS_SITE_DETAILS_SUBPAGE_ACCESSIBILITY_LABEL 8624
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_MEMBERSHIP_LABEL 8625
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_MORE_ACTIONS_TITLE 8626
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_SHOW_RELATED_SITES_BUTTON 8627
#define IDS_SETTINGS_SITE_SETTINGS_RELATED_WEBSITE_SETS_SITE_DELETE_STORAGE_BUTTON 8628
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_CONFIRMATION 8629
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_CONFIRMATION 8630
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_RWS_STORAGE_CONFIRMATION 8631
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_ALL_STORAGE_CONFIRMATION_INSTALLED 8632
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_DISPLAYED_STORAGE_CONFIRMATION_INSTALLED 8633
#define IDS_SETTINGS_SITE_SETTINGS_DELETE_RWS_STORAGE_CONFIRMATION_INSTALLED 8634
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_ALL_STORAGE_SIGN_OUT 8635
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_DISPLAYED_STORAGE_SIGN_OUT 8636
#define IDS_SETTINGS_SITE_SETTINGS_CLEAR_RWS_STORAGE_SIGN_OUT 8637
#define IDS_SETTINGS_SITE_SETTINGS_SITE_RESET_DIALOG_TITLE 8638
#define IDS_SETTINGS_SITE_SETTINGS_SITE_RESET_CONFIRMATION 8639
#define IDS_SETTINGS_SITE_SETTINGS_PARENT_APP_PERMISSION_EXPLANATION 8640
#define IDS_SETTINGS_SITE_SETTINGS_SUB_APP_PERMISSION_EXPLANATION 8641
#define IDS_SETTINGS_SITE_SETTINGS_SITE_DELETE_STORAGE_DIALOG_TITLE 8642
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE_CONFIRMATION 8643
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE_CONFIRMATION_NEW 8644
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE_SIGN_OUT 8645
#define IDS_SETTINGS_SITE_SETTINGS_SITE_DELETE_STORAGE_OFFLINE_DATA 8646
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_AD_PERSONALIZATION 8647
#define IDS_SETTINGS_SITE_SETTINGS_SITE_GROUP_DELETE_OFFLINE_DATA 8648
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_DIALOG_TITLE 8649
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_APP_DIALOG_TITLE 8650
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_PARTITIONED_DIALOG_TITLE 8651
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_DIALOG_TITLE 8652
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_APP_DIALOG_TITLE 8653
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_APP_PLURAL_DIALOG_TITLE 8654
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_ORIGIN_LOGOUT 8655
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_GROUP_LOGOUT 8656
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_OFFLINE_DATA 8657
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_PERMISSIONS 8658
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE_SITE_CONFIRM 8659
#define IDS_SETTINGS_SITE_SETTINGS_COOKIE_REMOVE_SITE 8660
#define IDS_SETTINGS_SITE_SETTINGS_SITE_RESET_ALL 8661
#define IDS_SETTINGS_SITE_SETTINGS_SITE_CLEAR_STORAGE 8662
#define IDS_SETTINGS_SITE_SETTINGS_HANDLER_IS_DEFAULT 8663
#define IDS_SETTINGS_SITE_SETTINGS_HANDLER_SET_DEFAULT 8664
#define IDS_SETTINGS_SITE_SETTINGS_REMOVE 8665
#define IDS_SETTINGS_SITE_SETTINGS_INCOGNITO_ONLY 8666
#define IDS_SETTINGS_SITE_SETTINGS_INCOGNITO_SITE_EXCEPTION_DESC 8667
#define IDS_SETTINGS_SITE_SETTINGS_NO_ZOOMED_SITES 8668
#define IDS_SETTINGS_SITE_NO_SITES_ADDED 8669
#define IDS_SETTINGS_SITE_SETTINGS_BLOCK_AUTOPLAY 8670
#define IDS_SETTINGS_SITE_SETTINGS_EMPTY_ALL_SITES_PAGE 8671
#define IDS_SETTINGS_SITE_SETTINGS_NO_SITES_FOUND 8672
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_DESCRIPTION 8673
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_ASK 8674
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_BLOCK 8675
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_ALLOWED_EXCEPTIONS 8676
#define IDS_SETTINGS_SITE_SETTINGS_BLUETOOTH_SCANNING_BLOCKED_EXCEPTIONS 8677
#define IDS_SETTINGS_SITE_SETTINGS_EXTENSION_ID_DESCRIPTION 8678
#define IDS_SETTINGS_SITE_SETTINGS_PAGE_SITE_DATA_ALLOWED_SUB_LABEL 8679
#define IDS_SETTINGS_SITE_SETTINGS_PAGE_SITE_DATA_BLOCKED_SUB_LABEL 8680
#define IDS_SETTINGS_SITE_SETTINGS_PAGE_SITE_DATA_DELETE_ON_EXIT_SUB_LABEL 8681
#define IDS_SETTINGS_EXPIRES_AFTER_TIME_LABEL 8682
#define IDS_SETTINGS_SITE_DATA_PAGE_TITLE 8683
#define IDS_SETTINGS_SITE_DATA_PAGE_DESCRIPTION 8684
#define IDS_SETTINGS_SITE_DATA_PAGE_DEFAULT_BEHAVIOR_HEADING 8685
#define IDS_SETTINGS_SITE_DATA_PAGE_DEFAULT_BEHAVIOR_DESCRIPTION 8686
#define IDS_SETTINGS_SITE_DATA_PAGE_ALLOW_RADIO_LABEL 8687
#define IDS_SETTINGS_SITE_DATA_PAGE_ALLOW_RADIO_SUB_LABEL 8688
#define IDS_SETTINGS_SITE_DATA_PAGE_CLEAR_ON_EXIT_RADIO_LABEL 8689
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_RADIO_LABEL 8690
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_RADIO_SUB_LABEL 8691
#define IDS_SETTINGS_SITE_DATA_PAGE_CUSTOMIZED_BEHAVIOR_HEADING 8692
#define IDS_SETTINGS_SITE_DATA_PAGE_CUSTOMIZED_BEHAVIOR_DESCRIPTION 8693
#define IDS_SETTINGS_SITE_DATA_PAGE_ALLOW_EXCEPTIONS_SUB_HEADING 8694
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_EXCEPTIONS_SUB_HEADING 8695
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_TITLE 8696
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_DESCRIPTION 8697
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_CONFIRM_BUTTON 8698
#define IDS_SETTINGS_SITE_DATA_PAGE_BLOCK_CONFIRM_DIALOG_CANCEL_BUTTON 8699
#define IDS_SETTINGS_ADD_SITE_TO_ALLOW_LIST_LABEL 8700
#define IDS_SETTINGS_ADD_SITE_TO_BLOCK_LIST_LABEL 8701
#define IDS_SETTINGS_ADD_SITE_CONTEXT_MENU_LABEL 8702
#define IDS_SETTINGS_STORAGE_ACCESS_DESCRIPTION 8703
#define IDS_SETTINGS_STORAGE_ACCESS_ASK 8704
#define IDS_SETTINGS_STORAGE_ACCESS_BLOCKED 8705
#define IDS_SETTINGS_STORAGE_ACCESS_ALLOWED_EXCEPTIONS 8706
#define IDS_SETTINGS_STORAGE_ACCESS_BLOCKED_EXCEPTIONS 8707
#define IDS_SETTINGS_STORAGE_ACCESS_RESET_ALL 8708
#define IDS_SETTINGS_STORAGE_ACCESS_RESET_SITE 8709
#define IDS_SETTINGS_STORAGE_ACCESS_OPEN_EXPAND 8710
#define IDS_SETTINGS_STORAGE_ACCESS_CLOSE_EXPAND 8711
#define IDS_SETTINGS_STORAGE_ACCESS_ALLOWED_SITE_LABEL 8712
#define IDS_SETTINGS_STORAGE_ACCESS_BLOCKED_SITE_LABEL 8713
#define IDS_SETTINGS_NO_BLUETOOTH_DEVICES_FOUND 8714
#define IDS_SETTINGS_NO_USB_DEVICES_FOUND 8715
#define IDS_SETTINGS_NO_SERIAL_PORTS_FOUND 8716
#define IDS_SETTINGS_NO_HID_DEVICES_FOUND 8717
#define IDS_SETTINGS_RESET_BLUETOOTH_CONFIRMATION 8718
#define IDS_SETTINGS_RESET_HID_CONFIRMATION 8719
#define IDS_SETTINGS_RESET_SERIAL_PORTS_CONFIRMATION 8720
#define IDS_SETTINGS_RESET_USB_CONFIRMATION 8721
#define IDS_SETTINGS_ADD_SITE_TITLE 8722
#define IDS_SETTINGS_ADD_SITES_TITLE 8723
#define IDS_SETTINGS_EDIT_SITE_TITLE 8724
#define IDS_SETTINGS_ADD_SITE 8725
#define IDS_SETTINGS_SITE_SETTINGS_NUM_COOKIES 8726
#define IDS_SETTINGS_PEOPLE 8727
#define IDS_SETTINGS_CHANGE_PICTURE_PROFILE_PHOTO 8728
#define IDS_SETTINGS_PEOPLE_SIGN_IN 8729
#define IDS_SETTINGS_PEOPLE_VERIFY_ACCOUNT_BUTTON 8730
#define IDS_SETTINGS_TURN_OFF_SYNC_MANAGED_PROFILE_EXPLANATION 8731
#define IDS_SETTINGS_TURN_OFF_SYNC_AND_SIGN_OUT_DIALOG_TITLE 8732
#define IDS_SETTINGS_TURN_OFF_SYNC_AND_SIGN_OUT_DIALOG_TITLE_SUPERVISED_PROFILE 8733
#define IDS_SETTINGS_TURN_OFF_SYNC_DIALOG_MANAGED_CONFIRM 8734
#define IDS_SETTINGS_TURN_OFF_SYNC_DIALOG_CHECKBOX 8735
#define IDS_SETTINGS_SYNC_SETTINGS_SAVED_TOAST_LABEL 8736
#define IDS_SETTINGS_CHROME_SIGNIN_OPTION_SAVED_TOAST_LABEL 8737
#define IDS_SETTINGS_PROFILE_NAME_INPUT_LABEL 8738
#define IDS_SETTINGS_PROFILE_SHORTCUT_TOGGLE_LABEL 8739
#define IDS_SETTINGS_CUSTOMIZE_PROFILE 8740
#define IDS_SETTINGS_PICK_A_THEME_COLOR 8741
#define IDS_SETTINGS_PICK_AN_AVATAR 8742
#define IDS_SETTINGS_CREATE_SHORTCUT 8743
#define IDS_SETTINGS_CREATE_SHORTCUT_SUBTITLE 8744
#define IDS_SETTINGS_ACCOUNT_PAGE_TITLE 8745
#define IDS_SETTINGS_ACCOUNT_DATATYPES_HEADING 8746
#define IDS_SETTINGS_ACCOUNT_BODY 8747
#define IDS_SETTINGS_ACCOUNT_SYNC_DISABLED 8748
#define IDS_SETTINGS_ACCOUNT_HISTORY_TOGGLE 8749
#define IDS_SETTINGS_ACCOUNT_HISTORY_TOGGLE_SUB_LABEL_OFF 8750
#define IDS_SETTINGS_GOOGLE_SERVICES_PAGE_TITLE 8751
#define IDS_SETTINGS_SYNC_DISCONNECT_EXPLANATION 8752
#define IDS_SETTINGS_SYNC_DISCONNECT_AND_SIGN_OUT_EXPLANATION 8753
#define IDS_SETTINGS_SYNC_DISCONNECT_AND_SIGN_OUT_EXPLANATION_SUPERVISED_PROFILE 8754
#define IDS_SETTINGS_SYNC_DISCONNECT_EXPAND_ACCESSIBILITY_LABEL 8755
#define IDS_SETTINGS_SYNC_WILL_START 8756
#define IDS_SETTINGS_USER_EVENTS_CHECKBOX_LABEL 8757
#define IDS_SETTINGS_USER_EVENTS_CHECKBOX_TEXT 8758
#define IDS_SETTINGS_ENCRYPT_WITH_SYNC_PASSPHRASE_LABEL 8759
#define IDS_SETTINGS_PASSPHRASE_EXPLANATION_TEXT 8760
#define IDS_SETTINGS_PASSPHRASE_RESET_HINT_ENCRYPTION 8761
#define IDS_SETTINGS_PASSPHRASE_RESET_HINT_TOGGLE 8762
#define IDS_SETTINGS_PASSPHRASE_RECOVER 8763
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_TITLE 8764
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_TITLE_V2 8765
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_WAA_TITLE 8766
#define IDS_SETTINGS_PERSONALIZE_GOOGLE_SERVICES_LINKED_SERVICES_TITLE 8767
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_PLACEHOLDER 8768
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_SIGNIN 8769
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_DO_NOT_SIGNIN 8770
#define IDS_SETTINGS_SIGNIN_CHROME_SIGNIN_OPTION_ALWAYS_ASK 8771
#define IDS_SETTINGS_GOOGLE_ACCOUNT 8772
#define IDS_SETTINGS_MANAGE_GOOGLE_ACCOUNT 8773
#define IDS_SETTINGS_IMPORT_SETTINGS_TITLE 8774
#define IDS_SETTINGS_IMPORT_FROM_LABEL 8775
#define IDS_SETTINGS_IMPORT_ITEMS_LABEL 8776
#define IDS_SETTINGS_IMPORT_LOADING_PROFILES 8777
#define IDS_SETTINGS_IMPORT_HISTORY_CHECKBOX 8778
#define IDS_SETTINGS_IMPORT_FAVORITES_CHECKBOX 8779
#define IDS_SETTINGS_IMPORT_PASSWORDS_CHECKBOX 8780
#define IDS_SETTINGS_IMPORT_SEARCH_ENGINES_CHECKBOX 8781
#define IDS_SETTINGS_IMPORT_AUTOFILL_FORM_DATA_CHECKBOX 8782
#define IDS_SETTINGS_IMPORT_CHOOSE_FILE 8783
#define IDS_SETTINGS_IMPORT_COMMIT 8784
#define IDS_SETTINGS_IMPORT_SUCCESS 8785
#define IDS_SETTINGS_IMPORT_NO_PROFILE_FOUND 8786
#define IDS_SETTINGS_HISTORY_SEARCH_SETTING_LABEL 8787
#define IDS_SETTINGS_HISTORY_SEARCH_SETTING_SUBLABEL_V2 8788
#define IDS_SETTINGS_HISTORY_SEARCH_LEARN_MORE_A11Y_LABEL 8789
#define IDS_SETTINGS_HISTORY_SEARCH_WHEN_ON_PAGE_CONTENT 8790
#define IDS_SETTINGS_HISTORY_SEARCH_WHEN_ON_SEARCH_FROM 8791
#define IDS_SETTINGS_HISTORY_SEARCH_WHEN_ON_LOG_START 8792
#define IDS_SETTINGS_HISTORY_SEARCH_CONSIDER_DATA 8793
#define IDS_SETTINGS_HISTORY_SEARCH_CONSIDER_DATA_ENCRYPTED 8794
#define IDS_SETTINGS_HISTORY_SEARCH_SUBLABEL_ON 8795
#define IDS_SETTINGS_HISTORY_SEARCH_SUBLABEL_OFF 8796
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_SETTING_SUBLABEL_V2 8797
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_WHEN_ON_PAGE_CONTENT 8798
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_WHEN_ON_RECALL_INFO 8799
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_CONSIDER_DATA_ENCRYPTED 8800
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_CONSIDER_OUTDATED 8801
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_SUBLABEL_ON 8802
#define IDS_SETTINGS_HISTORY_SEARCH_WITH_ANSWERS_SUBLABEL_OFF 8803
#define IDS_SETTINGS_PAGE_ZOOM_LABEL 8804
#define IDS_SETTINGS_FONT_SIZE_LABEL 8805
#define IDS_SETTINGS_VERY_SMALL_FONT 8806
#define IDS_SETTINGS_SMALL_FONT 8807
#define IDS_SETTINGS_MEDIUM_FONT 8808
#define IDS_SETTINGS_LARGE_FONT 8809
#define IDS_SETTINGS_VERY_LARGE_FONT 8810
#define IDS_SETTINGS_CUSTOMIZE_FONTS 8811
#define IDS_SETTINGS_FONTS 8812
#define IDS_SETTINGS_STANDARD_FONT_LABEL 8813
#define IDS_SETTINGS_SERIF_FONT_LABEL 8814
#define IDS_SETTINGS_SANS_SERIF_FONT_LABEL 8815
#define IDS_SETTINGS_FIXED_WIDTH_FONT_LABEL 8816
#define IDS_SETTINGS_MATH_FONT_LABEL 8817
#define IDS_SETTINGS_MINIMUM_FONT_SIZE_LABEL 8818
#define IDS_SETTINGS_TINY_FONT_SIZE 8819
#define IDS_SETTINGS_HUGE_FONT_SIZE 8820
#define IDS_SETTINGS_QUICK_BROWN_FOX 8821
#define IDS_SETTINGS_SYSTEM 8822
#define IDS_SETTINGS_SYSTEM_HARDWARE_ACCELERATION_LABEL 8823
#define IDS_SETTINGS_SYSTEM_FEATURE_NOTIFICATIONS_LABEL 8826
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_LABEL 8827
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_EXTENSION_LABEL 8828
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_POLICY_LABEL 8829
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_YOUR_ORGANIZATION_LABEL 8830
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_YOUR_DEVICE_LABEL 8831
#define IDS_SETTINGS_SYSTEM_PROXY_SETTINGS_MULTIPLE_SOURCES_LABEL 8832
#define IDS_PAGE_NOT_AVAILABLE_FOR_GUEST_HEADING 8835
#define IDS_SETTINGS_SECURITY_KEYS_TITLE 8836
#define IDS_SETTINGS_SECURITY_KEYS_DESC 8837
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN 8838
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_BUTTON 8839
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_DESC 8840
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_INITIAL_TITLE 8841
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_CREATE_TITLE 8842
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_CHANGE_TITLE 8843
#define IDS_SETTINGS_SECURITY_KEYS_RESET 8844
#define IDS_SETTINGS_SECURITY_KEYS_RESET_DESC 8845
#define IDS_SETTINGS_SECURITY_KEYS_RESET_TITLE 8846
#define IDS_SETTINGS_SECURITY_KEYS_RESET_CONFIRM_TITLE 8847
#define IDS_SETTINGS_SECURITY_KEYS_RESET_STEP1 8848
#define IDS_SETTINGS_SECURITY_KEYS_RESET_STEP2 8849
#define IDS_SETTINGS_SECURITY_KEYS_NO_RESET 8850
#define IDS_SETTINGS_SECURITY_KEYS_RESET_ERROR 8851
#define IDS_SETTINGS_SECURITY_KEYS_RESET_SUCCESS 8852
#define IDS_SETTINGS_SECURITY_KEYS_RESET_NOTALLOWED 8853
#define IDS_SETTINGS_SECURITY_KEYS_NO_PIN 8854
#define IDS_SETTINGS_SECURITY_KEYS_CURRENT_PIN_INTRO 8855
#define IDS_SETTINGS_SECURITY_KEYS_PIN_INCORRECT 8856
#define IDS_SETTINGS_SECURITY_KEYS_PIN_INCORRECT_RETRIES_SIN 8857
#define IDS_SETTINGS_SECURITY_KEYS_PIN_INCORRECT_RETRIES_PL 8858
#define IDS_SETTINGS_SECURITY_KEYS_SAME_PIN_AS_CURRENT 8859
#define IDS_SETTINGS_SECURITY_KEYS_NEW_PIN 8860
#define IDS_SETTINGS_SECURITY_KEYS_SET_PIN_CONFIRM 8861
#define IDS_SETTINGS_SECURITY_KEYS_CURRENT_PIN 8862
#define IDS_SETTINGS_SECURITY_KEYS_PIN 8863
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_TOO_SHORT_SMALL 8864
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_TOO_LONG 8865
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_INVALID 8866
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR_MISMATCH 8867
#define IDS_SETTINGS_SECURITY_KEYS_CONFIRM_PIN 8868
#define IDS_SETTINGS_SECURITY_KEYS_PIN_SUCCESS 8869
#define IDS_SETTINGS_SECURITY_KEYS_PIN_ERROR 8870
#define IDS_SETTINGS_SECURITY_KEYS_PIN_HARD_LOCK 8871
#define IDS_SETTINGS_SECURITY_KEYS_PIN_SOFT_LOCK 8872
#define IDS_SETTINGS_SECURITY_KEYS_SHOW_PINS 8873
#define IDS_SETTINGS_SECURITY_KEYS_HIDE_PINS 8874
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_LABEL 8875
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_USERNAME_LABEL 8876
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_DISPLAYNAME_LABEL 8877
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_WEBSITE_LABEL 8878
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DESC 8879
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DIALOG_TITLE 8880
#define IDS_SETTINGS_SECURITY_KEYS_UPDATE_CREDENTIAL_DIALOG_TITLE 8881
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_CONFIRM_DELETE_TITLE 8882
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_CONFIRM_DELETE_CREDENTIAL 8883
#define IDS_SETTINGS_SECURITY_KEYS_INPUT_ERROR_TOO_LONG 8884
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_NO_CREDENTIALS 8885
#define IDS_SETTINGS_SECURITY_KEYS_NO_CREDENTIAL_MANAGEMENT 8886
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_REMOVED 8887
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_NO_PIN 8888
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_ERROR 8889
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DELETE_SUCCESS 8890
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_DELETE_FAILED 8891
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_UPDATE_SUCCESS 8892
#define IDS_SETTINGS_SECURITY_KEYS_CREDENTIAL_MANAGEMENT_UPDATE_FAILED 8893
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_SUBPAGE_LABEL 8894
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_SUBPAGE_DESCRIPTION 8895
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_DIALOG_TITLE 8896
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ADD_TITLE 8897
#define IDS_SETTINGS_SECURITY_KEYS_BIO_CHOOSE_NAME 8898
#define IDS_SETTINGS_SECURITY_KEYS_BIO_NAME_LABEL 8899
#define IDS_SETTINGS_SECURITY_KEYS_BIO_NAME_LABEL_TOO_LONG 8900
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_NO_ENROLLMENTS_LABEL 8901
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ENROLLMENTS_LABEL 8902
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ENROLLING_LABEL 8903
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_TRY_AGAIN_LABEL 8904
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_FAILED_LABEL 8905
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_ENROLLING_COMPLETE_LABEL 8906
#define IDS_SETTINGS_SECURITY_KEYS_NO_BIOMETRIC_ENROLLMENT 8907
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_DELETE 8908
#define IDS_SETTINGS_SECURITY_KEYS_BIO_NO_PIN 8909
#define IDS_SETTINGS_SECURITY_KEYS_BIO_ENROLLMENT_STORAGE_FULL 8910
#define IDS_SETTINGS_SECURITY_KEYS_TOUCH_TO_CONTINUE 8911
#define IDS_SETTINGS_SECURITY_KEYS_PIN_PROMPT 8912
#define IDS_SETTINGS_SECURITY_KEYS_FORCE_PIN_CHANGE 8913
#define IDS_SETTINGS_EXTENSION_OR_APP_DISPLAY_NAME 8914
#define IDS_SETTINGS_SAFETY_HUB 8915
#define IDS_SETTINGS_SAFETY_HUB_ENTRY_POINT_BUTTON_LABEL 8916
#define IDS_SETTINGS_SAFETY_HUB_PAGE_CARD_SECTION_HEADER 8917
#define IDS_SETTINGS_SAFETY_HUB_PAGE_MODULE_SECTION_HEADER 8918
#define IDS_SETTINGS_SAFETY_HUB_EMPTY_STATE_MODULE_HEADER 8919
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_RECENTLY 8920
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_SOME_TIME_AGO 8921
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_HEADER_NO_WEAK_OR_REUSED 8922
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_SIGN_IN 8923
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_GO_TO_PASSWORD_MANAGER 8924
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_HEADER_NO_PASSWORDS 8925
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_CHECK_SUBHEADER_NO_PASSWORDS_POLICY 8926
#define IDS_SETTINGS_SAFETY_HUB_PASSWORD_NAVIGATION_ARIA_LABEL 8927
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_ENHANCED_HEADER 8928
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_ENHANCED_SUBHEADER 8929
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_STANDARD_HEADER 8930
#define IDS_SETTINGS_SAFETY_HUB_SB_ON_STANDARD_SUBHEADER 8931
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_HEADER 8932
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_MANAGED_SUBHEADER 8933
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_EXTENSION_SUBHEADER 8934
#define IDS_SETTINGS_SAFETY_HUB_SB_OFF_USER_SUBHEADER 8935
#define IDS_SETTINGS_SAFETY_HUB_SB_NAVIGATION_ARIA_LABEL 8936
#define IDS_SETTINGS_SAFETY_HUB_GO_SITE_SETTINGS_ITEM 8937
#define IDS_SETTINGS_SAFETY_HUB_GO_NOTIFICATION_SETTINGS_ITEM 8938
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_INCOGNITO_SUBHEADER 8939
#define IDS_SETTINGS_SAFETY_HUB_USER_EDU_SAFE_BROWSING_HEADER 8940
#define IDS_SETTINGS_SAFETY_HUB_VERSION_CARD_SUBHEADER_RESTART 8941
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATION_PERMISSIONS_PRIMARY_LABEL 8942
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATION_PERMISSIONS_SECONDARY_LABEL 8943
#define IDS_SETTINGS_SAFETY_HUB_REVOKED_PERMISSIONS_MENU_NOTIFICATION 8944
#define IDS_SETTINGS_SAFETY_HUB_REVIEW_NOTIFICATION_PERMISSIONS_MENU_NOTIFICATION 8945
#define IDS_SETTINGS_SAFETY_HUB_COMPROMISED_PASSWORDS_MENU_NOTIFICATION 8946
#define IDS_SETTINGS_SAFETY_HUB_EXTENSIONS_MENU_NOTIFICATION 8947
#define IDS_SETTINGS_SAFETY_HUB_SAFE_BROWSING_MENU_NOTIFICATION 8948
#define IDS_SETTINGS_SAFETY_HUB_PASSWORDS_MODULE_NAME 8949
#define IDS_SETTINGS_SAFETY_HUB_SAFE_BROWSING_MODULE_NAME 8950
#define IDS_SETTINGS_SAFETY_HUB_EXTENSIONS_MODULE_UPPERCASE_NAME 8951
#define IDS_SETTINGS_SAFETY_HUB_EXTENSIONS_MODULE_LOWERCASE_NAME 8952
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATIONS_MODULE_UPPERCASE_NAME 8953
#define IDS_SETTINGS_SAFETY_HUB_NOTIFICATIONS_MODULE_LOWERCASE_NAME 8954
#define IDS_SETTINGS_SAFETY_HUB_PERMISSIONS_MODULE_UPPERCASE_NAME 8955
#define IDS_SETTINGS_SAFETY_HUB_PERMISSIONS_MODULE_LOWERCASE_NAME 8956
#define IDS_SETTINGS_SAFETY_HUB_MODULE_NAME_SEPARATOR 8957
#define IDS_SETTINGS_AI_INNOVATIONS_PAGE_TITLE 8958
#define IDS_SETTINGS_AI_PAGE_MAIN_SUBLABEL_3 8959
#define IDS_SETTINGS_AI_PAGE_MAIN_MANAGED_LEARN_MORE_ACCESSIBILITY_LABEL 8960
#define IDS_SETTINGS_AI_SUBPAGE_SUBLABEL_AI 8961
#define IDS_SETTINGS_AI_SUBPAGE_SUBLABEL_REVIEWERS 8962
#define IDS_SETTINGS_AI_SUBPAGE_SUBLABEL_LOGGING_MANAGED_DISABLED 8963
#define IDS_SETTINGS_AI_SUBPAGE_FEATURE_MANAGED_DISABLED_LABEL 8964
#define IDS_SETTINGS_COMPARE_SETTING_SUBLABEL 8965
#define IDS_SETTINGS_COMPARE_SETTING_LINK_A11Y 8966
#define IDS_SETTINGS_COMPARE_WHEN_ON_PRODUCT_DETAILS 8967
#define IDS_SETTINGS_COMPARE_WHEN_ON_PRODUCT_SUGGEST 8968
#define IDS_SETTINGS_COMPARE_WHEN_ON_PRODUCT_FILTER 8969
#define IDS_SETTINGS_COMPARE_WHEN_ON_PRODUCT_REVIEWS 8970
#define IDS_SETTINGS_COMPARE_CONSIDER_DATA 8971
#define IDS_SETTINGS_COMPARE_CONSIDER_TABLES_IN_ACCOUNT 8972
#define IDS_SETTINGS_PASSWORD_CHANGE_LABEL 8973
#define IDS_SETTINGS_PASSWORD_CHANGE_SUBLABEL 8974
#define IDS_SETTINGS_PASSWORD_CHANGE_DATA_BREACH 8975
#define IDS_SETTINGS_PASSWORD_CHANGE_WHERE_SAVED 8976
#define IDS_SETTINGS_PASSWORD_CHANGE_EXPERIMENTAL 8977
#define IDS_SETTINGS_PASSWORD_CHANGE_CONTENT 8978
#define IDS_SETTINGS_PASSWORD_CHANGE_ENCRYPTION 8979
#define IDS_SETTINGS_SAFEBROWSING_TURN_ON_ENHANCED_TOAST_BUTTON 8980
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_ON_TOAST_MESSAGE 8981
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_OFF_TOAST_MESSAGE 8982
#define IDS_SYNC_ERROR_BOOKMARKS_LIMIT_EXCEEDED_DESCRIPTION 8983
#define IDS_SETTINGS_AI_PAGE_MAIN_TITLE 8984
#define IDS_SETTINGS_AI_PAGE_MAIN_SUBLABEL_1 8985
#define IDS_SETTINGS_AI_PAGE_MAIN_SUBLABEL_2 8986
#define IDS_SETTINGS_AI_PAGE_MAIN_MANAGED_SUBLABEL_3 8987
#define IDS_SETTINGS_SUBPAGE_BACK_BUTTON_ARIA_LABEL 8988
#define IDS_SETTINGS_SUBPAGE_BACK_BUTTON_ARIA_ROLE_DESCRIPTION 8989
#define IDS_SETTINGS_SUBPAGE_LEARN_MORE_ARIA_LABEL 8990
#define IDS_SETTINGS_CAPTIONS 8991
#define IDS_SETTINGS_CAPTIONS_PREFERENCES_TITLE 8992
#define IDS_SETTINGS_CAPTIONS_PREFERENCES_SUBTITLE 8993
#define IDS_SETTINGS_CAPTIONS_TEXT_SIZE 8994
#define IDS_SETTINGS_CAPTIONS_TEXT_FONT 8995
#define IDS_SETTINGS_CAPTIONS_TEXT_COLOR 8996
#define IDS_SETTINGS_CAPTIONS_TEXT_OPACITY 8997
#define IDS_SETTINGS_CAPTIONS_BACKGROUND_OPACITY 8998
#define IDS_SETTINGS_CAPTIONS_OPACITY_OPAQUE 8999
#define IDS_SETTINGS_CAPTIONS_OPACITY_SEMI_TRANSPARENT 9000
#define IDS_SETTINGS_CAPTIONS_OPACITY_TRANSPARENT 9001
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW 9002
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_NONE 9003
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_RAISED 9004
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_DEPRESSED 9005
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_UNIFORM 9006
#define IDS_SETTINGS_CAPTIONS_TEXT_SHADOW_DROP_SHADOW 9007
#define IDS_SETTINGS_CAPTIONS_BACKGROUND_COLOR 9008
#define IDS_SETTINGS_CAPTIONS_COLOR_BLACK 9009
#define IDS_SETTINGS_CAPTIONS_COLOR_WHITE 9010
#define IDS_SETTINGS_CAPTIONS_COLOR_RED 9011
#define IDS_SETTINGS_CAPTIONS_COLOR_GREEN 9012
#define IDS_SETTINGS_CAPTIONS_COLOR_BLUE 9013
#define IDS_SETTINGS_CAPTIONS_COLOR_YELLOW 9014
#define IDS_SETTINGS_CAPTIONS_COLOR_CYAN 9015
#define IDS_SETTINGS_CAPTIONS_COLOR_MAGENTA 9016
#define IDS_SETTINGS_CAPTIONS_DEFAULT_SETTING 9017
#define IDS_SETTINGS_CAPTIONS_LANGUAGE 9018
#define IDS_SETTINGS_CAPTIONS_MANAGE_LANGUAGES_TITLE 9019
#define IDS_SETTINGS_CAPTIONS_MANAGE_LANGUAGES_SUBTITLE 9020
#define IDS_SETTINGS_CAPTIONS_MANAGE_LANGUAGES_SUBTITLE_LIVE_CAPTION_ONLY 9021
#define IDS_SETTINGS_CAPTIONS_LIVE_TRANSLATE_TARGET_LANGUAGE 9022
#define IDS_SETTINGS_CAPTIONS_LIVE_TRANSLATE_TARGET_LANGUAGE_SUBTITLE 9023
#define IDS_SETTINGS_CAPTIONS_REMOVE_LANGUAGE_LABEL 9024
#define IDS_SETTINGS_CAPTIONS_MAKE_DEFAULT_LANGUAGE_LABEL 9025
#define IDS_SETTINGS_CAPTIONS_DEFAULT_LANGUAGE_LABEL 9026
#define IDS_SETTINGS_NEARBY_SHARE_TITLE 9027
#define IDS_SETTINGS_NEARBY_SHARE_TITLE_PH 9028
#define IDS_SETTINGS_NEARBY_SHARE_SET_UP_BUTTON_TITLE 9029
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_ROW_TITLE 9030
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_DIALOG_TITLE 9031
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_FIELD_LABEL 9032
#define IDS_SETTINGS_NEARBY_SHARE_EDIT_DEVICE_NAME 9033
#define IDS_SETTINGS_NEARBY_SHARE_FAST_INITIATION_NOTIFICATION_TOGGLE_TITLE 9034
#define IDS_SETTINGS_NEARBY_SHARE_FAST_INITIATION_NOTIFICATION_TOGGLE_DESCRIPTION 9035
#define IDS_SETTINGS_NEARBY_SHARE_FAST_INITIATION_NOTIFICATION_TOGGLE_ARIA_LABEL 9036
#define IDS_SETTINGS_NEARBY_SHARE_DEVICE_NAME_ARIA_DESCRIPTION 9037
#define IDS_SETTINGS_NEARBY_SHARE_CONFIRM_DEVICE_NAME 9038
#define IDS_SETTINGS_NEARBY_SHARE_MANAGE_CONTACTS_LABEL 9039
#define IDS_SETTINGS_NEARBY_SHARE_MANAGE_CONTACTS_ROW_TITLE 9040
#define IDS_SETTINGS_NEARBY_SHARE_EDIT_DATA_USAGE 9041
#define IDS_SETTINGS_NEARBY_SHARE_UPDATE_DATA_USAGE 9042
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_DIALOG_TITLE 9043
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_WIFI_ONLY_LABEL 9044
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_WIFI_ONLY_DESCRIPTION 9045
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_MOBILE_DATA_LABEL 9046
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_MOBILE_DATA_DESCRIPTION 9047
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_MOBILE_DATA_TOOLTIP 9048
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_OFFLINE_LABEL 9049
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_OFFLINE_DESCRIPTION 9050
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_EDIT_BUTTON_DATA_DESCRIPTION 9051
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_EDIT_BUTTON_WIFI_ONLY_DESCRIPTION 9052
#define IDS_SETTINGS_NEARBY_SHARE_DATA_USAGE_EDIT_BUTTON_OFFLINE_DESCRIPTION 9053
#define IDS_SETTINGS_NEARBY_SHARE_CONTACT_VISIBILITY_ROW_TITLE 9054
#define IDS_SETTINGS_NEARBY_SHARE_EDIT_VISIBILITY 9055
#define IDS_SETTINGS_NEARBY_SHARE_VISIBILITY_DIALOG_TITLE 9056
#define IDS_SETTINGS_NEARBY_SHARE_VISIBILITY_DIALOG_SAVE 9057
#define IDS_SETTINGS_NEARBY_SHARE_DESCRIPTION 9058
#define IDS_SETTINGS_NEARBY_SHARE_HIGH_VISIBILITY_TITLE 9059
#define IDS_SETTINGS_NEARBY_SHARE_HIGH_VISIBILITY_ON 9060
#define IDS_SETTINGS_NEARBY_SHARE_HIGH_VISIBILITY_OFF 9061
#define IDS_SETTINGS_ENABLE_URL_KEYED_ANONYMIZED_DATA_COLLECTION 9062
#define IDS_SETTINGS_ENABLE_URL_KEYED_ANONYMIZED_DATA_COLLECTION_DESC 9063
#define IDS_SETTINGS_SPELLING_PREF 9064
#define IDS_SETTINGS_ENABLE_LOGGING_PREF 9065
#define IDS_SETTINGS_ENABLE_LOGGING_PREF_DESC 9066
#define IDS_SETTINGS_SUGGEST_PREF 9067
#define IDS_SETTINGS_PEOPLE_SIGNED_IN_TO_ACCOUNT 9068
#define IDS_SETTINGS_PEOPLE_SYNCING_TO_ACCOUNT 9069
#define IDS_SETTINGS_PEOPLE_SYNC_PAUSED 9070
#define IDS_SETTINGS_PEOPLE_SIGN_IN_PROMPT 9071
#define IDS_SETTINGS_PEOPLE_SYNC_TURN_OFF 9072
#define IDS_SETTINGS_SETTINGS_CHECKBOX_LABEL 9073
#define IDS_SETTINGS_PEOPLE_SYNC_NOT_WORKING 9074
#define IDS_SETTINGS_PEOPLE_SYNC_PASSWORDS_NOT_WORKING 9075
#define IDS_SETTINGS_SYNC_ADVANCED_PAGE_TITLE 9076
#define IDS_SETTINGS_NEW_SYNC_ADVANCED_PAGE_TITLE 9077
#define IDS_SETTINGS_PEOPLE_SYNC_ANOTHER_ACCOUNT 9078
#define IDS_SETTINGS_TURN_ON_SYNC_BUTTON_UPDATE_SETTINGS_UI_ENABLED 9079
#define IDS_SETTINGS_ACCOUNT_AWARE_SIGNIN_BUTTON_LABEL 9080
#define IDS_SETTINGS_ERROR_PASSWORDS_USER_ERROR_DESCRIPTION 9081
#define IDS_SETTINGS_ERROR_RECOVERABILITY_DEGRADED_FOR_PASSWORDS_USER_ERROR_DESCRIPTION 9082
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL 9083
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL_WITH_BOOKMARKS 9084
#define IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL_SIMPLE 9085
#define IDS_SETTINGS_CHANGE_ACCOUNT 9086
#define IDS_SETTINGS_SYNC_DISCONNECT_CONFIRM 9087
#define IDS_SETTINGS_PEOPLE_SIGN_OUT 9088
#define IDS_SETTINGS_AUTOFILL_CHECKBOX_LABEL 9089
#define IDS_SETTINGS_HISTORY_CHECKBOX_LABEL 9090
#define IDS_SETTINGS_EXTENSIONS_CHECKBOX_LABEL 9091
#define IDS_SETTINGS_OPEN_TABS_CHECKBOX_LABEL 9092
#define IDS_SETTINGS_SAVED_TAB_GROUPS_CHECKBOX_LABEL 9093
#define IDS_SETTINGS_PRODUCT_COMPARISONS_CHECKBOX_LABEL 9094
#define IDS_SETTINGS_WIFI_CONFIGURATIONS_CHECKBOX_LABEL 9095
#define IDS_SETTINGS_SYNC_EVERYTHING_CHECKBOX_LABEL 9096
#define IDS_SETTINGS_APPS_CHECKBOX_LABEL 9097
#define IDS_SETTINGS_APPS_CHECKBOX_SUBLABEL 9098
#define IDS_SETTINGS_NON_PERSONALIZED_SERVICES_SECTION_LABEL 9099
#define IDS_SETTINGS_CUSTOMIZE_SYNC 9100
#define IDS_SETTINGS_SYNC_DATA 9101
#define IDS_SETTINGS_PASSWORDS_AND_PASSKEYS_CHECKBOX_LABEL 9102
#define IDS_SETTINGS_PASSPHRASE_PLACEHOLDER 9103
#define IDS_SETTINGS_EXISTING_PASSPHRASE_TITLE 9104
#define IDS_SETTINGS_SUBMIT_PASSPHRASE 9105
#define IDS_SETTINGS_ENCRYPT_WITH_GOOGLE_CREDENTIALS_LABEL 9106
#define IDS_SETTINGS_ENCRYPT_ACCOUNT_DATA_WITH_GOOGLE_CREDENTIALS_LABEL 9107
#define IDS_SETTINGS_BOOKMARKS_CHECKBOX_LABEL 9108
#define IDS_SETTINGS_READING_LIST_CHECKBOX_LABEL 9109
#define IDS_SETTINGS_ENCRYPTION_OPTIONS 9110
#define IDS_SETTINGS_MISMATCHED_PASSPHRASE_ERROR 9111
#define IDS_SETTINGS_EMPTY_PASSPHRASE_ERROR 9112
#define IDS_SETTINGS_INCORRECT_PASSPHRASE_ERROR 9113
#define IDS_SETTINGS_NEW_MANAGE_SYNCED_DATA_TITLE_UNIFIED_CONSENT 9114
#define IDS_SETTINGS_NEW_SYNC_ADVANCED_BROWSER_PAGE_TITLE 9115
#define IDS_SETTINGS_SYNC_SYNC_AND_NON_PERSONALIZED_SERVICES 9116
#define IDS_SETTINGS_PASSPHRASE_CONFIRMATION_PLACEHOLDER 9117
#define IDS_SETTINGS_SYNC_LOADING 9118
#define IDS_SETTINGS_SYNC_TIMEOUT 9119
#define IDS_SETTINGS_SYNC 9120
#define IDS_SETTINGS_SYNC_SETTINGS_CANCEL_SYNC 9121
#define IDS_SETTINGS_SYNC_SETUP_CANCEL_DIALOG_TITLE 9122
#define IDS_SETTINGS_SYNC_SETUP_CANCEL_DIALOG_BODY 9123
#define IDS_SYNC_UNAVAILABLE_FOR_NON_GOOGLE_ACCOUNT 9124
#define IDS_SETTINGS_ABOUT_UPGRADE_CHECK_STARTED 9127
#define IDS_SETTINGS_UPDATE_TO_ROLLBACK_VERSION_DISALLOWED 9128
#define IDS_SETTINGS_THEME_CHECKBOX_LABEL 9130
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_TITLE 9134
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES 9135
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_LOCAL_CERTIFICATES 9136
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_CERTIFICATES 9137
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_HASH_COPIED_TOAST 9138
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM 9139
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM_CERTS_TITLE 9140
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM_CERTS_VIEW_LINK 9142
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_ADMIN_CERTS_TITLE 9144
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_USER_CERTS_TITLE 9145
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_TRUSTED_CERTS_LIST 9146
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_INTERMEDIATE_CERTS_LIST 9147
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DISTRUSTED_CERTS_LIST 9148
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_NO_CERTIFICATES_ROW 9149
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_EXPORT_BUTTON_LABEL 9150
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_EXPORT_BUTTON_ARIA_LABEL 9151
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_BUTTON_LABEL 9152
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_BUTTON_ARIA_LABEL 9153
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_AND_BIND_BUTTON_LABEL 9154
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_AND_BIND_BUTTON_ARIA_LABEL 9155
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_NUM_CERTS 9156
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_DESCRIPTION 9157
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_LOCAL_CERTIFICATES_DESCRIPTION 9158
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_CERTIFICATES_DESCRIPTION 9159
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_LEARN_MORE_LINK 9160
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CRS_LEARN_MORE_LINK_ARIA_LABEL 9161
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_PLATFORM_CERTS_TOGGLE_LABEL 9162
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CUSTOM_CERTS_TITLE 9163
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_FROM_PLATFORM 9164
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_FROM_ADMIN 9165
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_CLIENT_CERTIFICATES_FROM_EXTENSION 9166
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_CERT_TITLE 9167
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_CLIENT_CERT_DESCRIPTION 9168
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_SERVER_CERT_DESCRIPTION 9169
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_READ_FILE_ERROR 9170
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_MULTIPLE_CERT_ERROR 9171
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_ERROR_TITLE 9172
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_DELETE_ERROR 9173
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_ENTER_PASSWORD_TITLE 9174
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_ERROR_TITLE 9175
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_INVALID_FILE 9176
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_FAILED 9177
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_BAD_PASSWORD 9178
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_INVALID_MAC 9179
#define IDS_SETTINGS_CERTIFICATE_MANAGER_V2_IMPORT_UNSUPPORTED 9180
#define IDS_CERTIFICATE_MANAGER_V2_SUBPAGE_BACK_BUTTON_ARIA_LABEL 9181
#define IDS_CERTIFICATE_MANAGER_V2_SUBPAGE_BACK_BUTTON_ARIA_ROLE_DESCRIPTION 9182
#define IDS_CERTIFICATE_MANAGER_V2_LIST_EXPAND_ARIA_LABEL 9183
#define IDS_CERTIFICATE_MANAGER_V2_CERT_ENTRY_VIEW_ARIA_LABEL 9184
#define IDS_CERTIFICATE_MANAGER_V2_CERT_ENTRY_DELETE_ARIA_LABEL 9185
#define IDS_CERTIFICATE_MANAGER_V2_CERT_HASH_COPY_ARIA_LABEL 9186
#define IDS_SUPPORT_TOOL_ISSUE_DETAILS_PAGE_TITLE 9210
#define IDS_SUPPORT_TOOL_DATA_SELECTION_PAGE_TITLE 9211
#define IDS_SUPPORT_TOOL_REVIEW_PII_PAGE_TITLE 9212
#define IDS_SUPPORT_TOOL_DATA_EXPORT_DONE_PAGE_TITLE 9213
#define IDS_SUPPORT_TOOL_DATA_EXPORTED_TEXT 9214
#define IDS_SUPPORT_TOOL_SUPPORT_CASE_ID 9215
#define IDS_SUPPORT_TOOL_EMAIL 9216
#define IDS_SUPPORT_TOOL_DESCRIBE_ISSUE_TEXT 9217
#define IDS_SUPPORT_TOOL_ISSUE_DESCRIPTION_PLACEHOLDER 9218
#define IDS_SUPPORT_TOOL_PII_WARNING_TEXT 9219
#define IDS_SUPPORT_TOOL_INCLUDE_ALL_PII_RADIO_BUTTON 9220
#define IDS_SUPPORT_TOOL_REMOVE_PII_RADIO_BUTTON 9221
#define IDS_SUPPORT_TOOL_PII_REMOVAL_DISCLAIMER 9222
#define IDS_SUPPORT_TOOL_MANUALLY_SELECT_PII_RADIO_BUTTON 9223
#define IDS_SUPPORT_TOOL_CANCEL_BUTTON_TEXT 9224
#define IDS_SUPPORT_TOOL_EXPORT_BUTTON_TEXT 9225
#define IDS_SUPPORT_TOOL_BACK_BUTTON_TEXT 9226
#define IDS_SUPPORT_TOOL_DISMISS_BUTTON_TEXT 9227
#define IDS_SUPPORT_TOOL_CONTINUE_BUTTON_TEXT 9228
#define IDS_SUPPORT_TOOL_DATA_COLLECTION_SPINNER 9229
#define IDS_SUPPORT_TOOL_DATA_EXPORT_SPINNER 9230
#define IDS_SUPPORT_TOOL_TAB_TITLE 9231
#define IDS_SUPPORT_TOOL_URL_GENERATOR_PAGE_TITLE 9232
#define IDS_SUPPORT_TOOL_DATA_COLLECTOR_LIST_TITLE 9233
#define IDS_SUPPORT_TOOL_GET_LINK_TEXT 9234
#define IDS_SUPPORT_TOOL_COPY_LINK_DESCRIPTION 9235
#define IDS_SUPPORT_TOOL_COPY_LINK_BUTTON_TEXT 9236
#define IDS_SUPPORT_TOOL_COPY_TOKEN_BUTTON_TEXT 9237
#define IDS_SUPPORT_TOOL_DONT_INCLUDE_EMAIL 9238
#define IDS_SUPPORT_TOOL_LINK_COPIED_TEXT 9239
#define IDS_SUPPORT_TOOL_TOKEN_COPIED_TEXT 9240
#define IDS_SUPPORT_TOOL_SELECT_DATA_COLLECTOR_ERROR 9241
#define IDS_SUPPORT_TOOL_SELECT_ALL 9242
#define IDS_SUPPORT_TOOL_CHROME_SYSTEM_INFO 9243
#define IDS_SUPPORT_TOOL_CRASH_IDS 9244
#define IDS_SUPPORT_TOOL_MEMORY_DETAILS 9245
#define IDS_SUPPORT_TOOL_UI_HIEARCHY 9246
#define IDS_SUPPORT_TOOL_ADDITIONAL_CROS_PLATFROM_LOGS 9247
#define IDS_SUPPORT_TOOL_DEVICE_EVENT 9248
#define IDS_SUPPORT_TOOL_INTEL_WIFI_DEBUG_DUMP 9249
#define IDS_SUPPORT_TOOL_TOUCH_EVENTS 9250
#define IDS_SUPPORT_TOOL_CHROMEOS_FLEX_LOGS 9251
#define IDS_SUPPORT_TOOL_DBUS_DETAILS 9252
#define IDS_SUPPORT_TOOL_CHROMEOS_NETWORK_ROUTES 9253
#define IDS_SUPPORT_TOOL_CHROMEOS_SHILL_LOGS 9254
#define IDS_SUPPORT_TOOL_POLICIES 9255
#define IDS_SUPPORT_TOOL_CHROMEOS_SYSTEM_STATE 9256
#define IDS_SUPPORT_TOOL_CHROMEOS_SYSTEM_LOGS 9257
#define IDS_SUPPORT_TOOL_CHROMEOS_CHROME_USER_LOGS 9258
#define IDS_SUPPORT_TOOL_CHROMEOS_BLUETOOTH_FLOSS 9259
#define IDS_SUPPORT_TOOL_CHROMEOS_CONNECTED_INPUT_DEVICES 9260
#define IDS_SUPPORT_TOOL_CHROMEOS_TRAFFIC_COUNTERS 9261
#define IDS_SUPPORT_TOOL_CHROMEOS_VIRTUAL_KEYBOARD 9262
#define IDS_SUPPORT_TOOL_CHROMEOS_NETWORK_HEALTH 9263
#define IDS_SUPPORT_TOOL_PERFORMANCE 9264
#define IDS_SUPPORT_TOOL_SIGN_IN 9265
#define IDS_SUPPORT_TOOL_CHROMEOS_APP_SERVICE 9266
#define IDS_SUPPORT_TOOL_CHROMEOS_KIOSK_APP_LEVEL_LOGS 9267
#define IDS_SUPPORT_TOOL_CHROME_UPDATER 9268
#define IDS_SUPPORT_TOOL_ANDROID_APP_INFO 9269
#define IDS_SUPPORT_TOOL_WIFI_SSID 9270
#define IDS_SUPPORT_TOOL_CELLULAR_LOCATION_INFO 9271
#define IDS_SUPPORT_TOOL_EMAIL_ADDRESS 9272
#define IDS_SUPPORT_TOOL_GAIA_ID 9273
#define IDS_SUPPORT_TOOL_STABLE_IDENTIDIERS 9274
#define IDS_SUPPORT_TOOL_PRINTING_IPP_ADDRESS 9275
#define IDS_SUPPORT_TOOL_IP_ADDRESS 9276
#define IDS_SUPPORT_TOOL_MAC_ADDRESS 9277
#define IDS_SUPPORT_TOOL_WINDOW_TITLES 9278
#define IDS_SUPPORT_TOOL_URLS 9279
#define IDS_SUPPORT_TOOL_SERIAL_NUMBERS 9280
#define IDS_SUPPORT_TOOL_REMOVABLE_STORAGE_NAMES 9281
#define IDS_SUPPORT_TOOL_EAP 9282
#define IDS_SUPPORT_TOOL_CREDIT_CARD 9283
#define IDS_SUPPORT_TOOL_IBAN 9284
#define IDS_SUPPORT_TOOL_CRASH_ID 9285
#define IDS_SUPPORT_TOOL_MEMORY 9286
#define IDS_SUPPORT_TOOL_BLUETOOTH_HID_DEVICE 9287
#define IDS_EXTENSIONS_ALLOW_FILE_ACCESS 9288
#define IDS_EXTENSIONS_ALLOW_ON_ALL_URLS 9289
#define IDS_EXTENSIONS_ALLOW_ON_FOLLOWING_SITES 9290
#define IDS_EXTENSIONS_VIEW_ACTIVITY_LOG 9291
#define IDS_EXTENSIONS_BACKGROUND_PAGE 9292
#define IDS_EXTENSIONS_SERVICE_WORKER_BACKGROUND 9293
#define IDS_EXTENSIONS_CORRUPTED_EXTENSION 9294
#define IDS_EXTENSIONS_ENABLE_ERROR_COLLECTION 9295
#define IDS_EXTENSIONS_ERROR_NO_ERRORS_CODE_MESSAGE 9296
#define IDS_EXTENSIONS_INSTALL_DROP_TARGET 9297
#define IDS_EXTENSIONS_INSTALL_WARNINGS 9298
#define IDS_EXTENSIONS_LOG_LEVEL_ERROR 9299
#define IDS_EXTENSIONS_LOG_LEVEL_INFO 9300
#define IDS_EXTENSIONS_LOG_LEVEL_WARN 9301
#define IDS_EXTENSIONS_PATH 9302
#define IDS_EXTENSIONS_PERMISSIONS_OFF 9303
#define IDS_EXTENSIONS_RELOAD_TERMINATED 9304
#define IDS_EXTENSIONS_REPAIR_CORRUPTED 9305
#define IDS_EXTENSIONS_MOVE_TO_ACCOUNT_ICON_TOOLTIP 9306
#define IDS_EXTENSIONS_VIEW_IFRAME 9307
#define IDS_EXTENSIONS_VIEW_INACTIVE 9308
#define IDS_EXTENSIONS_VIEW_INCOGNITO 9309
#define IDS_EXTENSIONS_DEVELOPER_MODE 9310
#define IDS_EXTENSIONS_DISABLED_UNSUPPORTED_DEVELOPER_MODE 9311
#define IDS_EXTENSIONS_DISABLED_UNSUPPORTED_DEVELOPER_MODE_DETAILS 9312
#define IDS_EXTENSIONS_DISABLED_UNSUPPORTED_DEVELOPER_MODE_TOAST 9313
#define IDS_EXTENSIONS_DISABLED_UPDATE_REQUIRED_BY_POLICY 9314
#define IDS_EXTENSIONS_DISABLED_PUBLISHED_IN_STORE_REQUIRED_BY_POLICY 9315
#define IDS_EXTENSIONS_MATCHING_RESTRICTED_SITES_ALLOW 9316
#define IDS_EXTENSIONS_MATCHING_RESTRICTED_SITES_TITLE 9317
#define IDS_EXTENSIONS_MATCHING_RESTRICTED_SITES_WARNING 9318
#define IDS_EXTENSIONS_MENU_BUTTON_LABEL 9319
#define IDS_EXTENSIONS_ERROR_PAGE_HEADING 9320
#define IDS_EXTENSIONS_EDIT_SITE_PERMISSIONS_ALLOW_ALL_EXTENSIONS 9321
#define IDS_EXTENSIONS_EDIT_SITE_PERMISSIONS_CUSTOMIZE_PER_EXTENSION 9322
#define IDS_EXTENSIONS_EDIT_SITE_PERMISSIONS_RESTRICT_EXTENSIONS 9323
#define IDS_EXTENSIONS_ERROR_ANONYMOUS_FUNCTION 9324
#define IDS_EXTENSIONS_ERROR_CONTEXT 9325
#define IDS_EXTENSIONS_ERROR_CONTEXT_UNKNOWN 9326
#define IDS_EXTENSIONS_CLEAR_ACTIVITIES 9327
#define IDS_EXTENSIONS_ERROR_CLEAR_ALL 9328
#define IDS_EXTENSIONS_A11Y_CLEAR_ENTRY 9329
#define IDS_EXTENSIONS_ERROR_STACK_TRACE 9330
#define IDS_EXTENSIONS_ERROR_LINES_NOT_SHOWN 9331
#define IDS_EXTENSIONS_HOST_PERMISSIONS_DESCRIPTION 9332
#define IDS_EXTENSIONS_PERMISSIONS_LEARN_MORE_A11Y_LABEL 9333
#define IDS_EXTENSIONS_HOST_PERMISSIONS_EDIT 9334
#define IDS_EXTENSIONS_ITEM_ERRORS 9335
#define IDS_EXTENSIONS_ITEM_WARNINGS 9336
#define IDS_EXTENSIONS_ITEM_HOST_PERMISSIONS_HEADING 9337
#define IDS_EXTENSIONS_NEW_HOST_PERMISSIONS_HEADING 9338
#define IDS_EXTENSIONS_HOST_PERMISSIONS_SUB_HEADING 9339
#define IDS_EXTENSIONS_HOST_ACCESS_ON_CLICK 9340
#define IDS_EXTENSIONS_HOST_ACCESS_ASK_ON_EVERY_VISIT 9341
#define IDS_EXTENSIONS_HOST_ACCESS_ON_SPECIFIC_SITES 9342
#define IDS_EXTENSIONS_HOST_ACCESS_ALLOW_ON_SPECIFIC_SITES 9343
#define IDS_EXTENSIONS_HOST_ACCESS_ON_ALL_SITES 9344
#define IDS_EXTENSIONS_HOST_ACCESS_ALLOW_ON_ALL_SITES 9345
#define IDS_EXTENSIONS_ITEM_ALLOWED_HOSTS 9346
#define IDS_EXTENSIONS_ACCESSIBILITY_ERROR_LINE 9347
#define IDS_EXTENSIONS_ACCESSIBILITY_ERROR_MULTI_LINE 9348
#define IDS_EXTENSIONS_ACTIVITY_LOG_PAGE_HEADING 9349
#define IDS_EXTENSIONS_ACTIVITY_LOG_SEARCH_LABEL 9350
#define IDS_EXTENSIONS_ACTIVITY_LOG_TYPE_COLUMN 9351
#define IDS_EXTENSIONS_ACTIVITY_LOG_NAME_COLUMN 9352
#define IDS_EXTENSIONS_ACTIVITY_LOG_COUNT_COLUMN 9353
#define IDS_EXTENSIONS_ACTIVITY_LOG_TIME_COLUMN 9354
#define IDS_EXTENSIONS_ACTIVITY_LOG_HISTORY_TAB_HEADING 9355
#define IDS_EXTENSIONS_ACTIVITY_LOG_STREAM_TAB_HEADING 9356
#define IDS_EXTENSIONS_START_ACTIVITY_STREAM 9357
#define IDS_EXTENSIONS_STOP_ACTIVITY_STREAM 9358
#define IDS_EXTENSIONS_EMPTY_STREAM_STARTED 9359
#define IDS_EXTENSIONS_EMPTY_STREAM_STOPPED 9360
#define IDS_EXTENSIONS_ACTIVITY_ARGUMENTS_HEADING 9361
#define IDS_EXTENSIONS_WEB_REQUEST_INFO_HEADING 9362
#define IDS_EXTENSIONS_ACTIVITY_LOG_MORE_ACTIONS_LABEL 9363
#define IDS_EXTENSIONS_ACTIVITY_LOG_EXPAND_ALL 9364
#define IDS_EXTENSIONS_ACTIVITY_LOG_COLLAPSE_ALL 9365
#define IDS_EXTENSIONS_ACTIVITY_LOG_EXPORT_HISTORY 9366
#define IDS_EXTENSIONS_ITEM_ID 9367
#define IDS_EXTENSIONS_ITEM_INSPECT_VIEWS 9368
#define IDS_EXTENSIONS_ITEM_INSPECT_VIEWS_EXTRA 9369
#define IDS_EXTENSIONS_ITEM_NO_ACTIVE_VIEWS 9370
#define IDS_EXTENSIONS_ITEM_ALLOW_INCOGNITO 9371
#define IDS_EXTENSIONS_ITEM_ALLOW_USER_SCRIPTS 9372
#define IDS_EXTENSIONS_ALLOW_USER_SCRIPTS_WARNING 9373
#define IDS_EXTENSIONS_ITEM_DEPENDENCIES 9374
#define IDS_EXTENSIONS_DEPENDENT_ENTRY 9375
#define IDS_EXTENSIONS_ITEM_DESCRIPTION 9376
#define IDS_EXTENSIONS_ITEM_DETAILS 9377
#define IDS_EXTENSIONS_DETAILS_BACK_BUTTON_ARIA_LABEL 9378
#define IDS_EXTENSIONS_DETAILS_BACK_BUTTON_ARIA_ROLE_DESCRIPTION 9379
#define IDS_EXTENSIONS_EXTENSION_A11Y_ASSOCIATION 9380
#define IDS_EXTENSIONS_APP_ICON 9381
#define IDS_EXTENSIONS_EXTENSION_ICON 9382
#define IDS_EXTENSIONS_ITEM_ID_HEADING 9383
#define IDS_EXTENSIONS_EXTENSION_ENABLED 9384
#define IDS_EXTENSIONS_APP_ENABLED 9385
#define IDS_EXTENSIONS_ITEM_OFF 9386
#define IDS_EXTENSIONS_ITEM_ON 9387
#define IDS_EXTENSIONS_ITEM_EXTENSION_WEBSITE 9388
#define IDS_EXTENSIONS_ITEM_CHROME_WEB_STORE 9389
#define IDS_EXTENSIONS_VIEW_IN_DEVTOOLS 9390
#define IDS_EXTENSIONS_ITEM_OPTIONS 9391
#define IDS_EXTENSIONS_ITEM_PERMISSIONS 9392
#define IDS_EXTENSIONS_ITEM_PERMISSIONS_EMPTY 9393
#define IDS_EXTENSIONS_ITEM_PERMISSIONS_AND_SITE_ACCESS_EMPTY 9394
#define IDS_EXTENSIONS_ITEM_PIN_TO_TOOLBAR 9395
#define IDS_EXTENSIONS_ITEM_REMOVE_EXTENSION 9396
#define IDS_EXTENSIONS_ITEM_SITE_ACCESS 9397
#define IDS_EXTENSIONS_ITEM_SITE_ACCESS_ADD_HOST 9398
#define IDS_EXTENSIONS_ITEM_SITE_ACCESS_EMPTY 9399
#define IDS_EXTENSIONS_REMOVE_SITES_DIALOG_TITLE 9400
#define IDS_EXTENSIONS_ITEM_SOURCE 9401
#define IDS_EXTENSIONS_ITEM_SOURCE_INSTALLED_BY_DEFAULT 9402
#define IDS_EXTENSIONS_ITEM_SOURCE_POLICY 9403
#define IDS_EXTENSIONS_ITEM_SOURCE_SIDELOADED 9404
#define IDS_EXTENSIONS_ITEM_SOURCE_UNPACKED 9405
#define IDS_EXTENSIONS_ITEM_SOURCE_WEBSTORE 9406
#define IDS_EXTENSIONS_ITEM_VERSION 9407
#define IDS_EXTENSIONS_ITEM_RELOADED 9408
#define IDS_EXTENSIONS_ITEM_RELOADING 9409
#define IDS_EXTENSIONS_LOAD_ERROR_HEADING 9410
#define IDS_EXTENSIONS_LOAD_ERROR_ERROR_LABEL 9411
#define IDS_EXTENSIONS_LOAD_ERROR_FILE_LABEL 9412
#define IDS_EXTENSIONS_LOAD_ERROR_COULD_NOT_LOAD_MANIFEST 9413
#define IDS_EXTENSIONS_LOAD_ERROR_RETRY 9414
#define IDS_EXTENSIONS_LOADING_ACTIVITIES 9415
#define IDS_MISSING_OR_UNINSTALLED_EXTENSION 9416
#define IDS_EXTENSIONS_NO_ACTIVITIES 9417
#define IDS_EXTENSIONS_NO_INSTALLED_ITEMS 9418
#define IDS_EXTENSIONS_NO_DESCRIPTION 9419
#define IDS_EXTENSIONS_OPENS_IN_NEW_TAB 9420
#define IDS_EXTENSIONS_PACK_DIALOG_TITLE 9421
#define IDS_EXTENSIONS_PACK_DIALOG_WARNING_TITLE 9422
#define IDS_EXTENSIONS_PACK_DIALOG_ERROR_TITLE 9423
#define IDS_EXTENSIONS_PACK_DIALOG_PROCEED_ANYWAY 9424
#define IDS_EXTENSIONS_PACK_DIALOG_BROWSE_BUTTON 9425
#define IDS_EXTENSIONS_PACK_DIALOG_EXTENSION_ROOT_LABEL 9426
#define IDS_EXTENSIONS_PACK_DIALOG_KEY_FILE_LABEL 9427
#define IDS_EXTENSIONS_PACK_DIALOG_CONFIRM_BUTTON 9428
#define IDS_EXTENSIONS_TOOLBAR_TITLE 9429
#define IDS_EXTENSIONS_SEARCH 9430
#define IDS_EXTENSIONS_SITE_PERMISSIONS 9431
#define IDS_EXTENSIONS_SITE_PERMISSIONS_PAGE_TITLE 9432
#define IDS_EXTENSIONS_SITE_PERMISSIONS_VIEW_ALL_SITES 9433
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALL_SITES_PAGE_TITLE 9434
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALL_SITES_ONE_EXTENSION 9435
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALL_SITES_EXTENSION_COUNT 9436
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALWAYS_ON_ALL_SITES 9437
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ALWAYS_ON_THIS_SITE 9438
#define IDS_EXTENSIONS_SITE_SETTINGS 9439
#define IDS_EXTENSIONS_PERMITTED_SITES 9440
#define IDS_EXTENSIONS_RESTRICTED_SITES 9441
#define IDS_EXTENSIONS_NO_SITES_ADDED 9442
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ADD_SITE_DIALOG_TITLE 9443
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_SITE_DIALOG_TITLE 9444
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_URL 9445
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_PERMISSIONS_DIALOG_TITLE 9446
#define IDS_EXTENSIONS_SITE_PERMISSIONS_EDIT_PERMISSIONS 9447
#define IDS_EXTENSIONS_SITE_PERMISSIONS_ASK_ON_EVERY_VISIT 9448
#define IDS_EXTENSIONS_SITE_PERMISSIONS_DIALOG_INPUT_ERROR 9449
#define IDS_EXTENSIONS_SITE_PERMISSIONS_DIALOG_INPUT_LABEL 9450
#define IDS_EXTENSIONS_SITE_PERMISSIONS_INCLUDES_SUBDOMAINS 9451
#define IDS_EXTENSIONS_EDIT_SHORTCUT_INPUT_LABEL 9452
#define IDS_EXTENSIONS_EDIT_SHORTCUT_BUTTON_LABEL 9453
#define IDS_EXTENSIONS_SET_SHORTCUT_IN_SYSTEM_SETTINGS 9454
#define IDS_EXTENSIONS_SHORTCUT_SCOPE_LABEL 9455
#define IDS_EXTENSIONS_SHORTCUT_SCOPE_GLOBAL 9456
#define IDS_EXTENSIONS_APPS_TITLE 9457
#define IDS_EXTENSIONS_REMOVE 9458
#define IDS_EXTENSIONS_MORE_OPTIONS 9459
#define IDS_EXTENSIONS_RUNTIME_HOSTS_DIALOG_TITLE 9460
#define IDS_EXTENSIONS_RUNTIME_HOSTS_DIALOG_INPUT_ERROR 9461
#define IDS_EXTENSIONS_RUNTIME_HOSTS_DIALOG_INPUT_LABEL 9462
#define IDS_EXTENSIONS_SIDEBAR_EXTENSIONS 9463
#define IDS_EXTENSIONS_SIDEBAR_DISCOVER_MORE 9464
#define IDS_EXTENSIONS_WHATS_NEW_SIDEBAR_PROMO 9465
#define IDS_EXTENSIONS_SIDEBAR_KEYBOARD_SHORTCUTS 9466
#define IDS_EXTENSIONS_TOOLBAR_LOAD_UNPACKED 9467
#define IDS_EXTENSIONS_TOOLBAR_LOAD_UNPACKED_DONE 9468
#define IDS_EXTENSIONS_TOOLBAR_PACK 9469
#define IDS_EXTENSIONS_TOOLBAR_UPDATE_NOW 9470
#define IDS_EXTENSIONS_TOOLBAR_UPDATE_NOW_TOOLTIP 9471
#define IDS_EXTENSIONS_TOOLBAR_UPDATE_DONE 9472
#define IDS_EXTENSIONS_TOOLBAR_UPDATING_TOAST 9473
#define IDS_EXTENSIONS_SUBPAGE_BUTTON 9474
#define IDS_EXTENSIONS_SECTION_HEADER 9475
#define IDS_EXTENSIONS_SAFETY_HUB_HEADER 9476
#define IDS_EXTENSIONS_SC_MALWARE 9477
#define IDS_EXTENSIONS_SC_POLICY_VIOLATION_OFF 9478
#define IDS_EXTENSIONS_SC_POLICY_VIOLATION_ON 9479
#define IDS_EXTENSIONS_SC_UNPUBLISHED_OFF 9480
#define IDS_EXTENSIONS_SC_UNPUBLISHED_ON 9481
#define IDS_EXTENSIONS_SAFETY_CHECK_NO_PRIVACY_PRACTICES_ON 9482
#define IDS_EXTENSIONS_SAFETY_CHECK_NO_PRIVACY_PRACTICES_OFF 9483
#define IDS_EXTENSIONS_SC_TITLE 9484
#define IDS_EXTENSIONS_SC_KEEP_EXT 9485
#define IDS_EXTENSIONS_SC_THREEDOT_DETAILS 9486
#define IDS_EXTENSIONS_SC_REMOVE_ALL 9487
#define IDS_EXTENSIONS_SC_ALL_DONE_FOR_NOW 9488
#define IDS_EXTENSIONS_SC_REMOVE_BUTTON_A11Y_LABEL 9489
#define IDS_EXTENSIONS_SC_OPTION_MENU_A11Y_LABEL 9490
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_TITLE 9491
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_WARNING_HEADER 9492
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_WARNING_SUBTITLE 9493
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_DISABLED_HEADER 9494
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_WARNING_HEADER 9495
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_WARNING_SUBTITLE 9496
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_DISABLED_HEADER 9497
#define IDS_EXTENSIONS_MV2_DEPRECATION_MESSAGE_REMOVE_BUTTON 9498
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_DISMISS_BUTTON 9499
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_FIND_ALTERNATIVE_BUTTON 9500
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_KEEP_FOR_NOW_BUTTON 9501
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_ACTION_MENU_BUTTON_LABEL 9502
#define IDS_EXTENSIONS_MV2_DEPRECATION_PANEL_FIND_ALTERNATIVE_BUTTON_ACC_LABEL 9503
#define IDS_EXTENSIONS_MV2_DEPRECATION_UNSUPPORTED_EXTENSION_OFF_TEXT 9504
#define IDS_EXTENSIONS_CANT_INSTALL_MV2_EXTENSION 9505
#define IDS_EXTENSIONS_ZERO_STATE_IPH_HEADER 9517
#define IDS_EXTENSIONS_ZERO_STATE_IPH_HEADER_V2 9518
#define IDS_EXTENSIONS_ZERO_STATE_CHIPS_IPH_DESCRIPTION 9519
#define IDS_EXTENSIONS_ZERO_STATE_CHIPS_WITH_LINK_IPH_LINK_LABEL 9520
#define IDS_EXTENSIONS_ZERO_STATE_CHIPS_WITH_LINK_IPH_DESCRIPTION 9521
#define IDS_EXTENSIONS_ZERO_STATE_PLAIN_LINK_IPH_DESCRIPTION 9522
#define IDS_EXTENSIONS_ZERO_STATE_IPH_SHOPPING_CATEGORY_LABEL 9523
#define IDS_EXTENSIONS_ZERO_STATE_IPH_WRITING_HELP_COLLECTION_LABEL 9524
#define IDS_EXTENSIONS_ZERO_STATE_IPH_PRODUCTIVITY_CATEGORY_LABEL 9525
#define IDS_EXTENSIONS_ZERO_STATE_IPH_AI_PRODUCTIVITY_COLLECTION_LABEL 9526
#define IDS_EXTENSIONS_ZERO_STATE_IPH_DISMISS_BUTTON_TITLE 9527
#define IDS_EXTENSIONS_ZERO_STATE_IPH_SHOPPING_CATEGORY_LINK 9528
#define IDS_EXTENSIONS_ZERO_STATE_IPH_WRITING_HELP_COLLECTION_LINK 9529
#define IDS_EXTENSIONS_ZERO_STATE_IPH_PRODUCTIVITY_CATEGORY_LINK 9530
#define IDS_EXTENSIONS_ZERO_STATE_IPH_AI_PRODUCTIVITY_COLLECTION_LINK 9531
#define IDS_EXTENSIONS_ZERO_STATE_IPH_WEB_STORE_LINK 9532
#define IDS_EXTENSIONS_ZERO_STATE_IPH_DISMISS_BUTTON_TEXT 9533
#define IDS_NEARBY_CONFIRMATION_PAGE_ADD_CONTACT_SUBTITLE 9534
#define IDS_NEARBY_CONFIRMATION_PAGE_ADD_CONTACT_TITLE 9535
#define IDS_NEARBY_CONFIRMATION_PAGE_TITLE 9536
#define IDS_QUICK_SHARE_V2_VISIBILITY_SECTION_TITLE 9537
#define IDS_QUICK_SHARE_V2_VISIBILITY_SECTION_SUBTITLE_ON_DISABLED 9538
#define IDS_QUICK_SHARE_V2_VISIBILITY_YOUR_DEVICES_SUBLABEL 9539
#define IDS_QUICK_SHARE_V2_VISIBILITY_CONTACTS_SUBLABEL 9540
#define IDS_QUICK_SHARE_V2_VISIBILITY_EVERYONE_LABEL 9541
#define IDS_QUICK_SHARE_V2_VISIBILITY_EVERYONE_SUBLABEL 9542
#define IDS_QUICK_SHARE_V2_VISIBILITY_ONLY_FOR_TEN_MINUTES_LABEL 9543
#define IDS_NEARBY_CONTACT_VISIBILITY_DOWNLOAD_FAILED 9544
#define IDS_NEARBY_CONTACT_VISIBILITY_DOWNLOADING 9545
#define IDS_NEARBY_CONTACT_VISIBILITY_NO_CONTACTS_SUBTITLE 9546
#define IDS_NEARBY_CONTACT_VISIBILITY_NO_CONTACTS_SUBTITLE_PH 9547
#define IDS_NEARBY_CONTACT_VISIBILITY_NO_CONTACTS_TITLE 9548
#define IDS_NEARBY_CONTACT_VISIBILITY_NUM_UNREACHABLE 9549
#define IDS_NEARBY_CONTACT_VISIBILITY_NUM_UNREACHABLE_PH 9550
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_ALL 9551
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_ALL_SELF_SHARE 9552
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_NONE 9553
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_SOME 9554
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_SOME_SELF_SHARE 9555
#define IDS_NEARBY_CONTACT_VISIBILITY_ZERO_STATE_TEXT 9556
#define IDS_NEARBY_CONTACT_VISIBILITY_OWN_YOUR_DEVICES 9557
#define IDS_NEARBY_DEVICE_NAME_EMPTY_ERROR 9558
#define IDS_NEARBY_DEVICE_NAME_TOO_LONG_ERROR 9559
#define IDS_NEARBY_DEVICE_NAME_INVALID_CHARACTERS_ERROR 9560
#define IDS_NEARBY_DISCOVERY_PAGE_INFO 9561
#define IDS_NEARBY_DISCOVERY_PAGE_SUBTITLE 9562
#define IDS_NEARBY_DISCOVERY_PAGE_TITLE 9563
#define IDS_NEARBY_DISCOVERY_PAGE_TITLE_PH 9564
#define IDS_NEARBY_DISCOVERY_PAGE_PLACEHOLDER 9565
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_NAME 9566
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_NAME_HELP 9567
#define IDS_NEARBY_ONBOARDING_PAGE_SUBTITLE 9568
#define IDS_NEARBY_ONBOARDING_PAGE_TITLE 9569
#define IDS_NEARBY_ONBOARDING_PAGE_TITLE_PH 9570
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_VISIBILITY 9571
#define IDS_NEARBY_ONBOARDING_PAGE_DEVICE_VISIBILITY_HELP_ALL_CONTACTS 9572
#define IDS_NEARBY_VISIBILITY_PAGE_MANAGE_CONTACTS 9573
#define IDS_NEARBY_VISIBILITY_PAGE_SUBTITLE 9574
#define IDS_NEARBY_VISIBILITY_PAGE_TITLE 9575
#define IDS_NEARBY_SHARE_FEATURE_NAME 9576
#define IDS_NEARBY_SHARE_FEATURE_NAME_PH 9577
#define IDS_NEARBY_ACTIONS_ACCEPT 9578
#define IDS_NEARBY_ACTIONS_CANCEL 9579
#define IDS_NEARBY_ACTIONS_CLOSE 9580
#define IDS_NEARBY_ACTIONS_CONFIRM 9581
#define IDS_NEARBY_ACTIONS_DECLINE 9582
#define IDS_NEARBY_ACTIONS_NEXT 9583
#define IDS_NEARBY_ACTIONS_REJECT 9584
#define IDS_NEARBY_DEFAULT_DEVICE_NAME 9585
#define IDS_NEARBY_ERROR_CANCELLED 9586
#define IDS_NEARBY_ERROR_CANT_RECEIVE 9587
#define IDS_NEARBY_ERROR_CANT_SHARE 9588
#define IDS_NEARBY_ERROR_NO_RESPONSE 9589
#define IDS_NEARBY_ERROR_TRANSFER_IN_PROGRESS 9590
#define IDS_NEARBY_ERROR_NOT_ENOUGH_SPACE 9591
#define IDS_NEARBY_ERROR_REJECTED 9592
#define IDS_NEARBY_ERROR_SOMETHING_WRONG 9593
#define IDS_NEARBY_ERROR_TIME_OUT 9594
#define IDS_NEARBY_ERROR_TRY_AGAIN 9595
#define IDS_NEARBY_ERROR_UNSUPPORTED_FILE_TYPE 9596
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_APPS 9597
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_APPS 9598
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_IMAGES 9599
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_IMAGES 9600
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_UNKNOWN 9601
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_UNKNOWN 9602
#define IDS_NEARBY_FILE_ATTACHMENTS_CAPITALIZED_VIDEOS 9603
#define IDS_NEARBY_FILE_ATTACHMENTS_NOT_CAPITALIZED_VIDEOS 9604
#define IDS_NEARBY_SECURE_CONNECTION_ID 9605
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_ADDRESSES 9606
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_ADDRESSES 9607
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_LINKS 9608
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_LINKS 9609
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_PHONE_NUMBERS 9610
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_PHONE_NUMBERS 9611
#define IDS_NEARBY_TEXT_ATTACHMENTS_CAPITALIZED_UNKNOWN 9612
#define IDS_NEARBY_TEXT_ATTACHMENTS_NOT_CAPITALIZED_UNKNOWN 9613
#define IDS_NEARBY_CAPITALIZED_UNKNOWN_ATTACHMENTS 9614
#define IDS_NEARBY_NOT_CAPITALIZED_UNKNOWN_ATTACHMENTS 9615
#define IDS_NEARBY_HIGH_VISIBILITY_SUB_TITLE 9616
#define IDS_NEARBY_HIGH_VISIBILITY_SUB_TITLE_MINUTES 9617
#define IDS_NEARBY_HIGH_VISIBILITY_SUB_TITLE_SECONDS 9618
#define IDS_NEARBY_HIGH_VISIBILITY_HELP_TEXT 9619
#define IDS_NEARBY_HIGH_VISIBILITY_TIMEOUT_TEXT 9620
#define IDS_NEARBY_HIGH_VISIBILITY_TRANSFER_IN_PROGRESS_ERROR 9621
#define IDS_NEARBY_HIGH_VISIBILITY_TRANSFER_IN_PROGRESS_DESCRIPTION 9622
#define IDS_NEARBY_HIGH_VISIBILITY_CONNECTION_MEDIUM_ERROR 9623
#define IDS_NEARBY_HIGH_VISIBILITY_CONNECTION_MEDIUM_DESCRIPTION 9624
#define IDS_NEARBY_HIGH_VISIBILITY_CONNECTION_MEDIUM_DESCRIPTION_PH 9625
#define IDS_NEARBY_RECEIVE_CONFIRM_PAGE_TITLE 9626
#define IDS_NEARBY_RECEIVE_CONFIRM_PAGE_CONNECTION_ID 9627
#define IDS_NEARBY_PREVIEW_TITLE_MULTIPLE_FILE 9628
#define IDS_NEARBY_ACCOUNT_ROW_LABEL 9629
#define IDS_NEARBY_ACCOUNT_ROW_LABEL_PH 9630
#define IDS_NEARBY_SETTINGS_HELP_CAPTION_TOP 9631
#define IDS_NEARBY_SETTINGS_HELP_CAPTION_TOP_PH 9632
#define IDS_NEARBY_SETTINGS_HELP_CAPTION_BOTTOM 9633
#define IDS_NEARBY_VISIBLITY_ALL_CONTACTS 9634
#define IDS_NEARBY_VISIBLITY_ALL_CONTACTS_DESCRIPTION 9635
#define IDS_NEARBY_VISIBILITY_CONTACTS_BUTTON 9636
#define IDS_NEARBY_VISIBLITY_SOME_CONTACTS 9637
#define IDS_NEARBY_VISIBLITY_SOME_CONTACTS_DESCRIPTION 9638
#define IDS_NEARBY_VISIBILITY_YOUR_DEVICES 9639
#define IDS_NEARBY_VISIBILITY_YOUR_DEVICES_DESCRIPTION 9640
#define IDS_NEARBY_VISIBILITY_ALL_CONTACTS_TOGGLE 9641
#define IDS_NEARBY_VISIBLITY_HIDDEN 9642
#define IDS_NEARBY_VISIBLITY_HIDDEN_DESCRIPTION 9643
#define IDS_NEARBY_VISIBLITY_UNKNOWN 9644
#define IDS_NEARBY_VISIBLITY_UNKNOWN_DESCRIPTION 9645
#define IDS_NEARBY_NOTIFICATION_ACTION_COPY_TO_CLIPBOARD 9646
#define IDS_NEARBY_NOTIFICATION_ACTION_OPEN_FOLDER 9647
#define IDS_NEARBY_NOTIFICATION_ACTION_OPEN_NETWORK_LIST 9648
#define IDS_NEARBY_NOTIFICATION_ACTION_OPEN_URL 9649
#define IDS_NEARBY_NOTIFICATION_ACCEPT_ACTION 9650
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_MESSAGE 9651
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_MESSAGE_WIFI_CREDENTIALS 9652
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_TITLE 9653
#define IDS_NEARBY_NOTIFICATION_CONNECTION_REQUEST_TITLE_PH 9654
#define IDS_NEARBY_NOTIFICATION_DECLINE_ACTION 9655
#define IDS_NEARBY_NOTIFICATION_ONBOARDING_MESSAGE 9656
#define IDS_NEARBY_NOTIFICATION_ONBOARDING_MESSAGE_PH 9657
#define IDS_NEARBY_NOTIFICATION_GO_VISIBLE_MESSAGE 9658
#define IDS_NEARBY_NOTIFICATION_ONBOARDING_TITLE 9659
#define IDS_NEARBY_NOTIFICATION_SET_UP_ACTION 9660
#define IDS_NEARBY_NOTIFICATION_GO_VISIBLE_ACTION 9661
#define IDS_NEARBY_NOTIFICATION_VISIBILITY_REMINDER_TITLE 9662
#define IDS_NEARBY_NOTIFICATION_VISIBILITY_REMINDER_MESSAGE 9663
#define IDS_NEARBY_NOTIFICATION_GO_TO_SETTINGS_ACTION 9664
#define IDS_NEARBY_NOTIFICATION_DISMISS_ACTION 9665
#define IDS_NEARBY_NOTIFICATION_RECEIVE_FAILURE_TITLE 9666
#define IDS_NEARBY_NOTIFICATION_RECEIVE_FAILURE_TITLE_WIFI_CREDENTIALS 9667
#define IDS_NEARBY_NOTIFICATION_RECEIVE_PROGRESS_TITLE 9668
#define IDS_NEARBY_NOTIFICATION_RECEIVE_PROGRESS_TITLE_WIFI_CREDENTIALS 9669
#define IDS_NEARBY_NOTIFICATION_RECEIVE_SUCCESS_TITLE 9670
#define IDS_NEARBY_NOTIFICATION_RECEIVE_SUCCESS_TITLE_WIFI_CREDENTIALS 9671
#define IDS_NEARBY_NOTIFICATION_SEND_FAILURE_TITLE 9672
#define IDS_NEARBY_NOTIFICATION_SEND_PROGRESS_TITLE 9673
#define IDS_NEARBY_NOTIFICATION_SEND_SUCCESS_TITLE 9674
#define IDS_NEARBY_NOTIFICATION_SOURCE 9675
#define IDS_NEARBY_NOTIFICATION_SOURCE_PH 9676
#define IDS_NEARBY_NOTIFICATION_SENDER_CANCELLED 9677
#define IDS_WHATS_NEW_TITLE 9678
#define IDS_PASSWORD_MANAGER_UI_TITLE 9679
#define IDS_PASSWORD_MANAGER_UI_DESCRIPTION 9680
#define IDS_PASSWORD_MANAGER_UI_SEARCH_PROMPT 9681
#define IDS_PASSWORD_MANAGER_UI_CHECKUP 9682
#define IDS_PASSWORD_MANAGER_UI_PASSWORDS 9683
#define IDS_PASSWORD_MANAGER_UI_SETTINGS 9684
#define IDS_PASSWORD_MANAGER_UI_SAVE_PASSWORDS_TOGGLE_LABEL 9685
#define IDS_PASSWORD_MANAGER_UI_AUTOSIGNIN_TOGGLE_LABEL 9686
#define IDS_PASSWORD_MANAGER_UI_AUTOSIGNIN_TOGGLE_DESC 9687
#define IDS_PASSWORD_MANAGER_UI_PASSWORDS_DESCRIPTION 9688
#define IDS_PASSWORD_MANAGER_UI_ADD_PASSWORD_BUTTON 9689
#define IDS_PASSWORD_MANAGER_UI_ADD_SHORTCUT_TITLE 9690
#define IDS_PASSWORD_MANAGER_UI_ADD_SHORTCUT_DESCRIPTION 9691
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPT_IN_TITLE 9692
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPT_IN_DESCRIPTION 9693
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPTED_IN_TITLE 9694
#define IDS_PASSWORD_MANAGER_UI_TRUSTED_VAULT_OPTED_IN_DESCRIPTION 9695
#define IDS_PASSWORD_MANAGER_UI_SHARE 9696
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_ERROR_DESCRIPTION 9697
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_ERROR_TITLE 9698
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_LOADING_TITLE 9699
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_SUCCESS_TITLE 9700
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CANCELED_TITLE 9701
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_NOT_FAMILY_MEMBER 9702
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_NO_OTHER_FAMILY_MEMBERS 9703
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_FAMILY_PICKER_DESCRIPTION 9704
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_DESCRIPTION_SINGLE 9705
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_DESCRIPTION_MULTIPLE 9706
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_FOOTER_WEBSITE 9707
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_CONFIRMATION_FOOTER_ANDROID_APP 9708
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_VIEW_FAMILY 9709
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_MEMBER_UNAVAILABLE 9710
#define IDS_PASSWORD_MANAGER_UI_SHARING_IS_MANAGED_BY_ADMIN 9711
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_NOT_AVAILABLE 9712
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_TRY_AGAIN 9713
#define IDS_PASSWORD_MANAGER_UI_SHARE_PASSWORD_GOT_IT 9714
#define IDS_PASSWORD_MANAGER_UI_SHARE_DIALOG_TITLE 9715
#define IDS_PASSWORD_MANAGER_UI_IMPORT_BANNER_TITLE 9716
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DESCRIPTION_ACCOUNT_STORE_USERS 9717
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DESCRIPTION_SYNCING_USERS 9718
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DESCRIPTION_SIGNEDOUT_USERS 9719
#define IDS_PASSWORD_MANAGER_UI_STORE_PICKER_OPTION_DEVICE 9720
#define IDS_PASSWORD_MANAGER_UI_STORE_PICKER_OPTION_ACCOUNT 9721
#define IDS_PASSWORD_MANAGER_UI_IMPORT_STORE_PICKER_ACCESSIBLE_NAME 9722
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SELECT_FILE_DESCRIPTION 9723
#define IDS_PASSWORD_MANAGER_UI_SELECT_FILE 9724
#define IDS_PASSWORD_MANAGER_UI_IMPORT_MISSING_PASSWORD 9725
#define IDS_PASSWORD_MANAGER_UI_IMPORT_MISSING_URL 9726
#define IDS_PASSWORD_MANAGER_UI_IMPORT_INVALID_URL 9727
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_URL 9728
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_USERNAME 9729
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_PASSWORD 9730
#define IDS_PASSWORD_MANAGER_UI_IMPORT_LONG_NOTE 9731
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICT_ACCOUNT 9732
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICT_DEVICE 9733
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_UNKNOWN 9734
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_BAD_FORMAT 9735
#define IDS_PASSWORD_MANAGER_UI_IMPORT_FILE_SIZE_EXCEEDED 9736
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_LIMIT_EXCEEDED 9737
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ERROR_TITLE 9738
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_TITLE 9739
#define IDS_PASSWORD_MANAGER_UI_IMPORT_COMPLETE_TITLE 9740
#define IDS_PASSWORD_MANAGER_UI_IMPORT_DELETE_FILE_OPTION 9741
#define IDS_PASSWORD_MANAGER_UI_IMPORT_VIEW_PASSWORDS 9742
#define IDS_PASSWORD_MANAGER_UI_IMPORT_ALREADY_ACTIVE 9743
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_TIP 9744
#define IDS_PASSWORD_MANAGER_UI_IMPORT_FAILURES_SUMMARY 9745
#define IDS_PASSWORD_MANAGER_UI_IMPORT_BAD_ROWS_FORMAT 9746
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_SUMMARY_ACCOUNT 9747
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SUCCESS_SUMMARY_DEVICE 9748
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICTS_TITLE 9749
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CONFLICTS_DESCRIPTION 9750
#define IDS_PASSWORD_MANAGER_UI_IMPORT_CANCEL 9751
#define IDS_PASSWORD_MANAGER_UI_IMPORT_SKIP 9752
#define IDS_PASSWORD_MANAGER_UI_IMPORT_REPLACE 9753
#define IDS_PASSWORD_MANAGER_UI_EXPORT_TITLE 9754
#define IDS_PASSWORD_MANAGER_UI_DOWNLOAD_FILE 9755
#define IDS_PASSWORD_MANAGER_UI_EXPORT_BANNER_DESCRIPTION 9756
#define IDS_PASSWORD_MANAGER_UI_EXPORT_SUCCESSFUL 9757
#define IDS_PASSWORD_MANAGER_UI_EXPORT_TRY_AGAIN 9758
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TITLE 9759
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TIPS 9760
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TIP_ENOUGH_SPACE 9761
#define IDS_PASSWORD_MANAGER_UI_EXPORTING_FAILURE_TIP_ANOTHER_FOLDER 9762
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_TITLE 9763
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_RESULT 9764
#define IDS_PASSWORD_MANAGER_UI_JUST_NOW 9765
#define IDS_PASSWORD_MANAGER_UI_COMPROMISED_PASSWORDS_COUNT 9766
#define IDS_PASSWORD_MANAGER_UI_NO_COMPROMISED_PASSWORDS 9767
#define IDS_PASSWORD_MANAGER_UI_HAS_COMPROMISED_PASSWORDS 9768
#define IDS_PASSWORD_MANAGER_UI_REUSED_PASSWORDS_COUNT 9769
#define IDS_PASSWORD_MANAGER_UI_NO_REUSED_PASSWORDS 9770
#define IDS_PASSWORD_MANAGER_UI_HAS_REUSED_PASSWORDS 9771
#define IDS_PASSWORD_MANAGER_UI_WEAK_PASSWORDS_COUNT 9772
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_GREEN_STATE_A11Y 9773
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_YELLOW_STATE_A11Y 9774
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_RED_STATE_A11Y 9775
#define IDS_PASSWORD_MANAGER_UI_NO_WEAK_PASSWORDS 9776
#define IDS_PASSWORD_MANAGER_UI_HAS_WEAK_PASSWORDS 9777
#define IDS_PASSWORD_MANAGER_UI_CHECK_PASSWORDS_AFTER_ERROR 9778
#define IDS_PASSWORD_MANAGER_UI_BLOCKED_SITES_TITLE 9779
#define IDS_PASSWORD_MANAGER_UI_BLOCKED_SITES_DESCRIPTION 9780
#define IDS_PASSWORD_MANAGER_UI_ALLOWED_ACTOR_LOGIN_SITES_TITLE 9781
#define IDS_PASSWORD_MANAGER_UI_ALLOWED_ACTOR_LOGIN_SITES_DESCRIPTION 9782
#define IDS_PASSWORD_MANAGER_UI_REMOVE_ACTOR_LOGIN_PERMISSION_DIALOG_TITLE 9783
#define IDS_PASSWORD_MANAGER_UI_REMOVE_ACTOR_LOGIN_PERMISSION_DIALOG_DESCRIPTION 9784
#define IDS_PASSWORD_MANAGER_UI_REMOVE_ACTOR_LOGIN_PERMISSION_DIALOG_CONFIRMATION 9785
#define IDS_PASSWORD_MANAGER_UI_NUMBER_OF_ACCOUNTS 9786
#define IDS_PASSWORD_MANAGER_UI_USERNAME_LABEL 9787
#define IDS_PASSWORD_MANAGER_UI_SITES_LABEL 9788
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LABEL 9789
#define IDS_PASSWORD_MANAGER_UI_NOTE_LABEL 9790
#define IDS_PASSWORD_MANAGER_UI_NO_NOTE_ADDED 9791
#define IDS_PASSWORD_MANAGER_UI_COPY_PASSWORD 9792
#define IDS_PASSWORD_MANAGER_UI_COPY_USERNAME 9793
#define IDS_PASSWORD_MANAGER_UI_SHOW_PASSWORD 9794
#define IDS_PASSWORD_MANAGER_UI_HIDE_PASSWORD 9795
#define IDS_PASSWORD_MANAGER_UI_SHOW_PASSWORD_A11Y 9796
#define IDS_PASSWORD_MANAGER_UI_HIDE_PASSWORD_A11Y 9797
#define IDS_PASSWORD_MANAGER_UI_FEDERATION_LABEL 9798
#define IDS_PASSWORD_MANAGER_UI_USERNAME_COPIED_TO_CLIPBOARD 9799
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_COPIED_TO_CLIPBOARD 9800
#define IDS_PASSWORD_MANAGER_UI_ADD_PASSWORD 9801
#define IDS_PASSWORD_MANAGER_UI_WEBSITE_LABEL 9802
#define IDS_PASSWORD_MANAGER_UI_ADD_PASSWORD_FOOTNOTE 9803
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LEAKED 9804
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_PHISHED 9805
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_PHISHED_AND_LEAKED 9806
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_BUTTON 9807
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_BUTTON_ARIA_DESCRIPTION 9808
#define IDS_PASSWORD_MANAGER_UI_MORE_ACTIONS 9809
#define IDS_PASSWORD_MANAGER_UI_MORE_ACTIONS_ARIA_DESCRIPTION 9810
#define IDS_PASSWORD_MANAGER_UI_COMPROMISED_PASSWORDS_DESCRIPTION 9811
#define IDS_PASSWORD_MANAGER_UI_REUSED_PASSWORDS_DESCRIPTION 9812
#define IDS_PASSWORD_MANAGER_UI_WEAK_PASSWORDS_DESCRIPTION 9813
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_SIGNED_OUT 9814
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_OFFLINE 9815
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_COMPROMISED_SECTION 9816
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_NO_PASSWORDS 9817
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_QUOTA_LIMIT 9818
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_OTHER_ERROR 9819
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_RUNNING_LABEL 9820
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROGRESS 9821
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_CANCELED 9822
#define IDS_PASSWORD_MANAGER_UI_MUTED_COMPROMISED_PASSWORDS 9823
#define IDS_PASSWORD_MANAGER_UI_MUTE_ISSUE 9824
#define IDS_PASSWORD_MANAGER_UI_UNMUTE_ISSUE 9825
#define IDS_PASSWORD_MANAGER_UI_NUMBER_OF_CREDENTIALS_WITH_REUSED_PASSWORD 9826
#define IDS_PASSWORD_MANAGER_UI_HELP 9827
#define IDS_PASSWORD_MANAGER_UI_EDIT_PASSWORD 9834
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_EDIT_FOOTNOTE 9835
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DELETED 9836
#define IDS_PASSWORD_MANAGER_UI_UNDO 9837
#define IDS_PASSWORD_MANAGER_UI_SEARCH_RESULT 9838
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_IN_APP 9839
#define IDS_PASSWORD_MANAGER_UI_CHANGE_PASSWORD_MANAGER_PIN 9840
#define IDS_PASSWORD_MANAGER_UI_ALREADY_CHANGED_PASSWORD 9841
#define IDS_PASSWORD_MANAGER_UI_EDIT_DISCLAIMER_DESCRIPTION 9842
#define IDS_PASSWORD_MANAGER_UI_EDIT_DISCLAIMER_TITLE 9843
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSWORD_CONFIRMATION_TITLE 9844
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSWORD_CONFIRMATION_DESCRIPTION 9845
#define IDS_PASSWORD_MANAGER_UI_SHOW_MORE 9846
#define IDS_PASSWORD_MANAGER_UI_NOT_VALID_WEB_ADDRESS 9847
#define IDS_PASSWORD_MANAGER_UI_MISSING_TLD 9848
#define IDS_PASSWORD_MANAGER_UI_USERNAME_ALREADY_USED 9849
#define IDS_PASSWORD_MANAGER_UI_NOTE_CHARACTER_COUNT 9850
#define IDS_PASSWORD_MANAGER_UI_NOTE_CHARACTER_COUNT_WARNING 9851
#define IDS_PASSWORD_MANAGER_UI_AUTH_TIMED_OUT 9852
#define IDS_PASSWORD_MANAGER_UI_AUTH_TIMED_OUT_DESCRIPTION 9853
#define IDS_PASSWORD_MANAGER_UI_VIEW_EXISTING_PASSWORD 9854
#define IDS_PASSWORD_MANAGER_UI_VIEW_EXISTING_PASSWORD_ARIA_DESCRIPTION 9855
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TO_ACCOUNT 9856
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TO_ACCOUNT_DIALOG_DESCRIPTION 9857
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_TO_ACCOUNT_DIALOG_DESCRIPTION 9858
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TO_ACCOUNT_DIALOG_PASSWORDS_TITLE 9859
#define IDS_PASSWORD_MANAGER_UI_OPENS_IN_NEW_TAB 9860
#define IDS_PASSWORD_MANAGER_UI_VIEW_PASSWORD_ARIA_DESCRIPTION 9861
#define IDS_PASSWORD_MANAGER_UI_RUN_CHECKUP_ARIA_DESCRIPTION 9862
#define IDS_PASSWORD_MANAGER_UI_REMOVE_BLOCKED_SITE_ARIA_DESCRIPTION 9863
#define IDS_PASSWORD_MANAGER_UI_EMPTY_STATE_ACCOUNT_STORE_USERS 9864
#define IDS_PASSWORD_MANAGER_UI_EMPTY_STATE_SYNCING_USERS 9865
#define IDS_PASSWORD_MANAGER_UI_EMPTY_STATE_SIGNEDOUT_USERS 9866
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROMO_CARD_TITLE 9867
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROMO_CARD_DESCRIPTION 9868
#define IDS_PASSWORD_MANAGER_UI_CHECKUP_PROMO_CARD_ACTION 9869
#define IDS_PASSWORD_MANAGER_UI_WEB_PROMO_CARD_TITLE 9870
#define IDS_PASSWORD_MANAGER_UI_WEB_PROMO_CARD_DESCRIPTION 9871
#define IDS_PASSWORD_MANAGER_UI_SHORTCUT_PROMO_CARD_TITLE 9872
#define IDS_PASSWORD_MANAGER_UI_SHORTCUT_PROMO_CARD_DESCRIPTION 9873
#define IDS_PASSWORD_MANAGER_UI_ANY_DEVICE_PROMO_CARD_TITLE 9874
#define IDS_PASSWORD_MANAGER_UI_ANY_DEVICE_PROMO_CARD_DESCRIPTION 9875
#define IDS_PASSWORD_MANAGER_UI_ACCOUNT_STORAGE_TOGGLE_SUB_LABEL 9876
#define IDS_PASSWORD_MANAGER_UI_ACCOUNT_STORAGE_WITH_PASSKEYS_TOGGLE_LABEL 9877
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_TITLE 9878
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_BODY 9879
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_FROM_ACCOUNT_CHECKBOX_LABEL 9880
#define IDS_PASSWORD_MANAGER_UI_DELETE_DIALOG_FROM_DEVICE_CHECKBOX_LABEL 9881
#define IDS_PASSWORD_MANAGER_UI_APPS_LABEL 9882
#define IDS_PASSWORD_MANAGER_UI_SITES_AND_APPS_LABEL 9883
#define IDS_PASSWORD_MANAGER_UI_BACK_TO_CHECKUP_ARIA_DESCRIPTION 9884
#define IDS_PASSWORD_MANAGER_UI_BACK_TO_PASSWORDS_ARIA_DESCRIPTION 9885
#define IDS_PASSWORD_MANAGER_UI_BACK_TO_PASSWORD_SETTINGS_ARIA_DESCRIPTION 9886
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_TITLE 9887
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_DESCRIPTION 9888
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_BUTTON 9889
#define IDS_PASSWORD_MANAGER_UI_NO_PASSWORDS_FOUND 9892
#define IDS_PASSWORD_MANAGER_UI_EDIT_PASSKEY 9893
#define IDS_PASSWORD_MANAGER_UI_DISPLAY_NAME_LABEL 9894
#define IDS_PASSWORD_MANAGER_UI_DISPLAY_NAME_PLACEHOLDER 9895
#define IDS_PASSWORD_MANAGER_UI_USERNAME_PLACEHOLDER 9896
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSKEY_CONFIRMATION_TITLE 9897
#define IDS_PASSWORD_MANAGER_UI_DELETE_PASSKEY_CONFIRMATION_DESCRIPTION 9898
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_HIDDEN_INFO_LABEL 9899
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_MANAGEMENT_INFO_LABEL 9900
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_UPGRADE_TOGGLE_LABEL 9901
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_UPGRADE_TOGGLE_SUBLABEL 9902
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_TITLE 9903
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_DESCRIPTION 9904
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_BUTTON 9905
#define IDS_PASSKEYS_MANAGER_UI_UNENROLL_TOAST_MESSAGE 9906
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_TITLE 9907
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DESCRIPTION 9908
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DELETE_ALL 9909
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRM 9910
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_SUCCESS_TOAST 9911
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRMATION_TITLE 9912
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRMATION_TITLE_LOCAL 9913
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_CONFIRMATION_DESCIPTION 9914
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DOMAINS_DISPLAY_ONE 9915
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DOMAINS_DISPLAY_TWO 9916
#define IDS_PASSWORD_MANAGER_UI_FULL_RESET_DOMAINS_DISPLAY_TWO_AND_X_MORE 9917
#define IDS_PASSWORD_MANAGER_PASSWORDS_COUNTER 9918
#define IDS_PASSWORD_MANAGER_PASSKEYS_COUNTER 9919
#define IDS_PASSWORD_MANAGER_UI_COPY_DISPLAY_NAME_LABEL 9920
#define IDS_PASSWORD_MANAGER_UI_DISPLAY_NAME_COPIED_TO_CLIPBOARD 9921
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DELETED 9922
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LIST_ARIA_LABEL 9923
#define IDS_PASSWORD_MANAGER_UI_DEVICE_ONLY_PASSWORDS_ICON_TOOLTIP 9924
#define IDS_PASSWORD_MANAGER_UI_MOVE_TO_ACCOUNT_ICON_TOOLTIP 9925
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_ARIA_LABEL 9926
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_DETAILS_CARD_ARIA_LABEL 9927
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_EDIT_BUTTON_ARIA_LABEL 9928
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_EDIT_BUTTON_NO_USERNAME_ARIA_LABEL 9929
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_DELETE_BUTTON_ARIA_LABEL 9930
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_DELETE_BUTTON_NO_USERNAME_ARIA_LABEL 9931
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_SHARE_BUTTON_ARIA_LABEL 9932
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_DETAILS_CARD_SHARE_BUTTON_NO_USERNAME_ARIA_LABEL 9933
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_NO_USERNAME_ARIA_LABEL 9934
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_ARIA_LABEL 9935
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_EDIT_BUTTON_ARIA_LABEL 9936
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_EDIT_BUTTON_NO_USERNAME_ARIA_LABEL 9937
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_DELETE_BUTTON_ARIA_LABEL 9938
#define IDS_PASSWORD_MANAGER_UI_PASSKEY_DETAILS_CARD_DELETE_BUTTON_NO_USERNAME_ARIA_LABEL 9939
#define IDS_PASSWORD_MANAGER_UI_FEDERATED_CREDENTIAL_ARIA_LABEL 9940
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_TO_ACCOUNT 9941
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_TITLE 9942
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_DESCRIPTION 9943
#define IDS_PASSWORD_MANAGER_UI_MOVE_SINGLE_PASSWORD_ACTION_BUTTON 9944
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_IN_SETTINGS_SUB_LABEL 9945
#define IDS_PASSWORD_MANAGER_UI_RELAUNCH_CHROME_PROMO_CARD_TITLE_LINUX 9948
#define IDS_PASSWORD_MANAGER_UI_RELAUNCH_CHROME_PROMO_CARD_DESCRIPTION_LINUX 9949
#define IDS_PASSWORD_MANAGER_UI_RELAUNCH_CHROME_PROMO_CARD_ACTION 9950
#define IDS_PASSWORD_MANAGER_UI_NO_USERNAME 9951
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_MOVED_TOAST_MESSAGE 9952
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_PROMO_CARD_TITLE 9953
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_PROMO_CARD_DESCRIPTION 9954
#define IDS_PASSWORD_MANAGER_UI_MOVE_PASSWORDS_PROMO_CARD_ACTION_BUTTON 9955
#define IDS_PASSWORD_MANAGER_UI_BATCH_UPLOAD_PROMO_CARD_TITLE 9956
#define IDS_PASSWORD_MANAGER_UI_BATCH_UPLOAD_PROMO_CARD_ACTION_BUTTON 9957
#define IDS_PASSWORD_MANAGER_SAVE_IN_ACCOUNT_BUBBLE_DESCRIPTION 9958
#define IDS_PASSWORD_MANAGER_SAVE_IN_ACCOUNT_BUBBLE_TITLE 9959
#define IDS_PASSWORD_MANAGER_SAVE_IN_ACCOUNT_BUBBLE_SAVE_BUTTON 9960
#define IDS_PASSWORD_MANAGER_MANAGEMENT_BUBBLE_LIST_ITEM_DEVICE_ONLY_ACCESSIBLE_TEXT 9961
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_LIST_ITEM_ARIA_LABEL 9962
#define IDS_PASSWORD_MANAGER_UI_PROMO_CARD_ARIA_LABEL 9963
#define IDS_PASSWORD_MANAGER_UI_CLOSE_PROMO_CARD_BUTTON_ARIA_LABEL 9964
#define IDS_PASSWORD_MANAGER_PIN_CHANGED 9965
#define IDS_PASSWORD_MANAGER_UI_CONFIRM 9966
#define IDS_PASSWORD_MANAGER_UI_DISCONNECT_CLOUD_AUTHENTICATOR_DIALOG_TITLE 9967
#define IDS_PASSWORD_MANAGER_UI_DISCONNECT_CLOUD_AUTHENTICATOR_DIALOG_DESCRIPTION 9968
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_CANCEL 9969
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_CONTINUE 9970
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGED_TITLE 9971
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_FAILED_TITLE 9972
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_FAILED_BODY 9973
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_FAILED_ACCEPT_BUTTON 9974
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_OMNIBOX_SIGN_IN_CHECK 9975
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_OMNIBOX_CHANGING_PASSWORD 9976
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_TOAST_SIGN_IN_TO_CONTINUE 9977
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_CHANGE_PASSWORD 9978
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_TITLE 9979
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_DETAILS_WITHOUT_PRIVACY_NOTICE 9980
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_DETAILS_WITH_PRIVACY_NOTICE 9981
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_LINK_WITHOUT_PRIVACY_NOTICE 9982
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_LEAK_DIALOG_LINK_WITH_PRIVACY_NOTICE 9983
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_PRIVACY_NOTICE 9984
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_SETTINGS_DESCRIPTION 9985
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_SETTINGS_TITLE 9986
#define IDS_SETTINGS_PASSWORD_CHANGE_SUBLABEL_WITH_LEARN_MORE 9987
#define IDS_PASSWORD_MANAGER_UI_OTP_DURING_PASSWORD_CHANGE_TITLE 9988
#define IDS_PASSWORD_MANAGER_UI_OTP_DURING_PASSWORD_CHANGE_BODY 9989
#define IDS_PASSWORD_MANAGER_UI_OTP_DURING_PASSWORD_CHANGE_ACTION 9990
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_SETTINGS_DESCRIPTION 9991
#define IDS_PASSWORD_MANAGER_UI_BACKUP_PASSWORD_SETTINGS_DESCRIPTION_DETAILS 9992
#define IDS_PASSWORD_MANAGER_UI_OTP_DIALOG_TITLE 9993
#define IDS_PASSWORD_MANAGER_UI_OTP_DIALOG_DETAILS 9994
#define IDS_PASSWORD_MANAGER_UI_VIEW_DETAILS_BUTTON 9995
#define IDS_PASSWORD_MANAGER_UI_USER_INTERVENTION_NEEDED_TITLE 9996
#define IDS_PASSWORD_MANAGER_UI_USER_INTERVENTION_NEEDED_DIALOG_DETAILS 9997
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_TAKE_OVER_TASK_BUTTON 9998
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_UNCHANGED 9999
#define IDS_PASSWORD_MANAGER_UI_PASSWORD_CHANGE_TOAST_RETRY_BUTTON 10000
#define IDS_UTILITY_PROCESS_PRINTING_SERVICE_NAME 10001
#define IDS_UTILITY_PROCESS_PRINT_BACKEND_SERVICE_NAME 10002
#define IDS_PRINT_INVALID_PRINTER_SETTINGS 10003
#define IDS_PRINT_PREVIEW_TITLE 10004
#define IDS_PRINT_PREVIEW_DESCRIPTION 10005
#define IDS_PRINT_PREVIEW_LOADING 10006
#define IDS_PRINT_PREVIEW_FAILED 10007
#define IDS_PRINT_PREVIEW_INVALID_PRINTER_SETTINGS 10008
#define IDS_PRINT_PREVIEW_PRINT_BUTTON 10009
#define IDS_PRINT_PREVIEW_SAVE_BUTTON 10010
#define IDS_PRINT_PREVIEW_PRINTING 10011
#define IDS_PRINT_PREVIEW_SAVING 10012
#define IDS_PRINT_PREVIEW_OPTION_ALL_PAGES 10013
#define IDS_PRINT_PREVIEW_OPTION_ODD_PAGES 10014
#define IDS_PRINT_PREVIEW_OPTION_EVEN_PAGES 10015
#define IDS_PRINT_PREVIEW_OPTION_CUSTOM_PAGES 10016
#define IDS_PRINT_PREVIEW_DESTINATION_LABEL 10017
#define IDS_PRINT_PREVIEW_OPTION_BW 10018
#define IDS_PRINT_PREVIEW_OPTION_COLLATE 10019
#define IDS_PRINT_PREVIEW_OPTION_COLOR 10020
#define IDS_PRINT_PREVIEW_OPTION_LANDSCAPE 10021
#define IDS_PRINT_PREVIEW_OPTION_PORTRAIT 10022
#define IDS_PRINT_PREVIEW_OPTION_TWO_SIDED 10023
#define IDS_PRINT_PREVIEW_PRINT_ON_BOTH_SIDES_LABEL 10024
#define IDS_PRINT_PREVIEW_OPTION_LONG_EDGE 10025
#define IDS_PRINT_PREVIEW_OPTION_SHORT_EDGE 10026
#define IDS_PRINT_PREVIEW_PAGES_LABEL 10027
#define IDS_PRINT_PREVIEW_LAYOUT_LABEL 10028
#define IDS_PRINT_PREVIEW_COPIES_LABEL 10029
#define IDS_PRINT_PREVIEW_SCALING_LABEL 10030
#define IDS_PRINT_PREVIEW_OPTION_DEFAULT_SCALING 10031
#define IDS_PRINT_PREVIEW_OPTION_CUSTOM_SCALING 10032
#define IDS_PRINT_PREVIEW_PAGES_PER_SHEET_LABEL 10033
#define IDS_PRINT_PREVIEW_EXAMPLE_PAGE_RANGE_TEXT 10034
#define IDS_PRINT_PREVIEW_PRINT_TO_PDF 10035
#define IDS_PRINT_PREVIEW_SHEET_SUMMARY_LABEL 10036
#define IDS_PRINT_PREVIEW_PAGE_SUMMARY_LABEL 10037
#define IDS_PRINT_PREVIEW_PAGE_RANGE_SYNTAX_INSTRUCTION 10038
#define IDS_PRINT_PREVIEW_PAGE_RANGE_LIMIT_INSTRUCTION_WITH_VALUE 10039
#define IDS_PRINT_PREVIEW_COPIES_INSTRUCTION 10040
#define IDS_PRINT_PREVIEW_SCALING_INSTRUCTION 10041
#define IDS_PRINT_PREVIEW_PRINT_PAGES_LABEL 10042
#define IDS_PRINT_PREVIEW_OPTIONS_LABEL 10043
#define IDS_PRINT_PREVIEW_OPTION_HEADER_FOOTER 10044
#define IDS_PRINT_PREVIEW_OPTION_FIT_TO_PAGE 10045
#define IDS_PRINT_PREVIEW_OPTION_FIT_TO_PAPER 10046
#define IDS_PRINT_PREVIEW_OPTION_ACTUAL_SIZE 10047
#define IDS_PRINT_PREVIEW_OPTION_BACKGROUND_COLORS_AND_IMAGES 10048
#define IDS_PRINT_PREVIEW_OPTION_SELECTION_ONLY 10049
#define IDS_PRINT_PREVIEW_OPTION_RASTERIZE 10050
#define IDS_PRINT_PREVIEW_MARGINS_LABEL 10051
#define IDS_PRINT_PREVIEW_DEFAULT_MARGINS 10052
#define IDS_PRINT_PREVIEW_NO_MARGINS 10053
#define IDS_PRINT_PREVIEW_CUSTOM_MARGINS 10054
#define IDS_PRINT_PREVIEW_MINIMUM_MARGINS 10055
#define IDS_PRINT_PREVIEW_TOP_MARGIN_LABEL 10056
#define IDS_PRINT_PREVIEW_BOTTOM_MARGIN_LABEL 10057
#define IDS_PRINT_PREVIEW_LEFT_MARGIN_LABEL 10058
#define IDS_PRINT_PREVIEW_RIGHT_MARGIN_LABEL 10059
#define IDS_PRINT_PREVIEW_MEDIA_SIZE_LABEL 10060
#define IDS_PRINT_PREVIEW_DPI_LABEL 10061
#define IDS_PRINT_PREVIEW_NON_ISOTROPIC_DPI_ITEM_LABEL 10062
#define IDS_PRINT_PREVIEW_DPI_ITEM_LABEL 10063
#define IDS_PRINT_PREVIEW_DESTINATION_SEARCH_TITLE 10064
#define IDS_PRINT_PREVIEW_SEARCH_BOX_PLACEHOLDER 10065
#define IDS_PRINT_PREVIEW_NO_DESTINATIONS_MESSAGE 10066
#define IDS_PRINT_PREVIEW_PRINT_DESTINATIONS_TITLE 10067
#define IDS_PRINT_PREVIEW_MANAGE 10068
#define IDS_PRINT_PREVIEW_SEE_MORE 10069
#define IDS_PRINT_PREVIEW_SEE_MORE_DESTINATIONS_LABEL 10070
#define IDS_PRINT_PREVIEW_EXTENSION_DESTINATION_ICON_TOOLTIP 10071
#define IDS_MORE_OPTIONS_LABEL 10072
#define IDS_PRINT_PREVIEW_COULD_NOT_PRINT 10073
#define IDS_PRINT_PREVIEW_ADVANCED_SETTINGS_SEARCH_BOX_PLACEHOLDER 10074
#define IDS_PRINT_PREVIEW_ADVANCED_SETTINGS_DIALOG_TITLE 10075
#define IDS_PRINT_PREVIEW_NO_ADVANCED_SETTINGS_MATCH_SEARCH_HINT 10076
#define IDS_PRINT_PREVIEW_ADVANCED_SETTINGS_DIALOG_CONFIRM 10077
#define IDS_PRINT_PREVIEW_NEW_SHOW_ADVANCED_OPTIONS 10078
#define IDS_PRINT_PREVIEW_BUTTON_SELECT 10079
#define IDS_PRINT_PREVIEW_BUTTON_GO_BACK 10080
#define IDS_PRINT_PREVIEW_RESOLVE_EXTENSION_USB_DIALOG_TITLE 10081
#define IDS_PRINT_PREVIEW_RESOLVE_EXTENSION_USB_PERMISSION_MESSAGE 10082
#define IDS_PRINT_PREVIEW_RESOLVE_EXTENSION_USB_ERROR_MESSAGE 10083
#define IDS_PRINT_PREVIEW_MANAGED_SETTINGS_TEXT 10084
#define IDS_PRINT_PREVIEW_SYSTEM_DIALOG_OPTION 10115
#define IDS_DEFAULT_PRINT_DOCUMENT_TITLE 10118
#define IDS_PRINT_SPOOL_FAILED_TITLE_TEXT 10119
#define IDS_PRINT_SPOOL_FAILED_ERROR_TEXT 10120
#define IDS_SKILL_SAVED_TOAST_BODY 10121
#define IDS_SKILL_DELETED_TOAST_BODY 10122
#define IDS_SKILL_UNDO_TOAST_BUTTON 10123
#define IDS_SKILL_CARD_ACTION_MENU_LABEL 10124
#define IDS_ADD_NEW_SKILL_LABEL 10125
#define IDS_SKILL_PAGE_TITLE 10126
#define IDS_SKILL_PAGE_SEARCH_BAR_PLACEHOLDER_TEXT 10127
#define IDS_SKILL_PAGE_MAIN_MENU 10128
#define IDS_SKILLS_SIDEBAR_FOOTER_TEXT 10129
#define IDS_SKILLS_SIDEBAR_FOOTER_BRANDING 10130
#define IDS_SKILLS_ERROR_PAGE_TITLE 10131
#define IDS_SKILLS_ERROR_PAGE_DESCRIPTION 10132
#define IDS_SKILLS_NO_SEARCH_RESULT_TITLE 10133
#define IDS_SKILLS_NO_SEARCH_RESULT_DESCRIPTION 10134
#define IDS_SKILL_PAGE_BROWSE_SKILLS_TITLE 10135
#define IDS_SKILL_PAGE_FIRST_PARTY_ADD_SKILL_ERROR_TOAST 10136
#define IDS_SKILLS_PAGE_ALL_CATEGORY 10137
#define IDS_SKILLS_CURATED_PREFIX 10138
#define IDS_SKILL_PAGE_EMPTY_STATE_TITLE 10139
#define IDS_SKILL_PAGE_EMPTY_STATE_DESCRIPTION 10140
#define IDS_SKILL_PAGE_USER_SKILLS_TITLE 10141
#define IDS_SKILL_PAGE_USER_SKILLS_DESCRIPTION 10142
#define IDS_SKILL_PAGE_USER_SKILLS_DELETE 10143
#define IDS_SKILL_PAGE_USER_SKILLS_COPY_INSTRUCTIONS 10144
#define IDS_SKILL_PAGE_INVALID_SKILL_TOAST 10145
#define IDS_SKILLS_DIALOG_ADD_SKILL_HEADER 10146
#define IDS_SKILLS_DIALOG_EDIT_SKILL_HEADER 10147
#define IDS_SKILLS_DIALOG_DESCRIPTION 10148
#define IDS_SKILLS_DIALOG_NAME_LABEL 10149
#define IDS_SKILLS_DIALOG_NAME_PLACEHOLDER 10150
#define IDS_SKILLS_DIALOG_CHOOSE_ICON_TOOLTIP 10151
#define IDS_SKILLS_DIALOG_INSTRUCTIONS_LABEL 10152
#define IDS_SKILLS_DIALOG_INSTRUCTIONS_PLACEHOLDER 10153
#define IDS_SKILLS_DIALOG_UNDO_TOOLTIP 10154
#define IDS_SKILLS_DIALOG_REDO_TOOLTIP 10155
#define IDS_SKILLS_DIALOG_REFINE_TOOLTIP 10156
#define IDS_SKILLS_DIALOG_REFINE_ERROR 10157
#define IDS_SKILLS_DIALOG_CHAR_LIMIT_ERROR 10158
#define IDS_SKILLS_DIALOG_ACCOUNT_INFO 10159
#define IDS_SKILLS_DIALOG_SAVE_ERROR 10160
#define IDS_SKILLS_EMOJI_PICKER_SEARCH_PLACEHOLDER 10161
#define IDS_SKILLS_EMOJI_PICKER_ARIA_LABEL 10162
#define IDS_VR_SHELL_SITE_IS_TRACKING_LOCATION 10163
#define IDS_VR_SHELL_SITE_IS_USING_MICROPHONE 10164
#define IDS_VR_SHELL_SITE_IS_USING_CAMERA 10165
#define IDS_VR_SHELL_SITE_IS_SHARING_SCREEN 10166
#define IDS_VR_SHELL_BG_IS_USING_MICROPHONE 10167
#define IDS_VR_SHELL_BG_IS_USING_CAMERA 10168
#define IDS_VR_SHELL_BG_IS_SHARING_SCREEN 10169
#define IDS_VR_SHELL_SITE_CAN_TRACK_LOCATION 10170
#define IDS_VR_SHELL_SITE_CAN_USE_MICROPHONE 10171
#define IDS_VR_SHELL_SITE_CAN_USE_CAMERA 10172
#define IDS_VR_SHELL_SITE_CAN_SHARE_SCREEN 10173
#define IDS_VR_SHELL_SITE_IS_USING_BLUETOOTH 10174
#define IDS_VR_SHELL_SITE_CAN_USE_BLUETOOTH 10176
#define IDS_DESKTOP_PROMPT_DOFF_HEADSET 10177
#define IDS_VR_DESKTOP_GENERIC_PERMISSION_PROMPT 10178
#define IDS_VR_SHELL_SITE_IS_USING_USB 10179
#define IDS_VR_SHELL_SITE_IS_USING_MIDI 10180
#define IDS_VR_SHELL_SITE_CAN_USE_MIDI 10181
#define IDS_VR_WEB_VR_TIMEOUT_MESSAGE 10182
#define IDS_WILDCARD 10183
#define IDS_BACKGROUND_CRASHED_APP_BALLOON_MESSAGE 10186
#define IDS_BACKGROUND_CRASHED_EXTENSION_BALLOON_MESSAGE 10187
#define IDS_BACKGROUND_APP_NOT_INSTALLED 10188
#define IDS_PERMISSIONS_REQUESTED_SCREENREADER_ANNOUNCEMENT 10189
#define IDS_PERMISSIONS_EXPIRED_SCREENREADER_ANNOUNCEMENT 10190
#define IDS_PERMISSIONS_BUBBLE_PROMPT 10191
#define IDS_PERMISSIONS_BUBBLE_PROMPT_ACCESSIBLE_TITLE_ONE_PERM 10192
#define IDS_PERMISSIONS_BUBBLE_PROMPT_ACCESSIBLE_TITLE_TWO_PERMS 10193
#define IDS_PERMISSIONS_BUBBLE_PROMPT_ACCESSIBLE_TITLE_TWO_PERMS_MORE 10194
#define IDS_PERMISSIONS_BUBBLE_PROMPT_THIS_FILE 10195
#define IDS_PERMISSION_CUSTOMIZE 10196
#define IDS_ALTERNATE_NAV_URL_VIEW_LABEL 10197
#define IDS_DOWNLOAD_HISTORY_TITLE 10198
#define IDS_TAB_LOADING_TITLE 10199
#define IDS_HOVER_CARD_FILE_URL_SOURCE 10200
#define IDS_HOVER_CARD_BLOB_URL_SOURCE 10201
#define IDS_HOVER_CARD_VIEW_SOURCE_URL_SOURCE 10202
#define IDS_HOVER_CARD_CRASHED_TITLE 10203
#define IDS_HISTORY_SEARCH_PROMPT 10204
#define IDS_HISTORY_DELETE 10205
#define IDS_HISTORY_OPEN 10206
#define IDS_HISTORY_ITEMS_SELECTED 10207
#define IDS_HISTORY_ITEMS_UNSELECTED 10208
#define IDS_HISTORY_HISTORY_MENU_DESCRIPTION 10209
#define IDS_HISTORY_NO_SYNCED_RESULTS 10210
#define IDS_HISTORY_OPEN_TABS_MENU_ITEM 10211
#define IDS_HISTORY_TURN_ON_SYNC_BUTTON 10212
#define IDS_HISTORY_TURN_ON_SYNC_PROMO 10213
#define IDS_HISTORY_TURN_ON_SYNC_PROMO_DESC 10214
#define IDS_HISTORY_SYNC_HISTORY_PROMO 10215
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_SIGNED_OUT 10216
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_PENDING_SIGN_IN 10217
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_PENDING_SIGN_IN_SYNC_HISTORY_ON 10218
#define IDS_RECENT_TABS_SYNC_HISTORY_PROMO_BODY_SIGNED_IN_SYNC_OFF 10219
#define IDS_HISTORY_SYNC_HISTORY_BUTTON 10220
#define IDS_EDIT 10221
#define IDS_CLEAR_SEARCH 10222
#define IDS_CONFIRM 10223
#define IDS_DISABLE 10224
#define IDS_SEARCH_CLEARED 10225
#define IDS_SEARCH_RESULTS 10226
#define IDS_SEARCH_RESULTS_SINGULAR 10227
#define IDS_SEARCH_RESULTS_PLURAL 10228
#define IDS_SEARCH_RESULT_BUBBLE_TEXT 10229
#define IDS_SEARCH_RESULTS_BUBBLE_TEXT 10230
#define IDS_SEARCH_NO_RESULTS 10231
#define IDS_SHOW_BUBBLE_INACTIVE_DESCRIPTION 10232
#define IDS_FOCUS_HELP_BUBBLE_DESCRIPTION 10233
#define IDS_FOCUS_HELP_BUBBLE_TOGGLE_DESCRIPTION 10234
#define IDS_FOCUS_HELP_BUBBLE_TUTORIAL_DESCRIPTION 10235
#define IDS_CONTENT_CONTEXT_INSPECTELEMENT 10236
#define IDS_CONTENT_CONTEXT_INSPECTELEMENT_WITH_GEMINI 10237
#define IDS_CONTENT_CONTEXT_INSPECTELEMENT_WITH_DEVTOOLS 10238
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_DIALOG_TITLE 10239
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_ENABLE 10240
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_BUBBLE_DISABLE 10241
#define IDS_CONTENT_CONTEXT_LIVE_CAPTION_ENABLE 10242
#define IDS_CONTENT_CONTEXT_LIVE_CAPTION_DISABLE 10243
#define IDS_CONTENT_CONTEXT_BACK 10244
#define IDS_CONTENT_CONTEXT_FORWARD 10245
#define IDS_CONTENT_CONTEXT_SAVEPAGEAS 10246
#define IDS_CONTENT_CONTEXT_PRINT 10247
#define IDS_CONTENT_CONTEXT_VIEWPAGESOURCE 10248
#define IDS_CONTENT_CONTEXT_OPENLINKWITH 10249
#define IDS_CONTENT_CONTEXT_OPENLINKWITH_CONFIGURE 10250
#define IDS_CONTENT_CONTEXT_INSPECTBACKGROUNDPAGE 10251
#define IDS_CONTENT_CONTEXT_READING_MODE 10252
#define IDS_CONTENT_CONTEXT_LISTEN_TO_THIS_PAGE 10253
#define IDS_CONTENT_CONTEXT_CLOSE_GLIC 10254
#define IDS_CONTENT_CONTEXT_ARCHIVE_GLIC 10255
#define IDS_CONTENT_CONTEXT_RELOAD 10256
#define IDS_CONTENT_CONTEXT_RESTART_APP 10257
#define IDS_CONTENT_CONTEXT_RELOAD_PACKAGED_APP 10258
#define IDS_CONTENT_CONTEXT_TRANSLATE 10259
#define IDS_CONTENT_CONTEXT_EXIT_FULLSCREEN 10260
#define IDS_CONTENT_CONTEXT_RELOADFRAME 10261
#define IDS_CONTENT_CONTEXT_VIEWFRAMESOURCE 10262
#define IDS_CONTENT_CONTEXT_OPENLINKNEWTAB 10263
#define IDS_CONTENT_CONTEXT_OPENLINKNEWWINDOW 10264
#define IDS_CONTENT_CONTEXT_OPENLINKOFFTHERECORD 10265
#define IDS_CONTENT_CONTEXT_OPENLINKSPLITVIEW 10266
#define IDS_CONTENT_CONTEXT_OPENLINKLEFTVIEW 10267
#define IDS_CONTENT_CONTEXT_OPENLINKRIGHTVIEW 10268
#define IDS_CONTENT_CONTEXT_OPENLINKINPROFILES 10269
#define IDS_CONTENT_CONTEXT_OPENLINKINPROFILE 10270
#define IDS_CONTENT_CONTEXT_OPENLINKBOOKMARKAPP 10271
#define IDS_CONTENT_CONTEXT_OPENLINKBOOKMARKAPP_SAMEAPP 10272
#define IDS_CONTENT_CONTEXT_OPENLINKWEBAPP_NEWTAB 10273
#define IDS_CONTENT_CONTEXT_SAVELINKAS 10274
#define IDS_CONTENT_CONTEXT_COPYLINKLOCATION 10275
#define IDS_CONTENT_CONTEXT_COPYEMAILADDRESS 10276
#define IDS_CONTENT_CONTEXT_COPYLINKTEXT 10277
#define IDS_CONTENT_CONTEXT_COPYLINKTOTEXT 10278
#define IDS_CONTENT_CONTEXT_ADD_A_NOTE 10279
#define IDS_CONTENT_CONTEXT_REMOVELINKTOTEXT 10280
#define IDS_CONTENT_CONTEXT_RESHARELINKTOTEXT 10281
#define IDS_CONTENT_CONTEXT_SAVEIMAGEAS 10282
#define IDS_CONTENT_CONTEXT_COPYIMAGELOCATION 10283
#define IDS_CONTENT_CONTEXT_COPYIMAGE 10284
#define IDS_CONTENT_CONTEXT_OPENIMAGENEWTAB 10285
#define IDS_CONTENT_CONTEXT_OPEN_ORIGINAL_IMAGE_NEW_TAB 10286
#define IDS_CONTENT_CONTEXT_LOAD_IMAGE 10287
#define IDS_CONTENT_CONTEXT_LOOP 10288
#define IDS_CONTENT_CONTEXT_CONTROLS 10289
#define IDS_CONTENT_CONTEXT_ROTATECW 10290
#define IDS_CONTENT_CONTEXT_ROTATECCW 10291
#define IDS_CONTENT_CONTEXT_VIDEO_FRAME 10292
#define IDS_CONTENT_CONTEXT_SAVEVIDEOFRAMEAS 10293
#define IDS_CONTENT_CONTEXT_SAVEVIDEOAS 10294
#define IDS_CONTENT_CONTEXT_COPYVIDEOLOCATION 10295
#define IDS_CONTENT_CONTEXT_COPYVIDEOFRAME 10296
#define IDS_CONTENT_CONTEXT_SEARCHFORVIDEOFRAME 10297
#define IDS_CONTENT_CONTEXT_OPENVIDEONEWTAB 10298
#define IDS_CONTENT_CONTEXT_SAVEAUDIOAS 10299
#define IDS_CONTENT_CONTEXT_COPYAUDIOLOCATION 10300
#define IDS_CONTENT_CONTEXT_OPENAUDIONEWTAB 10301
#define IDS_CONTENT_CONTEXT_PICTUREINPICTURE 10302
#define IDS_CONTENT_CONTEXT_UNDO 10303
#define IDS_CONTENT_CONTEXT_REDO 10304
#define IDS_CONTENT_CONTEXT_CUT 10305
#define IDS_CONTENT_CONTEXT_COPY 10306
#define IDS_CONTENT_CONTEXT_PASTE 10307
#define IDS_CONTENT_CONTEXT_PASTE_AND_MATCH_STYLE 10308
#define IDS_CONTENT_CONTEXT_ADD_TO_DICTIONARY 10309
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_MENU_OPTION 10310
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_SEND 10311
#define IDS_CONTENT_CONTEXT_ACCESSIBILITY_LABELS_SEND_ONCE 10312
#define IDS_CONTENT_CONTEXT_RUN_LAYOUT_EXTRACTION 10313
#define IDS_CONTENT_CONTEXT_SPELLING_ASK_GOOGLE 10314
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_TITLE 10315
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_ENABLE 10316
#define IDS_CONTENT_CONTEXT_SPELLING_BUBBLE_DISABLE 10317
#define IDS_CONTENT_CONTEXT_SPELLING_CHECKING 10318
#define IDS_CONTENT_CONTEXT_SPELLING_NO_SUGGESTIONS_FROM_GOOGLE 10319
#define IDS_CONTENT_CONTEXT_SELECTALL 10320
#define IDS_CONTENT_CONTEXT_PARTIAL_TRANSLATE 10321
#define IDS_CONTENT_CONTEXT_SEARCHWEBFOR 10322
#define IDS_CONTENT_CONTEXT_SEARCHWEBFORNEWTAB 10323
#define IDS_CONTENT_CONTEXT_SEARCHWEBFORIMAGE 10324
#define IDS_CONTENT_CONTEXT_SEARCHLENSFORIMAGE 10325
#define IDS_CONTENT_CONTEXT_LENS_REGION_SEARCH_ALT1 10326
#define IDS_CONTENT_CONTEXT_LENS_REGION_SEARCH 10327
#define IDS_CONTENT_CONTEXT_GOTOURL 10328
#define IDS_CONTENT_CONTEXT_GENERATEPASSWORD 10329
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_USE_PASSKEY_FROM_ANOTHER_DEVICE 10330
#define IDS_CONTENT_CONTEXT_MORE_APPS 10331
#define IDS_CONTENT_CONTEXT_OPEN_WITH_APP 10332
#define IDS_CONTENT_CONTEXT_AUTOFILL_FEEDBACK 10333
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_AT_MEMORY 10334
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_SELECT_PASSWORD 10335
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_IMPORT_PASSWORDS 10336
#define IDS_CONTENT_CONTEXT_AUTOFILL_FALLBACK_PASSWORDS_SUGGEST_PASSWORD 10337
#define IDS_SHARE_MENU_TITLE 10340
#define IDS_CONTENT_CONTEXT_PLUGIN_RUN 10341
#define IDS_CONTENT_CONTEXT_PLUGIN_HIDE 10342
#define IDS_CONTENT_CONTEXT_ENABLE_FLASH 10343
#define IDS_CONTENT_CONTEXT_SPELLCHECK_MENU 10345
#define IDS_CONTENT_CONTEXT_LANGUAGE_SETTINGS 10344
#define IDS_CONTENT_CONTEXT_SPELLCHECK_MULTI_LINGUAL 10346
#define IDS_CONTENT_CONTEXT_CHECK_SPELLING_WHILE_TYPING 10347
#define IDS_PROFILE_ROW_VERIFY_MESSAGE 10348
#define IDS_ADDRESSES_AND_MORE_SUBMENU_OPTION 10349
#define IDS_YOUR_SAVED_INFO_CONTACT_INFO_SUBMENU_OPTION 10350
#define IDS_PASSWORDS_AND_AUTOFILL_MENU 10351
#define IDS_RELAUNCH_TO_UPDATE_ALT 10352
#define IDS_RELAUNCH_TO_UPDATE_ALT_MINOR_TEXT 10353
#define IDS_NEW_TAB 10354
#define IDS_NEW_INCOGNITO_TAB 10355
#define IDS_SHOW_AS_TAB 10356
#define IDS_NEW_WINDOW 10357
#define IDS_NEW_INCOGNITO_WINDOW 10358
#define IDS_PROFILE_ROW_SIGNED_IN_MESSAGE_WITH_EMAIL 10359
#define IDS_PROFILE_ROW_SIGNED_IN_MESSAGE 10360
#define IDS_PROFILE_ROW_SYNC_IS_ON 10361
#define IDS_PROFILE_ROW_TURN_ON_SYNC 10362
#define IDS_PROFILE_ROW_SYNC_ERROR_MESSAGE 10363
#define IDS_EDIT2 10364
#define IDS_CUT 10365
#define IDS_COPY 10366
#define IDS_PASTE 10367
#define IDS_DELETE 10368
#define IDS_FIND 10369
#define IDS_FIND_AND_EDIT_MENU 10370
#define IDS_PAYMENT_METHOD_SUBMENU_OPTION 10371
#define IDS_YOUR_SAVED_INFO_PAYMENTS_SUBMENU_OPTION 10372
#define IDS_SAVE_AND_SHARE_MENU 10373
#define IDS_CAST_SAVE_AND_SHARE_MENU 10374
#define IDS_SAVE_AND_SHARE_MENU_CAST 10375
#define IDS_SAVE_AND_SHARE_MENU_SAVE 10376
#define IDS_SAVE_AND_SHARE_MENU_SHARE 10377
#define IDS_SAVE_PAGE 10378
#define IDS_MORE_TOOLS_MENU 10379
#define IDS_ZOOM_MENU 10380
#define IDS_ZOOM_MENU2 10381
#define IDS_ZOOM_PLUS 10382
#define IDS_ZOOM_PLUS2 10383
#define IDS_ZOOM_NORMAL 10384
#define IDS_ZOOM_MINUS 10385
#define IDS_ZOOM_MINUS2 10386
#define IDS_COPY_URL 10387
#define IDS_OPEN_IN_APP_WINDOW 10388
#define IDS_MOVE_TAB_TO_NEW_WINDOW 10389
#define IDS_SEARCH_TABS 10390
#define IDS_CLOSE_PROFILE 10391
#define IDS_MANAGE_GOOGLE_ACCOUNT 10392
#define IDS_OPEN_GUEST_PROFILE 10393
#define IDS_ADD_NEW_PROFILE 10394
#define IDS_ACCNAME_ZOOM_PLUS2 10398
#define IDS_ACCNAME_ZOOM_MINUS2 10399
#define IDS_VIEW_SOURCE 10400
#define IDS_FEEDBACK 10401
#define IDS_DEV_TOOLS 10402
#define IDS_DEV_TOOLS_ELEMENTS 10403
#define IDS_DEV_TOOLS_CONSOLE 10404
#define IDS_DEV_TOOLS_DEVICES 10405
#define IDS_TASK_MANAGER 10406
#define IDS_TAKE_SCREENSHOT 10407
#define IDS_REPORT_UNSAFE_SITE 10408
#define IDS_RESTORE_ALL_TABS 10409
#define IDS_RESTORE_TAB 10410
#define IDS_REOPEN_WINDOW 10411
#define IDS_REOPEN_GROUP 10412
#define IDS_RESTORE_WINDOW 10413
#define IDS_RESTORE_GROUP 10414
#define IDS_NAME_WINDOW 10415
#define IDS_CHROMELABS 10416
#define IDS_PREFERENCES 10417
#define IDS_TOS_NOTIFICATION_TITLE 10419
#define IDS_TOS_NOTIFICATION_BODY_TEXT 10420
#define IDS_TOS_NOTIFICATION_ACK_BUTTON_TEXT 10421
#define IDS_TOS_NOTIFICATION_REVIEW_BUTTON_TEXT 10422
#define IDS_TOS_NOTIFICATION_LINK 10423
#define IDS_HELP_MENU 10424
#define IDS_MANAGED 10425
#define IDS_MANAGED_BY 10426
#define IDS_MANAGED_BY_PARENT 10427
#define IDS_PROFILE_MANAGED_BY 10428
#define IDS_BROWSER_PROFILE_MANAGED 10429
#define IDS_CHROME_WHATS_NEW 10430
#define IDS_IMPORT_SETTINGS_MENU_LABEL 10431
#define IDS_PROFILING_ENABLED 10432
#define IDS_FULLSCREEN 10433
#define IDS_CLEAR_BROWSING_DATA 10434
#define IDS_SHOW_DOWNLOADS 10435
#define IDS_FIND_EXTENSIONS 10436
#define IDS_SHOW_EXTENSIONS 10437
#define IDS_EXTENSIONS_SUBMENU 10438
#define IDS_EXTENSIONS_SUBMENU_MANAGE_EXTENSIONS_ITEM 10439
#define IDS_EXTENSIONS_SUBMENU_CHROME_WEBSTORE_ITEM 10440
#define IDS_SHOW_PERFORMANCE 10441
#define IDS_SHOW_SEARCH_COMPANION 10442
#define IDS_SHOW_TRANSLATE 10443
#define IDS_SETTINGS 10444
#define IDS_OPTIONS 10445
#define IDS_HELP_PAGE 10446
#define IDS_BETA_FORUM 10447
#define IDS_GET_HELP 10448
#define IDS_EXIT 10449
#define IDS_AUTOCOMPLETE_MATCH_DESCRIPTION_SEPARATOR 10450
#define IDS_MANAGE_SEARCH_ENGINES 10451
#define IDS_MANAGE_SEARCH_ENGINES_AND_SITE_SEARCH 10452
#define IDS_MANAGE_SEARCH_ENGINES_AND_SHORTCUTS 10453
#define IDS_SEARCH_ENGINES_EDITOR_KEYWORD_COLUMN 10454
#define IDS_SEARCH_ENGINES_EDITOR_DESCRIPTION_COLUMN 10455
#define IDS_SEARCH_ENGINES_EDITOR_DEFAULT_ENGINE 10456
#define IDS_DOWNLOAD_INTERRUPTED_STATUS 10457
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_ACCESS_DENIED 10458
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_ACCESS_DENIED 10459
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_PATH_TOO_LONG 10460
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_PATH_TOO_LONG 10461
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_DISK_FULL 10462
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_DISK_FULL 10463
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FILE_TOO_LARGE 10464
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FILE_TOO_LARGE 10465
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_TEMPORARY_PROBLEM 10466
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_TEMPORARY_PROBLEM 10467
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_VIRUS 10468
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_VIRUS 10469
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_BLOCKED 10470
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_LOCAL_DOWNLOAD_BLOCKED 10471
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_LOCAL_DOWNLOAD_BLOCKED_DOWNLOAD_UI 10472
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_BLOCKED 10473
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_CONTENT_LENGTH_MISMATCH 10474
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_CONTENT_LENGTH_MISMATCH 10475
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SECURITY_CHECK_FAILED 10476
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SECURITY_CHECK_FAILED 10477
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FILE_TOO_SHORT 10478
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FILE_TOO_SHORT 10479
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FILE_SAME_AS_SOURCE 10480
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FILE_SAME_AS_SOURCE 10481
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NETWORK_TIMEOUT 10482
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NETWORK_TIMEOUT 10483
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NETWORK_DISCONNECTED 10484
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NETWORK_DISCONNECTED 10485
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SERVER_DOWN 10486
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SERVER_DOWN 10487
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NETWORK_ERROR 10488
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NETWORK_ERROR 10489
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_NO_FILE 10490
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_NO_FILE 10491
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SERVER_PROBLEM 10492
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SERVER_PROBLEM 10493
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_WEB_DRIVE_ERROR 10494
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SHUTDOWN 10495
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SHUTDOWN 10496
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_CRASH 10497
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_CRASH 10498
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_UNAUTHORIZED 10499
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_UNAUTHORIZED 10500
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_SERVER_CERT_PROBLEM 10501
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_SERVER_CERT_PROBLEM 10502
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_FORBIDDEN 10503
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_FORBIDDEN 10504
#define IDS_DOWNLOAD_INTERRUPTED_STATUS_UNREACHABLE 10505
#define IDS_DOWNLOAD_INTERRUPTED_DESCRIPTION_UNREACHABLE 10506
#define IDS_DOWNLOAD_NOTIFICATION_LABEL_OPEN_WHEN_COMPLETE 10507
#define IDS_DOWNLOAD_NOTIFICATION_LABEL_OPEN 10508
#define IDS_DOWNLOAD_STATUS_STARTING 10509
#define IDS_DOWNLOAD_STATUS_IN_PROGRESS 10520
#define IDS_DOWNLOAD_STATUS_SIZES 10521
#define IDS_DOWNLOAD_STATUS_OPEN_IN 10522
#define IDS_DOWNLOAD_STATUS_OPEN_WHEN_COMPLETE 10523
#define IDS_DOWNLOAD_STATUS_IN_PROGRESS_SHORT 10524
#define IDS_DOWNLOAD_STATUS_CANCELLED 10525
#define IDS_DOWNLOAD_STATUS_REMOVED 10526
#define IDS_DOWNLOAD_STATUS_UPLOADING 10527
#define IDS_DOWNLOAD_STATUS_UPLOADED 10528
#define IDS_DOWNLOAD_STATUS_UPLOAD_INTERRUPTED 10529
#define IDS_DOWNLOAD_STATUS_INTERRUPTED 10530
#define IDS_DOWNLOAD_UNCONFIRMED_PREFIX 10531
#define IDS_PROMPT_DANGEROUS_DOWNLOAD 10532
#define IDS_PROMPT_DANGEROUS_DOWNLOAD_EXTENSION 10533
#define IDS_PROMPT_UNCOMMON_DOWNLOAD_CONTENT 10534
#define IDS_PROMPT_UNCOMMON_DOWNLOAD_CONTENT_IN_ADVANCED_PROTECTION 10535
#define IDS_PROMPT_DEEP_SCANNING_APP_DOWNLOAD 10536
#define IDS_PROMPT_CONFIRM_INSECURE_DOWNLOAD 10537
#define IDS_PROMPT_DOWNLOAD_BLOCKED_TOO_LARGE 10538
#define IDS_PROMPT_DOWNLOAD_BLOCKED_PASSWORD_PROTECTED 10539
#define IDS_PROMPT_DOWNLOAD_SENSITIVE_CONTENT_WARNING 10540
#define IDS_PROMPT_DOWNLOAD_SENSITIVE_CONTENT_BLOCKED 10541
#define IDS_PROMPT_DOWNLOAD_FORCED_SAVE_TO_CLOUD 10542
#define IDS_PROMPT_DOWNLOAD_BLOCKED_SCAN_FAILED 10543
#define IDS_PROMPT_DOWNLOAD_DEEP_SCANNED_OPENED_DANGEROUS 10544
#define IDS_PROMPT_DOWNLOAD_INSECURE_WARNING 10545
#define IDS_PROMPT_DOWNLOAD_INSECURE_BLOCKED 10546
#define IDS_PROMPT_APP_DEEP_SCANNING 10547
#define IDS_PROMPT_DEEP_SCANNING 10548
#define IDS_BLOCK_REASON_UNCOMMON_DOWNLOAD_IN_ADVANCED_PROTECTION 10549
#define IDS_BLOCK_REASON_DEEP_SCANNING_UPDATED 10550
#define IDS_BLOCK_REASON_DEEP_SCANNING_SECOND_UPDATED 10551
#define IDS_BLOCK_REASON_PROMPT_FOR_SCANNING_UPDATED 10552
#define IDS_BLOCK_REASON_PROMPT_FOR_LOCAL_PASSWORD_SCANNING 10553
#define IDS_DEEP_SCANNED_OPENED_DANGEROUS_DESCRIPTION 10554
#define IDS_BLOCK_REASON_SENSITIVE_CONTENT_WARNING 10555
#define IDS_SENSITIVE_CONTENT_BLOCKED_DESCRIPTION 10556
#define IDS_FORCED_SAVE_TO_CLOUD_DESCRIPTION 10557
#define IDS_BLOCKED_TOO_LARGE_DESCRIPTION 10558
#define IDS_BLOCKED_PASSWORD_PROTECTED_DESCRIPTION 10559
#define IDS_DEEP_SCANNED_FAILED_DESCRIPTION 10560
#define IDS_DOWNLOADS_TOAST_DELETED_FROM_HISTORY_STILL_ON_DEVICE 10561
#define IDS_DOWNLOADS_TOAST_DELETED_FROM_HISTORY 10562
#define IDS_DOWNLOADS_TOAST_COPIED_DOWNLOAD_LINK 10563
#define IDS_DOWNLOADS_TOAST_COPY_DOWNLOAD_LINK_FAILED 10564
#define IDS_DOWNLOADS_TOAST_COPIED_LINK 10565
#define IDS_EMAIL_VERIFIED 10566
#define IDS_CONFIRM_KEEP_DANGEROUS_DOWNLOAD_TITLE 10570
#define IDS_CONFIRM_DOWNLOAD 10571
#define IDS_CONTINUE_EXTENSION_DOWNLOAD 10572
#define IDS_DISCARD_DOWNLOAD 10573
#define IDS_OPEN_DOWNLOAD_NOW 10574
#define IDS_SCAN_DOWNLOAD 10575
#define IDS_REVIEW_DOWNLOAD 10576
#define IDS_OPEN_DOWNLOAD_ANYWAY 10577
#define IDS_DOWNLOAD_LINK_PAUSE 10578
#define IDS_DOWNLOAD_HISTORY_SEARCH 10579
#define IDS_DOWNLOAD_NO_DOWNLOADS 10580
#define IDS_DOWNLOAD_LINK_RESUME 10581
#define IDS_DOWNLOAD_LINK_CANCEL 10582
#define IDS_DOWNLOAD_LINK_RETRY 10583
#define IDS_DOWNLOAD_LINK_SHOW_IN_WEB_DRIVE 10584
#define IDS_DOWNLOAD_LINK_SHOW 10585
#define IDS_DOWNLOAD_TAB_CANCELLED 10586
#define IDS_DOWNLOAD_FILE_REMOVED 10587
#define IDS_DOWNLOAD_TAB_PROGRESS_STATUS_TIME_UNKNOWN 10588
#define IDS_DOWNLOAD_TAB_PROGRESS_STATUS 10589
#define IDS_DOWNLOAD_TAB_PROGRESS_SIZE 10590
#define IDS_DOWNLOAD_PROGRESS_PAUSED 10591
#define IDS_DOWNLOAD_LINK_CLEAR_ALL 10592
#define IDS_DOWNLOAD_LINK_OPEN_DOWNLOADS_FOLDER 10593
#define IDS_DOWNLOAD_MORE_ACTIONS 10594
#define IDS_DOWNLOAD_ACTION_MENU_DESCRIPTION 10595
#define IDS_DOWNLOAD_BY_EXTENSION_URL 10596
#define IDS_DOWNLOADS_PAGE_INITIATOR_LINE 10597
#define IDS_DOWNLOAD_IN_INCOGNITO 10598
#define IDS_UNDO_DESCRIPTION 10599
#define IDS_DOWNLOAD_UNDO 10600
#define IDS_DOWNLOAD_TOAST_CLEARED_ALL 10601
#define IDS_DOWNLOAD_DEEP_SCAN 10602
#define IDS_DOWNLOAD_DEEP_SCAN_UPDATED 10603
#define IDS_DOWNLOAD_BYPASS_DEEP_SCAN 10604
#define IDS_DOWNLOAD_LOCAL_PASSWORD_SCAN 10605
#define IDS_DOWNLOAD_KEEP_DANGEROUS_FILE 10606
#define IDS_DOWNLOAD_KEEP_SUSPICIOUS_FILE 10607
#define IDS_DOWNLOAD_KEEP_UNVERIFIED_FILE 10608
#define IDS_DOWNLOAD_KEEP_INSECURE_FILE 10609
#define IDS_DOWNLOAD_DELETE_FROM_HISTORY 10610
#define IDS_DOWNLOAD_COPY_DOWNLOAD_LINK 10611
#define IDS_DOWNLOAD_DANGEROUS_ICON_ACCESSIBLE_LABEL 10612
#define IDS_DOWNLOAD_SUSPICIOUS_ICON_ACCESSIBLE_LABEL 10613
#define IDS_DOWNLOAD_INSECURE_ICON_ACCESSIBLE_LABEL 10614
#define IDS_DOWNLOAD_UNVERIFIED_ICON_ACCESSIBLE_LABEL 10615
#define IDS_DOWNLOAD_SCREENREADER_SAVED_DANGEROUS 10616
#define IDS_DOWNLOAD_SCREENREADER_SAVED_SUSPICIOUS 10617
#define IDS_DOWNLOAD_SCREENREADER_SAVED_INSECURE 10618
#define IDS_DOWNLOAD_SCREENREADER_SAVED_UNVERIFIED 10619
#define IDS_DOWNLOAD_SCREENREADER_PAUSED 10620
#define IDS_DOWNLOAD_SCREENREADER_RESUMED 10621
#define IDS_DOWNLOAD_SCREENREADER_CANCELED 10622
#define IDS_DOWNLOAD_WARNING_BYPASS_DIALOG_TITLE 10623
#define IDS_DOWNLOAD_WARNING_BYPASS_PROMPT_DESCRIPTION 10624
#define IDS_DOWNLOAD_STATUS_IN_PROGRESS_ACCESSIBLE_ALERT 10625
#define IDS_DOWNLOAD_STATUS_PERCENT_COMPLETE_ACCESSIBLE_ALERT 10626
#define IDS_DOWNLOAD_STATUS_TIME_REMAINING_ACCESSIBLE_ALERT 10627
#define IDS_DOWNLOAD_FAILED_ACCESSIBLE_ALERT 10628
#define IDS_DOWNLOAD_CANCELLED_ACCESSIBLE_ALERT 10629
#define IDS_DOWNLOAD_COMPLETE_ACCESSIBLE_ALERT 10630
#define IDS_DOWNLOAD_PAUSED_ACCESSIBLE_ALERT 10631
#define IDS_PROMPT_DEEP_SCANNING_ACCESSIBLE_ALERT 10632
#define IDS_DEEP_SCANNING_ACCESSIBLE_ALERT 10633
#define IDS_PROMPT_DOWNLOAD_INSECURE_BLOCKED_ACCESSIBLE_ALERT 10634
#define IDS_DOWNLOAD_NOTIFICATION_COPY_TO_CLIPBOARD 10635
#define IDS_DOWNLOAD_MENU_SHOW 10636
#define IDS_DOWNLOAD_MENU_OPEN_WHEN_COMPLETE 10637
#define IDS_DOWNLOAD_MENU_OPEN 10638
#define IDS_DOWNLOAD_MENU_ALWAYS_OPEN_TYPE 10639
#define IDS_DOWNLOAD_MENU_PLATFORM_OPEN 10640
#define IDS_DOWNLOAD_MENU_PLATFORM_OPEN_ALWAYS 10641
#define IDS_DOWNLOAD_MENU_CANCEL 10642
#define IDS_DOWNLOAD_MENU_PAUSE_ITEM 10643
#define IDS_DOWNLOAD_MENU_RESUME_ITEM 10644
#define IDS_DOWNLOAD_MENU_DISCARD 10645
#define IDS_DOWNLOAD_MENU_KEEP 10646
#define IDS_DOWNLOAD_MENU_LEARN_MORE_SCANNING 10647
#define IDS_DOWNLOAD_MENU_LEARN_MORE_INTERRUPTED 10648
#define IDS_DOWNLOAD_MENU_LEARN_MORE_INSECURE 10649
#define IDS_DOWNLOAD_MENU_DEEP_SCAN 10650
#define IDS_ABANDON_DOWNLOAD_DIALOG_TITLE 10661
#define IDS_ABANDON_DOWNLOAD_DIALOG_CONTINUE_BUTTON 10662
#define IDS_ABANDON_DOWNLOAD_DIALOG_INCOGNITO_MESSAGE 10663
#define IDS_ABANDON_DOWNLOAD_DIALOG_GUEST_MESSAGE 10664
#define IDS_ABANDON_DOWNLOAD_DIALOG_EXIT_BUTTON 10665
#define IDS_DOWNLOAD_BUBBLE_HEADER_LABEL 10666
#define IDS_DOWNLOAD_BUBBLE_FOOTER_LABEL 10667
#define IDS_DOWNLOAD_BUBBLE_FOOTER_TOOLTIP_LABEL 10668
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO 10669
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO_CUSTOM_ACTION 10670
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO_DISMISS 10671
#define IDS_DOWNLOAD_BUBBLE_ESB_PROMO_TITLE 10672
#define IDS_DOWNLOAD_BUBBLE_DOWNLOAD_STATUS_MESSAGE_WITH_SEPARATOR 10673
#define IDS_DOWNLOAD_BUBBLE_DOWNLOAD_STATUS_WITH_SYMBOL 10674
#define IDS_DOWNLOAD_BUBBLE_STATUS_RESUMING 10675
#define IDS_DOWNLOAD_BUBBLE_STATUS_DONE 10676
#define IDS_DOWNLOAD_BUBBLE_STATUS_DEEP_SCANNING_DONE_UPDATED 10677
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_INSECURE 10678
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_SUSPICIOUS 10679
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_DANGEROUS 10680
#define IDS_DOWNLOAD_BUBBLE_STATUS_WARNING_UNVERIFIED 10681
#define IDS_DOWNLOAD_BUBBLE_STATUS_BLOCKED 10682
#define IDS_DOWNLOAD_BUBBLE_STATUS_MALWARE 10683
#define IDS_DOWNLOAD_BUBBLE_STATUS_SUSPICIOUS 10684
#define IDS_DOWNLOAD_BUBBLE_STATUS_DEEP_SCANNED_FAILED_UPDATED 10685
#define IDS_DOWNLOAD_BUBBLE_CHECKBOX_BYPASS 10686
#define IDS_DOWNLOAD_BUBBLE_CONTINUE 10687
#define IDS_DOWNLOAD_BUBBLE_CONTINUE_INSECURE_FILE 10688
#define IDS_DOWNLOAD_BUBBLE_CONTINUE_SUSPICIOUS_FILE 10689
#define IDS_DOWNLOAD_BUBBLE_CONTINUE_UNVERIFIED_FILE 10690
#define IDS_DOWNLOAD_BUBBLE_DELETE 10691
#define IDS_DOWNLOAD_BUBBLE_DELETE_FROM_HISTORY 10692
#define IDS_DOWNLOAD_BUBBLE_MAIN_BUTTON_SUBPAGE 10693
#define IDS_DOWNLOAD_BUBBLE_RESUME 10694
#define IDS_DOWNLOAD_BUBBLE_SCAN 10695
#define IDS_DOWNLOAD_BUBBLE_OPEN 10696
#define IDS_DOWNLOAD_BUBBLE_SCAN_UPDATED 10697
#define IDS_DOWNLOAD_BUBBLE_OPEN_UPDATED 10698
#define IDS_DOWNLOAD_BUBBLE_OPEN_NOW 10699
#define IDS_DOWNLOAD_BUBBLE_REVIEW 10700
#define IDS_DOWNLOAD_BUBBLE_RETRY 10701
#define IDS_DOWNLOAD_BUBBLE_OPEN_ANYWAY 10702
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_DISK_FULL 10703
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_DISK_FULL 10704
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_PATH_TOO_LONG 10705
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_PATH_TOO_LONG 10706
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_NEEDS_PERMISSION 10707
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_FILE_TOO_LARGE 10708
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_FILE_TOO_LARGE 10709
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_UNFINISHED 10710
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_BLOCKED_ORGANIZATION 10711
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_WRONG 10712
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_NETWORK_ERROR 10713
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_SITE_UNAVAILABLE 10714
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_FILE_UNAVAILABLE 10715
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_SUBPAGE_SUMMARY_FILE_UNAVAILABLE 10716
#define IDS_DOWNLOAD_BUBBLE_INTERRUPTED_STATUS_FILE_UNFINISHED 10717
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_INSECURE 10718
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_DANGEROUS 10719
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_DECEPTIVE 10720
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_DANGEROUS_FILE_TYPE 10721
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_UNCOMMON_FILE 10722
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_NO_SAFE_BROWSING 10723
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_SAFE_BROWSING_SETTING_LABEL 10724
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_SAFE_BROWSING_SETTING_LINK 10725
#define IDS_DOWNLOAD_BUBBLE_STATUS_DANGEROUS 10726
#define IDS_DOWNLOAD_BUBBLE_STATUS_ENCRYPTED 10727
#define IDS_DOWNLOAD_BUBBLE_STATUS_TOO_BIG 10728
#define IDS_DOWNLOAD_BUBBLE_STATUS_ADVANCED_PROTECTION 10729
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ADVANCED_PROTECTION 10730
#define IDS_DOWNLOAD_BUBBLE_STATUS_UNCOMMON_FILE 10731
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_UNCOMMON_FILE 10732
#define IDS_DOWNLOAD_BUBBLE_STATUS_UNKNOWN_SOURCE 10733
#define IDS_DOWNLOAD_BUBBLE_STATUS_SENSITIVE_CONTENT 10734
#define IDS_DOWNLOAD_BUBBLE_STATUS_SCAN_FAILED 10735
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_SENSITIVE_CONTENT_WARNING 10736
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_SENSITIVE_CONTENT_BLOCK 10737
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ENCRYPTED 10738
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_TOO_BIG 10739
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING 10740
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_SECONDARY 10741
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_ENTERPRISE_SECONDARY 10742
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_DISCARD 10743
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_ASYNC_SCANNING_CANCEL 10744
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_SCAN_FAILED 10745
#define IDS_DOWNLOAD_BUBBLE_TRY_AGAIN 10746
#define IDS_DOWNLOAD_BUBBLE_STATUS_ASYNC_SCANNING_ENTERPRISE 10747
#define IDS_DOWNLOAD_BUBBLE_INCOGNITO_INFORMATION_ROW 10748
#define IDS_DOWNLOAD_BUBBLE_RESUME_QUICK_ACTION 10749
#define IDS_DOWNLOAD_BUBBLE_RESUME_QUICK_ACTION_ACCESSIBILITY 10750
#define IDS_DOWNLOAD_BUBBLE_PAUSE_QUICK_ACTION 10751
#define IDS_DOWNLOAD_BUBBLE_PAUSE_QUICK_ACTION_ACCESSIBILITY 10752
#define IDS_DOWNLOAD_BUBBLE_CANCEL_QUICK_ACTION 10753
#define IDS_DOWNLOAD_BUBBLE_CANCEL_QUICK_ACTION_ACCESSIBILITY 10754
#define IDS_DOWNLOAD_BUBBLE_OPEN_QUICK_ACTION 10755
#define IDS_DOWNLOAD_BUBBLE_OPEN_QUICK_ACTION_ACCESSIBILITY 10756
#define IDS_DOWNLOAD_BUBBLE_SHOW_IN_FOLDER_QUICK_ACTION 10757
#define IDS_DOWNLOAD_BUBBLE_SHOW_IN_FOLDER_QUICK_ACTION_ACCESSIBILITY 10758
#define IDS_DOWNLOAD_BUBBLE_BACK_RECENT_DOWNLOADS 10759
#define IDS_DOWNLOAD_BUBBLE_CANCEL_MAIN_BUTTON_ACCESSIBILITY 10760
#define IDS_DOWNLOAD_BUBBLE_DELETE_MAIN_BUTTON_ACCESSIBILITY 10761
#define IDS_DOWNLOAD_BUBBLE_KEEP_MAIN_BUTTON_ACCESSIBILITY 10762
#define IDS_DOWNLOAD_BUBBLE_SCAN_MAIN_BUTTON_ACCESSIBILITY 10763
#define IDS_DOWNLOAD_BUBBLE_OPEN_NOW_MAIN_BUTTON_ACCESSIBILITY 10764
#define IDS_DOWNLOAD_BUBBLE_RESUME_MAIN_BUTTON_ACCESSIBILITY 10765
#define IDS_DOWNLOAD_BUBBLE_REVIEW_MAIN_BUTTON_ACCESSIBILITY 10766
#define IDS_DOWNLOAD_BUBBLE_RETRY_MAIN_BUTTON_ACCESSIBILITY 10767
#define IDS_DOWNLOAD_BUBBLE_OPEN_MAIN_BUTTON_ACCESSIBILITY 10768
#define IDS_DOWNLOAD_BUBBLE_SUPPRESS_PARTIAL_VIEW 10769
#define IDS_DOWNLOAD_BUBBLE_SUPPRESS_PARTIAL_VIEW_SETTINGS_REMINDER 10770
#define IDS_DOWNLOAD_BUBBLE_SUPPRESS_PARTIAL_VIEW_SETTINGS_LINK 10771
#define IDS_DOWNLOAD_BUBBLE_TOOLTIP_IN_PROGRESS_COUNT 10772
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_COOKIE_THEFT 10775
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_WARNING_ARCHIVE_MALWARE 10776
#define IDS_DOWNLOAD_BUBBLE_STATUS_DEEP_SCANNING_PROMPT_UPDATED 10777
#define IDS_DOWNLOAD_BUBBLE_STATUS_ASYNC_SCANNING 10778
#define IDS_DOWNLOAD_BUBBLE_STATUS_ASYNC_CHECKING_SAFETY 10779
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_DEEP_SCANNING_PROMPT_UPDATED 10780
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_DEEP_SCANNING_PROMPT_ENCRYPTED_ARCHIVE 10781
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_DEEP_SCANNING_LINK 10782
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT 10783
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_EMPTY 10784
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_INVALID 10785
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_ACCESSIBLE_ALERT 10786
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_ACCESSIBLE_ALERT_EMPTY 10787
#define IDS_DOWNLOAD_BUBBLE_PASSWORD_PROMPT_ACCESSIBLE_ALERT_INVALID 10788
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_IMMEDIATE_DEEP_SCAN_IN_PROGRESS 10789
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_IMMEDIATE_DEEP_SCAN_CANCEL 10790
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_IMMEDIATE_DEEP_SCAN_BYPASS 10791
#define IDS_DOWNLOAD_BUBBLE_STATUS_LOCAL_DECRYPTION_STATUS 10792
#define IDS_DOWNLOAD_BUBBLE_STATUS_PASSWORD_NEEDED 10793
#define IDS_DOWNLOAD_BUBBLE_ACCEPT_LOCAL_DECRYPTION 10794
#define IDS_DOWNLOAD_BUBBLE_BYPASS_LOCAL_DECRYPTION 10795
#define IDS_DOWNLOAD_BUBBLE_LOCAL_DECRYPTION_CANCEL 10796
#define IDS_DOWNLOAD_BUBBLE_SUBPAGE_SUMMARY_LOCAL_DECRYPTION_IN_PROGRESS 10797
#define IDS_DOWNLOAD_BUBBLE_STATUS_LOCAL_DECRYPTING 10798
#define IDS_DOWNLOAD_LOCAL_DECRYPTION_PROMPT_ALERT 10799
#define IDS_WEB_APP_WITH_APP_TITLE 10800
#define IDS_OMNIBOX_PWA_INSTALL_ICON_LABEL 10801
#define IDS_OMNIBOX_PWA_INSTALL_ICON_TOOLTIP 10802
#define IDS_WEBAPP_UPDATE_REVIEW_ACCEPT_BUTTON 10803
#define IDS_WEBAPP_UPDATE_REVIEW_UNINSTALL_BUTTON 10804
#define IDS_WEBAPP_UPDATE_REVIEW_IGNORE_BUTTON 10805
#define IDS_WEBAPP_UPDATE_REVIEW_ACCEPT_BUTTON_MIGRATION 10806
#define IDS_ADD_TO_OS_LAUNCH_SURFACE_BUBBLE_TITLE 10807
#define IDS_CREATE_SHORTCUTS_BUTTON_LABEL 10808
#define IDS_CREATE_SHORTCUT_NOT_APPS_DIALOG_TITLE 10809
#define IDS_CREATE_SHORTCUT_NOT_APPS_AX_BUBBLE_LABEL 10810
#define IDS_INSTALL_TO_OS_LAUNCH_SURFACE_BUBBLE_TITLE 10811
#define IDS_INSTALL_PWA_BUTTON_LABEL 10812
#define IDS_INSTALL_PWA_DIALOG_TITLE 10813
#define IDS_WEB_APP_INSTALL_SUCCESS_TITLE 10814
#define IDS_WEB_APP_INSTALL_SUCCESS_OPEN_APP 10815
#define IDS_INSTALL_PWA_DIALOG_INSTALLING 10816
#define IDS_WEB_APP_DETAILED_INSTALL_DIALOG_DESCRIPTION_TITLE 10817
#define IDS_DIY_APP_INSTALL_DIALOG_TITLE 10818
#define IDS_DIY_APP_INSTALL_DIALOG_SUBTITLE 10819
#define IDS_WEB_APP_INSTALL_PIN_TO_SHELF 10820
#define IDS_DIY_APP_AX_BUBBLE_NAME_LABEL 10821
#define IDS_INSTALL_PWA_DIALOG_ORIGIN_LABEL 10822
#define IDS_WEB_APP_INSTALL_ADD_TO_START_MENU 10823
#define IDS_WEB_APP_INSTALL_CHROME_APPS_LOCATION 10824
#define IDS_WEB_APP_INSTALL_CREATE_DESKTOP_SHORTCUT 10825
#define IDS_WEB_APP_INSTALL_PIN_TO_TASKBAR 10826
#define IDS_WEB_APP_INSTALL_LAUNCHER 10827
#define IDS_BOOKMARK_APP_AX_BUBBLE_NAME_LABEL 10828
#define IDS_BOOKMARK_APP_BUBBLE_OPEN_AS_TAB 10829
#define IDS_BOOKMARK_APP_BUBBLE_OPEN_AS_WINDOW 10830
#define IDS_BOOKMARK_APP_BUBBLE_OPEN_AS_TABBED_WINDOW 10831
#define IDS_WEB_APP_INSTALL_NOT_SUPPORTED_DIALOG_TITLE_INCOGNITO_MODE 10832
#define IDS_WEB_APP_INSTALL_NOT_SUPPORTED_DIALOG_TITLE_GUEST_MODE 10833
#define IDS_WEB_APP_INSTALL_NOT_SUPPORTED_DIALOG_TITLE_POLICY_MODE 10834
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME 10835
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_ICON 10836
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_ICON 10837
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_LOGO 10838
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_LOGO 10839
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_URL 10840
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_URL_FORCED_MIGRATION 10841
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_URL 10842
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_LOGO_AND_URL 10843
#define IDS_WEBAPP_UPDATE_DIALOG_TITLE_NAME_AND_LOGO_AND_URL 10844
#define IDS_WEBAPP_UPDATE_NEW_EXPLANATION 10845
#define IDS_WEBAPP_UPDATE_URL_ONLY_NEW_EXPLANATION 10846
#define IDS_WEBAPP_UPDATE_EXPLANATION 10847
#define IDS_WEBAPP_UPDATE_CURRENT_ICON 10848
#define IDS_WEBAPP_UPDATE_NEW_ICON 10849
#define IDS_WEBAPP_UPDATE_NEGATIVE_BUTTON 10850
#define IDS_FINISH_POLICY_WEB_APP_INSTALLATION 10851
#define IDS_FINISH_POLICY_WEB_APP_INSTALATION_RESTART 10852
#define IDS_FINISH_POLICY_WEB_APP_INSTALLATION_NOT_NOW 10853
#define IDS_ADD_TO_OS_LAUNCH_SURFACE 10858
#define IDS_INSTALL_TO_OS_LAUNCH_SURFACE 10859
#define IDS_INSTALL_DIY_TO_OS_LAUNCH_SURFACE 10860
#define IDS_UNINSTALL_FROM_OS_LAUNCH_SURFACE 10861
#define IDS_REVIEW_APP_UPDATE 10862
#define IDS_APPLICATION_INFO_WEB_STORE_LINK 10863
#define IDS_APPLICATION_INFO_HOMEPAGE_LINK 10864
#define IDS_ARC_APPLICATION_INFO_MANAGE_LINK 10865
#define IDS_APPLICATION_INFO_APP_OVERVIEW_TITLE 10866
#define IDS_APPLICATION_INFO_APP_PERMISSIONS_TITLE 10867
#define IDS_APPLICATION_INFO_UNINSTALL_BUTTON_TEXT 10868
#define IDS_APPLICATION_INFO_LICENSES_BUTTON_TEXT 10869
#define IDS_APPLICATION_INFO_SIZE_LABEL 10870
#define IDS_APPLICATION_INFO_VERSION_LABEL 10871
#define IDS_APPLICATION_INFO_CREATE_SHORTCUTS_BUTTON_TEXT 10872
#define IDS_APPLICATION_INFO_LAUNCH_OPTIONS_ACCNAME 10873
#define IDS_APPLICATION_INFO_SIZE_LOADING_LABEL 10874
#define IDS_APPLICATION_INFO_SIZE_SMALL_LABEL 10875
#define IDS_APPLICATION_INFO_REVOKE_PERMISSION_ALT_TEXT 10876
#define IDS_APPLICATION_INFO_APP_NO_PERMISSIONS_TEXT 10877
#define IDS_APPLICATION_INFO_EXTENSION_NO_PERMISSIONS_TEXT 10878
#define IDS_APPLICATION_INFO_RETAINED_FILES 10879
#define IDS_APPLICATION_INFO_RETAINED_DEVICES 10880
#define IDS_CREATE_SHORTCUTS_TITLE 10881
#define IDS_CREATE_SHORTCUTS_LABEL 10882
#define IDS_CREATE_SHORTCUTS_DESKTOP_CHKBOX 10883
#define IDS_CREATE_SHORTCUTS_MENU_CHKBOX 10884
#define IDS_CREATE_SHORTCUTS_COMMIT 10885
#define IDS_BLUETOOTH_DEVICE_CREDENTIALS_TITLE 10888
#define IDS_BLUETOOTH_DEVICE_CREDENTIALS_LABEL 10889
#define IDS_BLUETOOTH_DEVICE_PAIR_CONFIRM_TITLE 10890
#define IDS_BLUETOOTH_DEVICE_PAIR_CONFIRM_LABEL 10891
#define IDS_BLUETOOTH_DEVICE_PASSKEY_CONFIRM_TITLE 10892
#define IDS_BLUETOOTH_DEVICE_PASSKEY_CONFIRM_LABEL 10893
#define IDS_MANAGE 10894
#define IDS_LIST_BULLET 10895
#define IDS_BLOCKED_DOWNLOAD_NO_ACTION 10896
#define IDS_BLOCKED_DOWNLOAD_UNBLOCK 10897
#define IDS_ALLOWED_DOWNLOAD_TITLE 10898
#define IDS_BLOCKED_DOWNLOAD_TITLE 10899
#define IDS_BLOCKED_DOWNLOADS_EXPLANATION 10900
#define IDS_ALLOWED_DOWNLOAD_NO_ACTION 10901
#define IDS_ALLOWED_DOWNLOAD_BLOCK 10902
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_TITLE 10903
#define IDS_ACCESSED_ON_DEVICE_SITE_DATA_TITLE 10904
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_MESSAGE 10905
#define IDS_ACCESSED_ON_DEVICE_SITE_DATA_MESSAGE 10906
#define IDS_BLOCKED_IMAGES_TITLE 10907
#define IDS_BLOCKED_IMAGES_MESSAGE 10908
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_UNBLOCK 10909
#define IDS_BLOCKED_IMAGES_UNBLOCK 10910
#define IDS_BLOCKED_ON_DEVICE_SITE_DATA_NO_ACTION 10911
#define IDS_ALLOWED_ON_DEVICE_SITE_DATA_NO_ACTION 10912
#define IDS_ALLOWED_ON_DEVICE_SITE_DATA_BLOCK 10913
#define IDS_BLOCKED_IMAGES_NO_ACTION 10914
#define IDS_BLOCKED_POPUPS_TOOLTIP 10915
#define IDS_BLOCKED_POPUPS_TITLE 10916
#define IDS_BLOCKED_POPUPS_REDIRECTS_UNBLOCK 10917
#define IDS_BLOCKED_POPUPS_REDIRECTS_NO_ACTION 10918
#define IDS_BLOCKED_MEDIASTREAM_MIC_AND_CAMERA_ALLOW 10919
#define IDS_BLOCKED_MEDIASTREAM_MIC_ALLOW 10920
#define IDS_BLOCKED_MEDIASTREAM_CAMERA_ALLOW 10921
#define IDS_BLOCKED_MEDIASTREAM_MIC_AND_CAMERA_ASK 10922
#define IDS_BLOCKED_MEDIASTREAM_MIC_ASK 10923
#define IDS_BLOCKED_MEDIASTREAM_CAMERA_ASK 10924
#define IDS_ALLOWED_MEDIASTREAM_MIC_AND_CAMERA_BLOCK 10925
#define IDS_ALLOWED_MEDIASTREAM_MIC_BLOCK 10926
#define IDS_ALLOWED_MEDIASTREAM_CAMERA_BLOCK 10927
#define IDS_BLOCKED_MEDIASTREAM_MIC_AND_CAMERA_NO_ACTION 10928
#define IDS_BLOCKED_MEDIASTREAM_MIC_NO_ACTION 10929
#define IDS_BLOCKED_MEDIASTREAM_CAMERA_NO_ACTION 10930
#define IDS_ALLOWED_MEDIASTREAM_MIC_AND_CAMERA_NO_ACTION 10931
#define IDS_ALLOWED_MEDIASTREAM_MIC_AND_CAMERA_PAN_TILT_ZOOM_NO_ACTION 10932
#define IDS_ALLOWED_MEDIASTREAM_MIC_NO_ACTION 10933
#define IDS_ALLOWED_MEDIASTREAM_CAMERA_NO_ACTION 10934
#define IDS_ALLOWED_CAMERA_PAN_TILT_ZOOM_NO_ACTION 10935
#define IDS_BLOCKED_POPUPS_EXPLANATORY_TEXT 10936
#define IDS_BLOCKED_JAVASCRIPT_TITLE 10937
#define IDS_BLOCKED_JAVASCRIPT_MESSAGE 10938
#define IDS_BLOCKED_JAVASCRIPT_UNBLOCK 10939
#define IDS_BLOCKED_JAVASCRIPT_NO_ACTION 10940
#define IDS_BLOCKED_SOUND_TITLE 10941
#define IDS_BLOCKED_SOUND_UNBLOCK 10942
#define IDS_BLOCKED_SOUND_NO_ACTION 10943
#define IDS_NOTIFICATIONS_OFF_EXPLANATORY_TEXT 10944
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_TITLE 10945
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_DESCRIPTION 10946
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_DESCRIPTION 10947
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_ALLOW_BUTTON 10948
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_COMPACT_ALLOW_BUTTON 10949
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_CONTINUE_BLOCKING_BUTTON 10950
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_EARLY_PROMO 10951
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_CROWD_DENY_DESCRIPTION 10952
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_CROWD_DENY_DESCRIPTION 10953
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_ABUSIVE_DESCRIPTION 10954
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_DISRUPTIVE_DESCRIPTION 10955
#define IDS_NOTIFICATIONS_QUIET_PERMISSION_BUBBLE_PREDICTION_SERVICE_DESCRIPTION 10956
#define IDS_GEOLOCATION_OFF_EXPLANATORY_TEXT 10957
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_TITLE 10958
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_PREDICTION_SERVICE_DESCRIPTION 10959
#define IDS_GEOLOCATION_QUIET_PERMISSION_BUBBLE_ALLOW_BUTTON 10960
#define IDS_STORAGE_ACCESS_PERMISSION_BUBBLE_MESSAGE 10961
#define IDS_STORAGE_ACCESS_PERMISSION_ALLOWED_TOOLTIP 10962
#define IDS_STORAGE_ACCESS_PERMISSION_BLOCKED_TOOLTIP 10963
#define IDS_COOKIE_CONTROLS_BUBBLE_COOKIES_BLOCKED_TITLE 10964
#define IDS_COOKIE_CONTROLS_BUBBLE_COOKIES_ALLOWED_TITLE 10965
#define IDS_COOKIE_CONTROLS_BUBBLE_SITE_NOT_WORKING_TITLE 10966
#define IDS_TRACKING_PROTECTION_BUBBLE_SITE_NOT_WORKING_DESCRIPTION 10967
#define IDS_COOKIE_CONTROLS_BUBBLE_SITE_NOT_WORKING_DESCRIPTION 10968
#define IDS_TRACKING_PROTECTION_BUBBLE_BLOCKING_RESTART_TITLE 10969
#define IDS_TRACKING_PROTECTION_BUBBLE_BLOCKING_RESTART_DESCRIPTION 10970
#define IDS_TRACKING_PROTECTION_BUBBLE_PERMANENT_ALLOWED_TITLE 10971
#define IDS_TRACKING_PROTECTION_BUBBLE_PERMANENT_ALLOWED_DESCRIPTION 10972
#define IDS_COOKIE_CONTROLS_BUBBLE_SEND_FEEDBACK_BUTTON_TITLE 10973
#define IDS_COOKIE_CONTROLS_BUBBLE_SEND_FEEDBACK_BUTTON_DESCRIPTION 10974
#define IDS_COOKIE_CONTROLS_BUBBLE_RELOADING_LABEL 10975
#define IDS_COOKIE_CONTROLS_BUBBLE_THIRD_PARTY_COOKIES_LABEL 10976
#define IDS_COOKIE_CONTROLS_BUBBLE_SEND_FEEDBACK_FORM_PLACEHOLDER 10977
#define IDS_COOKIE_CONTROLS_PAGE_ACTION_COOKIES_ALLOWED_LABEL 10978
#define IDS_COOKIE_CONTROLS_PAGE_ACTION_COOKIES_BLOCKED_LABEL 10979
#define IDS_COOKIE_CONTROLS_PROMO_TITLE 10980
#define IDS_COOKIE_CONTROLS_PROMO_TEXT 10981
#define IDS_COOKIE_CONTROLS_PROMO_CLOSE_BUTTON_TEXT 10982
#define IDS_COOKIE_CONTROLS_PROMO_SEE_HOW_BUTTON_TEXT 10983
#define IDS_JS_OPTIMIZATIONS_DISABLED_ICON_TOOLTIP 10984
#define IDS_JS_OPTIMIZATION_BUBBLE_TITLE 10985
#define IDS_JS_OPTIMIZATION_BUBBLE_POLICY_BODY 10986
#define IDS_JS_OPTIMIZATION_BUBBLE_ENABLE_BUTTON 10987
#define IDS_JS_OPTIMIZATION_SITE_RELOAD_TEXT 10988
#define IDS_JS_OPTIMIZATION_SITE_RELOAD_BUTTON 10989
#define IDS_CERT_SELECTOR_SUBJECT_COLUMN 10990
#define IDS_CERT_SELECTOR_ISSUER_COLUMN 10991
#define IDS_CERT_SELECTOR_PROVIDER_COLUMN 10992
#define IDS_CERT_SELECTOR_SERIAL_COLUMN 10993
#define IDS_CERT_EXPORT_TYPE_BASE64_ALL 10994
#define IDS_CERT_EXPORT_TYPE_BASE64 10995
#define IDS_CERT_EXPORT_TYPE_BASE64_CHAIN 10996
#define IDS_CERT_EXPORT_TYPE_DER 10997
#define IDS_CERT_EXPORT_TYPE_PKCS7 10998
#define IDS_CERT_EXPORT_TYPE_PKCS7_CHAIN 10999
#define IDS_CERT_INFO_DIALOG_TITLE 11000
#define IDS_CERT_INFO_GENERAL_TAB_LABEL 11001
#define IDS_CERT_INFO_DETAILS_TAB_LABEL 11002
#define IDS_CERT_INFO_MODIFICATIONS_TAB_LABEL 11003
#define IDS_CERT_INFO_TRUST_LABEL 11004
#define IDS_CERT_INFO_TRUST_STATE_LABEL 11005
#define IDS_CERT_INFO_TRUST_STATE_DISTRUSTED 11006
#define IDS_CERT_INFO_TRUST_STATE_HINT 11007
#define IDS_CERT_INFO_TRUST_STATE_TRUSTED 11008
#define IDS_CERT_INFO_CONSTRAINTS_LABEL 11009
#define IDS_CERT_INFO_ADD_CONSTRAINTS_LABEL 11010
#define IDS_CERT_INFO_ADD_CONSTRAINTS_BUTTON_LABEL 11011
#define IDS_CERT_INFO_ADD_CONSTRAINTS_PLACEHOLDER 11012
#define IDS_CERT_INFO_ADD_CONSTRAINT_ERROR_MESSAGE 11013
#define IDS_CERT_INFO_DELETE_CONSTRAINT_ERROR_MESSAGE 11014
#define IDS_CERT_INFO_TRUST_STATE_ERROR_MESSAGE 11015
#define IDS_CERT_USAGE_SSL_CLIENT 11016
#define IDS_CERT_USAGE_SSL_SERVER 11017
#define IDS_CERT_USAGE_OBJECT_SIGNER 11018
#define IDS_CERT_USAGE_SSL_CA 11019
#define IDS_CERT_INFO_IDN_VALUE_FORMAT 11020
#define IDS_CERT_INFO_FIELD_NOT_PRESENT 11021
#define IDS_CERT_DETAILS_CERTIFICATE_HIERARCHY_LABEL 11022
#define IDS_CERT_DETAILS_CERTIFICATE_FIELDS_LABEL 11023
#define IDS_CERT_DETAILS_CERTIFICATE_FIELD_VALUE_LABEL 11024
#define IDS_CERT_DETAILS_CERTIFICATE 11025
#define IDS_CERT_DETAILS_VERSION 11026
#define IDS_CERT_DETAILS_VERSION_FORMAT 11027
#define IDS_CERT_DETAILS_SERIAL_NUMBER 11028
#define IDS_CERT_DETAILS_CERTIFICATE_SIG_ALG 11029
#define IDS_CERT_DETAILS_ISSUER 11030
#define IDS_CERT_DETAILS_VALIDITY 11031
#define IDS_CERT_DETAILS_NOT_BEFORE 11032
#define IDS_CERT_DETAILS_NOT_AFTER 11033
#define IDS_CERT_DETAILS_SUBJECT 11034
#define IDS_CERT_DETAILS_SUBJECT_KEY_INFO 11035
#define IDS_CERT_DETAILS_SUBJECT_KEY_ALG 11036
#define IDS_CERT_DETAILS_SUBJECT_KEY 11037
#define IDS_CERT_RSA_PUBLIC_KEY_DUMP_FORMAT 11038
#define IDS_CERT_DETAILS_CERTIFICATE_SIG_VALUE 11039
#define IDS_CERT_DETAILS_EXPORT_CERTIFICATE 11040
#define IDS_CERT_DETAILS_EXPORT_CERTIFICATE_A11Y_LABEL 11041
#define IDS_CERT_OID_AVA_COMMON_NAME 11042
#define IDS_CERT_OID_AVA_STATE_OR_PROVINCE 11043
#define IDS_CERT_OID_AVA_ORGANIZATION_NAME 11044
#define IDS_CERT_OID_AVA_ORGANIZATIONAL_UNIT_NAME 11045
#define IDS_CERT_OID_AVA_DN_QUALIFIER 11046
#define IDS_CERT_OID_AVA_COUNTRY_NAME 11047
#define IDS_CERT_OID_AVA_SERIAL_NUMBER 11048
#define IDS_CERT_OID_AVA_LOCALITY 11049
#define IDS_CERT_OID_AVA_DC 11050
#define IDS_CERT_OID_RFC1274_MAIL 11051
#define IDS_CERT_OID_RFC1274_UID 11052
#define IDS_CERT_OID_PKCS9_EMAIL_ADDRESS 11053
#define IDS_CERT_OID_BUSINESS_CATEGORY 11054
#define IDS_CERT_OID_EV_INCORPORATION_LOCALITY 11055
#define IDS_CERT_OID_EV_INCORPORATION_STATE 11056
#define IDS_CERT_OID_EV_INCORPORATION_COUNTRY 11057
#define IDS_CERT_OID_AVA_STREET_ADDRESS 11058
#define IDS_CERT_OID_AVA_POSTAL_CODE 11059
#define IDS_CERT_EXT_NS_CERT_TYPE 11060
#define IDS_CERT_EXT_NS_CERT_TYPE_EMAIL 11061
#define IDS_CERT_EXT_NS_CERT_TYPE_EMAIL_CA 11062
#define IDS_CERT_EXT_NS_CERT_BASE_URL 11063
#define IDS_CERT_EXT_NS_CERT_REVOCATION_URL 11064
#define IDS_CERT_EXT_NS_CA_REVOCATION_URL 11065
#define IDS_CERT_EXT_NS_CERT_RENEWAL_URL 11066
#define IDS_CERT_EXT_NS_CA_POLICY_URL 11067
#define IDS_CERT_EXT_NS_SSL_SERVER_NAME 11068
#define IDS_CERT_EXT_NS_COMMENT 11069
#define IDS_CERT_EXT_NS_LOST_PASSWORD_URL 11070
#define IDS_CERT_EXT_NS_CERT_RENEWAL_TIME 11071
#define IDS_CERT_X509_SUBJECT_DIRECTORY_ATTR 11072
#define IDS_CERT_X509_SUBJECT_KEYID 11073
#define IDS_CERT_KEYID_FORMAT 11074
#define IDS_CERT_ISSUER_FORMAT 11075
#define IDS_CERT_SERIAL_NUMBER_FORMAT 11076
#define IDS_CERT_X509_KEY_USAGE 11077
#define IDS_CERT_X509_ISSUER_ALT_NAME 11078
#define IDS_CERT_X509_BASIC_CONSTRAINTS 11079
#define IDS_CERT_X509_NAME_CONSTRAINTS 11080
#define IDS_CERT_X509_CRL_DIST_POINTS 11081
#define IDS_CERT_X509_CERT_POLICIES 11082
#define IDS_CERT_X509_SCT_LIST 11083
#define IDS_CERT_QC_STATEMENTS 11084
#define IDS_CERT_X509_POLICY_MAPPINGS 11085
#define IDS_CERT_X509_POLICY_CONSTRAINTS 11086
#define IDS_CERT_X509_AUTH_KEYID 11087
#define IDS_CERT_X509_EXT_KEY_USAGE 11088
#define IDS_CERT_X509_KEY_USAGE_SIGNING 11089
#define IDS_CERT_X509_BASIC_CONSTRAINT_IS_CA 11090
#define IDS_CERT_X509_BASIC_CONSTRAINT_IS_NOT_CA 11091
#define IDS_CERT_X509_BASIC_CONSTRAINT_PATH_LEN 11092
#define IDS_CERT_X509_BASIC_CONSTRAINT_PATH_LEN_UNLIMITED 11093
#define IDS_CERT_REVOCATION_REASON_UNUSED 11094
#define IDS_CERT_REVOCATION_REASON_KEY_COMPROMISE 11095
#define IDS_CERT_REVOCATION_REASON_CA_COMPROMISE 11096
#define IDS_CERT_REVOCATION_REASON_AFFILIATION_CHANGED 11097
#define IDS_CERT_REVOCATION_REASON_SUPERSEDED 11098
#define IDS_CERT_REVOCATION_REASON_CESSATION_OF_OPERATION 11099
#define IDS_CERT_REVOCATION_REASON_CERTIFICATE_HOLD 11100
#define IDS_CERT_OCSP_RESPONDER_FORMAT 11101
#define IDS_CERT_CA_ISSUERS_FORMAT 11102
#define IDS_CERT_UNKNOWN_OID_INFO_FORMAT 11103
#define IDS_CERT_EXT_KEY_USAGE_FORMAT 11104
#define IDS_CERT_MULTILINE_INFO_START_FORMAT 11105
#define IDS_CERT_GENERAL_NAME_RFC822_NAME 11106
#define IDS_CERT_GENERAL_NAME_DNS_NAME 11107
#define IDS_CERT_GENERAL_NAME_X400_ADDRESS 11108
#define IDS_CERT_GENERAL_NAME_DIRECTORY_NAME 11109
#define IDS_CERT_GENERAL_NAME_EDI_PARTY_NAME 11110
#define IDS_CERT_GENERAL_NAME_URI 11111
#define IDS_CERT_GENERAL_NAME_IP_ADDRESS 11112
#define IDS_CERT_GENERAL_NAME_REGISTERED_ID 11113
#define IDS_CERT_EXT_MS_APP_POLICIES 11114
#define IDS_CERT_EXT_MS_CERT_TEMPLATE 11115
#define IDS_CERT_EXT_MS_CERT_TYPE 11116
#define IDS_CERT_EXT_MS_CA_VERSION 11117
#define IDS_CERT_EXT_MS_NT_PRINCIPAL_NAME 11118
#define IDS_CERT_EXT_MS_NTDS_REPLICATION 11119
#define IDS_CERT_EKU_TLS_WEB_SERVER_AUTHENTICATION 11120
#define IDS_CERT_EKU_TLS_WEB_CLIENT_AUTHENTICATION 11121
#define IDS_CERT_EKU_OCSP_SIGNING 11122
#define IDS_CERT_POLICY_ETSI_QEVCP_W 11123
#define IDS_CERT_POLICY_ETSI_QNCP_W 11124
#define IDS_CERT_QC_ETSI_QCS_QCCOMPLIANCE 11125
#define IDS_CERT_QC_ETSI_QCS_QCTYPE 11126
#define IDS_CERT_QC_ETSI_QCT_WEB 11127
#define IDS_CERT_EKU_MS_INDIVIDUAL_CODE_SIGNING 11128
#define IDS_CERT_EKU_MS_COMMERCIAL_CODE_SIGNING 11129
#define IDS_CERT_EKU_MS_TRUST_LIST_SIGNING 11130
#define IDS_CERT_EKU_MS_TIME_STAMPING 11131
#define IDS_CERT_EKU_MS_SERVER_GATED_CRYPTO 11132
#define IDS_CERT_EKU_MS_ENCRYPTING_FILE_SYSTEM 11133
#define IDS_CERT_EKU_MS_FILE_RECOVERY 11134
#define IDS_CERT_EKU_MS_WINDOWS_HARDWARE_DRIVER_VERIFICATION 11135
#define IDS_CERT_EKU_MS_QUALIFIED_SUBORDINATION 11136
#define IDS_CERT_EKU_MS_KEY_RECOVERY 11137
#define IDS_CERT_EKU_MS_DOCUMENT_SIGNING 11138
#define IDS_CERT_EKU_MS_LIFETIME_SIGNING 11139
#define IDS_CERT_EKU_MS_SMART_CARD_LOGON 11140
#define IDS_CERT_EKU_MS_KEY_RECOVERY_AGENT 11141
#define IDS_CERT_EKU_NETSCAPE_INTERNATIONAL_STEP_UP 11142
#define IDS_CERT_EXTENSION_CRITICAL 11143
#define IDS_CERT_EXTENSION_NON_CRITICAL 11144
#define IDS_CERT_DUMP_ERROR 11145
#define IDS_CERT_EXTENSION_DUMP_ERROR 11146
#define IDS_CERTIFICATE_MANAGER_TITLE 11147
#define IDS_CERT_MANAGER_HARDWARE_BACKED_KEY_FORMAT 11148
#define IDS_CERT_MANAGER_HARDWARE_BACKED 11149
#define IDS_CERT_MANAGER_EXTENSION_PROVIDED_FORMAT 11150
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR 11151
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR_LEARN_MORE 11152
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR_OPT_OUT 11153
#define IDS_DEV_TOOLS_SHARED_PROCESS_INFOBAR_RESTART_NEEDED 11154
#define IDS_DEV_TOOLS_INFOBAR_LABEL 11155
#define IDS_DEV_TOOLS_CONFIRM_ADD_FILE_SYSTEM_MESSAGE 11156
#define IDS_DEV_TOOLS_EDIT_DIRECTORY_PERMISSION_TITLE 11157
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_TITLE 11158
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_MESSAGE_PART_1 11159
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_MESSAGE_PART_2 11160
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_ALLOW_TEXT 11161
#define IDS_DEV_TOOLS_CONNECTION_DIALOG_DISABLE_TEXT 11162
#define IDS_DEV_TOOLS_CONFIRM_ALLOW_BUTTON 11163
#define IDS_DEV_TOOLS_CONFIRM_DENY_BUTTON 11164
#define IDS_RELOAD_MENU_NORMAL_RELOAD_ITEM 11165
#define IDS_RELOAD_MENU_HARD_RELOAD_ITEM 11166
#define IDS_RELOAD_MENU_EMPTY_AND_HARD_RELOAD_ITEM 11167
#define IDS_TAB_SHARING_INFOBAR_SHARING_CURRENT_TAB_LABEL 11168
#define IDS_TAB_SHARING_INFOBAR_SHARING_ANOTHER_UNTITLED_TAB_LABEL 11169
#define IDS_TAB_SHARING_INFOBAR_SHARING_ANOTHER_TAB_LABEL 11170
#define IDS_TAB_SHARING_INFOBAR_SHARING_ANOTHER_TAB_TO_THIS_TAB_LABEL 11171
#define IDS_TAB_SHARING_INFOBAR_SHARE_BUTTON 11172
#define IDS_TAB_SHARING_INFOBAR_STOP_BUTTON 11173
#define IDS_TAB_SHARING_INFOBAR_SWITCH_TO_BUTTON 11174
#define IDS_TAB_SHARING_INFOBAR_SWITCH_TO_CAPTURER_BUTTON 11175
#define IDS_TAB_SHARING_INFOBAR_SWITCH_TO_CAPTURED_BUTTON 11176
#define IDS_TAB_SHARING_INFOBAR_CAPTURED_SURFACE_CONTROL_PERMISSION_BUTTON 11177
#define IDS_TAB_CASTING_INFOBAR_CASTING_CURRENT_TAB_LABEL 11178
#define IDS_TAB_CASTING_INFOBAR_CASTING_CURRENT_TAB_NO_DEVICE_NAME_LABEL 11179
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_UNTITLED_TAB_LABEL 11180
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_UNTITLED_TAB_NO_DEVICE_NAME_LABEL 11181
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_TAB_LABEL 11182
#define IDS_TAB_CASTING_INFOBAR_CASTING_ANOTHER_TAB_NO_DEVICE_NAME_LABEL 11183
#define IDS_TAB_CASTING_INFOBAR_CAST_BUTTON 11184
#define IDS_TAB_CASTING_INFOBAR_STOP_BUTTON 11185
#define IDS_TASK_MANAGER_KILL 11186
#define IDS_TASK_MANAGER_KILL_V2 11187
#define IDS_TASK_MANAGER_PROCESS_ID_COLUMN 11188
#define IDS_TASK_MANAGER_GDI_HANDLES_COLUMN 11189
#define IDS_TASK_MANAGER_USER_HANDLES_COLUMN 11190
#define IDS_TASK_MANAGER_TASK_COLUMN 11191
#define IDS_TASK_MANAGER_NET_COLUMN 11192
#define IDS_TASK_MANAGER_CPU_COLUMN 11193
#define IDS_TASK_MANAGER_START_TIME_COLUMN 11194
#define IDS_TASK_MANAGER_CPU_TIME_COLUMN 11195
#define IDS_TASK_MANAGER_MEM_FOOTPRINT_COLUMN 11196
#define IDS_TASK_MANAGER_SWAPPED_MEM_COLUMN 11197
#define IDS_TASK_MANAGER_PROFILE_NAME_COLUMN 11198
#define IDS_TASK_MANAGER_IDLE_WAKEUPS_COLUMN 11199
#define IDS_TASK_MANAGER_HARD_FAULTS_COLUMN 11200
#define IDS_TASK_MANAGER_OPEN_FD_COUNT_COLUMN 11201
#define IDS_TASK_MANAGER_PROCESS_PRIORITY_COLUMN 11202
#define IDS_TASK_MANAGER_WEBCORE_IMAGE_CACHE_COLUMN 11203
#define IDS_TASK_MANAGER_WEBCORE_SCRIPTS_CACHE_COLUMN 11204
#define IDS_TASK_MANAGER_WEBCORE_CSS_CACHE_COLUMN 11205
#define IDS_TASK_MANAGER_VIDEO_MEMORY_COLUMN 11206
#define IDS_TASK_MANAGER_SQLITE_MEMORY_USED_COLUMN 11207
#define IDS_TASK_MANAGER_JAVASCRIPT_MEMORY_ALLOCATED_COLUMN 11208
#define IDS_TASK_MANAGER_KEEPALIVE_COUNT_COLUMN 11209
#define IDS_TASK_MANAGER_MEM_CELL_TEXT 11210
#define IDS_TASK_MANAGER_CACHE_SIZE_CELL_TEXT 11211
#define IDS_TASK_MANAGER_NA_CELL_TEXT 11212
#define IDS_TASK_MANAGER_BACKGROUNDED_TEXT 11213
#define IDS_TASK_MANAGER_FOREGROUNDED_TEXT 11214
#define IDS_TASK_MANAGER_HANDLES_CELL_TEXT 11215
#define IDS_TASK_MANAGER_TASK_GROUP_CONNECT_TEXT 11216
#define IDS_TASK_MANAGER_WEB_BROWSER_CELL_TEXT 11217
#define IDS_TASK_MANAGER_EXTENSION_PREFIX 11218
#define IDS_TASK_MANAGER_EXTENSION_INCOGNITO_PREFIX 11219
#define IDS_TASK_MANAGER_APP_PREFIX 11220
#define IDS_TASK_MANAGER_APP_INCOGNITO_PREFIX 11221
#define IDS_TASK_MANAGER_TAB_PREFIX 11222
#define IDS_TASK_MANAGER_TAB_INCOGNITO_PREFIX 11223
#define IDS_TASK_MANAGER_BACKGROUND_APP_PREFIX 11224
#define IDS_TASK_MANAGER_BACKGROUND_PREFIX 11225
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_PREFIX 11226
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_INCOGNITO_PREFIX 11227
#define IDS_TASK_MANAGER_PRELOADED_RENDERER_FOR_UI 11228
#define IDS_TASK_MANAGER_NO_STATE_PREFETCH_PREFIX 11229
#define IDS_TASK_MANAGER_PRERENDER_PREFIX 11230
#define IDS_TASK_MANAGER_SPARE_RENDERER_PREFIX 11231
#define IDS_TASK_MANAGER_UNKNOWN_RENDERER_PREFIX 11232
#define IDS_TASK_MANAGER_DEDICATED_WORKER_PREFIX 11233
#define IDS_TASK_MANAGER_SHARED_WORKER_PREFIX 11234
#define IDS_TASK_MANAGER_SERVICE_WORKER_PREFIX 11235
#define IDS_TASK_MANAGER_UTILITY_PREFIX 11236
#define IDS_TASK_MANAGER_GPU_PREFIX 11237
#define IDS_TASK_MANAGER_PRINT_PREFIX 11238
#define IDS_TASK_MANAGER_SUBFRAME_PREFIX 11239
#define IDS_TASK_MANAGER_SUBFRAME_INCOGNITO_PREFIX 11240
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_SUBFRAME_PREFIX 11241
#define IDS_TASK_MANAGER_BACK_FORWARD_CACHE_INCOGNITO_SUBFRAME_PREFIX 11242
#define IDS_TASK_MANAGER_PDF_SUBFRAME_PREFIX 11243
#define IDS_TASK_MANAGER_PDF_SUBFRAME_INCOGNITO_PREFIX 11244
#define IDS_TASK_MANAGER_PORTAL_PREFIX 11245
#define IDS_TASK_MANAGER_PORTAL_INCOGNITO_PREFIX 11246
#define IDS_TASK_MANAGER_FENCED_FRAME_PREFIX 11247
#define IDS_TASK_MANAGER_FENCED_FRAME_INCOGNITO_PREFIX 11248
#define IDS_TASK_MANAGER_ARC_PREFIX 11249
#define IDS_TASK_MANAGER_TOOL_PREFIX 11250
#define IDS_TASK_MANAGER_ARC_PREFIX_BACKGROUND_SERVICE 11251
#define IDS_TASK_MANAGER_ARC_PREFIX_RECEIVER 11252
#define IDS_TASK_MANAGER_ARC_SYSTEM 11253
#define IDS_TASK_MANAGER_LINUX_VM_PREFIX 11254
#define IDS_TASK_MANAGER_PLUGIN_VM_PREFIX 11255
#define IDS_TASK_MANAGER_OMNIBOX 11256
#define IDS_UTILITY_PROCESS_FILE_UTILITY_NAME 11257
#define IDS_UTILITY_PROCESS_PROFILE_IMPORTER_NAME 11258
#define IDS_UTILITY_PROCESS_QRCODE_GENERATOR_SERVICE_NAME 11259
#define IDS_UTILITY_PROCESS_IMAGE_WRITER_NAME 11261
#define IDS_UTILITY_PROCESS_MEDIA_GALLERY_UTILITY_NAME 11262
#define IDS_UTILITY_PROCESS_NOOP_SERVICE_NAME 11263
#define IDS_SERVICE_PROCESS_DOCUMENT_ANALYSIS_NAME 11264
#define IDS_THEME_INSTALL_INFOBAR_LABEL 11265
#define IDS_THEME_INSTALL_INFOBAR_UNDO_BUTTON 11266
#define IDS_CRITICAL_NOTIFICATION_RESTART 11267
#define IDS_EXTENSION_DISABLED_ERROR_LABEL 11268
#define IDS_EXTENSION_DISABLED_REMOTE_INSTALL_ERROR_TITLE 11269
#define IDS_EXTENSION_DISABLED_ERROR_TITLE 11270
#define IDS_EXTENSION_SITE_RELOAD_PAGE_BUBBLE_HEADING 11271
#define IDS_EXTENSION_RELOAD_PAGE_BUBBLE_OK_BUTTON 11272
#define IDS_EXTENSION_RELOAD_PAGE_BUBBLE_ALLOW_SINGLE_EXTENSION_TITLE 11273
#define IDS_EXTENSION_RELOAD_PAGE_BUBBLE_ALLOW_MULTIPLE_EXTENSIONS_TITLE 11274
#define IDS_APP_UNINSTALL_PROMPT_TITLE 11275
#define IDS_ARC_APP_UNINSTALL_PROMPT_DATA_REMOVAL_WARNING 11276
#define IDS_EXTENSION_UNINSTALL_PROMPT_TITLE 11277
#define IDS_EXTENSION_CONFIRM_PERMISSIONS 11278
#define IDS_EXTENSION_INSTALL_PROMPT_TITLE 11279
#define IDS_EXTENSION_REQUEST_PROMPT_TITLE 11280
#define IDS_EXTENSION_PENDING_REQUEST_PROMPT_TITLE 11281
#define IDS_EXTENSION_BLOCKED_BY_POLICY_PROMPT_TITLE 11282
#define IDS_EXTENSION_RE_ENABLE_PROMPT_TITLE 11283
#define IDS_EXTENSION_PERMISSIONS_PROMPT_TITLE 11284
#define IDS_EXTENSION_REMOTE_INSTALL_PROMPT_TITLE 11285
#define IDS_EXTENSION_REPAIR_PROMPT_TITLE 11286
#define IDS_EXTENSION_ASK_PARENT_PROMPT_TITLE 11287
#define IDS_EXTENSION_ASK_PARENT_PROMPT_BODY 11288
#define IDS_EXTENSION_ASK_PARENT_PROMPT_ASK_IN_PERSON_BUTTON 11289
#define IDS_EXTENSION_PARENT_APPROVAL_PROMPT_TITLE 11290
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ACCEPT_BUTTON_EXTENSION 11291
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ACCEPT_BUTTON_APP 11292
#define IDS_EXTENSION_EXTERNAL_INSTALL_PROMPT_ACCEPT_BUTTON_THEME 11293
#define IDS_EXTENSION_ALERT_TITLE 11294
#define IDS_APP_ALERT_TITLE 11295
#define IDS_EXTENSION_AND_APP_ALERT_TITLE 11296
#define IDS_POLICY_BLOCKED_EXTENSION_ALERT_TITLE 11297
#define IDS_POLICY_BLOCKED_EXTENSIONS_ALERT_ITEM_TITLE 11298
#define IDS_BLOCKLISTED_EXTENSIONS_ALERT_ITEM 11299
#define IDS_POLICY_BLOCKED_EXTENSION_ALERT_ITEM_DETAIL 11300
#define IDS_EXTENSION_ALERT_ITEM_OK 11301
#define IDS_EXTENSION_ALERT_ITEM_DETAILS 11302
#define IDS_EXTENSION_PROMPT_APP_CONNECT_FROM_INCOGNITO 11303
#define IDS_EXTENSION_PROMPT_EXTENSION_CONNECT_FROM_INCOGNITO 11304
#define IDS_EXTENSION_PROMPT_WILL_HAVE_ACCESS_TO 11305
#define IDS_EXTENSION_PROMPT_WILL_NOW_HAVE_ACCESS_TO 11306
#define IDS_EXTENSION_PROMPT_WANTS_ACCESS_TO 11307
#define IDS_EXTENSION_PROMPT_CAN_ACCESS 11308
#define IDS_EXTENSION_PROMPT_REQUESTS_PERMISSIONS 11309
#define IDS_EXTENSION_PROMPT_GRANT_PERMISSIONS_CHECKBOX 11310
#define IDS_EXTENSION_PERMISSION_LINE 11311
#define IDS_EXTENSION_RATING_COUNT 11312
#define IDS_EXTENSION_PROMPT_RATING_ACCESSIBLE_TEXT 11313
#define IDS_EXTENSION_PROMPT_NO_RATINGS_ACCESSIBLE_TEXT 11314
#define IDS_EXTENSION_USER_COUNT 11315
#define IDS_EXTENSION_PROMPT_STORE_LINK 11316
#define IDS_EXTENSION_PROMPT_WARNING_FULL_ACCESS 11317
#define IDS_EXTENSION_PROMPT_WARNING_ALL_HOSTS 11318
#define IDS_EXTENSION_PROMPT_WARNING_ALL_HOSTS_READ_ONLY 11319
#define IDS_EXTENSION_PROMPT_WARNING_AUDIO_CAPTURE 11320
#define IDS_EXTENSION_PROMPT_WARNING_VIDEO_CAPTURE 11321
#define IDS_EXTENSION_PROMPT_WARNING_AUDIO_AND_VIDEO_CAPTURE 11322
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH 11323
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH_DEVICES 11324
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH_PRIVATE 11325
#define IDS_EXTENSION_PROMPT_WARNING_BLUETOOTH_SERIAL 11326
#define IDS_EXTENSION_PROMPT_WARNING_BOOKMARKS 11327
#define IDS_EXTENSION_PROMPT_WARNING_READING_LIST 11328
#define IDS_EXTENSION_PROMPT_WARNING_CLIPBOARD 11329
#define IDS_EXTENSION_PROMPT_WARNING_CLIPBOARD_READWRITE 11330
#define IDS_EXTENSION_PROMPT_WARNING_CLIPBOARD_WRITE 11331
#define IDS_EXTENSION_PROMPT_WARNING_DEBUGGER 11332
#define IDS_EXTENSION_PROMPT_WARNING_DECLARATIVE_WEB_REQUEST 11333
#define IDS_EXTENSION_PROMPT_WARNING_DECLARATIVE_NET_REQUEST 11334
#define IDS_EXTENSION_PROMPT_WARNING_DOCUMENT_SCAN 11335
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_HARDWARE_PLATFORM 11336
#define IDS_EXTENSION_PROMPT_WARNING_FAVICON 11337
#define IDS_EXTENSION_PROMPT_WARNING_GEOLOCATION 11338
#define IDS_EXTENSION_PROMPT_WARNING_HISTORY_READ 11339
#define IDS_EXTENSION_PROMPT_WARNING_HISTORY_READ_ON_ALL_DEVICES 11340
#define IDS_EXTENSION_PROMPT_WARNING_HISTORY_WRITE_ON_ALL_DEVICES 11341
#define IDS_EXTENSION_PROMPT_WARNING_HOME_PAGE_SETTING_OVERRIDE 11342
#define IDS_EXTENSION_PROMPT_WARNING_1_HOST 11343
#define IDS_EXTENSION_PROMPT_WARNING_1_HOST_READ_ONLY 11344
#define IDS_EXTENSION_PROMPT_WARNING_2_HOSTS 11345
#define IDS_EXTENSION_PROMPT_WARNING_2_HOSTS_READ_ONLY 11346
#define IDS_EXTENSION_PROMPT_WARNING_3_HOSTS 11347
#define IDS_EXTENSION_PROMPT_WARNING_3_HOSTS_READ_ONLY 11348
#define IDS_EXTENSION_PROMPT_WARNING_HOSTS_LIST 11349
#define IDS_EXTENSION_PROMPT_WARNING_HOSTS_LIST_READ_ONLY 11350
#define IDS_EXTENSION_PROMPT_WARNING_HOST_AND_SUBDOMAIN 11351
#define IDS_EXTENSION_PROMPT_WARNING_HOST_AND_SUBDOMAIN_LIST 11352
#define IDS_EXTENSION_PROMPT_WARNING_INPUT 11353
#define IDS_EXTENSION_PROMPT_WARNING_LOGIN 11354
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_LOGIN 11355
#define IDS_EXTENSION_PROMPT_WARNING_LOGIN_SCREEN_UI 11356
#define IDS_EXTENSION_PROMPT_WARNING_LOGIN_SCREEN_STORAGE 11357
#define IDS_EXTENSION_PROMPT_WARNING_MANAGEMENT 11358
#define IDS_EXTENSION_PROMPT_WARNING_MDNS 11359
#define IDS_EXTENSION_PROMPT_WARNING_NETWORK_STATE 11360
#define IDS_EXTENSION_PROMPT_WARNING_NETWORKING_PRIVATE 11361
#define IDS_EXTENSION_PROMPT_WARNING_PRINTING 11362
#define IDS_EXTENSION_PROMPT_WARNING_PRINTING_METRICS 11363
#define IDS_EXTENSION_PROMPT_WARNING_SEARCH_SETTINGS_OVERRIDE 11364
#define IDS_EXTENSION_PROMPT_WARNING_SERIAL 11365
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_ANY_HOST 11366
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_HOSTS_IN_DOMAIN 11367
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_HOSTS_IN_DOMAINS 11368
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_SPECIFIC_HOST 11369
#define IDS_EXTENSION_PROMPT_WARNING_SOCKET_SPECIFIC_HOSTS 11370
#define IDS_EXTENSION_PROMPT_WARNING_SPEECH_RECOGNITION 11371
#define IDS_EXTENSION_PROMPT_WARNING_START_PAGE_SETTING_OVERRIDE 11372
#define IDS_EXTENSION_PROMPT_WARNING_SYSTEM_STORAGE 11373
#define IDS_EXTENSION_PROMPT_WARNING_TAB_GROUPS 11374
#define IDS_EXTENSION_PROMPT_WARNING_TOPSITES 11375
#define IDS_EXTENSION_PROMPT_WARNING_TTS_ENGINE 11376
#define IDS_EXTENSION_PROMPT_WARNING_U2F_DEVICES 11377
#define IDS_EXTENSION_PROMPT_WARNING_NOTIFICATIONS 11378
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE 11379
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_LIST 11380
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_LIST_ITEM_UNKNOWN_PRODUCT 11381
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_LIST_ITEM_UNKNOWN_VENDOR 11382
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_UNKNOWN_PRODUCT 11383
#define IDS_EXTENSION_PROMPT_WARNING_USB_DEVICE_UNKNOWN_VENDOR 11384
#define IDS_EXTENSION_PROMPT_WARNING_VPN 11385
#define IDS_EXTENSION_PROMPT_WARNING_CONTENT_SETTINGS 11386
#define IDS_EXTENSION_PROMPT_WARNING_PRIVACY 11387
#define IDS_EXTENSION_PROMPT_WARNING_DOWNLOADS 11388
#define IDS_EXTENSION_PROMPT_WARNING_DOWNLOADS_OPEN 11389
#define IDS_EXTENSION_PROMPT_WARNING_IDENTITY_EMAIL 11390
#define IDS_EXTENSION_PROMPT_WARNING_WALLPAPER 11391
#define IDS_EXTENSION_PROMPT_WARNING_FILE_SYSTEM_DIRECTORY 11392
#define IDS_EXTENSION_PROMPT_WARNING_FILE_SYSTEM_WRITE_DIRECTORY 11393
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ 11394
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ_WRITE 11395
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ_DELETE 11396
#define IDS_EXTENSION_PROMPT_WARNING_MEDIA_GALLERIES_READ_WRITE_DELETE 11397
#define IDS_EXTENSION_PROMPT_WARNING_SYNCFILESYSTEM 11398
#define IDS_EXTENSION_PROMPT_WARNING_NATIVE_MESSAGING 11399
#define IDS_EXTENSION_PROMPT_WARNING_SCREENLOCK_PRIVATE 11400
#define IDS_EXTENSION_PROMPT_WARNING_ACTIVITY_LOG_PRIVATE 11401
#define IDS_EXTENSION_PROMPT_WARNING_DESKTOP_CAPTURE 11402
#define IDS_EXTENSION_PROMPT_WARNING_ACCESSIBILITY_FEATURES_MODIFY 11403
#define IDS_EXTENSION_PROMPT_WARNING_ACCESSIBILITY_FEATURES_READ 11404
#define IDS_EXTENSION_PROMPT_WARNING_ACCESSIBILITY_FEATURES_READ_MODIFY 11405
#define IDS_EXTENSION_PROMPT_WARNING_PLATFORMKEYS 11406
#define IDS_EXTENSION_PROMPT_WARNING_CERTIFICATEPROVIDER 11407
#define IDS_EXTENSION_PROMPT_WARNING_SETTINGS_PRIVATE 11408
#define IDS_EXTENSION_PROMPT_WARNING_AUTOFILL_PRIVATE 11409
#define IDS_EXTENSION_PROMPT_WARNING_PASSWORDS_PRIVATE 11410
#define IDS_EXTENSION_PROMPT_WARNING_USERS_PRIVATE 11411
#define IDS_EXTENSION_PROMPT_WARNING_NEW_TAB_PAGE_OVERRIDE 11412
#define IDS_EXTENSION_PROMPT_WARNING_TRANSIENT_BACKGROUND 11413
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_DEVICE_ATTRIBUTES 11414
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_KIOSK_INPUT 11415
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_NETWORKING_ATTRIBUTES 11416
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_PLATFORMKEYS 11417
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_REPORTING_PRIVATE_ENABLED_LINUX_AND_MACOS 11419
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_REPORTING_PRIVATE 11420
#define IDS_EXTENSION_PROMPT_WARNING_ENTERPRISE_REMOTE_APPS 11421
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_ATTACHED_DEVICE_INFO 11422
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_BLUETOOTH_PERIPHERALS_INFO 11423
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_DIAGNOSTICS 11424
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_DIAGNOSTICS_NETWORK_INFO_FOR_MLAB 11425
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_EVENTS 11426
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_MANAGEMENT_AUDIO 11427
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_TELEMETRY 11428
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_TELEMETRY_SERIAL_NUMBER 11429
#define IDS_EXTENSION_PROMPT_WARNING_CHROMEOS_TELEMETRY_NETWORK_INFORMATION 11430
#define IDS_EXTENSION_PROMPT_WARNING_OMNIBOX_DIRECT_INPUT 11431
#define IDS_EXTENSION_INVALID_IMAGE_PATH 11434
#define IDS_EXTENSION_ASKS_IDENTITY_WHILE_SIGNED_IN_WEB_ONLY_BODY_PART_2 11436
#define IDS_EXTENSION_INSTALLED_PAGE_ACTION_INFO 11438
#define IDS_EXTENSION_INSTALLED_PAGE_ACTION_INFO_WITH_SHORTCUT 11439
#define IDS_EXTENSION_INSTALLED_BROWSER_ACTION_INFO 11440
#define IDS_EXTENSION_INSTALLED_BROWSER_ACTION_INFO_WITH_SHORTCUT 11441
#define IDS_EXTENSION_INSTALLED_OMNIBOX_KEYWORD_INFO 11442
#define IDS_EXTENSION_INSTALLED_MANAGE_INFO 11443
#define IDS_EXTENSION_INSTALLED_MANAGE_SHORTCUTS 11445
#define IDS_EXTENSION_INSTALLED_MANAGE_SHORTCUTS_LINK_TEXT 11446
#define IDS_EXTENSION_LAUNCH_WEB_AUTH_FLOW_TAB_INFO_BAR_TEXT 11447
#define IDS_EXTENSION_INSTALLED_DICE_PROMO_SYNC_MESSAGE 11448
#define IDS_EXTENSION_VERIFY_PROMO_SUBTITLE 11449
#define IDS_EXTENSIONS_DIRECTORY_CONFIRMATION_DIALOG_TITLE 11450
#define IDS_EXTENSIONS_DIRECTORY_CONFIRMATION_DIALOG_MESSAGE_READ_ONLY 11451
#define IDS_EXTENSIONS_DIRECTORY_CONFIRMATION_DIALOG_MESSAGE_WRITABLE 11452
#define IDS_DIRECT_SOCKETS_CONNECTION_BUBBLE_TITLE_LABEL 11453
#define IDS_DIRECT_SOCKETS_CONNECTION_BUBBLE_ADDRESS_LABEL 11454
#define IDS_DIRECT_SOCKETS_CONNECTION_BUBBLE_PORT_LABEL 11455
#define IDS_EXTENSIONS_WANTS_ACCESS_TO_SITE 11456
#define IDS_EXTENSIONS_HAS_ACCESS_TO_SITE 11457
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_TOOLTIP_SINGLE_EXTENSION 11458
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_TITLE_HAS_ACCESS 11459
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_TITLE_BLOCKED_ACCESS 11460
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_TITLE_REQUESTS_ACCESS 11461
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_ALL_EXTENSIONS_ALLOWED_ACCESS 11462
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_ALL_EXTENSIONS_BLOCKED_ACCESS 11463
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_EXTENSION_HAS_ACCESS 11464
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_DESCRIPTION_EXTENSION_REQUESTS_ACCESS 11465
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_POLICY_LABEL_PINNED_TEXT 11466
#define IDS_EXTENSIONS_TOOLBAR_ACTION_HOVER_CARD_POLICY_LABEL_INSTALLED_TEXT 11467
#define IDS_EXTENSIONS_CONTEXT_MENU_SITE_PERMISSIONS 11468
#define IDS_EXTENSIONS_CONTEXT_MENU_CANT_ACCESS_PAGE 11469
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS 11470
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_ALL_EXTENSIONS_GRANTED 11471
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_ALL_EXTENSIONS_BLOCKED 11472
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_CLICK_V2 11473
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_SITE_V2 11474
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_ALL_SITES_V2 11475
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_PERMISSIONS_PAGE 11476
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_CLICK 11477
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_SITE 11478
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_RUN_ON_ALL_SITES 11479
#define IDS_EXTENSIONS_CONTEXT_MENU_PAGE_ACCESS_LEARN_MORE 11480
#define IDS_EXTENSIONS_CONTEXT_MENU_PIN_TO_TOOLBAR 11481
#define IDS_EXTENSIONS_CONTEXT_MENU_UNPIN_FROM_TOOLBAR 11482
#define IDS_EXTENSIONS_OPTIONS_MENU_ITEM 11483
#define IDS_EXTENSIONS_INSTALLED_BY_ADMIN 11484
#define IDS_EXTENSIONS_PIN_TO_TOOLBAR 11485
#define IDS_EXTENSIONS_UNPIN_FROM_TOOLBAR 11486
#define IDS_EXTENSIONS_PINNED_BY_ADMIN 11487
#define IDS_MANAGE_EXTENSION 11488
#define IDS_MANAGE_EXTENSIONS 11489
#define IDS_VIEW_WEB_PERMISSIONS 11490
#define IDS_EXTENSION_ACTION_INSPECT_POPUP 11491
#define IDS_EXTENSIONS_DISABLE 11492
#define IDS_EXTENSIONS_PIN_TO_TOOLBAR_ACCESSIBLE_NAME 11493
#define IDS_EXTENSIONS_UNPIN_FROM_TOOLBAR_ACCESSIBLE_NAME 11494
#define IDS_EXTENSIONS_PINNED_BY_ADMIN_ACCESSIBLE_NAME 11495
#define IDS_EXTENSIONS_SUBMENU_OPEN_SIDE_PANEL_ITEM 11496
#define IDS_EXTENSIONS_SUBMENU_CLOSE_SIDE_PANEL_ITEM 11497
#define IDS_EXTENSIONS_LOCKED_SUPERVISED_USER 11501
#define IDS_EXTENSION_LOAD_FROM_DIRECTORY 11502
#define IDS_EXTENSION_COMMANDS_GENERIC_ACTIVATE 11503
#define IDS_EXTENSION_PACK_DIALOG_HEADING 11504
#define IDS_EXTENSION_PACK_DIALOG_SELECT_KEY 11505
#define IDS_EXTENSION_PACK_DIALOG_KEY_FILE_TYPE_DESCRIPTION 11506
#define IDS_EXTENSION_PACK_DIALOG_ERROR_ROOT_REQUIRED 11507
#define IDS_EXTENSION_PACK_DIALOG_ERROR_ROOT_INVALID 11508
#define IDS_EXTENSION_PACK_DIALOG_ERROR_KEY_INVALID 11509
#define IDS_EXTENSION_PACK_DIALOG_SUCCESS_BODY_NEW 11510
#define IDS_EXTENSION_PACK_DIALOG_SUCCESS_BODY_UPDATE 11511
#define IDS_EXTENSION_PROMPT_INSTALL_FRICTION_CONTINUE_BUTTON 11512
#define IDS_EXTENSION_PROMPT_INSTALL_FRICTION_TITLE 11513
#define IDS_EXTENSION_PROMPT_INSTALL_FRICTION_WARNING_TEXT 11514
#define IDS_EXTENSION_INSTALL_PROMPT_ACCEPT_BUTTON_EXTENSION 11515
#define IDS_EXTENSION_INSTALL_PROMPT_ACCEPT_BUTTON_APP 11516
#define IDS_EXTENSION_INSTALL_PROMPT_ACCEPT_BUTTON_THEME 11517
#define IDS_EXTENSION_INSTALL_PROMPT_ASK_A_PARENT_BUTTON 11518
#define IDS_EXTENSION_INSTALL_BLOCKED_BY_PARENT_PROMPT_TITLE 11519
#define IDS_EXTENSION_ENABLE_BLOCKED_BY_PARENT_PROMPT_TITLE 11520
#define IDS_PARENT_PERMISSION_PROMPT_GO_GET_A_PARENT_FOR_EXTENSION_LABEL 11521
#define IDS_PARENT_PERMISSION_PROMPT_EXTENSION_TYPE_EXTENSION 11522
#define IDS_PARENT_PERMISSION_PROMPT_EXTENSION_TYPE_APP 11523
#define IDS_PARENT_PERMISSION_PROMPT_CHILD_WANTS_TO_INSTALL_LABEL 11524
#define IDS_PARENT_PERMISSION_PROMPT_APPROVE_BUTTON 11525
#define IDS_PARENT_PERMISSION_PROMPT_CANCEL_BUTTON 11526
#define IDS_PARENT_PERMISSION_PROMPT_SELECT_PARENT_LABEL 11527
#define IDS_PARENT_PERMISSION_PROMPT_PARENT_ACCOUNT_LABEL 11528
#define IDS_PARENT_PERMISSION_PROMPT_PARENT_ACCOUNT_VERIFY_LABEL 11529
#define IDS_PARENT_PROMPT_ENTER_PASSWORD_TO_ALLOW_EXTENSION_LABEL 11530
#define IDS_SKIP_PARENT_PERMISSION_EXTENSION_INFORMATION 11531
#define IDS_PARENT_PERMISSION_PROMPT_ENTER_PASSWORD_LABEL 11532
#define IDS_PARENT_PERMISSION_PROMPT_PASSWORD_INCORRECT_LABEL 11533
#define IDS_EXTENSION_INSTALL_PROMPT_REQUEST_BUTTON 11534
#define IDS_EXTENSION_PROMPT_UNINSTALL_BUTTON 11535
#define IDS_EXTENSION_PROMPT_UNINSTALL_REPORT_ABUSE 11536
#define IDS_EXTENSION_PROMPT_UNINSTALL_REPORT_ABUSE_FROM_EXTENSION 11537
#define IDS_EXTENSION_PROMPT_UNINSTALL_TITLE 11538
#define IDS_EXTENSION_PROMPT_UNINSTALL_APP_BUTTON 11539
#define IDS_EXTENSION_PROMPT_MULTIPLE_UNINSTALL_NAME_BULLET_POINT 11540
#define IDS_EXTENSION_PROMPT_MULTIPLE_UNINSTALL_TITLE 11541
#define IDS_EXTENSION_PROMPT_UNINSTALL_TRIGGERED_BY_EXTENSION 11542
#define IDS_EXTENSION_PROMPT_RE_ENABLE_BUTTON 11543
#define IDS_EXTENSION_PROMPT_PERMISSIONS_BUTTON 11544
#define IDS_EXTENSION_PROMPT_PERMISSIONS_ACCEPT_BUTTON 11545
#define IDS_EXTENSION_PROMPT_PERMISSIONS_ABORT_BUTTON 11546
#define IDS_EXTENSION_PROMPT_REMOTE_INSTALL_BUTTON_EXTENSION 11547
#define IDS_EXTENSION_PROMPT_REMOTE_INSTALL_BUTTON_APP 11548
#define IDS_EXTENSION_PROMPT_REPAIR_BUTTON_EXTENSION 11549
#define IDS_EXTENSION_PROMPT_REPAIR_BUTTON_APP 11550
#define IDS_EXTENSION_WEB_STORE_TITLE_SHORT 11551
#define IDS_EXTENSIONS_SHOW_DETAILS 11552
#define IDS_EXTENSIONS_HIDE_DETAILS 11553
#define IDS_EXTENSION_WARNINGS_WRENCH_MENU_ITEM 11554
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_EXTENSION 11555
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_APP 11556
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_THEME 11557
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_TITLE 11558
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_HEADING_APP 11559
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_HEADING_EXTENSION 11560
#define IDS_EXTENSION_EXTERNAL_INSTALL_ALERT_BUBBLE_HEADING_THEME 11561
#define IDS_EXTENSIONS_ADDED_WITHOUT_KNOWLEDGE 11562
#define IDS_EXTENSIONS_ADDED_WITHOUT_KNOWLEDGE_LEARN_MORE 11563
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_KEEP_DIALOG_TITLE 11564
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_KEEP_DIALOG_OK_BUTTON 11565
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_TITLE 11566
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_PLURAL_TITLE 11567
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_OK_BUTTON 11568
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_DISABLED_DIALOG_CANCEL_BUTTON 11569
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_REENABLE_DIALOG_TITLE 11570
#define IDS_EXTENSIONS_MANIFEST_V2_DEPRECATION_REENABLE_DIALOG_OK_BUTTON 11571
#define IDS_EXTENSION_SETTINGS_OVERRIDDEN_DIALOG_CHANGE_IT_BACK 11572
#define IDS_EXTENSION_SETTINGS_OVERRIDDEN_DIALOG_KEEP_IT 11573
#define IDS_EXTENSION_NTP_OVERRIDDEN_DIALOG_TITLE_GENERIC 11574
#define IDS_EXTENSION_NTP_OVERRIDDEN_DIALOG_TITLE_BACK_TO_GOOGLE 11575
#define IDS_EXTENSION_NTP_OVERRIDDEN_DIALOG_BODY_GENERIC 11576
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_GENERIC 11577
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_BACK_TO_GOOGLE 11578
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_BACK_TO_OTHER 11579
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_TITLE_EXPLICIT_CHOICE 11580
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_BODY_GENERIC 11581
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_BODY_EXPLICIT_CHOICE 11582
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_RECENT_CHANGE 11583
#define IDS_EXTENSION_SEARCH_OVERRIDDEN_DIALOG_PREVIOUS_CHOICE 11584
#define IDS_FORCE_INSTALLED_DEPRECATED_APPS_CONTENT 11585
#define IDS_FORCE_INSTALLED_PREINSTALLED_DEPRECATED_APPS_TITLE 11586
#define IDS_FORCE_INSTALLED_PREINSTALLED_DEPRECATED_APPS_CONTENT 11587
#define IDS_FORCE_INSTALLED_PREINSTALLED_DEPRECATED_APPS_GO_TO_SITE_BUTTON 11588
#define IDS_DEPRECATED_APPS_RENDERER_TITLE_PLURAL 11589
#define IDS_DEPRECATED_APPS_RENDERER_TITLE_WITH_APP_NAME 11590
#define IDS_DEPRECATED_APPS_MONITOR_RENDERER 11591
#define IDS_DEPRECATED_APPS_LEARN_MORE 11592
#define IDS_DEPRECATED_APPS_LEARN_MORE_AX_LABEL 11593
#define IDS_DEPRECATED_APPS_DELETION_LINK 11594
#define IDS_DEPRECATED_APPS_OK_LABEL 11595
#define IDS_DEPRECATED_APPS_CANCEL_LABEL 11596
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON 11597
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_DISMISSED_TEXT 11598
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_TOOLTIP_MULTIPLE_EXTENSIONS 11599
#define IDS_EXTENSIONS_MENU_TITLE 11600
#define IDS_EXTENSIONS_MENU_CONTEXT_MENU_TOOLTIP 11601
#define IDS_EXTENSIONS_MENU_ZERO_STATE_HEADER 11602
#define IDS_EXTENSIONS_MENU_CONTEXT_MENU_TOOLTIP_ACCESSIBLE_NAME 11603
#define IDS_EXTENSIONS_MENU_PIN_BUTTON_TOOLTIP 11604
#define IDS_EXTENSIONS_MENU_UNPIN_BUTTON_TOOLTIP 11605
#define IDS_EXTENSIONS_MENU_ACCESSING_SITE_DATA_SHORT 11606
#define IDS_EXTENSIONS_MENU_ACCESSING_SITE_DATA 11607
#define IDS_EXTENSIONS_MENU_WANTS_TO_ACCESS_SITE_DATA_SHORT 11608
#define IDS_EXTENSIONS_MENU_WANTS_TO_ACCESS_SITE_DATA 11609
#define IDS_EXTENSIONS_MENU_CANT_ACCESS_SITE_DATA_SHORT 11610
#define IDS_EXTENSIONS_MENU_CANT_ACCESS_SITE_DATA 11611
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_LABEL 11612
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_NOT_ALLOWED_LABEL 11613
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_TOGGLE_ON_TOOLTIP 11614
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_TOGGLE_OFF_TOOLTIP 11615
#define IDS_EXTENSIONS_MENU_SITE_SETTINGS_TOGGLE_ACCESSIBLE_NAME 11616
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_ENTERPRISE_TOOLTIP_ICON_TEXT 11617
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_RELOAD_CONTAINER_DESCRIPTION_TEXT 11618
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_RELOAD_CONTAINER_BUTTON_TEXT 11619
#define IDS_EXTENSIONS_MENU_MESSAGE_SECTION_RELOAD_CONTAINER_BUTTON_TOOLTIP 11620
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_TITLE 11621
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_ALLOW_BUTTON_TEXT 11622
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_ALLOW_BUTTON_TOOLTIP 11623
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_ALLOW_BUTTON_ACCESSIBLE_NAME 11624
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_DISMISS_BUTTON_TEXT 11625
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_DISMISS_BUTTON_TOOLTIP 11626
#define IDS_EXTENSIONS_MENU_REQUESTS_ACCESS_SECTION_DISMISS_BUTTON_ACCESSIBLE_NAME 11627
#define IDS_EXTENSIONS_MENU_EXTENSION_SITE_ACCESS_TOGGLE_ON_TOOLTIP 11628
#define IDS_EXTENSIONS_MENU_EXTENSION_SITE_ACCESS_TOGGLE_OFF_TOOLTIP 11629
#define IDS_EXTENSIONS_MENU_EXTENSION_SITE_ACCESS_TOGGLE_ACCESSIBLE_NAME 11630
#define IDS_EXTENSIONS_MENU_EXTENSION_CONTEXT_MENU_BUTTON_TOOLTIP 11631
#define IDS_EXTENSIONS_MENU_EXTENSION_CONTEXT_MENU_BUTTON_ACCESSIBLE_NAME 11632
#define IDS_EXTENSIONS_MENU_EXTENSION_CONTEXT_MENU_BUTTON_PINNED_ACCESSIBLE_NAME 11633
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_NONE 11634
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_DISCOVER_EXTENSIONS 11635
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_TOOLTIP 11636
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_ENTERPRISE_EXTENSION_SITE_ACCESS_TOOLTIP 11637
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ACCESSIBLE_NAME 11638
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_ENTERPRISE_EXTENSION_SITE_ACCESS_ACCESSIBLE_NAME 11639
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_BUTTON_HAS_ACCESS_TOOLTIP 11640
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_BUTTON_BLOCKED_ACCESS_TOOLTIP 11641
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_BUTTON_REQUESTS_TOOLTIP 11642
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ON_CLICK 11643
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ON_SITE 11644
#define IDS_EXTENSIONS_MENU_MAIN_PAGE_EXTENSION_SITE_ACCESS_ON_ALL_SITES 11645
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SETTINGS_BUTTON 11646
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SETTINGS_BUTTON_TOOLTIP 11647
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SHOW_REQUESTS_LABEL 11648
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SHOW_REQUESTS_TOGGLE_ON 11649
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SHOW_REQUESTS_TOGGLE_OFF 11650
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_LABEL 11651
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_CLICK_TEXT 11652
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_SITE_TEXT 11653
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_ALL_SITES_TEXT 11654
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_CLICK_DESCRIPTION 11655
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_SITE_DESCRIPTION 11656
#define IDS_EXTENSIONS_MENU_SITE_PERMISSIONS_PAGE_SITE_ACCESS_ON_ALL_SITES_DESCRIPTION 11657
#define IDS_EXTENSIONS_CONTROLLED_HOME_DIALOG_TITLE 11658
#define IDS_EXTENSIONS_CONTROLLED_HOME_DIALOG_DESCRIPTION 11659
#define IDS_EXTENSIONS_CONTROLLED_HOME_DIALOG_LEARN_MORE_LINK 11660
#define IDS_EXTENSIONS_SETTINGS_API_SECOND_LINE_SEARCH_ENGINE 11661
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_BUBBLE_TITLE 11662
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_BUBBLE_HEADING 11663
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_ALLOW 11664
#define IDS_EXTENSIONS_PRINTING_API_PRINT_REQUEST_DENY 11665
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_BUBBLE_TITLE 11666
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_BUBBLE_HEADING 11667
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_ALLOW 11668
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_DISCOVERY_REQUEST_DENY 11669
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_BUBBLE_TITLE 11670
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_BUBBLE_HEADING 11671
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_ALLOW 11672
#define IDS_EXTENSIONS_DOCUMENT_SCAN_API_START_SCAN_REQUEST_DENY 11673
#define IDS_EXTENSIONS_NTP_CONTROLLED_FIRST_LINE 11674
#define IDS_EXTENSIONS_PROXY_CONTROLLED_FIRST_LINE 11675
#define IDS_EXTENSIONS_PROXY_CONTROLLED_FIRST_LINE_EXTENSION_SPECIFIC 11676
#define IDS_EXTENSIONS_SETTINGS_API_THIRD_LINE_CONFIRMATION 11677
#define IDS_EXTENSION_CONTROLLED_RESTORE_SETTINGS 11678
#define IDS_EXTENSION_CONTROLLED_KEEP_CHANGES 11679
#define IDS_SUB_APPS_INSTALL_DIALOG_TITLE 11680
#define IDS_SUB_APPS_INSTALL_DIALOG_DESCRIPTION 11681
#define IDS_SUB_APPS_INSTALL_DIALOG_PERMISSIONS_DESCRIPTION 11682
#define IDS_SUB_APPS_INSTALL_DIALOG_MANAGE_PERMISSIONS_LINK 11683
#define IDS_SUB_APPS_INSTALL_DIALOG_PERMISSIONS_BUTTON 11684
#define IDS_SUB_APPS_INSTALL_DIALOG_CANCEL_BUTTON 11685
#define IDS_WEB_APP_UNINSTALL_BUTTON_FRAME_TOOLTIP 11686
#define IDS_WEB_APP_UNINSTALL_BUTTON_FRAME 11687
#define IDS_WEB_APP_MENU_BUTTON_TOOLTIP 11688
#define IDS_WEB_APP_MENU_BUTTON_TOOLTIP_UPDATE_AVAILABLE 11689
#define IDS_WEB_APP_MENU_BUTTON_UPDATE 11690
#define IDS_WEB_APP_BLOCKED_MIGRATION_MESSAGE 11691
#define IDS_WEB_APP_ENABLE_WINDOW_CONTROLS_OVERLAY_TOOLTIP 11692
#define IDS_WEB_APP_DISABLE_WINDOW_CONTROLS_OVERLAY_TOOLTIP 11693
#define IDS_WEB_APP_WINDOW_CONTROLS_OVERLAY_ENABLED_ALERT 11694
#define IDS_WEB_APP_WINDOW_CONTROLS_OVERLAY_DISABLED_ALERT 11695
#define IDS_APP_HOME_TITLE 11696
#define IDS_APP_HOME_OPEN_IN_WINDOW 11697
#define IDS_APP_HOME_LAUNCH_AT_STARTUP 11698
#define IDS_APP_HOME_CREATE_SHORTCUT 11699
#define IDS_APP_HOME_INSTALL_LOCALLY 11700
#define IDS_APP_HOME_UNINSTALL_APP 11701
#define IDS_APP_HOME_REMOVE_APP 11702
#define IDS_APP_HOME_APP_SETTINGS 11703
#define IDS_ACCNAME_APP_HOME_NOT_INSTALLED 11704
#define IDS_APP_HOME_APP_NO_APPS 11705
#define IDS_APP_HOME_APP_LEARN_INSTALL 11706
#define IDS_WEB_APP_SETTINGS_TITLE 11707
#define IDS_WEB_APP_SETTINGS_LINK 11708
#define IDS_WEB_APP_SETTINGS_LINK_TOOLTIP 11709
#define IDS_COMPONENTS_TITLE 11710
#define IDS_COMPONENTS_VERSION 11711
#define IDS_COMPONENTS_NONE_INSTALLED 11712
#define IDS_COMPONENTS_NO_COMPONENTS 11713
#define IDS_COMPONENTS_CHECK_FOR_UPDATE 11714
#define IDS_COMPONENTS_STATUS_LABEL 11715
#define IDS_COMPONENTS_CHECKING_LABEL 11716
#define IDS_COMPONENTS_SVC_STATUS_NEW 11717
#define IDS_COMPONENTS_SVC_STATUS_CHECKING 11718
#define IDS_COMPONENTS_SVC_STATUS_UPDATE 11719
#define IDS_COMPONENTS_SVC_STATUS_DNL 11720
#define IDS_COMPONENTS_SVC_STATUS_DECOMPRESSING 11721
#define IDS_COMPONENTS_SVC_STATUS_PATCHING 11722
#define IDS_COMPONENTS_SVC_STATUS_UPDATING 11723
#define IDS_COMPONENTS_SVC_STATUS_UPDATED 11724
#define IDS_COMPONENTS_SVC_STATUS_UPTODATE 11725
#define IDS_COMPONENTS_SVC_STATUS_UPDATE_ERROR 11726
#define IDS_COMPONENTS_UNKNOWN 11727
#define IDS_PASSWORD_MANAGER_ACCOUNT_CHOOSER_TITLE 11728
#define IDS_PASSWORD_GENERATION_SUGGESTION_GPM 11729
#define IDS_PASSWORD_GENERATION_SUGGESTION_GPM_WITHOUT_STRONG 11730
#define IDS_PASSWORD_GENERATION_NUDGE_CANCEL_BUTTON 11731
#define IDS_PASSWORD_MANAGER_CONFIRM_SAVED_TITLE 11732
#define IDS_PASSWORD_MANAGER_CONFIRM_UPDATE_TITLE 11733
#define IDS_PASSWORD_GENERATION_EDITING_SUGGESTION 11734
#define IDS_SAVE_PASSWORD 11735
#define IDS_SAVE_ACCOUNT 11736
#define IDS_ADD_USERNAME_TITLE 11737
#define IDS_ADD_USERNAME 11738
#define IDS_ADD_USERNAME_BODY 11739
#define IDS_UPDATE_PASSWORD 11740
#define IDS_VERIFY_IT_IS_YOU 11741
#define IDS_PASSWORD_ERROR_DESCRIPTION_SIGN_IN 11742
#define IDS_PASSWORD_ERROR_DESCRIPTION_SIGN_UP 11743
#define IDS_PASSWORD_ERROR_VERIFY_BUTTON_TITLE 11744
#define IDS_SAVE_PASSWORD_DIFFERENT_DOMAINS_TITLE 11746
#define IDS_UPDATE_PASSWORD_DIFFERENT_DOMAINS_TITLE 11747
#define IDS_SAVE_PASSWORD_FOOTER 11748
#define IDS_PASSWORD_BUBBLES_PASSWORD_MANAGER_LINK_TEXT_SYNCED_TO_ACCOUNT 11749
#define IDS_PASSWORD_BUBBLES_FOOTER_SYNCED_TO_ACCOUNT 11750
#define IDS_PASSWORD_BUBBLES_FOOTER_SAVING_ON_DEVICE 11751
#define IDS_PASSWORD_GENERATION_PROMPT_GOOGLE_PASSWORD_MANAGER 11752
#define IDS_PASSWORD_GENERATION_NUDGE_TITLE 11753
#define IDS_PASSWORD_MANAGEMENT_BUBBLE_FOOTER_ACCOUNT_STORE_USERS 11754
#define IDS_PASSWORD_MANAGER_GENERATED_PASSWORD_SAVED_MESSAGE_DESCRIPTION 11755
#define IDS_PASSWORD_MANAGER_SAVE_PASSWORD_SIGNED_IN_MESSAGE_DESCRIPTION 11756
#define IDS_PASSWORD_MANAGER_UPDATE_PASSWORD_SIGNED_IN_MESSAGE_DESCRIPTION 11757
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_CONFIRMATION_TITLE 11758
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_CONFIRMATION_DESCRIPTION 11759
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_CONFIRMATION_CONFIRM_BUTTON_LABEL 11760
#define IDS_PASSWORD_CROSS_DOMAIN_FILLING_WARNING_DESCRIPTION 11761
#define IDS_PASSWORD_MANAGER_ACCOUNT_CHOOSER_SIGN_IN 11762
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORDS_BUTTON 11763
#define IDS_PASSWORD_MANAGER_MANAGE_PASSWORD_BUTTON 11764
#define IDS_SETTINGS_PASSWORDS_ANDROID_APP 11765
#define IDS_SHARED_PASSWORDS_NOTIFICATION_GOT_IT_BUTTON 11766
#define IDS_SHARED_PASSWORDS_NOTIFICATION_TEXT_SINGLE_PASSWORD 11767
#define IDS_SHARED_PASSWORDS_NOTIFICATION_TEXT_MULTIPLE_PASSWORD 11768
#define IDS_SHARED_PASSWORDS_NOTIFICATION_TITLE 11769
#define IDS_PASSWORD_MANAGER_ONBOARDING_TITLE_A 11770
#define IDS_PASSWORD_MANAGER_ONBOARDING_TITLE_B 11771
#define IDS_PASSWORD_MANAGER_ONBOARDING_TITLE_C 11772
#define IDS_PASSWORD_MANAGER_ONBOARDING_DETAILS_A 11773
#define IDS_PASSWORD_MANAGER_ONBOARDING_DETAILS_B 11774
#define IDS_PASSWORD_MANAGER_DICE_PROMO_SIGNIN_MESSAGE 11775
#define IDS_PASSWORD_MANAGER_DICE_PROMO_SYNC_MESSAGE 11776
#define IDS_WEBRTC_LOGS_TITLE 11777
#define IDS_WEBRTC_TEXT_LOGS_LOG_COUNT_BANNER_FORMAT 11778
#define IDS_WEBRTC_EVENT_LOGS_LOG_COUNT_BANNER_FORMAT 11779
#define IDS_WEBRTC_LOGS_LOG_HEADER_FORMAT 11780
#define IDS_WEBRTC_LOGS_LOG_LOCAL_FILE_LABEL_FORMAT 11781
#define IDS_WEBRTC_LOGS_NO_LOCAL_LOG_FILE_MESSAGE 11782
#define IDS_WEBRTC_LOGS_LOG_UPLOAD_TIME_FORMAT 11783
#define IDS_WEBRTC_LOGS_LOG_FAILED_UPLOAD_TIME_FORMAT 11784
#define IDS_WEBRTC_LOGS_LOG_REPORT_ID_FORMAT 11785
#define IDS_WEBRTC_LOGS_BUG_LINK_LABEL 11786
#define IDS_WEBRTC_LOGS_LOG_PENDING_MESSAGE 11787
#define IDS_WEBRTC_LOGS_LOG_ACTIVELY_UPLOADED_MESSAGE 11788
#define IDS_WEBRTC_LOGS_LOG_NOT_UPLOADED_MESSAGE 11789
#define IDS_WEBRTC_LOGS_EVENT_LOG_LOCAL_LOG_ID 11790
#define IDS_WEBRTC_LOGS_NO_TEXT_LOGS_MESSAGE 11791
#define IDS_WEBRTC_LOGS_NO_EVENT_LOGS_MESSAGE 11792
#define IDS_PLUGIN_HIDE 11793
#define IDS_PLUGIN_BLOCKED 11794
#define IDS_PLUGIN_BLOCKED_BY_POLICY 11795
#define IDS_PLUGIN_NOT_AUTHORIZED 11796
#define IDS_PLUGIN_DISABLED 11797
#define IDS_PLUGIN_DEPRECATED 11798
#define IDS_SESSION_CRASHED_BUBBLE_TITLE 11799
#define IDS_SESSION_CRASHED_BUBBLE_UMA_LINK_TEXT 11800
#define IDS_IDLE_BUBBLE_TITLE_CLEAR 11801
#define IDS_SETTINGS_STORAGE_PRESSURE_BUBBLE_VIEW_TITLE 11802
#define IDS_SETTINGS_STORAGE_PRESSURE_BUBBLE_VIEW_MESSAGE 11803
#define IDS_SETTINGS_STORAGE_PRESSURE_BUBBLE_VIEW_BUTTON_LABEL 11804
#define IDS_BAD_FLAGS_WARNING_MESSAGE 11805
#define IDS_BAD_FEATURES_WARNING_MESSAGE 11806
#define IDS_BAD_FLAGS_FROM_FILE_WARNING_MESSAGE 11807
#define IDS_BAD_ENVIRONMENT_VARIABLES_WARNING_MESSAGE 11808
#define IDS_BLOCKED_DISPLAYING_INSECURE_CONTENT_TITLE 11809
#define IDS_BLOCKED_DISPLAYING_INSECURE_CONTENT 11810
#define IDS_ALLOW_INSECURE_CONTENT_BUTTON 11811
#define IDS_ADD_TO_SHELF_INFOBAR_TITLE 11812
#define IDS_ADD_TO_SHELF_INFOBAR_ADD_BUTTON 11813
#define IDS_ABOUT_SYS_TITLE 11814
#define IDS_ABOUT_SYS_DESC 11815
#define IDS_ABOUT_SYS_TABLE_TITLE 11816
#define IDS_ABOUT_SYS_LOG_FILE_TABLE_TITLE 11817
#define IDS_ABOUT_SYS_EXPAND_ALL 11818
#define IDS_ABOUT_SYS_COLLAPSE_ALL 11819
#define IDS_ABOUT_SYS_EXPAND 11820
#define IDS_ABOUT_SYS_COLLAPSE 11821
#define IDS_ABOUT_SYS_PARSE_ERROR 11822
#define IDS_ABOUT_BROWSER_SWITCH_TITLE 11823
#define IDS_ABOUT_BROWSER_SWITCH_OPENING_TITLE_UNKNOWN_BROWSER 11824
#define IDS_ABOUT_BROWSER_SWITCH_OPENING_TITLE_KNOWN_BROWSER 11825
#define IDS_ABOUT_BROWSER_SWITCH_ERROR_TITLE_UNKNOWN_BROWSER 11826
#define IDS_ABOUT_BROWSER_SWITCH_ERROR_TITLE_KNOWN_BROWSER 11827
#define IDS_ABOUT_BROWSER_SWITCH_COUNTDOWN_TITLE_UNKNOWN_BROWSER 11828
#define IDS_ABOUT_BROWSER_SWITCH_COUNTDOWN_TITLE_KNOWN_BROWSER 11829
#define IDS_ABOUT_BROWSER_SWITCH_GENERIC_ERROR_UNKNOWN_BROWSER 11830
#define IDS_ABOUT_BROWSER_SWITCH_GENERIC_ERROR_KNOWN_BROWSER 11831
#define IDS_ABOUT_BROWSER_SWITCH_PROTOCOL_ERROR 11832
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_DESC 11833
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_TITLE 11834
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_NOTHING_SHOWN 11835
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_LBS_DISABLED 11836
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_URL_CHECKER_TITLE 11837
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_URL_CHECKER_DESC 11838
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER 11839
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_PROTOCOL_REASON 11840
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_RULE_REASON 11841
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_INVERT_RULE_REASON 11842
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_OPEN_BROWSER_DEFAULT_REASON 11843
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_INVALID_URL 11844
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_TITLE 11845
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_DESC 11846
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SOURCE 11847
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_NOT_CONFIGURED 11848
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_NOT_FETCHED 11849
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_DOWNLOAD_BUTTON 11850
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_LAST_DOWNLOAD_DATE 11851
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_XML_SITELIST_NEXT_DOWNLOAD_DATE 11852
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_TITLE 11853
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_DESCRIPTION 11854
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_FIRST_PARAGRAPH 11855
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_IN_SECOND_PARAGRAPH 11856
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_TABLE_COLUMN_RULE 11857
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_TABLE_COLUMN_OPENS_IN 11858
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_FORCE_OPEN_TABLE_COLUMN_SOURCE 11859
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_TITLE 11860
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_DESCRIPTION 11861
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_FIRST_PARAGRAPH 11862
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_SECOND_PARAGRAPH 11863
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_TABLE_COLUMN_RULE 11864
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_IGNORE_TABLE_COLUMN_SOURCE 11865
#define IDS_ABOUT_BROWSER_SWITCH_INTERNALS_POLICIES_DOWNLOAD_BUTTON 11866
#define IDS_OMNIBOX_PLACEHOLDER_TEXT 11871
#define IDS_OMNIBOX_AIM_PLACEHOLDER_TEXT 11872
#define IDS_PASTE_AND_GO 11873
#define IDS_PASTE_AND_SEARCH 11874
#define IDS_PASTE_AND_GO_EMPTY 11875
#define IDS_OMNIBOX_KEYWORD_TEXT 11876
#define IDS_OMNIBOX_CLEAR_ALL 11877
#define IDS_OMNIBOX_WHY_THIS_SUGGESTION 11878
#define IDS_OMNIBOX_CLOSE_IPH_SUGGESTION 11879
#define IDS_OMNIBOX_THUMBS_UP_SUGGESTION 11880
#define IDS_OMNIBOX_THUMBS_DOWN_SUGGESTION 11881
#define IDS_OMNIBOX_REMOVE_SUGGESTION 11882
#define IDS_OMNIBOX_REMOVE_SUGGESTION_BUBBLE_TITLE 11883
#define IDS_OMNIBOX_REMOVE_SUGGESTION_BUBBLE_DESCRIPTION 11884
#define IDS_CONTEXT_MENU_SHOW_FULL_URLS 11885
#define IDS_CONTEXT_MENU_SHOW_SEARCH_TOOLS 11886
#define IDS_WEBUI_OMNIBOX_PLACEHOLDER_TEXT 11889
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_THIS_PAGE 11890
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_THIS_PAGE_ARIA_LABEL 11891
#define IDS_WEBUI_OMNIBOX_COMPOSE_LENS_OVERLAY 11892
#define IDS_WEBUI_OMNIBOX_COMPOSE_ASK_ABOUT_YOUR_TABS 11893
#define IDS_NTP_DRIVE_CONNECT_TITLE 11894
#define IDS_NTP_DRIVE_DISCLAIMER_BODY 11895
#define IDS_NTP_DRIVE_DISCLAIMER_CANCEL 11896
#define IDS_NTP_DRIVE_DISCLAIMER_CONNECT 11897
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_MD 11898
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_SHORT 11899
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_MULTIMODAL 11900
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_CONTEXTUAL 11901
#define IDS_GOOGLE_SEARCH_BOX_EMPTY_HINT_CONTEXTUAL_PDF 11902
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_PRIMARY 11903
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_PRIMARY_PDF 11904
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_SECONDARY 11905
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_ERROR_TEXT 11906
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_LOADING_HINT_PRIMARY_ALT 11907
#define IDS_GOOGLE_SEARCH_BOX_CONTEXTUAL_NO_SUGGEST_TEXT 11908
#define IDS_GOOGLE_SEARCH_BOX_MULTIMODAL_IMAGE_THUMBNAIL 11909
#define IDS_GOOGLE_LENS_SEARCH_BOX_EMPTY_HINT 11910
#define IDS_NTP_SEARCH_BOX_PLACEHOLDER_ASK_OR_TYPE 11911
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_ASK_GOOGLE 11912
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_PLAN 11913
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_COMPARE 11914
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_RESEARCH 11915
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_TEACH 11916
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_WRITE 11917
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_TAB 11918
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_IMAGE 11919
#define IDS_NTP_SEARCH_BOX_DYNAMIC_PLACEHOLDER_CANVAS 11920
#define IDS_NTP_CUSTOM_LINKS_ADD_SHORTCUT_TOOLTIP 11921
#define IDS_NTP_CUSTOM_LINKS_ADD_SHORTCUT_TITLE 11922
#define IDS_NTP_CUSTOM_LINKS_EDIT_SHORTCUT_TOOLTIP 11923
#define IDS_NTP_CUSTOM_LINKS_EDIT_SHORTCUT 11924
#define IDS_NTP_CUSTOM_LINKS_SHORTCUT_DETAILS_TITLE 11925
#define IDS_NTP_CUSTOM_LINKS_MORE_ACTIONS 11926
#define IDS_NTP_ENTERPRISE_SHORTCUT_SUBTITLE 11927
#define IDS_UPLOAD_IMAGE_FORMAT 11928
#define IDS_NTP_CUSTOM_LINKS_NAME 11929
#define IDS_NTP_CUSTOM_LINKS_URL 11930
#define IDS_NTP_CUSTOM_LINKS_REMOVE 11931
#define IDS_NTP_MOST_VISITED_SITES_REMOVE 11932
#define IDS_NTP_CUSTOM_LINKS_CANCEL 11933
#define IDS_NTP_CUSTOM_LINKS_DONE 11934
#define IDS_NTP_CUSTOM_LINKS_DETAILS 11935
#define IDS_NTP_CUSTOM_LINKS_INVALID_URL 11936
#define IDS_NTP_CUSTOM_LINKS_CANT_CREATE 11937
#define IDS_NTP_CUSTOM_LINKS_CANT_EDIT 11938
#define IDS_NTP_CUSTOM_LINKS_CANT_REMOVE 11939
#define IDS_NTP_CUSTOM_LINKS_HELP_PIN 11940
#define IDS_NTP_CONFIRM_MSG_SHORTCUT_REMOVED 11941
#define IDS_NTP_CONFIRM_MSG_SHORTCUT_EDITED 11942
#define IDS_NTP_CONFIRM_MSG_SHORTCUT_ADDED 11943
#define IDS_NTP_CUSTOM_LINKS_ALREADY_EXISTS 11944
#define IDS_NTP_CONFIRM_MSG_RESTORE_DEFAULTS 11945
#define IDS_NTP_CONFIRM_MSG_RESTORE_ENTERPRISE_DEFAULTS 11946
#define IDS_NTP_CUSTOM_BG_UPLOAD_AN_IMAGE 11947
#define IDS_NTP_CUSTOM_BG_SELECT_A_COLLECTION 11948
#define IDS_NTP_CUSTOM_BG_DAILY_REFRESH 11949
#define IDS_NTP_CUSTOM_BG_RESTORE_DEFAULT 11950
#define IDS_NTP_CUSTOM_BG_CANCEL 11951
#define IDS_NTP_CONNECTION_ERROR_NO_PERIOD 11952
#define IDS_NTP_CONNECTION_ERROR 11953
#define IDS_NTP_ERROR_MORE_INFO 11954
#define IDS_NTP_CUSTOM_BG_BACKGROUNDS_UNAVAILABLE 11955
#define IDS_NTP_CUSTOM_BG_BACK_LABEL 11956
#define IDS_NTP_CUSTOM_BG_IMAGE_SELECTED 11957
#define IDS_NTP_CUSTOM_BG_CUSTOMIZE_NTP_LABEL 11958
#define IDS_NTP_CUSTOM_BG_CUSTOMIZE_NTP_WALLPAPER_SEARCH_LABEL 11959
#define IDS_NTP_CLOSE 11960
#define IDS_NTP_DISMISS 11961
#define IDS_NTP_DISMISS_PROMO 11962
#define IDS_NTP_DOODLE_SHARE_LABEL 11963
#define IDS_NTP_DOODLE_SHARE_DIALOG_CLOSE_LABEL 11964
#define IDS_NTP_DOODLE_SHARE_DIALOG_FACEBOOK_LABEL 11965
#define IDS_NTP_DOODLE_SHARE_DIALOG_TWITTER_LABEL 11966
#define IDS_NTP_DOODLE_SHARE_DIALOG_MAIL_LABEL 11967
#define IDS_NTP_DOODLE_SHARE_DIALOG_COPY_LABEL 11968
#define IDS_NTP_DOODLE_SHARE_DIALOG_LINK_LABEL 11969
#define IDS_NTP_CUSTOMIZE_APPEARANCE_LABEL 11970
#define IDS_NTP_CUSTOMIZE_THEMES_HEADER 11971
#define IDS_NTP_CUSTOMIZE_MENU_SHORTCUTS_LABEL 11972
#define IDS_NTP_CUSTOMIZE_MENU_TOOLBAR_LABEL 11973
#define IDS_NTP_CUSTOMIZE_MENU_EXTENSIONS_LABEL 11974
#define IDS_NTP_CUSTOMIZE_MENU_MODULES_LABEL 11975
#define IDS_NTP_CUSTOMIZE_NO_BACKGROUND_LABEL 11976
#define IDS_NTP_CUSTOMIZE_CHROME_CHANGE_THEME_LABEL 11977
#define IDS_NTP_CUSTOMIZE_FOOTER_HEADER 11978
#define IDS_NTP_CUSTOMIZE_TOOLS_HEADER 11979
#define IDS_NTP_MANAGED_BY_SEARCH_ENGINE 11980
#define IDS_NTP_MANAGED_BY_EXTENSION 11981
#define IDS_NTP_CUSTOMIZE_CHROME_MANAGED_NEW_TAB_PAGE_ACCESSIBILITY 11982
#define IDS_NTP_CUSTOMIZE_CHROME_RESET_TO_CLASSIC_CHROME_COMPLETE 11983
#define IDS_NTP_CUSTOMIZE_CHROME_RESET_TO_UPLOADED_IMAGE_COMPLETE 11984
#define IDS_NTP_CUSTOMIZE_CHROME_FOLLOW_THEME_LABEL 11985
#define IDS_NTP_CUSTOMIZE_UPLOADED_IMAGE_LABEL 11986
#define IDS_NTP_CUSTOMIZE_YOUR_UPLOADED_IMAGE_LABEL 11987
#define IDS_NTP_CUSTOMIZE_YOUR_SEARCHED_IMAGE_LABEL 11988
#define IDS_NTP_CUSTOMIZE_CHROME_CURRENT_THEME_LABEL 11989
#define IDS_NTP_CUSTOMIZE_SHOW_CARDS_LABEL 11990
#define IDS_NTP_CUSTOMIZE_SHOW_FOOTER_LABEL 11991
#define IDS_NTP_CUSTOMIZE_SHOW_CHIPS_LABEL 11992
#define IDS_NTP_CUSTOMIZE_SHOW_SUGGESTIONS_CHIPS_LABEL 11993
#define IDS_NTP_CUSTOMIZE_SHOW_SHORTCUTS_LABEL 11994
#define IDS_NTP_CUSTOMIZE_SHOW_PERSONAL_SHORTCUTS_LABEL 11995
#define IDS_NTP_CUSTOMIZE_SHOW_PERSONAL_SHORTCUTS_DESC 11996
#define IDS_NTP_CUSTOMIZE_MY_SHORTCUTS_LABEL 11997
#define IDS_NTP_CUSTOMIZE_MOST_VISITED_LABEL 11998
#define IDS_NTP_CUSTOMIZE_ENTERPRISE_SHORTCUTS_LABEL 11999
#define IDS_NTP_CUSTOMIZE_MOST_VISITED_DESC 12000
#define IDS_NTP_CUSTOMIZE_MY_SHORTCUTS_DESC 12001
#define IDS_NTP_CUSTOMIZE_ENTERPRISE_SHORTCUTS_DESC 12002
#define IDS_NTP_CUSTOMIZE_COLOR_PICKER_LABEL 12003
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_TITLE 12004
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_ARIA_LABEL 12005
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_DELETE_TITLE 12006
#define IDS_NTP_CUSTOMIZE_COLOR_HUE_SLIDER_DELETE_A11Y_LABEL 12007
#define IDS_NTP_THEME_MANAGED_DIALOG_TITLE 12008
#define IDS_NTP_THEME_MANAGED_DIALOG_BODY 12009
#define IDS_NTP_THEMES_CONTAINER_LABEL 12010
#define IDS_NTP_CUSTOMIZE_DEFAULT_LABEL 12011
#define IDS_NTP_CUSTOMIZE_GREY_DEFAULT_LABEL 12012
#define IDS_NTP_COLORS_WARM_GREY 12013
#define IDS_NTP_COLORS_COOL_GREY 12014
#define IDS_NTP_COLORS_MIDNIGHT_BLUE 12015
#define IDS_NTP_COLORS_BLACK 12016
#define IDS_NTP_COLORS_BEIGE_AND_WHITE 12017
#define IDS_NTP_COLORS_YELLOW_AND_WHITE 12018
#define IDS_NTP_COLORS_GREEN_AND_WHITE 12019
#define IDS_NTP_COLORS_LIGHT_TEAL_AND_WHITE 12020
#define IDS_NTP_COLORS_LIGHT_PURPLE_AND_WHITE 12021
#define IDS_NTP_COLORS_PINK_AND_WHITE 12022
#define IDS_NTP_COLORS_BEIGE 12023
#define IDS_NTP_COLORS_ORANGE 12024
#define IDS_NTP_COLORS_LIGHT_GREEN 12025
#define IDS_NTP_COLORS_LIGHT_TEAL 12026
#define IDS_NTP_COLORS_LIGHT_BLUE 12027
#define IDS_NTP_COLORS_PINK 12028
#define IDS_NTP_COLORS_DARK_PINK_AND_RED 12029
#define IDS_NTP_COLORS_DARK_RED_AND_ORANGE 12030
#define IDS_NTP_COLORS_DARK_GREEN 12031
#define IDS_NTP_COLORS_DARK_TEAL 12032
#define IDS_NTP_COLORS_DARK_BLUE 12033
#define IDS_NTP_COLORS_DARK_PURPLE 12034
#define IDS_NTP_COLORS_BLUE 12035
#define IDS_NTP_COLORS_GREY 12036
#define IDS_NTP_COLORS_AQUA 12037
#define IDS_NTP_COLORS_GREEN 12038
#define IDS_NTP_COLORS_VIRIDIAN 12039
#define IDS_NTP_COLORS_CITRON 12040
#define IDS_NTP_COLORS_APRICOT 12041
#define IDS_NTP_COLORS_ROSE 12042
#define IDS_NTP_COLORS_FUCHSIA 12043
#define IDS_NTP_COLORS_VIOLET 12044
#define IDS_NTP_COLORS_BATCH_UPLOAD_DESCRIPTION 12045
#define IDS_NTP_UNDO_DISMISS_PROMO_BUTTON_TOAST 12046
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_GROUP_LABEL 12047
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_LIGHT_LABEL 12048
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_DARK_LABEL 12049
#define IDS_NTP_CUSTOMIZE_CHROME_COLOR_SCHEME_MODE_SYSTEM_LABEL 12050
#define IDS_NTP_CUSTOMIZE_CHROME_WEBSTORE_LABEL 12051
#define IDS_NTP_SHOW_MORE_BUTTON_LABEL 12052
#define IDS_NTP_SHOW_LESS_BUTTON_LABEL 12053
#define IDS_NTP_THREADS_HISTORY_LABEL 12054
#define IDS_NTP_THREADS_NEW_SEARCH_LABEL 12055
#define IDS_NTP_WEBSTORE_SHOPPING_CATEOGRY_LABEL 12056
#define IDS_NTP_WEBSTORE_WRITTING_HELP_COLLECTION_LABEL 12057
#define IDS_NTP_WEBSTORE_PRODUCTIVITY_CATEOGRY_LABEL 12058
#define IDS_NTP_WEBSTORE_TOAST_MESSAGE 12059
#define IDS_NTP_WEBSTORE_TOAST_BUTTON_TEXT 12060
#define IDS_NTP_WALLPAPER_SEARCH_FEEDBACK_PLACEHOLDER 12061
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION 12062
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION_WITH_HISTORY 12063
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION_WITH_INSPIRATION 12064
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_DESCRIPTION_WITH_HISTORY_AND_INSPIRATION 12065
#define IDS_NTP_WALLPAPER_SEARCH_GENERIC_ERROR_TITLE 12066
#define IDS_NTP_WALLPAPER_SEARCH_TILE_LABEL 12067
#define IDS_NTP_WALLPAPER_SEARCH_PAGE_HEADER 12068
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_HEADER 12069
#define IDS_NTP_WALLPAPER_SEARCH_OFFLINE_DESCRIPTION 12070
#define IDS_NTP_WALLPAPER_SEARCH_OFFLINE_DESCRIPTION_WITH_HISTORY 12071
#define IDS_NTP_WALLPAPER_SEARCH_OFFLINE_TITLE 12072
#define IDS_NTP_WALLPAPER_SEARCH_OPTIONAL_DETAILS_LABEL 12073
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_RED_LABEL 12074
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_BLUE_LABEL 12075
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_YELLOW_LABEL 12076
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_GREEN_LABEL 12077
#define IDS_NTP_WALLPAPER_SEARCH_COLOR_BLACK_LABEL 12078
#define IDS_NTP_WALLPAPER_SEARCH_REQUEST_THROTTLED_DESCRIPTION 12079
#define IDS_NTP_WALLPAPER_SEARCH_REQUEST_THROTTLED_TITLE 12080
#define IDS_NTP_WALLPAPER_SEARCH_SUBMIT_BTN_TEXT 12081
#define IDS_NTP_WALLPAPER_SEARCH_TRY_AGAIN_CTA 12082
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_NO_DESCRIPTOR 12083
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL 12084
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_WITH_DESCRIPTOR_B 12085
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_WITH_DESCRIPTOR_C 12086
#define IDS_NTP_WALLPAPER_SEARCH_HISTORY_RESULT_LABEL_WITH_DESCRIPTORS_B_AND_C 12087
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL 12088
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL_WITH_DESCRIPTOR_B 12089
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL_WITH_DESCRIPTOR_C 12090
#define IDS_NTP_WALLPAPER_SEARCH_RESULT_LABEL_WITH_DESCRIPTORS_B_AND_C 12091
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LABEL 12092
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_DEFAULT_OPTION_LABEL 12093
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_LABEL 12094
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_DEFAULT_OPTION_LABEL 12095
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_LABEL 12096
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_DEFAULT_OPTION_LABEL 12097
#define IDS_LEARN_MORE_ABOUT_FEATURE_A11Y_LABEL 12098
#define IDS_THUMBS_DOWN_OPENS_FEEDBACK_FORM_A11Y_LABEL 12099
#define IDS_THUMBS_UP_RESULTS_A11Y_LABEL 12100
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_HEADER 12101
#define IDS_NTP_WALLPAPER_SEARCH_LOADING_A11Y_MESSAGE 12102
#define IDS_NTP_WALLPAPER_SEARCH_SUCCESS_A11Y_MESSAGE 12103
#define IDS_NTP_WALLPAPER_SEARCH_DISCLAIMER 12104
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_CARD_TOGGLE_TITLE 12105
#define IDS_NTP_WALLPAPER_SEARCH_DESCRIPTORS_CHANGED_A11Y_MESSAGE 12106
#define IDS_NTP_WALLPAPER_SEARCH_SIGNED_OUT_DESCRIPTION 12107
#define IDS_NTP_WALLPAPER_SEARCH_SIGNED_OUT_TITLE 12108
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_DESSERTS 12109
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_INTERIORS 12110
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_LANDSCAPE 12111
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_NATURE 12112
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_OUTER_SPACE 12113
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_PLACES 12114
#define IDS_NTP_WALLPAPER_SEARCH_CATEGORY_STRUCTURES 12115
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CAKE_POPS 12116
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CHEESECAKE 12117
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_FRUIT_TART 12118
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ICE_CREAM 12119
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MACARON 12120
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PANNA_COTTA 12121
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CHEMISTRY_LAB 12122
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HALLWAY 12123
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_KITCHEN 12124
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LIVING_ROOM 12125
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_READING_NOOK 12126
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_DESERT 12127
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_FOREST 12128
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HIGHLANDS 12129
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MEADOW 12130
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MOUNTAIN 12131
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_OCEAN 12132
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RAINFOREST 12133
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RICE_PADDY 12134
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SALT_FLAT 12135
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SHORELINE 12136
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_TUNDRA 12137
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_WATERFALL 12138
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_AURORA_BOREALIS 12139
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CLIFF 12140
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CRASHING_WAVES 12141
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CREEK 12142
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ECLIPSES 12143
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_FLOWERS 12144
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LIGHTNING 12145
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_NIGHT_SKY 12146
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PALM_TREE 12147
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RAINBOW 12148
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_RIVER 12149
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SLOT_CANYON 12150
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SUNSET 12151
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ASTEROID 12152
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_COMET 12153
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_MOON 12154
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_NEBULA 12155
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PLANET 12156
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_SPACE_STATION 12157
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_STARS 12158
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CHICHEN_ITZA 12159
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_GRAND_CANYON 12160
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_GRAND_TETON_NATIONAL_PARK 12161
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_GREAT_PYRAMID_OF_GIZA 12162
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ROCKY_MOUNTAINS_NATIONAL_PARK 12163
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_THE_COLOSSEUM 12164
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_ZION_NATIONAL_PARK 12165
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_BRICK_BUILDING 12166
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_CASTLE 12167
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HIGHWAY 12168
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_HOUSE 12169
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_LIGHTHOUSE 12170
#define IDS_NTP_WALLPAPER_SEARCH_SUBJECT_PIER 12171
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_ANIMATED 12172
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_COLORED_PENCIL 12173
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_CYBERPUNK 12174
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_DREAM 12175
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_EXPRESSIONISM 12176
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_FANTASY 12177
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_IMPRESSIONISM 12178
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_OIL_PAINTING 12179
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_ORGANIC 12180
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_PHOTOGRAPHY 12181
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_SPLATTER 12182
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_STEAMPUNK 12183
#define IDS_NTP_WALLPAPER_SEARCH_STYLE_WATERCOLOR 12184
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_CHAOTIC 12185
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_CREATIVE 12186
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_DARK 12187
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_DREAMY 12188
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_EXCITED 12189
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_HAPPY 12190
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_INTELLECTUAL 12191
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_ORDERLY 12192
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_ROMANTIC 12193
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SERENE 12194
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SNOWY 12195
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SUBDUED 12196
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_SUNNY 12197
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_THOUGHTFUL 12198
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_WHIMSICAL 12199
#define IDS_NTP_WALLPAPER_SEARCH_MOOD_WILD 12200
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_1 12201
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_2 12202
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_3 12203
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_4 12204
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_5 12205
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_6 12206
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_7 12207
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_8 12208
#define IDS_NTP_WALLPAPER_SEARCH_INSPIRATION_DESCRIPTION_9 12209
#define IDS_NTP_WALLPAPER_SEARCH_SEPARATOR 12210
#define IDS_NTP_CUSTOMIZE_TOOLBAR_BUTTON_A11Y_LABEL 12211
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CHOOSE_ICONS_LABEL 12212
#define IDS_NTP_CUSTOMIZE_TOOLBAR_ENTERPRISE_ENABLED_LABEL 12213
#define IDS_NTP_CUSTOMIZE_TOOLBAR_REORDER_TIP_LABEL 12214
#define IDS_NTP_CUSTOMIZE_TOOLBAR_RESET_TO_DEFAULT_ANNOUNCEMENT 12215
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_NAVIGATION 12216
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_SIDE_PANELS 12217
#define IDS_NTP_CUSTOMIZE_TOOLBAR_CATEGORY_TOOLS_AND_ACTIONS 12218
#define IDS_NTP_CUSTOMIZE_TOOLBAR_RESET_TO_DEFAULT_BUTTON_LABEL 12219
#define IDS_NTP_COMPOSE_ENTRYPOINT 12220
#define IDS_NTP_COMPOSE_ENTRYPOINT_A11Y_LABEL 12221
#define IDS_NTP_COMPOSE_PLACEHOLDER_TEXT 12222
#define IDS_NTP_COMPOSE_CANCEL_BUTTON_A11Y_LABEL 12223
#define IDS_NTP_COMPOSE_CANCEL_BUTTON_A11Y_LABEL_INPUT 12224
#define IDS_NTP_COMPOSE_IMAGE_UPLOAD_BUTTON_A11Y_LABEL 12225
#define IDS_NTP_COMPOSE_PDF_UPLOAD_BUTTON_A11Y_LABEL 12226
#define IDS_NTP_COMPOSE_SUBMIT_BUTTON_A11Y_LABEL 12227
#define IDS_NTP_COMPOSE_DELETE_FILE_A11Y_LABEL 12228
#define IDS_NTP_COMPOSE_FILE_UPLOAD_STARTED_A11Y_TEXT 12229
#define IDS_NTP_COMPOSE_FILE_UPLOAD_COMPLETE_A11Y_TEXT 12230
#define IDS_NTP_COMPOSE_FILE_UPLOAD_INVALID_EMPTY_SIZE 12231
#define IDS_NTP_COMPOSE_FILE_UPLOAD_INVALID_TOO_LARGE 12232
#define IDS_NTP_COMPOSE_FILE_UPLOAD_IMAGE_PROCESSING_ERROR 12233
#define IDS_NTP_COMPOSE_FILE_UPLOAD_VALIDATION_FAILED 12234
#define IDS_NTP_COMPOSE_DRAG_AND_DROP_HINT 12235
#define IDS_NTP_COMPOSE_MAX_FILES_REACHED_ERROR 12236
#define IDS_NTP_COMPOSE_MAX_IMAGES_REACHED_ERROR 12237
#define IDS_NTP_COMPOSE_MAX_PDFS_REACHED_ERROR 12238
#define IDS_NTP_COMPOSE_FILE_TYPE_NOT_ALLOWED_ERROR 12239
#define IDS_NTP_COMPOSE_FILE_UPLOAD_NOT_ALLOWED 12240
#define IDS_NTP_COMPOSE_FILE_UPLOAD_FAILED 12241
#define IDS_NTP_COMPOSE_FILE_UPLOAD_EXPIRED 12242
#define IDS_NTP_COMPOSE_MOST_RECENT_TABS 12243
#define IDS_NTP_COMPOSEBOX_TAB_PICKER_ADD_TABS_TITLE 12244
#define IDS_NTP_COMPOSEBOX_SHARE_TABS 12245
#define IDS_NTP_COMPOSEBOX_RECENT_TAB_SUFFIX 12246
#define IDS_NTP_COMPOSE_ADD_IMAGE 12247
#define IDS_NTP_COMPOSE_ADD_FILE 12248
#define IDS_NTP_COMPOSE_ADD_DRIVE 12249
#define IDS_NTP_COMPOSE_ADD_CONTEXT 12250
#define IDS_NTP_COMPOSE_ADD_CONTEXTS 12251
#define IDS_NTP_COMPOSE_ADD_CONTEXT_TITLE 12252
#define IDS_NTP_COMPOSE_SUGGESTIONS_INFO 12253
#define IDS_NTP_COMPOSE_SMART_COMPOSE_A11Y_LABEL 12254
#define IDS_NTP_COMPOSE_SMART_COMPOSE_TAB 12255
#define IDS_NTP_COMPOSE_DEEP_SEARCH 12256
#define IDS_NTP_COMPOSE_CREATE_IMAGES 12257
#define IDS_NTP_COMPOSE_CANVAS 12258
#define IDS_NTP_COMPOSE_MODELS_LABEL 12259
#define IDS_NTP_COMPOSE_AUTO_MODEL 12260
#define IDS_NTP_COMPOSE_THINKING_3_PRO 12261
#define IDS_COMPOSE_DEEP_SEARCH_PLACEHOLDER 12262
#define IDS_COMPOSE_CREATE_IMAGE_IPH 12263
#define IDS_COMPOSE_DEEP_SEARCH_IPH 12264
#define IDS_COMPOSE_CREATE_IMAGE_PLACEHOLDER 12265
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THESE 12266
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THIS_IMAGE 12267
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THIS_TAB 12268
#define IDS_COMPOSE_HINT_TEXT_ASK_ABOUT_THIS_DOC 12269
#define IDS_COMPOSE_SHARING_TABS 12270
#define IDS_COMPOSE_SHARING_TABS_WITH_GOOGLE 12271
#define IDS_COMPOSE_ADD_TABS 12272
#define IDS_COMPOSE_CURRENT_TAB 12273
#define IDS_NTP_ACTION_CHIP_TAB_HEADING_1 12274
#define IDS_NTP_ACTION_CHIP_TAB_HEADING_2 12275
#define IDS_NTP_ACTION_CHIP_TAB_BODY_1 12276
#define IDS_NTP_ACTION_CHIP_TAB_BODY_2 12277
#define IDS_NTP_ACTION_CHIP_CREATE_IMAGE_HEADING 12278
#define IDS_NTP_ACTION_CHIP_CREATE_IMAGE_BODY_1 12279
#define IDS_NTP_ACTION_CHIP_CREATE_IMAGE_BODY_2 12280
#define IDS_NTP_ACTION_CHIP_DEEP_SEARCH_HEADING 12281
#define IDS_NTP_ACTION_CHIP_DEEP_SEARCH_BODY 12282
#define IDS_NTP_ACTION_CHIP_CANVAS_HEADING 12283
#define IDS_NTP_ACTION_CHIP_CANVAS_BODY 12284
#define IDS_NTP_ACTION_CHIP_DISABLE_TEXT 12285
#define IDS_NTP_ACTION_CHIPS_UNDO_DISABLEMENT_TOAST_MESSAGE 12286
#define IDS_COMPOSE_REMOVE_TOOL_CHIP_A11Y_LABEL 12287
#define IDS_COMPOSE_ASK_ABOUT_THIS_TAB 12288
#define IDS_COMPOSE_ASK_ABOUT_THIS_TAB_ARIA_LABEL 12289
#define IDS_COMPOSE_ASK_ABOUT_THIS_PAGE 12290
#define IDS_COMPOSE_ASK_ABOUT_THIS_PAGE_ARIA_LABEL 12291
#define IDS_NTP_MODULES_SETUP_LIST_DISABLE_TOAST_MESSAGE 12292
#define IDS_NTP_MODULES_SETUP_LIST_DISMISS_TOAST_MESSAGE 12293
#define IDS_NTP_MODULES_SETUP_LIST_INFO 12294
#define IDS_NTP_MODULES_INFO_BUTTON_TITLE 12295
#define IDS_NTP_MODULES_DISMISS_TOAST_MESSAGE 12296
#define IDS_NTP_MODULES_DISABLE_TOAST_MESSAGE 12297
#define IDS_NTP_MODULE_INACTIVITY_REMOVAL 12298
#define IDS_NTP_MODULES_INACTIVITY_REMOVAL 12299
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISABLE_TOAST_MESSAGE 12300
#define IDS_NTP_MODULES_DISMISS_BUTTON_TEXT 12301
#define IDS_NTP_MODULES_DRIVE_MORE_ACTIONS_BUTTON_TEXT 12302
#define IDS_NTP_MODULES_DISABLE_BUTTON_TEXT 12303
#define IDS_NTP_MODULES_DISABLE_BUTTON_TEXT_V2 12304
#define IDS_NTP_MODULES_MORE_ACTIONS 12305
#define IDS_NTP_MODULE_HEADER_MORE_ACTIONS_MENU 12306
#define IDS_NTP_MODULES_CUSTOMIZE_BUTTON_TEXT 12307
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_TODAY 12308
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_YESTERDAY 12309
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_PAST_WEEK 12310
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_PAST_MONTH 12311
#define IDS_NTP_MODULES_STATEFUL_TASKS_VIEWED_PREVIOUSLY 12312
#define IDS_NTP_MODULES_SHOPPING_TASKS_SENTENCE 12313
#define IDS_NTP_MODULES_SHOPPING_TASKS_LOWER 12314
#define IDS_NTP_MODULES_DRIVE_DISABLE_BUTTON_TEXT 12315
#define IDS_NTP_MODULES_DRIVE_DISABLE_BUTTON_TEXT_V2 12316
#define IDS_NTP_MODULES_DRIVE_NAME 12317
#define IDS_NTP_MODULES_FILES_SENTENCE 12318
#define IDS_NTP_MODULES_DUMMY_LOWER 12319
#define IDS_NTP_MODULES_DUMMY_TITLE 12320
#define IDS_NTP_MODULES_DRIVE_INFO 12321
#define IDS_NTP_MODULES_MICROSOFT_FILES_NAME 12322
#define IDS_NTP_MODULES_MICROSOFT_FILES_INFO 12323
#define IDS_NTP_MODULES_MICROSOFT_FILES_DISABLE_BUTTON_TEXT 12324
#define IDS_NTP_MODULES_MICROSOFT_FILES_TRENDING_JUSTIFICATION_TEXT 12325
#define IDS_NTP_MODULES_MICROSOFT_FILES_OPENED_TODAY_JUSTIFICATION_TEXT 12326
#define IDS_NTP_MODULES_MICROSOFT_FILES_OPENED_YESTERDAY_JUSTIFICATION_TEXT 12327
#define IDS_NTP_MODULES_MICROSOFT_FILES_OPENED_PAST_WEEK_JUSTIFICATION_TEXT 12328
#define IDS_NTP_MODULES_MICROSOFT_FILES_SHARED_BY_JUSTIFICATION_TEXT 12329
#define IDS_NTP_MODULES_DISMISS_FOR_HOURS_BUTTON_TEXT 12330
#define IDS_NTP_MODULES_DISMISS_FOR_DAYS_BUTTON_TEXT 12331
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_DISMISS_TOAST_MESSAGE 12332
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_DISABLE_TOAST_MESSAGE 12333
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_INFO 12334
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_MORE_ACTIONS 12335
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_TITLE 12336
#define IDS_NTP_MODULES_GOOGLE_CALENDAR_DISABLE_BUTTON_TEXT 12337
#define IDS_NTP_MODULES_MICROSOFT_SIGN_OUT_BUTTON_TEXT 12338
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_TITLE 12339
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_DISABLE_BUTTON_TEXT 12340
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_DISMISS_TOAST_MESSAGE 12341
#define IDS_NTP_MODULES_OUTLOOK_CALENDAR_INFO 12342
#define IDS_NTP_MODULES_CALENDAR_DOUBLE_BOOKED 12343
#define IDS_NTP_MODULES_CALENDAR_JOIN_MEETING_BUTTON_TEXT 12344
#define IDS_NTP_MODULES_CALENDAR_JOIN_MEETING_BUTTON_ACCNAME 12345
#define IDS_NTP_MODULES_CALENDAR_IN_PROGRESS 12346
#define IDS_NTP_MODULES_CALENDAR_IN_X_MIN 12347
#define IDS_NTP_MODULES_CALENDAR_IN_X_HR 12348
#define IDS_NTP_MODULES_CALENDAR_SEE_MORE 12349
#define IDS_NTP_MODULES_CALENDAR_SEE_MORE_ACCNAME 12350
#define IDS_NTP_MODULES_KALEIDOSCOPE_TITLE 12351
#define IDS_NTP_MODULES_SHOPPING_TASKS_INFO_TITLE 12352
#define IDS_NTP_MODULES_TASKS_INFO 12353
#define IDS_NTP_MODULES_SHOPPING_TASKS_INFO_CLOSE 12354
#define IDS_NTP_MODULES_SHOPPING_TASKS_RELATED 12355
#define IDS_NTP_MODULES_CART_DISCOUNT_CHIP_AMOUNT 12356
#define IDS_NTP_MODULES_CART_DISCOUNT_CHIP_UP_TO_AMOUNT 12357
#define IDS_NTP_MODULES_CUSTOMIZE_IPH 12358
#define IDS_NTP_MODULES_FEED_TITLE 12359
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_RESUME_BROWSING 12360
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_RESUME_BROWSING_FOR 12361
#define IDS_NTP_MODULES_SHOW_ALL 12362
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_BOOKMARKED 12363
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_INFO 12364
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_WITH_DISCOUNT_INFO 12365
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_SENTENCE2 12366
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISABLE_TOAST_NAME 12367
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISMISS_BUTTON 12368
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DISABLE_DROPDOWN_TEXT 12369
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_DONE_BUTTON 12370
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_OPEN_ALL_IN_NEW_TAB_GROUP_BUTTON_TEXT 12371
#define IDS_NTP_MODULES_HISTORY_CLUSTERS_SHOW_ALL_BUTTON 12372
#define IDS_ACCNAME_SHOW_ALL 12373
#define IDS_ACCNAME_SEARCH_SUGG 12374
#define IDS_NTP_MODULES_TAB_RESUMPTION_DISMISS_BUTTON 12375
#define IDS_NTP_MODULES_TAB_RESUMPTION_INFO 12376
#define IDS_NTP_MODULES_TAB_RESUMPTION_MULTI_DISMISS 12377
#define IDS_NTP_MODULES_TAB_RESUMPTION_SINGLE_DISMISS 12378
#define IDS_NTP_MODULES_TAB_RESUMPTION_RECENTLY_OPENED 12379
#define IDS_NTP_MODULES_TAB_RESUMPTION_DEVICE_PREFIX 12380
#define IDS_NTP_MODULES_MOST_RELEVANT_TAB_RESUMPTION_DISMISS_BUTTON 12381
#define IDS_NTP_MODULES_MOST_RELEVANT_TAB_RESUMPTION_TITLE 12382
#define IDS_NTP_MODULES_MOST_RELEVANT_TAB_RESUMPTION_SEE_MORE 12383
#define IDS_NTP_MODULES_MICROSOFT_AUTHENTICATION_NAME 12384
#define IDS_NTP_MODULES_TAB_GROUPS_DISMISS_TOAST_MESSAGE 12385
#define IDS_NTP_MODULES_TAB_GROUPS_DISABLE_TOAST_MESSAGE 12386
#define IDS_NTP_MODULES_TAB_GROUPS_INFO 12387
#define IDS_NTP_MODULES_TAB_GROUPS_TITLE 12388
#define IDS_NTP_MODULES_TAB_GROUPS_TIME_DELTA 12389
#define IDS_NTP_MODULES_TAB_GROUPS_RECENTLY_USED 12390
#define IDS_NTP_MODULES_TAB_GROUPS_ZERO_STATE_TITLE 12391
#define IDS_NTP_MODULES_TAB_GROUPS_ZERO_STATE_TEXT 12392
#define IDS_NTP_MICROSOFT_AUTHENTICATION_DISABLE_BUTTON_TEXT 12393
#define IDS_NTP_MICROSOFT_AUTHENTICATION_DISMISS_BUTTON_TEXT 12394
#define IDS_NTP_MICROSOFT_AUTHENTICATION_HEADING 12395
#define IDS_NTP_MICROSOFT_AUTHENTICATION_SUBHEADING 12396
#define IDS_NTP_MICROSOFT_AUTHENTICATION_SIGN_IN_BUTTON_TEXT 12397
#define IDS_NTP_MICROSOFT_AUTHENTICATION_SIDE_PANEL_DESCRIPTION 12398
#define IDS_NTP_MOBILE_PROMO_HEADER 12399
#define IDS_NTP_MOBILE_PROMO_DESCRIPTION 12400
#define IDS_NTP_MOBILE_PROMO_QR_CODE_LABEL 12401
#define IDS_NTP_MOST_VISITED_SHORTCUTS_INACTIVITY_REMOVAL 12402
#define IDS_EXTENSIONS_PROMO_PERFORMANCE 12403
#define IDS_EXTENSIONS_PROMO_PRIVACY 12404
#define IDS_EXTENSIONS_PROMO_NEUTRAL 12405
#define IDS_NEW_TAB_FOOTER_NAME 12406
#define IDS_OPENS_MANAGEMENT_PAGE 12407
#define IDS_HIDE_NEW_TAB_FOOTER 12408
#define IDS_NEW_TAB_FOOTER_BACKGROUND_ATTRIBUTION_ARIA_DESC 12409
#define IDS_NEW_TAB_FOOTER_BACKGROUND_ATTRIBUTION_TEXT 12410
#define IDS_STAR_VIEW_MENU_ADD_BOOKMARK 12411
#define IDS_STAR_VIEW_MENU_EDIT_BOOKMARK 12412
#define IDS_STAR_VIEW_MENU_MOVE_TO_READ_LATER 12413
#define IDS_STAR_VIEW_MENU_MARK_AS_READ 12414
#define IDS_READ_LATER_TITLE 12415
#define IDS_READ_LATER_EXPAND_BUTTON_ARIA_LABEL 12416
#define IDS_READ_LATER_COLLAPSE_BUTTON_ARIA_LABEL 12417
#define IDS_READ_LATER_MENU_UNREAD_HEADER 12418
#define IDS_READ_LATER_MENU_READ_HEADER 12419
#define IDS_READ_LATER_MENU_TOOLTIP_MARK_AS_READ 12420
#define IDS_READ_LATER_MENU_TOOLTIP_MARK_AS_UNREAD 12421
#define IDS_READ_LATER_MENU_EMPTY_STATE_ADD_FROM_DIALOG_SUBHEADER 12422
#define IDS_READ_LATER_MENU_EMPTY_STATE_HEADER 12423
#define IDS_READ_LATER_MENU_EMPTY_STATE_SUBHEADER 12424
#define IDS_READ_LATER_ADD_CURRENT_TAB 12425
#define IDS_READ_LATER_CANT_ADD_CURRENT_TAB 12426
#define IDS_READ_LATER_MARK_CURRENT_TAB_READ 12427
#define IDS_READ_LATER_REMOVE_CURRENT_TAB 12428
#define IDS_READ_LATER_CONTEXT_MENU_MARK_AS_UNREAD 12429
#define IDS_READ_LATER_CONTEXT_MENU_MARK_AS_READ 12430
#define IDS_READ_LATER_CONTEXT_MENU_DELETE 12431
#define IDS_READING_LIST_MENU 12432
#define IDS_READING_LIST_MENU_ADD_TAB 12433
#define IDS_READING_LIST_MENU_SHOW_UI 12434
#define IDS_ACCNAME_SIDE_PANEL_RESIZE 12435
#define IDS_ACCNAME_SIDE_PANEL_CLOSE 12436
#define IDS_SIDE_PANEL_RESIZE_ACCESSIBLE_ALERT 12437
#define IDS_SIDE_PANEL_RESIZE_LEFT_SIDE_ACCESSIBLE_ALERT 12438
#define IDS_SIDE_PANEL_RESIZE_RIGHT_SIDE_ACCESSIBLE_ALERT 12439
#define IDS_ACCNAME_SIDE_PANEL_SELECTOR 12440
#define IDS_ACCNAME_SIDE_PANEL_COMPANION_SHOW 12441
#define IDS_ACCNAME_SIDE_PANEL_COMPANION_HIDE 12442
#define IDS_SIDE_PANEL_COMPANION_TITLE 12443
#define IDS_SIDE_PANEL_COMPANION_TOOLBAR_TOOLTIP 12444
#define IDS_SIDE_PANEL_COMPANION_PROMO 12445
#define IDS_SIDE_PANEL_COMPANION_PROMO_PINNING 12446
#define IDS_SIDE_PANEL_COMPANION_PROMO_SCREEN_READER 12447
#define IDS_SIDE_PANEL_COMPANION_ERROR_PAGE_FIRST_LINE 12448
#define IDS_SIDE_PANEL_COMPANION_ERROR_PAGE_SECOND_LINE 12449
#define IDS_SHOW_CUSTOMIZE_CHROME_SIDE_PANEL 12450
#define IDS_SHOW_CUSTOMIZE_CHROME_TOOLBAR 12451
#define IDS_SIDE_PANEL_SHOW_TABS_FROM_OTHER_DEVICES 12452
#define IDS_SIDE_PANEL_TABS_FROM_OTHER_DEVICES_TITLE 12453
#define IDS_SIDE_PANEL_TOOLBAR_BUTTON_CXMENU_UNPIN 12454
#define IDS_SIDE_PANEL_TOOLBAR_BUTTON_CXMENU_PIN 12455
#define IDS_SIDE_PANEL_HEADER_UNPIN_BUTTON_TOOLTIP 12456
#define IDS_SIDE_PANEL_HEADER_PIN_BUTTON_TOOLTIP 12457
#define IDS_SIDE_PANEL_UNPINNED 12458
#define IDS_SIDE_PANEL_PINNED 12459
#define IDS_PINNED_ACTION_BUTTON_ACCESSIBLE_TITLE 12460
#define IDS_SIDE_PANEL_GENERIC_PINNABLE_IPH 12461
#define IDS_SIDE_PANEL_GENERIC_PINNABLE_IPH_SCREENREADER 12462
#define IDS_SIDE_PANEL_HEADER_MORE_INFO_BUTTON_TOOLTIP 12463
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_TITLE 12464
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_SUBTITLE 12465
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_FOLDER_SUBTITLE 12466
#define IDS_BOOKMARKS_MOVE_TO_ACCOUNT_DIALOG_OK_BUTTON_LABEL 12467
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_TITLE 12468
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_SUBTITLE 12469
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_FOLDER_SUBTITLE 12470
#define IDS_BOOKMARKS_MOVE_TO_DEVICE_DIALOG_OK_BUTTON_LABEL 12471
#define IDS_BOOKMARKS_SORT_BY_TYPE 12472
#define IDS_BOOKMARKS_ALL_BOOKMARKS 12473
#define IDS_BOOKMARKS_ALL_BOOKMARKS_OPEN_SIDE_PANEL 12474
#define IDS_BOOKMARKS_ACCOUNT_BOOKMARKS 12475
#define IDS_BOOKMARKS_DEVICE_BOOKMARKS 12476
#define IDS_BOOKMARKS_LABEL_TRACKED_PRODUCTS 12477
#define IDS_BOOKMARKS_SORT_NEWEST 12478
#define IDS_BOOKMARKS_SORT_NEWEST_LOWER 12479
#define IDS_BOOKMARKS_SORT_OLDEST 12480
#define IDS_BOOKMARKS_SORT_OLDEST_LOWER 12481
#define IDS_BOOKMARKS_SORT_ALPHABETICALLY 12482
#define IDS_BOOKMARKS_SORT_REVERSE_ALPHABETICALLY 12483
#define IDS_BOOKMARKS_SORT_LAST_OPENED 12484
#define IDS_BOOKMARKS_SORT_LAST_OPENED_LOWER 12485
#define IDS_BOOKMARKS_VISUAL_VIEW 12486
#define IDS_BOOKMARKS_COMPACT_VIEW 12487
#define IDS_BOOKMARKS_SORT_MENU_A11Y_LABEL 12488
#define IDS_BOOKMARKS_CREATE_NEW_FOLDER_A11Y_LABEL 12489
#define IDS_BOOKMARKS_NEW_FOLDER_TOOLTIP 12490
#define IDS_BOOKMARKS_EDIT_BOOKMARK_LIST_A11Y_LABEL 12491
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE 12492
#define IDS_BOOKMARKS_EMPTY_STATE_BODY 12493
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE_FOLDER 12494
#define IDS_BOOKMARKS_EMPTY_STATE_BODY_FOLDER 12495
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE_GUEST 12496
#define IDS_BOOKMARKS_EMPTY_STATE_BODY_GUEST 12497
#define IDS_BOOKMARKS_EMPTY_STATE_TITLE_SEARCH 12498
#define IDS_BOOKMARKS_EMPTY_STATE_BODY_SEARCH 12499
#define IDS_BOOKMARK_FOLDER_CHILD_COUNT 12500
#define IDS_BOOKMARKS_EDIT_BOOKMARK 12501
#define IDS_BOOKMARKS_EDIT_MOVE_TO_ANOTHER_FOLDER 12502
#define IDS_BOOKMARKS_EDIT_MORE 12503
#define IDS_BOOKMARKS_EDIT_MOVE_TO 12504
#define IDS_BOOKMARKS_EDIT_NEW_FOLDER 12505
#define IDS_BOOKMARKS_EDIT_CANCEL 12506
#define IDS_BOOKMARKS_EDIT_SAVE 12507
#define IDS_BOOKMARKS_EDIT_NAME 12508
#define IDS_BOOKMARKS_EDIT_URL 12509
#define IDS_BOOKMARK_DELETION_COUNT 12510
#define IDS_UNDO_BOOKMARK_DELETION 12511
#define IDS_BOOKMARKS_MOVE_TO_BOOKMARKS_BAR 12512
#define IDS_BOOKMARKS_MOVE_TO_ALL_BOOKMARKS 12513
#define IDS_BOOKMARKS_EDIT 12514
#define IDS_BOOKMARKS_RENAME 12515
#define IDS_BOOKMARKS_URL_FOLDER_DESCRIPTION 12516
#define IDS_BOOKMARKS_DISABLED_FEATURE 12517
#define IDS_BOOKMARKS_BACK_BUTTON_LABEL 12518
#define IDS_BOOKMARKS_BACK_BUTTON_TOOLTIP 12519
#define IDS_BOOKMARKS_FORWARD_BUTTON_LABEL 12520
#define IDS_BOOKMARK_OPTIONS_LABEL 12521
#define IDS_FOLDER_OPTIONS_LABEL 12522
#define IDS_BOOKMARKS_OPEN_FOLDER_LABEL 12523
#define IDS_BOOKMARKS_OPEN_BOOKMARK_LABEL 12524
#define IDS_BOOKMARKS_SELECT_FOLDER_LABEL 12525
#define IDS_BOOKMARKS_SELECT_BOOKMARK_LABEL 12526
#define IDS_BOOKMARKS_DESELECT_FOLDER_LABEL 12527
#define IDS_BOOKMARKS_DESELECT_BOOKMARK_LABEL 12528
#define IDS_BOOKMARK_ACCESSIBLE_DESCRIPTION_PRICE_TRACKING 12529
#define IDS_BOOKMARK_ACCESSIBLE_DESCRIPTION_PRICE_CHANGE 12530
#define IDS_BOOKMARKS_CHECKBOX_LABEL 12531
#define IDS_BOOKMARKS_PRIMARY_FILTER_HEADING 12532
#define IDS_BOOKMARKS_SECONDARY_FILTER_HEADING 12533
#define IDS_SHOW_READING_MODE_SIDE_PANEL 12534
#define IDS_READING_MODE_TITLE 12535
#define IDS_IMMERSIVE_READING_MODE_OPENED_ANNOUNCEMENT 12536
#define IDS_READING_MODE_TOOLTIP 12537
#define IDS_READING_MODE_NOT_SELECTABLE_HEADER 12538
#define IDS_READING_MODE_EMPTY_STATE_HEADER 12539
#define IDS_READING_MODE_EMPTY_STATE_SUBHEADER 12540
#define IDS_READING_MODE_TOOLBAR_LABEL 12541
#define IDS_READING_MODE_READ_ALOUD_TOOLBAR_LABEL 12542
#define IDS_READING_MODE_FONT_SIZE 12543
#define IDS_READING_MODE_FONT_NAME_COMBOBOX_LABEL 12544
#define IDS_READING_MODE_DECREASE_FONT_SIZE_BUTTON_LABEL 12545
#define IDS_READING_MODE_INCREASE_FONT_SIZE_BUTTON_LABEL 12546
#define IDS_READING_MODE_INCREASE_FONT_SIZE_ANNOUNCEMENT 12547
#define IDS_READING_MODE_DECREASE_FONT_SIZE_ANNOUNCEMENT 12548
#define IDS_READING_MODE_DISABLE_LINKS_BUTTON_LABEL 12549
#define IDS_READING_MODE_ENABLE_LINKS_BUTTON_LABEL 12550
#define IDS_READING_MODE_IMAGES_LABEL 12551
#define IDS_READING_MODE_DISABLE_IMAGES_BUTTON_LABEL 12552
#define IDS_READING_MODE_ENABLE_IMAGES_BUTTON_LABEL 12553
#define IDS_READING_MODE_PIN_LABEL 12554
#define IDS_READING_MODE_DISABLE_PIN_BUTTON_LABEL 12555
#define IDS_READING_MODE_ENABLE_PIN_BUTTON_LABEL 12556
#define IDS_READING_MODE_COLORS_COMBOBOX_LABEL 12557
#define IDS_READING_MODE_LINE_SPACING_COMBOBOX_LABEL 12558
#define IDS_READING_MODE_LETTER_SPACING_COMBOBOX_LABEL 12559
#define IDS_READING_MODE_SPACING_COMBOBOX_STANDARD 12560
#define IDS_READING_MODE_SPACING_COMBOBOX_LOOSE 12561
#define IDS_READING_MODE_SPACING_COMBOBOX_VERY_LOOSE 12562
#define IDS_READING_MODE_SPACING_COMBOBOX_WIDE 12563
#define IDS_READING_MODE_SPACING_COMBOBOX_VERY_WIDE 12564
#define IDS_READING_MODE_DEFAULT_COLOR_LABEL 12565
#define IDS_READING_MODE_LIGHT_COLOR_LABEL 12566
#define IDS_READING_MODE_DARK_COLOR_LABEL 12567
#define IDS_READING_MODE_YELLOW_COLOR_LABEL 12568
#define IDS_READING_MODE_HIGH_CONTRAST_COLOR_LABEL 12569
#define IDS_READING_MODE_LOW_CONTRAST_LIGHT_COLOR_LABEL 12570
#define IDS_READING_MODE_LOW_CONTRAST_DARK_COLOR_LABEL 12571
#define IDS_READING_MODE_BLUE_COLOR_LABEL 12572
#define IDS_READING_MODE_VOICE_HIGHLIGHT 12573
#define IDS_READING_MODE_AUTO_HIGHLIGHT_LABEL 12574
#define IDS_READING_MODE_WORD_HIGHLIGHT_LABEL 12575
#define IDS_READING_MODE_PHRASE_HIGHLIGHT_LABEL 12576
#define IDS_READING_MODE_SENTENCE_HIGHLIGHT_LABEL 12577
#define IDS_READING_MODE_OFF_HIGHLIGHT_LABEL 12578
#define IDS_READING_MODE_LINE_FOCUS_WINDOW_HEADING 12579
#define IDS_READING_MODE_LINE_FOCUS_STYLE_HEADING 12580
#define IDS_READING_MODE_LINE_FOCUS_SMALL_FOCUS_LABEL 12581
#define IDS_READING_MODE_LINE_FOCUS_MEDIUM_FOCUS_LABEL 12582
#define IDS_READING_MODE_LINE_FOCUS_LARGE_FOCUS_LABEL 12583
#define IDS_READING_MODE_LINE_FOCUS_UNDERLINE_LABEL 12584
#define IDS_READING_MODE_LINE_FOCUS_LINE_HEADING 12585
#define IDS_READING_MODE_LINE_FOCUS_MOVEMENT_HEADING 12586
#define IDS_READING_MODE_LINE_FOCUS_STATIC_LABEL 12587
#define IDS_READING_MODE_LINE_FOCUS_STATIC_LINE_LABEL 12588
#define IDS_READING_MODE_LINE_FOCUS_CURSOR_LINE_LABEL 12589
#define IDS_READING_MODE_LINE_FOCUS_OFF_LABEL 12590
#define IDS_READING_MODE_LINE_FOCUS_SMALL_FOCUS_LABEL_SCREENREADER 12591
#define IDS_READING_MODE_LINE_FOCUS_MEDIUM_FOCUS_LABEL_SCREENREADER 12592
#define IDS_READING_MODE_LINE_FOCUS_LARGE_FOCUS_LABEL_SCREENREADER 12593
#define IDS_READING_MODE_LINE_FOCUS_UNDERLINE_LABEL_SCREENREADER 12594
#define IDS_READING_MODE_LINE_FOCUS_STATIC_LABEL_SCREENREADER 12595
#define IDS_READING_MODE_LINE_FOCUS_CURSOR_LINE_LABEL_SCREENREADER 12596
#define IDS_READING_MODE_LINE_FOCUS_OFF_LABEL_SCREENREADER 12597
#define IDS_READING_MODE_KEYBOARD_SHORTCUT_IPH_BODY 12598
#define IDS_READING_MODE_KEYBOARD_SHORTCUT_IPH_SCREENREADER 12599
#define IDS_READ_ANYTHING_LOADING 12600
#define IDS_READING_MODE_FONT_RESET 12601
#define IDS_READING_MODE_FONT_RESET_TOOLTIP 12602
#define IDS_READING_MODE_TURN_HIGHLIGHT_OFF 12603
#define IDS_READING_MODE_TURN_HIGHLIGHT_ON 12604
#define IDS_READING_MODE_PLAY_DESCRIPTION 12605
#define IDS_READING_MODE_PLAY_SPEECH 12606
#define IDS_READING_MODE_PLAY_TOOLTIP 12607
#define IDS_READING_MODE_PREVIEW_TOOLTIP 12608
#define IDS_READING_MODE_PAUSE_TOOLTIP 12609
#define IDS_READING_MODE_STOP_SPEECH 12610
#define IDS_READING_MODE_NAVIGATE_PREVIOUS_SENTENCE 12611
#define IDS_READING_MODE_NAVIGATE_NEXT_SENTENCE 12612
#define IDS_READING_MODE_MORE_OPTIONS 12613
#define IDS_READING_MODE_SETTINGS 12614
#define IDS_READING_MODE_VOICE_SPEED 12615
#define IDS_READING_MODE_VOICE_SPEED_WITH_RATE 12616
#define IDS_READING_MODE_VOICE_SPEED_OPTION_TITLE 12617
#define IDS_READING_MODE_VOICE_SELECTION 12618
#define IDS_READING_MODE_SYSTEM_VOICE 12619
#define IDS_READING_MODE_ITEM_SELECTED 12620
#define IDS_READING_MODE_LANGUAGE_MENU 12621
#define IDS_READING_MODE_LANGUAGE_MENU_TITLE 12622
#define IDS_READING_MODE_LANGUAGE_MENU_CLOSE 12623
#define IDS_READING_MODE_CLOSE 12624
#define IDS_READING_MODE_LANGUAGE_MENU_NO_RESULTS 12625
#define IDS_READING_MODE_LANGUAGE_MENU_SEARCH_LABEL 12626
#define IDS_READING_MODE_LANGUAGE_MENU_SEARCH_CLEAR 12627
#define IDS_READING_MODE_LANGUAGE_MENU_DOWNLOADING 12628
#define IDS_READING_MODE_VOICE_MENU_DOWNLOADING 12629
#define IDS_READING_MODE_LANGUAGE_MENU_VOICES_UNAVAILABLE 12630
#define IDS_READING_MODE_LANGUAGE_MENU_NO_INTERNET 12631
#define IDS_READING_MODE_CANT_USE_READ_ALOUD 12632
#define IDS_READING_MODE_VOICE_MENU_NO_INTERNET 12633
#define IDS_READING_MODE_LANGUAGE_MENU_DOWNLOAD_FAILED 12634
#define IDS_READING_MODE_LANGUAGE_MENU_NO_SPACE 12635
#define IDS_READING_MODE_TOAST_NO_SPACE 12636
#define IDS_READING_MODE_VOICE_MENU_NO_SPACE 12637
#define IDS_READING_MODE_VOICE_MENU_PREVIEW_LANGUAGE 12638
#define IDS_READING_MODE_LANGUAGE_MENU_NO_SPACE_BUT_VOICES_EXIST 12639
#define IDS_READING_MODE_LANGUAGE_MENU_ITEM_LABEL 12640
#define IDS_READING_MODE_VOICE_DOWNLOADED_TITLE 12641
#define IDS_READING_MODE_VOICE_DOWNLOADED_MESSAGE 12642
#define IDS_READING_MODE_SIDE_PANEL_PROMO 12643
#define IDS_READING_MODE_SIDE_PANEL_PROMO_PINNING 12644
#define IDS_READING_MODE_OMNIBOX_ENTRY_POINT_PROMO 12645
#define IDS_READING_MODE_OMNIBOX_ENTRY_POINT_PROMO_SCREEN_READER 12646
#define IDS_READING_MODE_VOICE_PREVIEW_STRING 12647
#define IDS_READING_MODE_FONT_LOADING_STRING 12648
#define IDS_READING_MODE_LINE_FOCUS_LABEL 12649
#define IDS_READING_MODE_SIDE_PANEL_LABEL 12650
#define IDS_READING_MODE_VIEW_FULL_PAGE_LABEL 12651
#define IDS_READING_MODE_FULL_SCREEN_LABEL 12652
#define IDS_READING_MODE_VIEW_LABEL 12653
#define IDS_READING_MODE_LINKS_LABEL 12654
#define IDS_GOOGLE_LENS_TITLE 12655
#define IDS_LENS_DEFAULT_TITLE 12656
#define IDS_TOOLTIP_BACK 12657
#define IDS_ACCDESCRIPTION_BACK 12658
#define IDS_TOOLTIP_CHROMELABS_BUTTON 12659
#define IDS_TOOLTIP_LEFT_ALIGNED_SIDE_PANEL_BUTTON 12660
#define IDS_TOOLTIP_CHROMELABS_COMBOBOX 12661
#define IDS_TOOLTIP_CHROMELABS_FEEDBACK_BUTTON 12662
#define IDS_TOOLTIP_FORWARD 12663
#define IDS_ACCDESCRIPTION_FORWARD 12664
#define IDS_TOOLTIP_DOWNLOAD_ICON 12665
#define IDS_TOOLTIP_DOWNLOAD_ICON_NEW_DOWNLOAD 12666
#define IDS_TOOLTIP_HOME 12667
#define IDS_TOOLTIP_RELOAD 12668
#define IDS_TOOLTIP_RELOAD_WITH_MENU 12669
#define IDS_TOOLTIP_STOP 12670
#define IDS_TOOLTIP_EXTENSIONS_BUTTON 12671
#define IDS_TOOLTIP_OVERFLOW_BUTTON 12672
#define IDS_TOOLTIP_EXTENSIONS_BUTTON_ALL_EXTENSIONS_BLOCKED 12673
#define IDS_TOOLTIP_EXTENSIONS_BUTTON_ANY_EXTENSION_HAS_ACCESS 12674
#define IDS_ACC_NAME_EXTENSIONS_BUTTON 12675
#define IDS_ACC_NAME_EXTENSIONS_BUTTON_ALL_EXTENSIONS_BLOCKED 12676
#define IDS_ACC_NAME_EXTENSIONS_BUTTON_ANY_EXTENSION_HAS_ACCESS 12677
#define IDS_TOOLTIP_EXTENSIONS_SITE_ACCESS_BUTTON 12678
#define IDS_TOOLTIP_SIDE_PANEL_SHOW 12679
#define IDS_TOOLTIP_SIDE_PANEL_HIDE 12680
#define IDS_TOOLTIP_SIDE_PANEL 12681
#define IDS_TOOLTIP_LOCATION_ICON 12683
#define IDS_TOOLTIP_NEW_TAB 12684
#define IDS_TOOLTIP_TAB_SCROLL_LEADING 12685
#define IDS_TOOLTIP_TAB_SCROLL_TRAILING 12686
#define IDS_TOOLTIP_MIC_SEARCH 12687
#define IDS_TOOLTIP_LENS_SEARCH 12688
#define IDS_TOOLTIP_LENS_REINVOKE_VISUAL_SELECTION_A11Y_LABEL 12689
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_CLOSE_BUTTON_LABEL 12690
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_TITLE 12691
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_TITLE_SHORT 12692
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_DRAG_TITLE 12693
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_UPLOAD_FILE_TITLE 12694
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OR_TEXT 12695
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_TEXT_PLACEHOLDER 12696
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_SEARCH_BUTTON_LABEL 12697
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_DRAG_DROP_TITLE 12698
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_LOADING_TEXT 12699
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OFFLINE_TEXT 12700
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OFFLINE_SUBTITLE_TEXT 12701
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_OFFLINE_BUTTON_LABEL 12702
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_FILE_TYPE 12703
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_FILE_SIZE 12704
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_MULTIPLE_FILES 12705
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_VALIDATION_ERROR_SCHEME 12706
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_VALIDATION_ERROR_CONFORMANCE 12707
#define IDS_LENS_SEARCH_UPLOAD_DIALOG_ERROR_MULTIPLE_URLS 12708
#define IDS_TOOLTIP_SAVE_CREDIT_CARD 12709
#define IDS_TOOLTIP_SAVE_CREDIT_CARD_PENDING 12710
#define IDS_TOOLTIP_SAVE_CVC 12711
#define IDS_TOOLTIP_SAVE_IBAN 12712
#define IDS_TOOLTIP_MIGRATE_LOCAL_CARD 12713
#define IDS_TOOLTIP_TRANSLATE 12714
#define IDS_TOOLTIP_ZOOM 12715
#define IDS_TOOLTIP_ZOOM_EXTENSION_ICON 12716
#define IDS_ZOOM_SET_DEFAULT 12717
#define IDS_TOOLTIP_FIND 12718
#define IDS_TOOLTIP_TAB_SEARCH 12719
#define IDS_SPLIT_VIEW_NTP_EMPTY_TITLE 12720
#define IDS_SPLIT_VIEW_NTP_EMPTY_BODY 12721
#define IDS_SPLIT_VIEW_NTP_TITLE 12722
#define IDS_SPLIT_VIEW_NTP_TAB_TITLE 12723
#define IDS_ACCNAME_SPLIT_VIEW_MINI_TOOLBAR_MENU_BUTTON 12724
#define IDS_SPLIT_VIEW_NTP_CLOSE_BUTTON_ARIA_LABEL 12725
#define IDS_SPLIT_VIEW_TITLE_IPH 12726
#define IDS_SPLIT_VIEW_BODY_IPH 12727
#define IDS_SPLIT_VIEW_PIN_ACTION_2_IPH 12728
#define IDS_SPLIT_VIEW_TAB_SWITCH_ENTRY_IPH_TITLE 12729
#define IDS_SPLIT_VIEW_TAB_SWITCH_ENTRY_IPH_BODY 12730
#define IDS_SPLIT_VIEW_TAB_SWITCH_STEP_IPH_BODY 12731
#define IDS_SPLIT_VIEW_TAB_SWITCH_COMPLETION_IPH_BODY 12732
#define IDS_SPLIT_VIEW_TOOLBAR_BUTTON_STEP_IPH_BODY 12733
#define IDS_SPLIT_VIEW_DRAG_ENTRYPOINT_LABEL 12734
#define IDS_SPLIT_VIEW_RESIZE_ACCESSIBLE_ALERT 12735
#define IDS_SPLIT_VIEW_RESIZE_LEFT_SIDE_ACCESSIBLE_ALERT 12736
#define IDS_SPLIT_VIEW_RESIZE_RIGHT_SIDE_ACCESSIBLE_ALERT 12737
#define IDS_SWITCH_TO_VERTICAL_TAB 12738
#define IDS_SWITCH_TO_HORIZONTAL_TAB 12739
#define IDS_COLLAPSE_VERTICAL_TABS 12740
#define IDS_EXPAND_VERTICAL_TABS 12741
#define IDS_VERTICAL_TABS_SEND_FEEDBACK 12742
#define IDS_VERTICAL_TABS_TUTORIAL_STEP_SHOW_VERTICAL 12743
#define IDS_VERTICAL_TABS_TUTORIAL_STEP_COLLAPSE 12744
#define IDS_VERTICAL_TABS_TUTORIAL_STEP_END 12745
#define IDS_VERTICAL_TABS_ENABLE_EXPAND_ON_HOVER 12746
#define IDS_VERTICAL_TABS_DISABLE_EXPAND_ON_HOVER 12747
#define IDS_VERTICAL_TABS_COLLAPSE_BUTTON_TOGGLE_EXPAND_ON_HOVER 12748
#define IDS_VERTICAL_TABS_IPH_TITLE 12749
#define IDS_VERTICAL_TABS_IPH_BODY 12750
#define IDS_VERTICAL_TABS_EXPAND_ON_HOVER_DEFAULT_ENABLED_IPH_BODY 12751
#define IDS_VERTICAL_TABS_EXPAND_ON_HOVER_DEFAULT_DISABLED_IPH_BODY 12752
#define IDS_VERTICAL_RESIZE_AREA 12753
#define IDS_VERTICAL_TAB_RESIZE_ACCESSIBLE_ALERT 12754
#define IDS_VERTICAL_TAB_GROUP_MORE_OPTIONS 12755
#define IDS_VIEW_PROJECTS_PANEL 12756
#define IDS_HIDE_PROJECTS_PANEL 12757
#define IDS_TAB_GROUPS_TITLE 12758
#define IDS_RECENT_CHATS_TITLE 12759
#define IDS_TAB_GROUP_MORE_OPTIONS 12760
#define IDS_THREADS_SHOW_MORE 12761
#define IDS_THREADS_SHOW_LESS 12762
#define IDS_PROJECTS_PANEL 12763
#define IDS_PROJECTS_PANEL_GEMINI_ACTIVITY 12764
#define IDS_PROJECTS_PANEL_AI_MODE_ACTIVITY 12765
#define IDS_TAB_GROUPS_NO_TAB_GROUPS 12766
#define IDS_OPEN_GEMINI_THREAD_TOOLTIP 12767
#define IDS_OPEN_AI_MODE_THREAD_TOOLTIP 12768
#define IDS_OPEN_GEMINI_THREAD_ACCESSIBILITY_LABEL 12769
#define IDS_OPEN_AI_MODE_THREAD_ACCESSIBILITY_LABEL 12770
#define IDS_TAB_STRIP_UNPIN_TAB_SEARCH 12771
#define IDS_TAB_STRIP_PIN_TAB_SEARCH 12772
#define IDS_TAB_SEARCH_BUTTON_CXMENU_UNPIN 12773
#define IDS_TAB_SEARCH_BUTTON_CXMENU_PIN 12774
#define IDS_PROJECTS_PANEL_BUTTON_CXMENU_UNPIN 12775
#define IDS_PROJECTS_PANEL_BUTTON_CXMENU_PIN 12776
#define IDS_EVERYTHING_MENU_BUTTON_CXMENU_UNPIN 12777
#define IDS_EVERYTHING_MENU_BUTTON_CXMENU_PIN 12778
#define IDS_TOOLTIP_INTENT_PICKER_ICON 12779
#define IDS_INTENT_PICKER_BUBBLE_VIEW_OPEN_WITH 12780
#define IDS_INTENT_PICKER_BUBBLE_VIEW_OPEN_IN_APP 12781
#define IDS_INTENT_PICKER_BUBBLE_VIEW_REMEMBER_SELECTION 12782
#define IDS_INTENT_PICKER_BUBBLE_VIEW_OPEN 12783
#define IDS_INTENT_PICKER_BUBBLE_VIEW_STAY_IN_CHROME 12784
#define IDS_INTENT_PICKER_BUBBLE_VIEW_INITIATING_ORIGIN 12785
#define IDS_INTENT_CHIP_OPEN_IN_APP 12786
#define IDR_INTENT_PICKER_SUPPORTED_LINKS_INFOBAR_MESSAGE 12787
#define IDR_INTENT_PICKER_SUPPORTED_LINKS_INFOBAR_OK_LABEL 12788
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_BUTTON_ACCEPT_REMINDER 12795
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_BUTTON_DECLINE 12796
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_REMINDER_CONFIRMATION_BUTTON 12797
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_REMINDER_CONFIRMATION_TITLE 12798
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_LENS_FEATURE_NAME 12799
#define IDS_IOS_DESKTOP_PROMO_BUBBLE_ENHANCED_BROWSING_FEATURE_NAME 12800
#define IDS_IOS_DEVICE_TYPE_IPHONE 12801
#define IDS_IOS_DEVICE_TYPE_IPAD 12802
#define IDS_NTP_MOBILE_PROMO_BODY 12803
#define IDS_NTP_MOBILE_PROMO_PASSWORDS_BODY 12804
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_TITLE 12805
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_FOOTER_TITLE_REMINDER 12806
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_BUTTON_DECLINE 12807
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_BUBBLE_SUBTITLE 12808
#define IDS_IOS_DESKTOP_PASSWORD_PROMO_NOTIFICATION_BODY 12809
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_TITLE 12810
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_FOOTER_TITLE 12811
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_BUTTON_DECLINE 12812
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_SUBTITLE 12813
#define IDS_IOS_DESKTOP_ADDRESS_PROMO_BUBBLE_FOOTER_DESCRIPTION_QR 12814
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_TITLE 12815
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_FOOTER_TITLE 12816
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_BUTTON_DECLINE 12817
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_SUBTITLE 12818
#define IDS_IOS_DESKTOP_PAYMENT_PROMO_BUBBLE_FOOTER_DESCRIPTION_QR 12819
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_DESCRIPTION_QR 12820
#define IDS_IOS_DESKTOP_ESB_PROMO_BUBBLE_TITLE_REMINDER 12821
#define IDS_IOS_DESKTOP_SAFE_BROWSING_PROMO_NOTIFICATION_BODY 12822
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_DESCRIPTION_QR 12823
#define IDS_IOS_DESKTOP_LENS_PROMO_BUBBLE_TITLE_REMINDER 12824
#define IDS_IOS_DESKTOP_LENS_PROMO_NOTIFICATION_BODY 12825
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_BUBBLE_DESCRIPTION_REMINDER 12826
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_BUBBLE_TITLE_QR 12827
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_BUBBLE_TITLE_REMINDER 12828
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_NOTIFICATION_BODY 12829
#define IDS_IOS_DESKTOP_PRICE_TRACKING_PROMO_NOTIFICATION_TITLE 12830
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_DESCRIPTION_REMINDER 12831
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_TITLE_QR 12832
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_BUBBLE_TITLE_REMINDER 12833
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_NOTIFICATION_BODY 12834
#define IDS_IOS_DESKTOP_TAB_GROUPS_PROMO_NOTIFICATION_TITLE 12835
#define IDS_ACCESSIBLE_INCOGNITO_WINDOW_TITLE_FORMAT 12836
#define IDS_ACCESSIBLE_GUEST_WINDOW_TITLE_FORMAT 12837
#define IDS_ACCESSIBLE_WINDOW_TITLE_WITH_PROFILE_FORMAT 12838
#define IDS_ACCNAME_APP_UPGRADE_RECOMMENDED 12839
#define IDS_ACCNAME_FULLSCREEN 12840
#define IDS_ACCNAME_EXIT_FULLSCREEN 12841
#define IDS_ACCNAME_FULLSCREEN_DISABLED 12842
#define IDS_ACCNAME_HOME 12843
#define IDS_ACCNAME_RELOAD 12844
#define IDS_ACCNAME_SPLIT_TABS_TOOLBAR_BUTTON_PINNED 12845
#define IDS_ACCNAME_SPLIT_TABS_TOOLBAR_BUTTON_ENABLED 12846
#define IDS_ACCNAME_FIND 12847
#define IDS_ACCNAME_BOOKMARKS 12848
#define IDS_ACCNAME_SAVED_TAB_GROUPS 12849
#define IDS_ACCNAME_SAVED_TAB_GROUPS_CHEVRON 12850
#define IDS_SAVED_TAB_GROUPS_OVERFLOW_BUTTON_TOOLTIP 12851
#define IDS_TAB_GROUP_EDITOR_BUBBLE_FOOTER_SYNC_DISABLED 12852
#define IDS_TAB_GROUP_EDITOR_BUBBLE_FOOTER_SYNC_ENABLED 12853
#define IDS_TAB_GROUP_EDITOR_BUBBLE_FOOTER_LEARN_MORE 12854
#define IDS_ACCNAME_TAB_GROUPS_EVERYTHING 12855
#define IDS_TAB_GROUPS_EVERYTHING_BUTTON_TOOLTIP 12856
#define IDS_ACCNAME_BOOKMARKS_CHEVRON 12857
#define IDS_ACCNAME_BOOKMARK_BUTTON_ROLE_DESCRIPTION 12858
#define IDS_ACCNAME_BOOKMARK_FOLDER_BUTTON_ROLE_DESCRIPTION 12859
#define IDS_ACCNAME_SAVED_TAB_GROUP_BUTTON_ROLE_DESCRIPTION 12860
#define IDS_ACCNAME_CHROMELABS_BUTTON 12861
#define IDS_ACCNAME_LEFT_ALIGNED_SIDE_PANEL_BUTTON 12862
#define IDS_ACCESSIBLE_TEXT_CHROMELABS_BUTTON_ADDED_BY_ENTERPRISE_POLICY 12863
#define IDS_ACCESSIBLE_TEXT_CHROMELABS_BUTTON_REMOVED_BY_ENTERPRISE_POLICY 12864
#define IDS_ACCNAME_CHROMELABS_COMBOBOX 12865
#define IDS_ACCNAME_CHROMELABS_COMBOBOX_MAC 12866
#define IDS_ACCNAME_SEPARATOR 12867
#define IDS_ACCNAME_EXTENSIONS 12868
#define IDS_ACCNAME_NEWTAB 12869
#define IDS_ACCNAME_MINIMIZE 12870
#define IDS_ACCNAME_MAXIMIZE 12871
#define IDS_ACCNAME_RESTORE 12872
#define IDS_ACCNAME_CLOSE_TAB 12873
#define IDS_ACCNAME_ZOOM_SET_DEFAULT 12874
#define IDS_ACCNAME_TAB_SEARCH 12875
#define IDS_ACCNAME_TAB_SCROLL_LEADING 12876
#define IDS_ACCNAME_TAB_SCROLL_TRAILING 12877
#define IDS_ACCNAME_MUTE_TAB 12878
#define IDS_ACCNAME_WEB_APP_DETAILED_INSTALL_DIALOG_LEADING_SCROLL_BUTTON 12879
#define IDS_ACCNAME_WEB_APP_DETAILED_INSTALL_DIALOG_TRAILING_SCROLL_BUTTON 12880
#define IDS_TOOLBAR_BUTTON_UNPINNED 12881
#define IDS_TOOLBAR_BUTTON_PINNED 12882
#define IDS_ALLOWED_CLIPBOARD_TITLE 12883
#define IDS_BLOCKED_CLIPBOARD_TITLE 12884
#define IDS_ALLOWED_CLIPBOARD_MESSAGE 12885
#define IDS_ALLOWED_CLIPBOARD_BLOCK 12886
#define IDS_ALLOWED_CLIPBOARD_NO_ACTION 12887
#define IDS_BLOCKED_CLIPBOARD_MESSAGE 12888
#define IDS_BLOCKED_CLIPBOARD_UNBLOCK 12889
#define IDS_BLOCKED_CLIPBOARD_NO_ACTION 12890
#define IDS_BACK_NAVIGATION_MENU_PROMO 12891
#define IDS_BACK_NAVIGATION_MENU_PROMO_ACCESSIBLE_TEXT 12892
#define IDS_BOOKMARK_PROMO_0 12893
#define IDS_BOOKMARK_PROMO_1 12894
#define IDS_BOOKMARK_PROMO_2 12895
#define IDS_CHROME_TIP 12896
#define IDS_EXTENSIONS_MENU_IPH_ENTRY_POINT_TITLE 12897
#define IDS_EXTENSIONS_MENU_IPH_ENTRY_POINT_BODY 12898
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_IPH_ENTRY_POINT_TITLE 12899
#define IDS_EXTENSIONS_REQUEST_ACCESS_BUTTON_IPH_ENTRY_POINT_BODY 12900
#define IDS_EXTENSIONS_ZERO_STATE_PROMO_IPH_TITLE 12901
#define IDS_EXTENSIONS_ZERO_STATE_PROMO_CUSTOM_ACTION_IPH_DESCRIPTION 12902
#define IDS_EXTENSIONS_ZERO_STATE_PROMO_CUSTOM_ACTION_IPH_ACCEPT 12903
#define IDS_GLOBAL_MEDIA_CONTROLS_PROMO 12904
#define IDS_INCOGNITOWINDOW_PROMO_0 12905
#define IDS_INCOGNITOWINDOW_PROMO_1 12906
#define IDS_INCOGNITOWINDOW_PROMO_2 12907
#define IDS_INCOGNITOWINDOW_PROMO_3 12908
#define IDS_NEWTAB_PROMO_0 12909
#define IDS_NEWTAB_PROMO_1 12910
#define IDS_NEWTAB_PROMO_2 12911
#define IDS_POWER_BOOKMARKS_SIDE_PANEL_PROMO 12912
#define IDS_POWER_BOOKMARKS_SIDE_PANEL_PROMO_PINNING 12913
#define IDS_READING_LIST_DISCOVERY_PROMO 12914
#define IDS_READING_LIST_DISCOVERY_PROMO_PINNING 12915
#define IDS_READING_LIST_ENTRY_POINT_PROMO 12916
#define IDS_DESKTOP_PWA_INSTALL_PROMO 12917
#define IDS_DESKTOP_PWA_LINK_CAPTURING_TEXT 12918
#define IDS_DESKTOP_PWA_LINK_CAPTURING_SETTINGS 12919
#define IDS_UPDATED_CONNECTION_SECURITY_INDICATORS_PROMO 12920
#define IDS_READING_LIST_IN_SIDE_PANEL_PROMO 12921
#define IDS_READING_LIST_IN_SIDE_PANEL_PROMO_PINNING 12922
#define IDS_TAB_GROUPS_UNNAMED_GROUP_TOOLTIP 12923
#define IDS_TAB_GROUPS_NAMED_GROUP_TOOLTIP 12924
#define IDS_SHARED_HIGHLIGHTING_PROMO 12925
#define IDS_TAB_AUDIO_MUTING_PROMO 12926
#define IDS_BATTERY_SAVER_MODE_PROMO_TITLE 12927
#define IDS_BATTERY_SAVER_MODE_PROMO_TEXT 12928
#define IDS_BATTERY_SAVER_MODE_PROMO_ACTION_TEXT 12929
#define IDS_MEMORY_SAVER_MODE_PROMO_TEXT 12930
#define IDS_MEMORY_SAVER_MODE_PROMO_ACTION_TEXT 12931
#define IDS_TAB_GROUPS_HOVER_CARD_HEADER 12932
#define IDS_TAB_GROUPS_UNNAMED_GROUP_HOVER_CARD_HEADER 12933
#define IDS_TAB_GROUPS_HOVER_CARD_FOOTER 12934
#define IDS_DISCARD_RING_PROMO_TITLE 12935
#define IDS_DISCARD_RING_PROMO_TEXT 12936
#define IDS_DISCARD_RING_PROMO_ACTION_TEXT 12937
#define IDS_DISCARD_RING_SETTINGS_TOAST 12938
#define IDS_TUTORIAL_GENERIC_SUCCESS_TITLE 12939
#define IDS_TUTORIAL_TAB_GROUP_ADD_TAB_TO_GROUP 12940
#define IDS_TUTORIAL_ADD_TAB_TO_GROUP_WITH_EXISTING_GROUP_IN_TAB_STRIP 12941
#define IDS_TUTORIAL_TAB_GROUP_EDIT_BUBBLE 12942
#define IDS_TUTORIAL_TAB_GROUP_DRAG_TAB 12943
#define IDS_TUTORIAL_TAB_GROUP_COLLAPSE 12944
#define IDS_TUTORIAL_TAB_GROUP_SUCCESS_DESCRIPTION 12945
#define IDS_TUTORIAL_SAVED_TAB_GROUP_ADD_TAB_TO_GROUP 12946
#define IDS_TUTORIAL_SAVED_TAB_GROUP_OPEN_EDITOR 12947
#define IDS_TUTORIAL_SAVED_TAB_GROUP_NAME_SAVE_GROUP 12948
#define IDS_TUTORIAL_SAVED_TAB_GROUP_HIDE_GROUP 12949
#define IDS_TUTORIAL_SAVED_TAB_GROUP_REOPEN_GROUP 12950
#define IDS_TUTORIAL_SAVED_TAB_GROUP_SUCCESS_DESCRIPTION 12951
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_OPEN_SIDE_PANEL 12952
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_ADD_TAB 12953
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_MARK_READ 12954
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_CLICK_DROPDOWN 12955
#define IDS_TUTORIAL_SIDE_PANEL_READING_LIST_SUCCESS_BODY 12956
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_START_TUTORIAL_IPH 12957
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_OPEN_SIDE_PANEL 12958
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_CHANGE_THEME 12959
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_SELECT_COLLECTION 12960
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_APPLY_THEME 12961
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_CLICK_BACK_ARROW 12962
#define IDS_TUTORIAL_CUSTOMIZE_CHROME_SUCCESS_BODY 12963
#define IDS_TUTORIAL_PASSWORD_MANAGER_OPEN_MENU 12964
#define IDS_TUTORIAL_PASSWORD_MANAGER_CLICK_PASSWORDS_MENU 12965
#define IDS_TUTORIAL_PASSWORD_MANAGER_SELECT_SETTINGS 12966
#define IDS_TUTORIAL_PASSWORD_MANAGER_ADD_SHORTCUT 12967
#define IDS_TUTORIAL_PASSWORD_MANAGER_CLICK_INSTALL 12968
#define IDS_TUTORIAL_LENS_OVERLAY_INTRO_HEADER 12969
#define IDS_TUTORIAL_LENS_OVERLAY_INTRO_BODY 12970
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_ADDRESS_BAR 12971
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_LENS 12972
#define IDS_TUTORIAL_LENS_OVERLAY_HOMEWORK_INTRO_HEADER 12973
#define IDS_TUTORIAL_LENS_OVERLAY_HOMEWORK_INTRO_BODY 12974
#define IDS_TUTORIAL_LENS_OVERLAY_HOMEWORK_CLICK_LENS 12975
#define IDS_TUTORIAL_LENS_OVERLAY_SELECT 12976
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_SEARCH_BOX 12977
#define IDS_TUTORIAL_LENS_OVERLAY_CLICK_PIN_ICON 12978
#define IDS_TUTORIAL_LENS_OVERLAY_SUCCESS_BODY 12979
#define IDS_BROWSER_HANGMONITOR_RENDERER_TITLE 12981
#define IDS_BROWSER_HANGMONITOR_RENDERER 12982
#define IDS_BROWSER_HANGMONITOR_IFRAME_TITLE 12983
#define IDS_BROWSER_HANGMONITOR_RENDERER_WAIT 12984
#define IDS_BROWSER_HANGMONITOR_RENDERER_END 12985
#define IDS_BROWSER_HANGMONITOR_PLUGIN_INFOBAR 12986
#define IDS_BROWSER_HANGMONITOR_PLUGIN_INFOBAR_KILLBUTTON 12987
#define IDS_PASSWORDS_AUTO_SIGNIN_TITLE 12988
#define IDS_PASSWORDS_AUTO_SIGNIN_DESCRIPTION 12989
#define IDS_PASSWORDS_VIA_FEDERATION 12990
#define IDS_CONFIRM_MESSAGEBOX_YES_BUTTON_LABEL 12991
#define IDS_CONFIRM_MESSAGEBOX_NO_BUTTON_LABEL 12992
#define IDS_NEAR_OOM_REDUCTION_MESSAGE_TITLE 12993
#define IDS_NEAR_OOM_REDUCTION_MESSAGE_DESCRIPTION 12994
#define IDS_TAILORED_SECURITY_UNCONSENTED_MESSAGE_TITLE 12995
#define IDS_TAILORED_SECURITY_UNCONSENTED_MESSAGE_ACCEPT 12996
#define IDS_TAILORED_SECURITY_DISPLAY_SOURCE 12997
#define IDS_PASSWORD_MANAGER_CANCEL_BUTTON 12998
#define IDS_PASSWORD_MANAGER_USERNAME_LABEL 12999
#define IDS_PASSWORD_MANAGER_PASSWORD_LABEL 13000
#define IDS_PASSWORD_MANAGER_UPDATED_BUBBLE_TITLE 13001
#define IDS_PASSWORD_MANAGER_MORE_TO_FIX_BODY_MESSAGE_GOOGLE_PASSWORD_MANAGER 13002
#define IDS_PASSWORD_MANAGER_SAFE_STATE_BODY_MESSAGE_GOOGLE_PASSWORD_MANAGER 13003
#define IDS_PASSWORD_MANAGER_CHECK_REMAINING_BUTTON 13004
#define IDS_PASSWORD_MANAGER_SAVE_BUTTON 13005
#define IDS_PASSWORD_MANAGER_MOVE_BUBBLE_CANCEL_BUTTON 13006
#define IDS_PASSWORD_MANAGER_UPDATE_BUTTON 13007
#define IDS_PASSWORD_MANAGER_BUBBLE_BLOCKLIST_BUTTON 13008
#define IDS_PASSWORD_MANAGER_DESTINATION_DROPDOWN_ACCESSIBLE_NAME 13009
#define IDS_PASSWORD_MANAGER_DESTINATION_DROPDOWN_SAVE_TO_ACCOUNT 13010
#define IDS_PASSWORD_MANAGER_DESTINATION_DROPDOWN_SAVE_TO_DEVICE 13011
#define IDS_PASSWORD_MANAGER_IPH_TITLE_SAVE_TO_ACCOUNT 13012
#define IDS_PASSWORD_MANAGER_IPH_BODY_SAVE_TO_ACCOUNT 13013
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_BODY_TEMPLATE 13014
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_BODY_SIGNED_IN 13015
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_BODY_NOT_SIGNED_IN 13016
#define IDS_PASSWORDS_SAVE_PRIMING_PROMO_SCREENREADER 13017
#define IDS_PASSWORDS_SAVE_RECOVERY_PROMO_BODY 13018
#define IDS_PASSWORDS_SAVE_RECOVERY_PROMO_SCREENREADER 13019
#define IDS_PASSWORD_MANAGER_TOOLTIP_BLOCKED 13020
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_AFTER_SAVE 13021
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_AFTER_SAVE_SCREENREADER 13022
#define IDS_PASSWORD_MANAGER_IPH_SHARE_PASSWORD_BUTTON 13023
#define IDS_PASSWORD_MANAGER_IPH_SHARE_PASSWORD_BUTTON_SCREENREADER 13024
#define IDS_PASSWORD_MANAGER_IPH_ACCOUNT_STORAGE_TOGGLE 13025
#define IDS_PASSWORD_MANAGER_IPH_CREATE_SHORTCUT_TITLE 13026
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_DURING_SIGNIN 13027
#define IDS_PASSWORD_MANAGER_IPH_MANAGEMENT_BUBBLE_DURING_SIGNIN_SCREENREADER 13028
#define IDS_PASSWORD_MANAGER_TOOLTIP_SAVE 13029
#define IDS_PASSWORD_MANAGER_TOOLTIP_MANAGE 13030
#define IDS_PASSWORD_MANAGER_TOOLTIP_MOVE 13031
#define IDS_PASSWORD_MANAGER_TOOLTIP_PROTECT 13032
#define IDS_PASSWORD_MANAGER_TOOLTIP_SHARED_NOTIFICATION 13033
#define IDS_PASSWORD_MANAGER_TOOLTIP_KEYCHAIN_ERROR 13034
#define IDS_IMPORT_FROM_FIREFOX 13056
#define IDS_IMPORT_FROM_ICEWEASEL 13057
#define IDS_IMPORT_FROM_SAFARI 13058
#define IDS_IMPORT_FROM_BOOKMARKS_HTML_FILE 13059
#define IDS_IMPORTER_LOCK_TITLE 13063
#define IDS_IMPORTER_LOCK_TEXT 13064
#define IDS_IMPORTER_LOCK_OK 13065
#define IDS_FEEDBACK_REPORT_APP_TITLE 13066
#define IDS_FEEDBACK_REPORT_PAGE_TITLE 13067
#define IDS_FEEDBACK_REPORT_PAGE_TITLE_SAD_TAB_FLOW 13068
#define IDS_FEEDBACK_MINIMIZE_BUTTON_LABEL 13069
#define IDS_FEEDBACK_CLOSE_BUTTON_LABEL 13070
#define IDS_FEEDBACK_FREE_TEXT_LABEL 13071
#define IDS_FEEDBACK_FREE_TEXT_AI_LABEL 13072
#define IDS_FEEDBACK_REPORT_URL_LABEL 13073
#define IDS_FEEDBACK_USER_EMAIL_LABEL 13074
#define IDS_FEEDBACK_ANONYMOUS_EMAIL_OPTION 13075
#define IDS_FEEDBACK_CONSENT_CHECKBOX_LABEL 13076
#define IDS_FEEDBACK_SCREENSHOT_LABEL 13077
#define IDS_FEEDBACK_SCREENSHOT_A11Y_TEXT 13078
#define IDS_FEEDBACK_OFFLINE_DIALOG_TITLE 13079
#define IDS_FEEDBACK_OFFLINE_DIALOG_TEXT 13080
#define IDS_FEEDBACK_INCLUDE_SYSTEM_INFORMATION_CHKBOX 13081
#define IDS_FEEDBACK_ATTACH_FILE_NOTE 13084
#define IDS_FEEDBACK_ATTACH_FILE_LABEL 13085
#define IDS_FEEDBACK_ATTACH_FILE_TO_BIG 13086
#define IDS_FEEDBACK_INCLUDE_AUTOFILL_METADATA_CHECKBOX 13087
#define IDS_FEEDBACK_IWLWIFI_DEBUG_DUMP_EXPLAINER 13088
#define IDS_FEEDBACK_LOG_ID_CHECKBOX_LABEL 13089
#define IDS_FEEDBACK_PRIVACY_NOTE 13090
#define IDS_FEEDBACK_NO_DESCRIPTION 13091
#define IDS_FEEDBACK_OFFENSIVE_CHECKBOX_LABEL 13092
#define IDS_FEEDBACK_SEND_REPORT 13093
#define IDS_FEEDBACK_AUTOFILL_METADATA_PAGE_TITLE 13094
#define IDS_FEEDBACK_SYSINFO_PAGE_TITLE 13095
#define IDS_FEEDBACK_SYSINFO_PAGE_LOADING 13096
#define IDS_FEEDBACK_ADDITIONAL_INFO_LABEL 13097
#define IDS_CLEAR_BROWSING_DATA_TITLE 13098
#define IDS_CLEAR_BROWSING_DATA_HISTORY_NOTICE 13099
#define IDS_CLEAR_BROWSING_DATA_HISTORY_NOTICE_TITLE 13100
#define IDS_CLEAR_BROWSING_DATA_HISTORY_NOTICE_OK 13101
#define IDS_CLEAR_BROWSING_DATA_PASSWORDS_NOTICE 13102
#define IDS_CLEAR_BROWSING_DATA_PASSWORDS_NOTICE_TITLE 13103
#define IDS_CLEAR_BROWSING_DATA_PASSWORDS_NOTICE_OK 13104
#define IDS_MEDIA_SELECTED_MIC_LABEL 13105
#define IDS_MEDIA_SELECTED_CAMERA_LABEL 13106
#define IDS_MEDIA_MENU_NO_DEVICE_TITLE 13107
#define IDS_MEDIA_CONTROLS_TITLE_PLACEHOLDER_INCOGNITO 13108
#define IDS_ZOOMLEVELS_CHROME_ERROR_PAGES_LABEL 13109
#define IDS_STORAGE_ACCESS_MANAGE_TEXT 13110
#define IDS_STORAGE_ACCESS_MANAGE_TOOLTIP 13111
#define IDS_REPORT_AN_ISSUE 13122
#define IDS_REENABLE_UPDATES 13123
#define IDS_PICTURE_IN_PICTURE_TITLE_TEXT 13124
#define IDS_PICTURE_IN_PICTURE_PAUSE_CONTROL_TEXT 13125
#define IDS_PICTURE_IN_PICTURE_PLAY_CONTROL_TEXT 13126
#define IDS_PICTURE_IN_PICTURE_REPLAY_CONTROL_TEXT 13127
#define IDS_PICTURE_IN_PICTURE_BACK_TO_TAB_CONTROL_TEXT 13128
#define IDS_PICTURE_IN_PICTURE_SKIP_AD_CONTROL_TEXT 13129
#define IDS_PICTURE_IN_PICTURE_LIVE_STATUS_TEXT 13130
#define IDS_PICTURE_IN_PICTURE_MUTE_MICROPHONE_TEXT 13131
#define IDS_PICTURE_IN_PICTURE_UNMUTE_MICROPHONE_TEXT 13132
#define IDS_PICTURE_IN_PICTURE_MUTE_TEXT 13133
#define IDS_PICTURE_IN_PICTURE_UNMUTE_TEXT 13134
#define IDS_PICTURE_IN_PICTURE_TURN_ON_CAMERA_TEXT 13135
#define IDS_PICTURE_IN_PICTURE_TURN_OFF_CAMERA_TEXT 13136
#define IDS_PICTURE_IN_PICTURE_HANG_UP_TEXT 13137
#define IDS_PICTURE_IN_PICTURE_CLOSE_CONTROL_TEXT 13138
#define IDS_PICTURE_IN_PICTURE_MINIMIZE_CONTROL_TEXT 13139
#define IDS_PICTURE_IN_PICTURE_LIVE_CAPTION_CONTROL_TEXT 13140
#define IDS_PICTURE_IN_PICTURE_REPLAY_10_TEXT 13141
#define IDS_PICTURE_IN_PICTURE_FORWARD_10_TEXT 13142
#define IDS_PICTURE_IN_PICTURE_RESIZE_HANDLE_TEXT 13143
#define IDS_PICTURE_IN_PICTURE_PLAY_PAUSE_CONTROL_ACCESSIBLE_TEXT 13144
#define IDS_PICTURE_IN_PICTURE_NEXT_TRACK_CONTROL_ACCESSIBLE_TEXT 13145
#define IDS_PICTURE_IN_PICTURE_PREVIOUS_TRACK_CONTROL_ACCESSIBLE_TEXT 13146
#define IDS_PICTURE_IN_PICTURE_PREVIOUS_SLIDE_CONTROL_ACCESSIBLE_TEXT 13147
#define IDS_PICTURE_IN_PICTURE_NEXT_SLIDE_CONTROL_ACCESSIBLE_TEXT 13148
#define IDS_AUTO_PICTURE_IN_PICTURE_DESCRIPTION 13149
#define IDS_LOAD_STATE_WAITING_FOR_SOCKET_SLOT 13150
#define IDS_LOAD_STATE_WAITING_FOR_DELEGATE 13151
#define IDS_LOAD_STATE_WAITING_FOR_DELEGATE_GENERIC 13152
#define IDS_LOAD_STATE_WAITING_FOR_CACHE 13153
#define IDS_LOAD_STATE_ESTABLISHING_PROXY_TUNNEL 13154
#define IDS_LOAD_STATE_RESOLVING_PROXY_FOR_URL 13155
#define IDS_LOAD_STATE_RESOLVING_HOST_IN_PAC_FILE 13156
#define IDS_LOAD_STATE_DOWNLOADING_PAC_FILE 13157
#define IDS_LOAD_STATE_RESOLVING_HOST 13158
#define IDS_LOAD_STATE_CONNECTING 13159
#define IDS_LOAD_STATE_SSL_HANDSHAKE 13160
#define IDS_LOAD_STATE_SENDING_REQUEST 13161
#define IDS_LOAD_STATE_SENDING_REQUEST_WITH_PROGRESS 13162
#define IDS_LOAD_STATE_WAITING_FOR_RESPONSE 13163
#define IDS_TAB_CXMENU_NEWTABTORIGHT 13164
#define IDS_TAB_CXMENU_NEWTABTOLEFT 13165
#define IDS_TAB_CXMENU_NEWTABBELOW 13166
#define IDS_TAB_CXMENU_RELOAD 13167
#define IDS_TAB_CXMENU_DUPLICATE 13168
#define IDS_TAB_CXMENU_CLOSETAB 13169
#define IDS_TAB_CXMENU_CLOSEOTHERTABS 13170
#define IDS_TAB_CXMENU_CLOSETABSTORIGHT 13171
#define IDS_TAB_CXMENU_CLOSETABSTOLEFT 13172
#define IDS_TAB_CXMENU_CLOSETABSBELOW 13173
#define IDS_TAB_CXMENU_CLOSEALLTABS 13174
#define IDS_TAB_CXMENU_FOCUS_THIS_TAB 13175
#define IDS_TAB_CXMENU_PIN_TAB 13176
#define IDS_TAB_CXMENU_UNPIN_TAB 13177
#define IDS_TAB_CXMENU_SOUND_MUTE_SITE 13178
#define IDS_TAB_CXMENU_SOUND_UNMUTE_SITE 13179
#define IDS_TAB_CXMENU_READ_LATER 13180
#define IDS_TAB_CXMENU_ADD_TAB_TO_GROUP 13181
#define IDS_TAB_CXMENU_ADD_TAB_TO_NEW_GROUP 13182
#define IDS_TAB_CXMENU_ADD_TAB_TO_NEW_SPLIT 13183
#define IDS_TAB_CXMENU_NEW_SPLIT_WITH_CURRENT 13184
#define IDS_TAB_CXMENU_ARRANGE_SPLIT 13185
#define IDS_TAB_CXMENU_SWAP_WITH_ACTIVE_SPLIT 13186
#define IDS_TAB_CXMENU_SUBMENU_NEW_GROUP 13187
#define IDS_TAB_CXMENU_REMOVE_TAB_FROM_GROUP 13188
#define IDS_TAB_CXMENU_PLACEHOLDER_GROUP_TITLE 13189
#define IDS_TAB_CXMENU_MOVE_TABS_TO_NEW_WINDOW 13190
#define IDS_TAB_CXMENU_MOVETOANOTHERWINDOW 13191
#define IDS_TAB_CXMENU_MOVETOANOTHERNEWWINDOW 13192
#define IDS_TAB_CXMENU_COMMERCE_PRODUCT_SPEC 13193
#define IDS_TAB_CXMENU_ADD_TAB_TO_NEW_COMPARISON_TABLE 13194
#define IDS_ACCNAME_SPLIT_TABS_RESIZE 13198
#define IDS_PIN_SPLIT_TAB_TOGGLE 13199
#define IDS_SPLIT_TAB_REVERSE_VIEWS 13200
#define IDS_SPLIT_TAB_CLOSE 13201
#define IDS_SPLIT_TAB_CLOSE_LEFT_VIEW 13202
#define IDS_SPLIT_TAB_CLOSE_RIGHT_VIEW 13203
#define IDS_SPLIT_TAB_CLOSE_TOP_VIEW 13204
#define IDS_SPLIT_TAB_CLOSE_BOTTOM_VIEW 13205
#define IDS_SPLIT_TAB_SEPARATE_VIEWS 13206
#define IDS_SPLIT_TAB_SWAP_LEFT_VIEW 13207
#define IDS_SPLIT_TAB_SWAP_RIGHT_VIEW 13208
#define IDS_SPLIT_TAB_SWAP_TOP_VIEW 13209
#define IDS_SPLIT_TAB_SWAP_BOTTOM_VIEW 13210
#define IDS_SPLIT_TAB_SEND_FEEDBACK 13211
#define IDS_TAB_SEARCH_TOOLBAR_BUTTON_PROMO_TITLE 13212
#define IDS_TAB_SEARCH_TOOLBAR_BUTTON_PROMO_BODY 13213
#define IDS_TAB_SEARCH_TOOLBAR_BUTTON_PROMO_ACTION 13214
#define IDS_TAB_SEARCH_COMBO_BUTTON_PROMO_TITLE 13215
#define IDS_TAB_SEARCH_COMBO_BUTTON_PROMO_BODY 13216
#define IDS_TAB_SEARCH_COMBO_BUTTON_PROMO_SCREENREADER 13217
#define IDS_TAB_SEARCH_SEARCH_TABS 13218
#define IDS_TAB_SEARCH_NO_RESULTS_FOUND 13219
#define IDS_TAB_SEARCH_CLOSE_TAB 13220
#define IDS_TAB_SEARCH_SUBMIT_FEEDBACK 13221
#define IDS_TAB_SEARCH_A11Y_TAB_CLOSED 13222
#define IDS_TAB_SEARCH_A11Y_FOUND_TAB 13223
#define IDS_TAB_SEARCH_A11Y_FOUND_TABS 13224
#define IDS_TAB_SEARCH_A11Y_FOUND_TAB_FOR 13225
#define IDS_TAB_SEARCH_A11Y_FOUND_TABS_FOR 13226
#define IDS_TAB_SEARCH_A11Y_OPEN_TAB 13227
#define IDS_TAB_SEARCH_A11Y_RECENTLY_CLOSED_TAB 13228
#define IDS_TAB_SEARCH_A11Y_RECENTLY_CLOSED_TAB_GROUP 13229
#define IDS_TAB_SEARCH_MEDIA_TABS 13230
#define IDS_TAB_SEARCH_OPEN_TABS 13231
#define IDS_TAB_SEARCH_RECENTLY_CLOSED 13232
#define IDS_TAB_SEARCH_RECENTLY_CLOSED_TABS 13233
#define IDS_TAB_SEARCH_ONE_TAB 13234
#define IDS_TAB_SEARCH_TAB_COUNT 13235
#define IDS_TAB_SEARCH_EXPAND_RECENTLY_CLOSED_ITEMS 13236
#define IDS_TAB_SEARCH_EXPAND_RECENTLY_CLOSED 13237
#define IDS_TAB_SEARCH_COLLAPSE_RECENTLY_CLOSED 13238
#define IDS_TAB_SEARCH_TAB_NAME 13239
#define IDS_TAB_SEARCH_MENU 13240
#define IDS_BROWSER_WINDOW_TITLE_MENU_ENTRY 13241
#define IDS_TABS_TITLE_CXMENU 13242
#define IDS_SAVED_TAB_GROUP_TABS_COUNT 13243
#define IDS_CREATE_NEW_TAB_GROUP 13244
#define IDS_GROUP_UNGROUPED_TABS 13245
#define IDS_SAVED_TAB_GROUPS_MENU 13246
#define IDS_OPEN_GROUP_IN_BROWSER_MENU 13247
#define IDS_NEW_TAB_IN_GROUP 13248
#define IDS_NEW_TAB_IN_GROUP_NO_GROUPS 13249
#define IDS_NEW_TAB_IN_GROUP_NO_NAME 13250
#define IDS_NEW_TAB_GROUP 13251
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_APP_MENU_SYNCED_BODY 13252
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_DEFAULT_BODY_A11Y 13253
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_APP_MENU_NOT_SYNCED_BODY 13254
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_BOOKMARKS_BAR_SYNCED_BODY 13255
#define IDS_SAVED_TAB_GROUPS_V2_INTRO_IPH_BOOKMARKS_BAR_NOT_SYNCED_BODY 13256
#define IDS_RESUMPTION_RAIL_IPH_TITLE 13257
#define IDS_RESUMPTION_RAIL_IPH_BODY 13258
#define IDS_RESUMPTION_RAIL_IPH_BODY_ONLY_GEMINI 13259
#define IDS_RESUMPTION_RAIL_IPH_BODY_ONLY_AI_MODE 13260
#define IDS_RESUMPTION_RAIL_IPH_BODY_NO_THREADS 13261
#define IDS_RESUMPTION_RAIL_THREADS_IPH_TITLE 13262
#define IDS_RESUMPTION_RAIL_THREADS_IPH_TITLE_ONLY_GEMINI 13263
#define IDS_RESUMPTION_RAIL_THREADS_IPH_TITLE_ONLY_AI_MODE 13264
#define IDS_RESUMPTION_RAIL_THREADS_IPH_BODY 13265
#define IDS_RESUMPTION_RAIL_THREADS_IPH_BODY_ONLY_GEMINI 13266
#define IDS_RESUMPTION_RAIL_THREADS_IPH_BODY_ONLY_AI_MODE 13267
#define IDS_RESUMPTION_RAIL_IPH_OK_BUTTON 13268
#define IDS_SAVED_TAB_GROUPS_UNSUPPORTED_ERROR 13269
#define IDS_TAB_GROUP_DELETION_DIALOG_MISSING_EMAIL 13270
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_SYNCED_DELETE 13271
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_SYNCED_UNGROUP 13272
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_NOT_SYNCED_DELETE 13273
#define IDS_TAB_GROUP_DELETION_DIALOG_BODY_NOT_SYNCED_UNGROUP 13274
#define IDS_TAB_GROUP_DELETION_DIALOG_DONT_ASK 13275
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_DELETE 13276
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_UNGROUP 13277
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_CLOSE_TAB_AND_DELETE 13278
#define IDS_TAB_GROUP_DELETION_DIALOG_TITLE_REMOVE_TAB_AND_DELETE 13279
#define IDS_TAB_GROUP_DELETION_DIALOG_OK_TEXT_DELETE 13280
#define IDS_TAB_GROUP_DELETION_DIALOG_OK_TEXT_UNGROUP 13281
#define IDS_TAB_GROUP_HEADER_CXMENU_TAB_GROUP_TITLE_ACCESSIBLE_NAME 13282
#define IDS_TAB_GROUP_HEADER_CXMENU_TAB_GROUP_FACE_PILE_ACCESSIBLE_NAME 13283
#define IDS_TAB_GROUP_HEADER_CXMENU_NEW_TAB_IN_GROUP 13284
#define IDS_TAB_GROUP_HEADER_CXMENU_UNGROUP 13285
#define IDS_TAB_GROUP_HEADER_CXMENU_FOCUS_GROUP 13286
#define IDS_TAB_GROUP_HEADER_CXMENU_UNFOCUS_GROUP 13287
#define IDS_TAB_GROUP_HEADER_CXMENU_SHARE_GROUP 13288
#define IDS_TAB_GROUP_HEADER_CXMENU_RECENT_ACTIVITY 13289
#define IDS_TAB_GROUP_HEADER_CXMENU_MANAGE_GROUP 13290
#define IDS_TAB_GROUP_HEADER_CXMENU_CLOSE_GROUP 13291
#define IDS_TAB_GROUP_HEADER_CXMENU_HIDE_GROUP 13292
#define IDS_TAB_GROUP_HEADER_CXMENU_DELETE_GROUP 13293
#define IDS_TAB_GROUP_HEADER_CXMENU_MOVE_GROUP_TO_NEW_WINDOW 13294
#define IDS_TAB_GROUP_HEADER_CXMENU_OPEN_GROUP_IN_NEW_WINDOW 13295
#define IDS_TAB_GROUP_HEADER_CXMENU_PIN_GROUP 13296
#define IDS_TAB_GROUP_HEADER_CXMENU_UNPIN_GROUP 13297
#define IDS_TAB_GROUP_HEADER_CXMENU_CONVERT_GROUP_TO_BOOKMARK_FOLDER 13298
#define IDS_TAB_GROUP_HEADER_CXMENU_SEND_FEEDBACK 13299
#define IDS_TAB_GROUP_HEADER_BUBBLE_TITLE_PLACEHOLDER 13300
#define IDS_DATA_SHARING_SHARE_GROUP_TITLE 13301
#define IDS_DATA_SHARING_COPY_LINK 13302
#define IDS_DATA_SHARING_COPY_LINK_SUCCESS 13303
#define IDS_DATA_SHARING_MANAGE_GROUP_TITLE 13304
#define IDS_DATA_SHARING_MANAGE_STOP_SHARING_OPTION 13305
#define IDS_DATA_SHARING_MANAGE_ACTIVITY_LOG_OPTION 13306
#define IDS_DATA_SHARING_OWNER_STOP_SHARING_DIALOG_TITLE 13307
#define IDS_DATA_SHARING_OWNER_REMOVE_MEMBER_DIALOG_TITLE 13308
#define IDS_DATA_SHARING_OWNER_REMOVE_MEMBER_DIALOG_CONFIRM 13309
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_TITLE 13310
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_CONFIRM 13311
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE 13312
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE_ZERO 13313
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE_SINGULAR 13314
#define IDS_DATA_SHARING_PREVIEW_DIALOG_TITLE_PLURAL 13315
#define IDS_DATA_SHARING_PREVIEW_DIALOG_CONFIRM 13316
#define IDS_DATA_SHARING_PREVIEW_DIALOG_DETAILS_TITLE 13317
#define IDS_DATA_SHARING_LINK_FAILED_TITLE 13318
#define IDS_DATA_SHARING_LEAVE_DIALOG_TITLE 13319
#define IDS_DATA_SHARING_BLOCK_LEAVE_DIALOG_TITLE 13320
#define IDS_DATA_SHARING_BLOCK_LEAVE_DIALOG_CONFIRM 13321
#define IDS_DATA_SHARING_NEED_SIGN_IN 13322
#define IDS_DATA_SHARING_NEED_SYNC 13323
#define IDS_DATA_SHARING_NEED_SYNC_TAB_GROUPS 13324
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT 13325
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT_BUTTON 13326
#define IDS_DATA_SHARING_GOT_IT 13327
#define IDS_DATA_SHARING_SOMETHING_WRONG 13328
#define IDS_DATA_SHARING_ORGANIZATION_DISALLOW_SIGN_IN 13329
#define IDS_DATA_SHARING_ORGANIZATION_LIMIT_SAVE 13330
#define IDS_DATA_SHARING_SIGNED_OUT 13331
#define IDS_DATA_SHARING_GROUP_FULL 13332
#define IDS_DATA_SHARING_DELETE_LAST_TAB_TITLE 13333
#define IDS_DATA_SHARING_DELETE_LAST_TAB_CONFIRM 13334
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_CANCEL 13335
#define IDS_DATA_SHARING_MEMBER_DELETE_LAST_TAB_CANCEL 13336
#define IDS_DATA_SHARING_RECENT_ACTIVITY_TITLE 13337
#define IDS_DATA_SHARING_RECENT_ACTIVITY_LATEST_UPDATE_TAB 13338
#define IDS_DATA_SHARING_RECENT_ACTIVITY_LATEST_UPDATE_GROUP 13339
#define IDS_DATA_SHARING_SHARE_GROUP_BODY 13340
#define IDS_DATA_SHARING_SHARE_GROUP_SHARE_AS 13341
#define IDS_DATA_SHARING_MANAGE_SHARE_WISELY 13342
#define IDS_DATA_SHARING_OWNER_STOP_SHARING_DIALOG_BODY 13343
#define IDS_DATA_SHARING_OWNER_REMOVE_MEMBER_DIALOG_BODY 13344
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_BODY 13345
#define IDS_DATA_SHARING_OWNER_DELETE_DIALOG_BODY_NO_GROUP_TITLE 13346
#define IDS_DATA_SHARING_PREVIEW_DIALOG_BODY 13347
#define IDS_DATA_SHARING_PREVIEW_DIALOG_DETAILS_TABS_IN_GROUP 13348
#define IDS_DATA_SHARING_LINK_FAILED_BODY 13349
#define IDS_DATA_SHARING_JOIN_GROUP_JOIN_AS 13350
#define IDS_DATA_SHARING_GET_GROUP_PREVIEW_ARIA_LABEL 13351
#define IDS_DATA_SHARING_PREVIEW_A11Y_NAME 13352
#define IDS_DATA_SHARING_LEAVE_DIALOG_BODY 13353
#define IDS_DATA_SHARING_LEAVE_DIALOG_BODY_NO_GROUP_TITLE 13354
#define IDS_DATA_SHARING_LEAVE_DIALOG_CONFIRM 13355
#define IDS_DATA_SHARING_BLOCK_DIALOG_TITLE 13356
#define IDS_DATA_SHARING_BLOCK_DIALOG_BODY 13357
#define IDS_DATA_SHARING_BLOCK_LEAVE_DIALOG_BODY 13358
#define IDS_DATA_SHARING_BLOCK_LEAVE_LEARN_MORE 13359
#define IDS_DATA_SHARING_NEED_SIGN_IN_BODY 13360
#define IDS_DATA_SHARING_NEED_SIGN_IN_CONTINUE_BUTTON 13361
#define IDS_DATA_SHARING_NEED_SYNC_BODY 13362
#define IDS_DATA_SHARING_NEED_SYNC_TAB_GROUPS_BODY 13363
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT_BODY 13364
#define IDS_SYNC_HISTORY_TITLE 13365
#define IDS_DATA_SHARING_NEED_SIGN_IN_AND_SYNC_HISTORY_BODY 13366
#define IDS_DATA_SHARING_NEED_SYNC_HISTORY_BODY 13367
#define IDS_DATA_SHARING_NEED_VERIFY_ACCOUNT_SYNC_HISTORY_BODY 13368
#define IDS_SYNC_HISTORY_BUTTON 13369
#define IDS_SYNC_HISTORY_FOOTER 13370
#define IDS_DATA_SHARING_SOMETHING_WRONG_BODY 13371
#define IDS_DATA_SHARING_SHARE_ERROR_BODY 13372
#define IDS_DATA_SHARING_JOIN_WARNING 13373
#define IDS_DATA_SHARING_ORGANIZATION_DISALLOW_SIGN_IN_BODY 13374
#define IDS_DATA_SHARING_ORGANIZATION_LIMIT_SAVE_BODY 13375
#define IDS_DATA_SHARING_SIGNED_OUT_BODY 13376
#define IDS_DATA_SHARING_SETTINGS 13377
#define IDS_DATA_SHARING_GROUP_FULL_BODY 13378
#define IDS_DATA_SHARING_OWNER_CANNOT_SHARE 13379
#define IDS_DATA_SHARING_DELETE_LAST_DIALOG_HEADER 13380
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_BODY 13381
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_BODY_SINGULAR 13382
#define IDS_DATA_SHARING_OWNER_DELETE_LAST_TAB_BODY_2 13383
#define IDS_DATA_SHARING_MEMBER_DELETE_LAST_TAB_BODY 13384
#define IDS_DATA_SHARING_MEMBER_DELETE_LAST_TAB_BODY_SINGULAR 13385
#define IDS_DATA_SHARING_RECENT_ACTIVITY_NO_UPDATES 13386
#define IDS_DATA_SHARING_PAGE_ACTION_ADDED_NEW_TAB 13387
#define IDS_DATA_SHARING_PAGE_ACTION_CHANGED_TAB 13388
#define IDS_DATA_SHARING_USER_ED_FIRST_TAB_CHANGE 13389
#define IDS_DATA_SHARING_SHARED_GROUPS_FEEDBACK 13390
#define IDS_DATA_SHARING_SHARED_GROUPS_FEEDBACK_IPH 13391
#define IDS_DATA_SHARING_SHARED_GROUPS_FEEDBACK_IPH_SCREENREADER 13392
#define IDS_DATA_SHARING_LEARN_ABOUT_SHARED_GROUPS 13393
#define IDS_DATA_SHARING_PEOPLE_WITH_ACCESS 13394
#define IDS_DATA_SHARING_LINK_EDIT_ACCESS 13395
#define IDS_DATA_SHARING_LINK_JOIN_TOGGLE 13396
#define IDS_DATA_SHARING_CANCEL 13397
#define IDS_DATA_SHARING_CLOSE 13398
#define IDS_DATA_SHARING_BACK 13399
#define IDS_DATA_SHARING_BLOCK 13400
#define IDS_DATA_SHARING_REMOVE 13401
#define IDS_DATA_SHARING_LEAVE_GROUP 13402
#define IDS_DATA_SHARING_KEEP_GROUP 13403
#define IDS_DATA_SHARING_DELETE_GROUP 13404
#define IDS_DATA_SHARING_LOADING 13405
#define IDS_DATA_SHARING_COPY_LINK_FAILED 13406
#define IDS_DATA_SHARING_YOU 13407
#define IDS_DATA_SHARING_OWNER 13408
#define IDS_DATA_SHARING_MEMBER_COUNT_SINGULAR 13409
#define IDS_DATA_SHARING_MEMBER_COUNT_PLURAL 13410
#define IDS_DATA_SHARING_TAB_COUNT_SINGULAR 13411
#define IDS_DATA_SHARING_TAB_COUNT_PLURAL 13412
#define IDS_DATA_SHARING_MORE_OPTIONS 13413
#define IDS_DATA_SHARING_MORE_OPTIONS_DESCRIPTION 13414
#define IDS_APP_MENU_RELOAD 13415
#define IDS_APP_MENU_NEW_WEB_PAGE 13416
#define IDS_APP_MENU_COPY_LINK 13417
#define IDS_APP_MENU_CREATE_QR_CODE 13418
#define IDS_APP_MENU_BUTTON_UPDATE 13419
#define IDS_APP_MENU_BUTTON_UPDATE_ALT1 13420
#define IDS_APP_MENU_BUTTON_UPDATE_ALT2 13421
#define IDS_APP_MENU_BUTTON_UPDATE_ALT3 13422
#define IDS_APP_MENU_BUTTON_ERROR 13423
#define IDS_APP_MENU_BUTTON_ACTION_REQUIRED 13424
#define IDS_MEDIA_SCREEN_CAPTURE_CONFIRMATION_TITLE 13425
#define IDS_MEDIA_SCREEN_CAPTURE_CONFIRMATION_TEXT 13426
#define IDS_MEDIA_SCREEN_AND_AUDIO_CAPTURE_CONFIRMATION_TEXT 13427
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_TEXT 13428
#define IDS_MEDIA_SCREEN_CAPTURE_WITH_AUDIO_NOTIFICATION_TEXT 13429
#define IDS_MEDIA_WINDOW_CAPTURE_NOTIFICATION_TEXT 13430
#define IDS_MEDIA_WINDOW_CAPTURE_WITH_AUDIO_NOTIFICATION_TEXT 13431
#define IDS_MEDIA_TAB_CAPTURE_NOTIFICATION_TEXT 13432
#define IDS_MEDIA_TAB_CAPTURE_WITH_AUDIO_NOTIFICATION_TEXT 13433
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_HIDE 13434
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_SOURCE 13435
#define IDS_MEDIA_SCREEN_CAPTURE_NOTIFICATION_STOP 13436
#define IDS_PLATFORM_KEYS_SELECT_CERT_DIALOG_TEXT 13437
#define IDS_UNSAFE_FRAME_MESSAGE 13438
#define IDS_CLIENT_CERT_DIALOG_TITLE 13439
#define IDS_CLIENT_CERT_DIALOG_TEXT 13440
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TITLE 13441
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CERT_ENROLLMENT 13442
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CLIENT_AUTH 13443
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_LIST_CERTS 13444
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CERT_IMPORT 13445
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_TEXT_CERT_EXPORT 13446
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_PASSWORD_FIELD 13447
#define IDS_CRYPTO_MODULE_AUTH_DIALOG_OK_BUTTON_LABEL 13448
#define IDS_FR_ENABLE_LOGGING 13450
#define IDS_CRASHED_TAB_FEEDBACK_MESSAGE 13454
#define IDS_CRASHED_TAB_FEEDBACK_LINK 13455
#define IDS_KILLED_TAB_FEEDBACK_MESSAGE 13457
#define IDS_DEFAULT_BROWSER_CHANGED_TITLE 13459
#define IDS_DEFAULT_BROWSER_CHANGED_YES_BUTTON 13460
#define IDS_DEFAULT_BROWSER_CHANGED_NO_THANKS_BUTTON 13461
#define IDS_DEFAULT_BROWSER_MODAL_CONFIRM_BUTTON 13462
#define IDS_DEFAULT_BROWSER_MODAL_CANCEL_BUTTON 13463
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_STEPS_COMBINED 13464
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_OPEN_SETTINGS_LABEL 13465
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_SET_DEFAULT_LABEL 13466
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_YES_LABEL 13467
#define IDS_DEFAULT_BROWSER_BUBBLE_DIALOG_SET_LATER_LABEL 13468
#define IDS_RELAUNCH_BUTTON 13469
#define IDS_HELP_MANAGED_BY_YOUR_PARENT 13470
#define IDS_CONTROLLED_SETTING_POLICY 13473
#define IDS_TOOLBAR_INFORM_SET_HOME_PAGE 13474
#define IDS_MANAGE_EXTENSIONS_SETTING_WINDOWS_TITLE 13475
#define IDS_CONTROLLED_SETTING_EXTENSION 13476
#define IDS_CONTROLLED_SETTING_EXTENSION_WITHOUT_NAME 13477
#define IDS_CONTROLLED_SETTING_RECOMMENDED 13478
#define IDS_CONTROLLED_SETTING_HAS_RECOMMENDATION 13479
#define IDS_CONTROLLED_SETTING_CHILD_RESTRICTION 13480
#define IDS_CONTROLLED_SETTING_PARENT 13481
#define IDS_EXTENSIONS_INSTALL_LOCATION_UNKNOWN 13482
#define IDS_EXTENSIONS_INSTALL_LOCATION_3RD_PARTY 13483
#define IDS_EXTENSIONS_INSTALL_LOCATION_ENTERPRISE 13484
#define IDS_EXTENSIONS_INSTALL_LOCATION_SHARED_MODULE 13485
#define IDS_EXTENSIONS_BLOCKLISTED_MALWARE 13486
#define IDS_EXTENSIONS_BLOCKLISTED_SECURITY_VULNERABILITY 13487
#define IDS_EXTENSIONS_BLOCKLISTED_CWS_POLICY_VIOLATION 13488
#define IDS_EXTENSIONS_BLOCKLISTED_POTENTIALLY_UNWANTED 13489
#define IDS_EXTENSIONS_SAFE_BROWSING_CRX_ALLOWLIST_WARNING 13490
#define IDS_EXTENSIONS_SAFE_BROWSING_CRX_ALLOWLIST_WARNING_LEARN_MORE 13491
#define IDS_EXTENSIONS_ACCESS_REQUESTS_LEARN_MORE 13492
#define IDS_UPLOAD_MOVE_TO_ACCOUNT_DIALOG_TITLE 13493
#define IDS_EXTENSIONS_MOVE_TO_ACCOUNT_DIALOG_SUBTITLE 13494
#define IDS_BOOKMARK_UPLOAD_MOVE_TO_ACCOUNT_DIALOG_SUBTITLE 13495
#define IDS_EXTENSIONS_MOVE_TO_ACCOUNT_DIALOG_OK_BUTTON_LABEL 13496
#define IDS_BOOKMARK_MOVE_TO_ACCOUNT_ICON_TOOLTIP 13497
#define IDS_RESET_PROFILE_SETTINGS_EXPLANATION 13498
#define IDS_TRIGGERED_RESET_PROFILE_SETTINGS_TITLE 13499
#define IDS_TRIGGERED_RESET_PROFILE_SETTINGS_EXPLANATION 13500
#define IDS_TRIGGERED_RESET_PROFILE_SETTINGS_DEFAULT_TOOL_NAME 13501
#define IDS_RESET_PROFILE_SETTINGS_LOCALE 13502
#define IDS_RESET_PROFILE_SETTINGS_STARTUP_URLS 13503
#define IDS_RESET_PROFILE_SETTINGS_STARTUP_TYPE 13504
#define IDS_RESET_PROFILE_SETTINGS_HOMEPAGE 13505
#define IDS_RESET_PROFILE_SETTINGS_HOMEPAGE_IS_NTP 13506
#define IDS_RESET_PROFILE_SETTINGS_YES 13507
#define IDS_RESET_PROFILE_SETTINGS_NO 13508
#define IDS_RESET_PROFILE_SETTINGS_SHOW_HOME_BUTTON 13509
#define IDS_RESET_PROFILE_SETTINGS_DSE 13510
#define IDS_RESET_PROFILE_SETTINGS_EXTENSIONS 13511
#define IDS_RESET_PROFILE_SETTINGS_SHORTCUTS 13512
#define IDS_RESET_PROFILE_SETTINGS_PROCESSING_SHORTCUTS 13513
#define IDS_AUTOFILL_DIALOG_PLACEHOLDER_EXPIRY_MONTH 13515
#define IDS_AUTOFILL_DIALOG_PLACEHOLDER_EXPIRY_YEAR 13516
#define IDS_AUTOFILL_FROM_GOOGLE_ACCOUNT 13517
#define IDS_SHOW_WINDOW_DECORATIONS 13518
#define IDS_OMNIBOX_ICON_SEND_TAB_TO_SELF 13519
#define IDS_OMNIBOX_TOOLTIP_SEND_TAB_TO_SELF 13520
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_FROM_DEVICE 13521
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_TITLE 13522
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_BUTTON_LABEL 13523
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_BUTTON_A11Y_NAME 13524
#define IDS_TOOLBAR_BUTTON_SEND_TAB_TO_SELF_BUTTON_HINT_TEXT 13525
#define IDS_MENU_SEND_TAB_TO_SELF 13526
#define IDS_SEND_TAB_TO_SELF 13527
#define IDS_SEND_TAB_TO_SELF_DEVICE_LABEL 13528
#define IDS_SEND_TAB_TO_SELF_MANAGE_DEVICES 13529
#define IDS_SEND_TAB_TO_SELF_SENDING_ANNOUNCE 13532
#define IDS_SEND_TAB_TO_SELF_MANAGE_DEVICES_LINK 13533
#define IDS_SEND_TAB_TO_SELF_SIGN_IN_PROMO_LABEL 13534
#define IDS_SEND_TAB_TO_SELF_NO_TARGET_DEVICE_LABEL 13535
#define IDS_CONTEXT_MENU_GENERATE_QR_CODE_PAGE 13536
#define IDS_CONTEXT_MENU_GENERATE_QR_CODE_IMAGE 13537
#define IDS_CONTEXT_MENU_GENERATE_QR_CODE_LINK 13538
#define IDS_OMNIBOX_QRCODE_GENERATOR_ICON_LABEL 13539
#define IDS_OMNIBOX_QRCODE_GENERATOR_ICON_TOOLTIP 13540
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_TITLE 13541
#define IDS_SHARING_HUB_GENERATE_QR_CODE_LABEL 13542
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_URL_TEXTFIELD_ACCESSIBLE_NAME 13543
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_TOOLTIP 13544
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_DOWNLOAD_BUTTON_LABEL 13545
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_COPY_BUTTON_LABEL 13546
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_ERROR_TOO_LONG 13547
#define IDS_BROWSER_SHARING_QR_CODE_DIALOG_ERROR_UNKNOWN 13548
#define IDS_SHARING_HUB_TITLE 13549
#define IDS_SHARING_HUB_TOOLTIP 13550
#define IDS_SHARING_HUB_SCREENSHOT_LABEL 13551
#define IDS_SHARING_HUB_COPY_LINK_LABEL 13552
#define IDS_SHARING_HUB_SAVE_PAGE_LABEL 13553
#define IDS_SHARING_HUB_MEDIA_ROUTER_LABEL 13554
#define IDS_SHARING_HUB_SHARE_LABEL 13555
#define IDS_BROWSER_SHARING_SCREENSHOT_POST_CAPTURE_TITLE 13556
#define IDS_BROWSER_SHARING_SCREENSHOT_DIALOG_DOWNLOAD_BUTTON_LABEL 13557
#define IDS_BROWSER_SHARING_SCREENSHOT_DIALOG_EDIT_BUTTON_LABEL 13558
#define IDS_BROWSER_SHARING_SCREENSHOT_DIALOG_SHARE_BUTTON_LABEL 13559
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_SELECTION 13560
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_CROP 13561
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_TEXT 13562
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ELLIPSE 13563
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_RECTANGLE 13564
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_LINE 13565
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ARROW 13566
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_BRUSH 13567
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_EMOJI 13568
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_HIGHLIGHTER 13569
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_UNDO 13570
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_REDO 13571
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ZOOM_IN 13572
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ZOOM_OUT 13573
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_COMMIT_CROP 13574
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_COMMIT_CROP 13575
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_CANCEL_CROP 13576
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_CANCEL_CROP 13577
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_BUTTON_DOWNLOAD_IMAGE 13578
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_BUTTON_COPY 13579
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TITLE 13580
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_BUTTON_TEXT_CLEAR 13581
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ALIGN_LEFT 13582
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ALIGN_CENTER 13583
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_ALIGN_RIGHT 13584
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_SHADOW_NONE 13585
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_SHADOW_SMALL 13586
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_SHADOW_LARGE 13587
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_FONT_DEFAULT 13588
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_FONT_MONOSPACE 13589
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_FONT_ITALIC 13590
#define IDS_BROWSER_SHARING_SCREENSHOT_IMAGE_EDITOR_TOOLTIP_FONT_OUTLINE 13591
#define IDS_CONTEXT_MENU_PASTE_FROM_CLIPBOARD 13592
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_TEXT_CONTENT_UNKNOWN_DEVICE 13593
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_TEXT_CONTENT 13594
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_IMAGE_CONTENT_UNKNOWN_DEVICE 13595
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_TITLE_IMAGE_CONTENT 13596
#define IDS_SHARING_REMOTE_COPY_NOTIFICATION_DESCRIPTION 13597
#define IDS_CONTENT_CONTEXT_SHARING_CLICK_TO_CALL_MULTIPLE_DEVICES 13598
#define IDS_CONTENT_CONTEXT_SHARING_CLICK_TO_CALL_SINGLE_DEVICE 13599
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_MULTIPLE_DEVICES 13600
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_SINGLE_DEVICE 13601
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_NOTIFICATION_TITLE_UNKNOWN_DEVICE 13602
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_NOTIFICATION_TITLE 13603
#define IDS_CONTENT_CONTEXT_SHARING_SHARED_CLIPBOARD_NOTIFICATION_DESCRIPTION 13604
#define IDS_OMNIBOX_TOOLTIP_SHARED_CLIPBOARD 13605
#define IDS_COLLECTED_COOKIES_DIALOG_TITLE 13606
#define IDS_COLLECTED_COOKIES_ALLOWED_COOKIES_LABEL 13607
#define IDS_COLLECTED_COOKIES_BLOCKED_COOKIES_LABEL 13608
#define IDS_COLLECTED_COOKIES_BLOCKED_THIRD_PARTY_BLOCKING_ENABLED 13609
#define IDS_COLLECTED_COOKIES_ALLOW_BUTTON 13610
#define IDS_COLLECTED_COOKIES_SESSION_ONLY_BUTTON 13611
#define IDS_COLLECTED_COOKIES_BLOCK_BUTTON 13612
#define IDS_COLLECTED_COOKIES_ALLOW_RULE_CREATED 13613
#define IDS_COLLECTED_COOKIES_BLOCK_RULE_CREATED 13614
#define IDS_COLLECTED_COOKIES_SESSION_RULE_CREATED 13615
#define IDS_COLLECTED_COOKIES_ALLOWED_COOKIES_TAB_LABEL 13616
#define IDS_COLLECTED_COOKIES_BLOCKED_COOKIES_TAB_LABEL 13617
#define IDS_COLLECTED_COOKIES_ALLOWED_AUX_TEXT 13618
#define IDS_COLLECTED_COOKIES_BLOCKED_AUX_TEXT 13619
#define IDS_COLLECTED_COOKIES_CLEAR_ON_EXIT_AUX_TEXT 13620
#define IDS_COLLECTED_COOKIES_INFOBAR_MESSAGE 13621
#define IDS_COLLECTED_COOKIES_INFOBAR_BUTTON 13622
#define IDS_COLLECTED_COOKIES_PARTITIONED_COOKIE 13623
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_TITLE 13624
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SUBTITLE 13625
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SETTINGS_LINK 13626
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_FIRST_PARTY_TITLE 13627
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_FIRST_PARTY_SUBTITLE 13628
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_THIRD_PARTY_TITLE 13629
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_THIRD_PARTY_SUBTITLE 13630
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_EMPTY_STATE_LABEL 13631
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_RELATED_APPS_TITLE 13632
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_RELATED_APPS_SUBTITLE 13633
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_RELATED_APPS_SETTINGS_LINK_TOOLTIP 13634
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_ALLOW_MENU_ITEM 13635
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_ALLOW_THIRD_PARTY_MENU_ITEM 13636
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_BLOCK_MENU_ITEM 13637
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SESSION_ONLY_MENU_ITEM 13638
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_ALLOWED_STATE_SUBTITLE 13639
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_BLOCKED_STATE_SUBTITLE 13640
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_SESSION_ONLY_STATE_SUBTITLE 13641
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_PARTITIONED_STATE_SUBTITLE 13642
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_PARTITIONED_SESSION_ONLY_STATE_SUBTITLE 13643
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_CONTEXT_MENU_TOOLTIP 13644
#define IDS_PAGE_SPECIFIC_SITE_DATA_DIALOG_DELETE_BUTTON_TOOLTIP 13645
#define IDS_ACCNAME_INFOBAR_CONTAINER 13646
#define IDS_ACCNAME_INFOBAR 13647
#define IDS_ONE_CLICK_BUBBLE_UNDO 13648
#define IDS_ENTERPRISE_SIGNIN_CANCEL 13649
#define IDS_ENTERPRISE_SIGNIN_CREATE_NEW_PROFILE 13650
#define IDS_ENTERPRISE_SIGNIN_CREATE_NEW_WORK_PROFILE 13651
#define IDS_ENTERPRISE_SIGNIN_CONTINUE 13652
#define IDS_ENTERPRISE_SIGNIN_ALERT 13653
#define IDS_PROFILE_WILL_BE_DELETED_DIALOG_TITLE 13654
#define IDS_PROFILE_WILL_BE_DELETED_DIALOG_DESCRIPTION 13655
#define IDS_MANAGED_WITH_HYPERLINK 13658
#define IDS_MANAGED_BY_WITH_HYPERLINK 13659
#define IDS_PROFILE_MANAGED_BY_WITH_HYPERLINK 13660
#define IDS_BROWSER_MANAGED_AND_PROFILE_MANAGED_BY_WITH_HYPERLINK 13661
#define IDS_BROWSER_AND_PROFILE_DIFFERENT_MANAGED_BY_WITH_HYPERLINK 13662
#define IDS_BROWSER_AND_PROFILE_SAME_MANAGED_BY_WITH_HYPERLINK 13663
#define IDS_MANAGED_BY_PARENT_WITH_HYPERLINK 13664
#define IDS_BROWSER_MANAGED_AND_PROFILE_MANAGED_BY_TOOLTIP 13665
#define IDS_BROWSER_AND_PROFILE_DIFFERENT_MANAGED_BY_TOOLTIP 13666
#define IDS_COOKIES_COOKIE_EXPIRES_SESSION 13667
#define IDS_COOKIES_COOKIE_SENDFOR_ANY 13668
#define IDS_COOKIES_COOKIE_SENDFOR_SECURE 13669
#define IDS_COOKIES_COOKIE_SENDFOR_SAME_SITE 13670
#define IDS_COOKIES_COOKIE_SENDFOR_SECURE_SAME_SITE 13671
#define IDS_COOKIES_COOKIE_ACCESSIBLE_TO_SCRIPT_YES 13672
#define IDS_COOKIES_COOKIE_ACCESSIBLE_TO_SCRIPT_NO 13673
#define IDS_COOKIES_COOKIES 13674
#define IDS_COOKIES_WEB_DATABASES 13675
#define IDS_COOKIES_LOCAL_STORAGE 13676
#define IDS_COOKIES_SESSION_STORAGE 13677
#define IDS_COOKIES_INDEXED_DBS 13678
#define IDS_COOKIES_FILE_SYSTEMS 13679
#define IDS_COOKIES_FILE_SYSTEM_USAGE_NONE 13680
#define IDS_COOKIES_SERVICE_WORKER 13681
#define IDS_COOKIES_SERVICE_WORKERS 13682
#define IDS_COOKIES_SHARED_WORKERS 13683
#define IDS_COOKIES_CACHE_STORAGE 13684
#define IDS_APP_DEFAULT_PAGE_NAME 13685
#define IDS_APP_LAUNCHER_TAB_TITLE 13686
#define IDS_NEW_TAB_GUEST_SESSION_HEADING 13687
#define IDS_NEW_TAB_GUEST_SESSION_DESCRIPTION 13688
#define IDS_NEW_TAB_GUEST_SESSION_LEARN_MORE_ACCESSIBILITY_TEXT 13689
#define IDS_NEW_TAB_ENTERPRISE_GUEST_SESSION_LEARN_MORE_ACCESSIBILITY_TEXT 13690
#define IDS_NEW_TAB_TILE_GRID_ACCESSIBLE_DESCRIPTION 13691
#define IDS_NEW_TAB_APP_INSTALL_HINT_LABEL 13692
#define IDS_NEW_TAB_MOST_VISITED 13693
#define IDS_NEW_TAB_RESTORE_THUMBNAILS_SHORT_LINK 13694
#define IDS_NEW_TAB_ATTRIBUTION_INTRO 13695
#define IDS_NEW_TAB_THUMBNAIL_REMOVED_NOTIFICATION 13696
#define IDS_NEW_TAB_REMOVE_THUMBNAIL_TOOLTIP 13697
#define IDS_NEW_TAB_PAGE_SWITCHER_CHANGE_TITLE 13698
#define IDS_NEW_TAB_PAGE_SWITCHER_SAME_TITLE 13699
#define IDS_NEW_TAB_VOICE_AUDIO_ERROR 13700
#define IDS_NEW_TAB_VOICE_CLOSE_TOOLTIP 13701
#define IDS_NEW_TAB_VOICE_DETAILS 13702
#define IDS_NEW_TAB_VOICE_LANGUAGE_ERROR 13703
#define IDS_NEW_TAB_VOICE_LISTENING 13704
#define IDS_NEW_TAB_VOICE_NETWORK_ERROR 13705
#define IDS_NEW_TAB_VOICE_NO_TRANSLATION 13706
#define IDS_NEW_TAB_VOICE_NO_VOICE 13707
#define IDS_NEW_TAB_VOICE_OTHER_ERROR 13708
#define IDS_NEW_TAB_VOICE_PERMISSION_ERROR 13709
#define IDS_NEW_TAB_VOICE_LEARN_MORE_ACCESSIBILITY_LABEL 13710
#define IDS_NEW_TAB_VOICE_READY 13711
#define IDS_NEW_TAB_VOICE_TRY_AGAIN 13712
#define IDS_NEW_TAB_VOICE_WAITING 13713
#define IDS_NEW_TAB_VOICE_SEARCH_CLOSED 13714
#define IDS_FUSEBOX_VOICE_SEARCH_TRANSCRIBING 13715
#define IDS_FUSEBOX_VOICE_SEARCH_STOP_TITLE 13716
#define IDS_NEW_TAB_APP_OPTIONS 13717
#define IDS_NEW_TAB_APP_DETAILS 13718
#define IDS_NEW_TAB_APP_CREATE_SHORTCUT 13719
#define IDS_NEW_TAB_APP_INSTALL_LOCALLY 13720
#define IDS_APP_CONTEXT_MENU_SHOW_INFO 13721
#define IDS_APP_CONTEXT_MENU_OPEN_PINNED 13722
#define IDS_APP_CONTEXT_MENU_OPEN_REGULAR 13723
#define IDS_APP_CONTEXT_MENU_OPEN_WINDOW 13724
#define IDS_APP_CONTEXT_MENU_OPEN_FULLSCREEN 13725
#define IDS_APP_CONTEXT_MENU_OPEN_MAXIMIZED 13726
#define IDS_APP_CONTEXT_MENU_OPEN_TAB 13727
#define IDS_APP_CONTEXT_MENU_RUN_ON_OS_LOGIN 13732
#define IDS_APPS_PAGE_DEPRECATED_APP_TITLE 13735
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_TITLE 13736
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_PROCEED_BUTTON 13737
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_CANCEL_BUTTON 13738
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_BODY_TEXT 13739
#define IDS_DEVICE_SIGNALS_CONSENT_DIALOG_DEFAULT_BODY_TEXT 13740
#define IDS_SYNC_CONFIRMATION_SETTINGS_INFO 13741
#define IDS_SYNC_CONFIRMATION_CONFIRM_BUTTON_LABEL 13742
#define IDS_SYNC_CONFIRMATION_SETTINGS_BUTTON_LABEL 13743
#define IDS_SYNC_CONFIRMATION_REFRESHED_SETTINGS_BUTTON_LABEL 13744
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_TITLE 13745
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_INFO_TITLE 13746
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_INFO_TITLE_SIGNIN_INTERCEPT_V2 13747
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_BOOKMARKS 13748
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_READING_LIST 13749
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_AUTOFILL 13750
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_EXTENSIONS 13751
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_HISTORY_AND_MORE 13752
#define IDS_SYNC_CONFIRMATION_TANGIBLE_SYNC_INFO_DESC 13753
#define IDS_SYNC_CONFIRMATION_WELCOME_TITLE_SIGNIN_INTERCEPT 13754
#define IDS_SYNC_CONFIRMATION_TURN_ON_SYNC_BUTTON_LABEL 13755
#define IDS_SYNC_DISABLED_CONFIRMATION_CHROME_SYNC_TITLE 13756
#define IDS_SYNC_DISABLED_CONFIRMATION_DETAILS 13757
#define IDS_SYNC_DISABLED_CONFIRMATION_CONFIRM_BUTTON_LABEL 13758
#define IDS_SYNC_DISABLED_CONFIRMATION_CONFIRM_BUTTON_MANAGED_ACCOUNT_SIGNOUT_DISALLOWED_LABEL 13759
#define IDS_SYNC_DISABLED_CONFIRMATION_UNDO_BUTTON_LABEL 13760
#define IDS_SYNC_LOADING_CONFIRMATION_TITLE 13761
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_NEW_PROFILE_BUTTON_LABEL 13762
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_AVATAR_BUTTON_SEPARATE_BROWSING_TEXT 13763
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_AVATAR_BUTTON_SWITCH_PROFILE_TEXT 13764
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CREATE_PROFILE_BUTTON_LABEL 13765
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_STAY_HERE_BUTTON_LABEL 13766
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_TITLE_SUPERVISED 13767
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CANCEL_BUTTON_LABEL 13768
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CANCEL_SWITCH_BUTTON_LABEL 13769
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_CREATE_BUBBLE_DESC_SUPERVISED 13770
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_SWITCH_BUBBLE_CONTINUE_BUTTON_LABEL 13771
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_ACCEPT_TEXT 13772
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_ENTERPRISE_BUBBLE_DESC_MANAGED_BY_TOKEN 13773
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_MANAGED_DISCLAIMER 13774
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_MANAGED_BY_DISCLAIMER 13775
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_TITLE_SIGNIN_REMINDER 13776
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_IPH_OK_BUTTON 13777
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_TITLE 13778
#define IDS_CHROME_SIGNOUT_CONFIRMATION_PROMPT_DELETE_AND_SIGNOUT_BUTTON 13779
#define IDS_CLOSE_WARNING_FOR_CLEAR_COOKIES_ON_EXIT_TEXT_LINK 13780
#define IDS_SYNC_PASSPHRASE_DIALOG_FOOTER_LINK 13781
#define IDS_SYNC_PASSPHRASE_DIALOG_TITLE 13782
#define IDS_SYNC_PASSPHRASE_DIALOG_OK_BUTTON 13783
#define IDS_CLOSE_WARNING_FOR_CLEAR_COOKIES_ON_EXIT_CLOSE 13784
#define IDS_SIGNIN_DICE_WEB_INTERCEPT_ENTERPRISE_PROFILE_NAME 13785
#define IDS_SIGNIN_ERROR_TITLE 13786
#define IDS_SIGNIN_ERROR_EMAIL_TITLE 13787
#define IDS_SIGNIN_ERROR_CLOSE_BUTTON_LABEL 13788
#define IDS_SIGNIN_ERROR_OK_BUTTON_LABEL 13789
#define IDS_SIGNIN_ERROR_SWITCH_BUTTON_LABEL 13790
#define IDS_SIGNIN_ACCESSIBLE_CLOSE_BUTTON 13791
#define IDS_SIGNIN_ACCESSIBLE_BACK_BUTTON 13792
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CREATE_PROFILE_RADIO_BUTTON_TITLE 13793
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CREATE_PROFILE_RADIO_BUTTON_SUBTITLE 13794
#define IDS_SIGNIN_EMAIL_CONFIRMATION_START_SYNC_RADIO_BUTTON_TITLE 13795
#define IDS_SIGNIN_EMAIL_CONFIRMATION_START_SYNC_RADIO_BUTTON_SUBTITLE 13796
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CLOSE_BUTTON_LABEL 13797
#define IDS_SIGNIN_EMAIL_CONFIRMATION_CONFIRM_BUTTON_LABEL 13798
#define IDS_PLUGIN_CRASHED_PROMPT 13799
#define IDS_RELOAD_PAGE_WITH_PLUGIN 13800
#define IDS_EXTERNAL_PROTOCOL_TITLE 13801
#define IDS_EXTERNAL_PROTOCOL_MESSAGE_WITH_INITIATING_ORIGIN 13802
#define IDS_EXTERNAL_PROTOCOL_MESSAGE 13803
#define IDS_EXTERNAL_PROTOCOL_OK_BUTTON_TEXT 13804
#define IDS_EXTERNAL_PROTOCOL_CANCEL_BUTTON_TEXT 13805
#define IDS_EXTERNAL_PROTOCOL_CHECKBOX_PER_ORIGIN_TEXT 13806
#define IDS_DIRECTORY_LISTING_HEADER 13808
#define IDS_DIRECTORY_LISTING_PARENT 13809
#define IDS_DIRECTORY_LISTING_NAME 13810
#define IDS_DIRECTORY_LISTING_SIZE 13811
#define IDS_DIRECTORY_LISTING_DATE_MODIFIED 13812
#define IDS_SAVE_PAGE_DESC_HTML_ONLY 13813
#define IDS_SAVE_PAGE_DESC_SINGLE_FILE 13814
#define IDS_SAVE_PAGE_DESC_COMPLETE 13815
#define IDS_PROFILE_ERROR_DIALOG_TITLE 13816
#define IDS_COULDNT_OPEN_PROFILE_ERROR 13817
#define IDS_OPEN_PROFILE_DATA_LOSS 13818
#define IDS_PROFILE_ERROR_DIALOG_CHECKBOX 13819
#define IDS_PROFILE_ERROR_FEEDBACK_DESCRIPTION 13820
#define IDS_REFUSE_TO_RUN_AS_ROOT 13821
#define IDS_REFUSE_TO_RUN_AS_ROOT_2 13822
#define IDS_CANT_WRITE_USER_DIRECTORY_TITLE 13824
#define IDS_RECENT_TABS_MENU 13825
#define IDS_RECENTLY_CLOSED_WINDOW 13826
#define IDS_RECENTLY_CLOSED_GROUP 13827
#define IDS_RECENTLY_CLOSED_GROUP_UNNAMED 13828
#define IDS_RECENT_TABS_NO_DEVICE_TABS 13829
#define IDS_RECENT_TABS_LOGIN_FOR_DEVICE_TABS 13830
#define IDS_RECENT_TABS_SEE_DEVICE_TABS 13831
#define IDS_HISTORY_MENU 13832
#define IDS_DEFAULT_DOWNLOAD_FILENAME 13833
#define IDS_DEFAULT_BROWSER_INFOBAR_OK_BUTTON_LABEL 13835
#define IDS_MINIMIZE_WINDOW_MENU 13836
#define IDS_MAXIMIZE_WINDOW_MENU 13837
#define IDS_RESTORE_WINDOW_MENU 13838
#define IDS_CLOSE_WINDOW_MENU 13839
#define IDS_SHOW_WINDOW_DECORATIONS_MENU 13840
#define IDS_USED_EXISTING_BROWSER 13841
#define IDS_DECLINE_RECOVERY 13842
#define IDS_SYNC_ACCOUNT_SYNCING 13843
#define IDS_SYNC_ACCOUNT_SYNCING_CUSTOM_DATA_TYPES 13844
#define IDS_SIGNIN_ERROR_DISPLAY_SOURCE 13845
#define IDS_SIGNIN_ERROR_BUBBLE_VIEW_TITLE 13846
#define IDS_SYNC_ERROR_BUBBLE_VIEW_TITLE 13847
#define IDS_SYNC_ERROR_PASSWORDS_BUBBLE_VIEW_TITLE 13848
#define IDS_SYNC_ERROR_USER_MENU_TITLE 13849
#define IDS_SYNC_ERROR_PASSWORDS_USER_MENU_ERROR_DESCRIPTION 13850
#define IDS_SYNC_ERROR_RECOVERABILITY_DEGRADED_FOR_PASSWORDS_USER_MENU_ERROR_DESCRIPTION 13851
#define IDS_SYNC_NEEDS_VERIFICATION_BUBBLE_VIEW_TITLE 13852
#define IDS_SYNC_ERROR_USER_MENU_CONFIRM_SYNC_SETTINGS_BUTTON 13853
#define IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON 13854
#define IDS_SYNC_ERROR_USER_MENU_CONFIRM_SYNC_SETTINGS_BUTTON_MAYBE_TITLE_CASE 13855
#define IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON_MAYBE_TITLE_CASE 13856
#define IDS_SYNC_EMPTY_STRING 13862
#define IDS_SYNC_OVERVIEW 13863
#define IDS_SYNC_START_SYNC_BUTTON_LABEL 13864
#define IDS_SIGNED_IN_WITH_SYNC_DISABLED_BY_POLICY 13865
#define IDS_SYNC_SETTINGS_NOT_CONFIRMED 13867
#define IDS_SYNC_SETUP_IN_PROGRESS 13868
#define IDS_SYNC_STATUS_UNRECOVERABLE_ERROR 13869
#define IDS_SYNC_STATUS_UNRECOVERABLE_ERROR_NEEDS_SIGNOUT 13870
#define IDS_SYNC_STATUS_NEEDS_PASSWORD 13871
#define IDS_SYNC_STATUS_NEEDS_PASSWORD_BUTTON 13872
#define IDS_SYNC_STATUS_NEEDS_KEYS_BUTTON 13873
#define IDS_SYNC_STATUS_NEEDS_PASSWORD_BUTTON_MAYBE_TITLE_CASE 13874
#define IDS_SYNC_STATUS_NEEDS_KEYS_BUTTON_MAYBE_TITLE_CASE 13875
#define IDS_SYNC_RELOGIN_ERROR 13876
#define IDS_SYNC_RELOGIN_BUTTON 13877
#define IDS_SYNC_RELOGIN_BUTTON_MAYBE_TITLE_CASE 13878
#define IDS_SYNC_ADVANCED_OPTIONS 13880
#define IDS_SYNC_FULL_ENCRYPTION_BODY_CUSTOM 13882
#define IDS_SYNC_FULL_ENCRYPTION_BODY_CUSTOM_WITH_DATE 13883
#define IDS_SYNC_FULL_ACCOUNT_DATA_ENCRYPTION_BODY_CUSTOM 13884
#define IDS_SYNC_FULL_ACCOUNT_DATA_ENCRYPTION_BODY_CUSTOM_WITH_DATE 13885
#define IDS_PARTIAL_TRANSLATE_BUBBLE_WAITING_TITLE 13886
#define IDS_TRANSLATE_BUBBLE_BEFORE_TRANSLATE_TITLE 13887
#define IDS_TRANSLATE_BUBBLE_TRANSLATED_TITLE 13888
#define IDS_PARTIAL_TRANSLATE_BUBBLE_COULD_NOT_TRANSLATE_TITLE 13889
#define IDS_TRANSLATE_BUBBLE_COULD_NOT_TRANSLATE_TITLE 13890
#define IDS_TRANSLATE_BUBBLE_SOURCE_LANG_COMBOBOX_ACCNAME 13891
#define IDS_TRANSLATE_BUBBLE_TARGET_LANG_COMBOBOX_ACCNAME 13892
#define IDS_TRANSLATE_BUBBLE_TRANSLATION_COMPLETE_ANNOUNCEMENT 13893
#define IDS_TRANSLATE_BUBBLE_ADVANCED_BUTTON 13894
#define IDS_TRANSLATE_BUBBLE_ADVANCED_MENU_BUTTON 13895
#define IDS_TRANSLATE_BUBBLE_CHANGE_TARGET_LANGUAGE 13896
#define IDS_TRANSLATE_BUBBLE_CHANGE_SOURCE_LANGUAGE 13897
#define IDS_TRANSLATE_BUBBLE_OPEN_LANGUAGE_SETTINGS 13898
#define IDS_PARTIAL_TRANSLATE_BUBBLE_CHANGE_SOURCE_LANGUAGE 13899
#define IDS_TRANSLATE_BUBBLE_ACCEPT 13900
#define IDS_TRANSLATE_BUBBLE_DENY 13901
#define IDS_TRANSLATE_BUBBLE_ALWAYS_TRANSLATE_LANG 13902
#define IDS_TRANSLATE_BUBBLE_NEVER_TRANSLATE_LANG 13903
#define IDS_TRANSLATE_BUBBLE_NEVER_TRANSLATE_SITE 13904
#define IDS_TRANSLATE_BUBBLE_TRANSLATING 13905
#define IDS_TRANSLATE_BUBBLE_REVERT 13906
#define IDS_TRANSLATE_BUBBLE_TRY_AGAIN 13907
#define IDS_TRANSLATE_BUBBLE_ALWAYS 13908
#define IDS_TRANSLATE_BUBBLE_OPTIONS_MENU_BUTTON 13909
#define IDS_TRANSLATE_BUBBLE_PAGE_LANGUAGE 13910
#define IDS_TRANSLATE_BUBBLE_TRANSLATION_LANGUAGE 13911
#define IDS_TRANSLATE_BUBBLE_ADVANCED_TARGET 13912
#define IDS_TRANSLATE_BUBBLE_ADVANCED_SOURCE 13913
#define IDS_PARTIAL_TRANSLATE_BUBBLE_ADVANCED_SOURCE 13914
#define IDS_PARTIAL_TRANSLATE_BUBBLE_TRANSLATE_FULL_PAGE 13915
#define IDS_TRANSLATE_BUBBLE_RESET 13916
#define IDS_NOTIFICATION_BUTTON_SETTINGS 13917
#define IDS_NOTIFICATION_BUTTON_CLOSE 13918
#define IDS_NOTIFICATION_BUTTON_MORE 13919
#define IDS_NOTIFICATION_REPLY_PLACEHOLDER 13920
#define IDS_NOTIFICATION_MUTED_MESSAGE 13921
#define IDS_NOTIFICATION_MUTED_TITLE 13922
#define IDS_NOTIFICATION_MUTED_ACTION_SHOW 13923
#define IDS_NOTIFICATION_MUTED_ACTION_SNOOZE 13924
#define IDS_FILE_MENU_LINUX 14045
#define IDS_EDIT_MENU_LINUX 14046
#define IDS_VIEW_MENU_LINUX 14047
#define IDS_HISTORY_MENU_LINUX 14048
#define IDS_TOOLS_MENU_LINUX 14049
#define IDS_HELP_MENU_LINUX 14050
#define IDS_REOPEN_CLOSED_TABS_LINUX 14051
#define IDS_OPEN_FILE_LINUX 14052
#define IDS_OPEN_LOCATION_LINUX 14053
#define IDS_CLOSE_WINDOW_LINUX 14054
#define IDS_CLOSE_TAB_LINUX 14055
#define IDS_STOP_MENU_LINUX 14056
#define IDS_RELOAD_MENU_LINUX 14057
#define IDS_TEXT_DEFAULT_LINUX 14058
#define IDS_TEXT_BIGGER_LINUX 14059
#define IDS_TEXT_SMALLER_LINUX 14060
#define IDS_HISTORY_HOME_LINUX 14061
#define IDS_HISTORY_BACK_LINUX 14062
#define IDS_HISTORY_FORWARD_LINUX 14063
#define IDS_HISTORY_VISITED_LINUX 14064
#define IDS_HISTORY_CLOSED_LINUX 14065
#define IDS_HISTORY_CLOSED_RESTORE_WINDOW_LINUX 14066
#define IDS_ALLOWED_GEOLOCATION_TITLE 14067
#define IDS_BLOCKED_GEOLOCATION_TITLE 14068
#define IDS_ALLOWED_GEOLOCATION_MESSAGE 14069
#define IDS_ALLOWED_GEOLOCATION_BLOCK 14070
#define IDS_ALLOWED_GEOLOCATION_NO_ACTION 14071
#define IDS_BLOCKED_GEOLOCATION_MESSAGE 14072
#define IDS_BLOCKED_GEOLOCATION_UNBLOCK 14073
#define IDS_BLOCKED_GEOLOCATION_NO_ACTION 14074
#define IDS_GEOLOCATION 14075
#define IDS_GEOLOCATION_WILL_ASK_AGAIN 14076
#define IDS_GEOLOCATION_TURNED_OFF 14078
#define IDS_ALLOWED_MIDI_SYSEX_TITLE 14079
#define IDS_BLOCKED_MIDI_SYSEX_TITLE 14080
#define IDS_ALLOWED_MIDI_SYSEX_MESSAGE 14081
#define IDS_ALLOWED_MIDI_SYSEX_BLOCK 14082
#define IDS_ALLOWED_MIDI_SYSEX_NO_ACTION 14083
#define IDS_BLOCKED_MIDI_SYSEX_MESSAGE 14084
#define IDS_BLOCKED_MIDI_SYSEX_UNBLOCK 14085
#define IDS_BLOCKED_MIDI_SYSEX_NO_ACTION 14086
#define IDS_MICROPHONE_CAMERA_ALLOWED 14087
#define IDS_MICROPHONE_CAMERA_BLOCKED 14088
#define IDS_MICROPHONE_ACCESSED 14089
#define IDS_CAMERA_ACCESSED 14090
#define IDS_MICROPHONE_BLOCKED 14091
#define IDS_CAMERA_BLOCKED 14092
#define IDS_MICROPHONE_CAMERA_ALLOWED_TITLE 14093
#define IDS_MICROPHONE_CAMERA_BLOCKED_TITLE 14094
#define IDS_MICROPHONE_ACCESSED_TITLE 14095
#define IDS_CAMERA_ACCESSED_TITLE 14096
#define IDS_MICROPHONE_BLOCKED_TITLE 14097
#define IDS_CAMERA_BLOCKED_TITLE 14098
#define IDS_MEDIASTREAM_SETTING_CHANGED_MESSAGE 14099
#define IDS_A11Y_OMNIBOX_CHIP_HINT 14109
#define IDS_A11Y_INDICATORS_ANNOUNCEMENT 14110
#define IDS_MICROPHONE_CAMERA_IN_USE 14111
#define IDS_MICROPHONE_CAMERA_NOT_ALLOWED 14112
#define IDS_MICROPHONE_IN_USE 14113
#define IDS_CAMERA_IN_USE 14114
#define IDS_MICROPHONE_NOT_ALLOWED 14115
#define IDS_CAMERA_NOT_ALLOWED 14116
#define IDS_CAMERA_CANNOT_ACCESS 14117
#define IDS_MICROPHONE_CANNOT_ACCESS 14118
#define IDS_CAMERA_MICROPHONE_CANNOT_ACCESS 14119
#define IDS_MANAGE_PASSWORDS_CONFIRM_GENERATED_TEXT 14120
#define IDS_PASSWORDS_WEB_LINK 14121
#define IDS_MANAGE_PASSWORDS_LINK 14123
#define IDS_MANAGE_PASSWORDS_TITLE 14124
#define IDS_MANAGE_PASSWORDS_NO_PASSWORDS_TITLE 14125
#define IDS_MANAGE_PASSWORDS_DIFFERENT_DOMAIN_TITLE 14126
#define IDS_MANAGE_PASSWORDS_DIFFERENT_DOMAIN_NO_PASSWORDS_TITLE 14127
#define IDS_MANAGE_PASSWORDS_SHOW_PASSWORD 14128
#define IDS_MANAGE_PASSWORDS_HIDE_PASSWORD 14129
#define IDS_MANAGE_PASSWORDS_EMPTY_NOTE 14130
#define IDS_MANAGE_PASSWORDS_EDIT_USERNAME_TOOLTIP 14131
#define IDS_MANAGE_PASSWORDS_EDIT_NOTE_TOOLTIP 14132
#define IDS_MANAGE_PASSWORDS_NOTE_ACCESSIBLE_NAME 14133
#define IDS_MANAGE_PASSWORDS_NOTE_TEXTFIELD 14134
#define IDS_MANAGE_PASSWORDS_UPDATE 14135
#define IDS_MANAGE_PASSWORDS_USERNAME_ACCESSIBLE_NAME 14136
#define IDS_MANAGE_PASSWORDS_USERNAME_TEXTFIELD 14137
#define IDS_MANAGE_PASSWORDS_AUTO_SIGNIN_TITLE_MD 14138
#define IDS_MANAGE_PASSWORDS_AUTO_SIGNIN_TOAST_BODY 14139
#define IDS_AUTO_SIGNIN_FIRST_RUN_TITLE_MANY_DEVICES 14140
#define IDS_AUTO_SIGNIN_FIRST_RUN_TITLE_LOCAL_DEVICE 14141
#define IDS_AUTO_SIGNIN_FIRST_RUN_TEXT 14142
#define IDS_AUTO_SIGNIN_FIRST_RUN_OK 14143
#define IDS_FILE_SELECTION_DIALOG_INFOBAR 14152
#define IDS_ABOUT_LINUX_PROXY_CONFIG_TITLE 14153
#define IDS_ABOUT_LINUX_PROXY_CONFIG_BODY 14154
#define IDS_IMAGE_FILES 14155
#define IDS_AUDIO_FILES 14156
#define IDS_VIDEO_FILES 14157
#define IDS_CUSTOM_FILES 14158
#define IDS_SENSORS_ALLOWED_TOOLTIP 14159
#define IDS_MOTION_SENSORS_ALLOWED_TOOLTIP 14160
#define IDS_SENSORS_BLOCKED_TOOLTIP 14161
#define IDS_MOTION_SENSORS_BLOCKED_TOOLTIP 14162
#define IDS_BLOCKED_SENSORS_UNBLOCK 14163
#define IDS_BLOCKED_SENSORS_NO_ACTION 14164
#define IDS_ALLOWED_SENSORS_TITLE 14165
#define IDS_BLOCKED_SENSORS_TITLE 14166
#define IDS_ALLOWED_SENSORS_MESSAGE 14167
#define IDS_ALLOWED_MOTION_SENSORS_MESSAGE 14168
#define IDS_BLOCKED_SENSORS_MESSAGE 14169
#define IDS_BLOCKED_MOTION_SENSORS_MESSAGE 14170
#define IDS_ALLOWED_SENSORS_NO_ACTION 14171
#define IDS_ALLOWED_SENSORS_BLOCK 14172
#define IDS_LIVE_CAPTION_PROMO 14179
#define IDS_LIVE_CAPTION_PROMO_SCREENREADER 14180
#define IDS_ENABLE_CARET_BROWSING_INFO 14181
#define IDS_CARET_BROWSING_DO_NOT_ASK 14188
#define IDS_ENABLE_CARET_BROWSING_TITLE 14189
#define IDS_ENABLE_CARET_BROWSING_TURN_ON 14190
#define IDS_MEDIA_GALLERIES_DIALOG_HEADER 14191
#define IDS_MEDIA_GALLERIES_DIALOG_SUBTEXT_READ_WRITE 14192
#define IDS_MEDIA_GALLERIES_DIALOG_SUBTEXT_READ_DELETE 14193
#define IDS_MEDIA_GALLERIES_DIALOG_SUBTEXT_READ_ONLY 14194
#define IDS_MEDIA_GALLERIES_PERMISSION_SUGGESTIONS 14195
#define IDS_MEDIA_GALLERIES_LAST_ATTACHED 14196
#define IDS_MEDIA_GALLERIES_DIALOG_ADD_GALLERY 14197
#define IDS_MEDIA_GALLERIES_DIALOG_CONFIRM 14198
#define IDS_MEDIA_GALLERIES_DIALOG_ADD_GALLERY_TITLE 14199
#define IDS_MEDIA_GALLERIES_DIALOG_DEVICE_ATTACHED 14200
#define IDS_MEDIA_GALLERIES_DIALOG_DEVICE_NOT_ATTACHED 14201
#define IDS_MEDIA_GALLERIES_DIALOG_DELETE 14202
#define IDS_CHROME_SHORTCUT_DESCRIPTION 14204
#define IDS_WEBSTORE_NAME_STORE 14205
#define IDS_DESKTOP_MEDIA_PICKER_TITLE 14206
#define IDS_DISPLAY_MEDIA_PICKER_TITLE 14207
#define IDS_DESKTOP_MEDIA_PICKER_TITLE_SCREEN_ONLY 14208
#define IDS_DESKTOP_MEDIA_PICKER_TITLE_WINDOW_ONLY 14209
#define IDS_DESKTOP_MEDIA_PICKER_TEXT 14210
#define IDS_DISPLAY_MEDIA_PICKER_TEXT 14211
#define IDS_DESKTOP_MEDIA_PICKER_TEXT_DELEGATED 14212
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_SCREEN_WITH_MUTE_WARNING 14213
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_SYSTEM_AUDIO 14214
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_APPLICATION_AUDIO 14215
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_ALL_AUDIO_OUTPUT 14216
#define IDS_DESKTOP_MEDIA_PICKER_ALSO_SHARE_TAB_AUDIO 14217
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_HINT_TAB 14218
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_HINT_TAB_OR_SCREEN 14219
#define IDS_DESKTOP_MEDIA_PICKER_AUDIO_SHARE_HINT_TAB_OR_WINDOW 14220
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_SCREEN 14221
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_WINDOW 14222
#define IDS_DESKTOP_MEDIA_PICKER_SINGLE_SCREEN_NAME 14223
#define IDS_DESKTOP_MEDIA_PICKER_MULTIPLE_SCREEN_NAME 14224
#define IDS_DESKTOP_MEDIA_PICKER_MANAGED 14225
#define IDS_DESKTOP_MEDIA_PICKER_PERMISSION_BUTTON_MAC 14226
#define IDS_DESKTOP_MEDIA_PICKER_RESELECT_SCREEN 14227
#define IDS_DESKTOP_MEDIA_PICKER_RESELECT_WINDOW 14228
#define IDS_DESKTOP_MEDIA_PICKER_SOURCE_TYPE_THIS_TAB 14229
#define IDS_DESKTOP_MEDIA_PICKER_EMPTY_PREVIEW 14230
#define IDS_DESKTOP_MEDIA_PICKER_PREVIEW_ACCESSIBLE_NAME 14231
#define IDS_DESKTOP_MEDIA_SOURCE_EMPTY_ACCESSIBLE_NAME 14232
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_WINDOW_TEXT 14233
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_WINDOW_BUTTON 14234
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_SCREEN_TEXT 14235
#define IDS_DESKTOP_MEDIA_PICKER_DELEGATED_SOURCE_LIST_SCREEN_BUTTON 14236
#define IDS_SHARE_THIS_TAB_DIALOG_TITLE 14237
#define IDS_SHARE_THIS_TAB_DIALOG_TEXT 14238
#define IDS_SHARE_THIS_TAB_DIALOG_ALLOW 14239
#define IDS_SHARE_THIS_TAB_AUDIO_SHARE 14240
#define IDS_TAB_CAPTURE_TERMINATED_BY_POLICY_TITLE 14241
#define IDS_TAB_CAPTURE_TERMINATED_BY_POLICY_TEXT 14242
#define IDS_TOOLTIP_TAB_ALERT_STATE_MEDIA_RECORDING 14243
#define IDS_TOOLTIP_TAB_ALERT_STATE_AUDIO_RECORDING 14244
#define IDS_TOOLTIP_TAB_ALERT_STATE_VIDEO_RECORDING 14245
#define IDS_TOOLTIP_TAB_ALERT_STATE_TAB_CAPTURING 14246
#define IDS_TOOLTIP_TAB_ALERT_STATE_AUDIO_PLAYING 14247
#define IDS_TOOLTIP_TAB_ALERT_STATE_AUDIO_MUTING 14248
#define IDS_TOOLTIP_TAB_ALERT_STATE_BLUETOOTH_CONNECTED 14249
#define IDS_TOOLTIP_TAB_ALERT_STATE_BLUETOOTH_SCAN_ACTIVE 14250
#define IDS_TOOLTIP_TAB_ALERT_STATE_USB_CONNECTED 14251
#define IDS_TOOLTIP_TAB_ALERT_STATE_HID_CONNECTED 14252
#define IDS_TOOLTIP_TAB_ALERT_STATE_SERIAL_CONNECTED 14253
#define IDS_TOOLTIP_TAB_ALERT_STATE_PIP_PLAYING 14254
#define IDS_TOOLTIP_TAB_ALERT_STATE_DESKTOP_CAPTURING 14255
#define IDS_TOOLTIP_TAB_ALERT_STATE_VR_PRESENTING 14256
#define IDS_TAB_AX_LABEL_MEDIA_RECORDING_FORMAT 14257
#define IDS_TAB_AX_LABEL_AUDIO_RECORDING_FORMAT 14258
#define IDS_TAB_AX_LABEL_VIDEO_RECORDING_FORMAT 14259
#define IDS_TAB_AX_LABEL_TAB_CAPTURING_FORMAT 14260
#define IDS_TAB_AX_LABEL_PIP_PLAYING_FORMAT 14261
#define IDS_TAB_AX_LABEL_AUDIO_PLAYING_FORMAT 14262
#define IDS_TAB_AX_LABEL_AUDIO_MUTING_FORMAT 14263
#define IDS_TAB_AX_LABEL_BLUETOOTH_CONNECTED_FORMAT 14264
#define IDS_TAB_AX_LABEL_BLUETOOTH_SCAN_ACTIVE_FORMAT 14265
#define IDS_TAB_AX_LABEL_USB_CONNECTED_FORMAT 14266
#define IDS_TAB_AX_LABEL_HID_CONNECTED_FORMAT 14267
#define IDS_TAB_AX_LABEL_SERIAL_CONNECTED_FORMAT 14268
#define IDS_TAB_AX_LABEL_NETWORK_ERROR_FORMAT 14269
#define IDS_TAB_AX_LABEL_CRASHED_FORMAT 14270
#define IDS_TAB_AX_LABEL_DESKTOP_CAPTURING_FORMAT 14271
#define IDS_TAB_AX_LABEL_VR_PRESENTING 14272
#define IDS_TAB_AX_LABEL_SPLIT_TAB_LEFT_VIEW_FORMAT 14273
#define IDS_TAB_AX_LABEL_SPLIT_TAB_RIGHT_VIEW_FORMAT 14274
#define IDS_TAB_AX_LABEL_UNNAMED_GROUP_FORMAT 14275
#define IDS_TAB_AX_LABEL_NAMED_GROUP_FORMAT 14276
#define IDS_TAB_AX_LABEL_PINNED_FORMAT 14277
#define IDS_TAB_AX_LABEL_PERMISSION_REQUESTED_FORMAT 14278
#define IDS_GROUP_AX_LABEL_UNNAMED_GROUP_FORMAT 14279
#define IDS_GROUP_AX_LABEL_NAMED_GROUP_FORMAT 14280
#define IDS_GROUP_AX_LABEL_COLLAPSED 14281
#define IDS_GROUP_AX_LABEL_EXPANDED 14282
#define IDS_GROUP_AX_LABEL_UNNAMED_SAVED_GROUP_FORMAT 14283
#define IDS_GROUP_AX_LABEL_NAMED_SAVED_GROUP_FORMAT 14284
#define IDS_GROUP_AX_LABEL_GROUP_MENU_ITEM_FORMAT 14285
#define IDS_SAVED_GROUP_AX_LABEL_OPENED 14286
#define IDS_SAVED_GROUP_AX_LABEL_CLOSED 14287
#define IDS_SAVED_GROUP_AX_LABEL_SHARED 14288
#define IDS_TAB_AX_ANNOUNCE_MOVED_RIGHT 14289
#define IDS_TAB_AX_ANNOUNCE_MOVED_LEFT 14290
#define IDS_TAB_AX_ANNOUNCE_MOVED_UP 14291
#define IDS_TAB_AX_ANNOUNCE_MOVED_DOWN 14292
#define IDS_TAB_AX_ANNOUNCE_MOVED_FIRST 14293
#define IDS_TAB_AX_ANNOUNCE_MOVED_LAST 14294
#define IDS_TAB_AX_ANNOUNCE_TAB_ADDED_TO_UNNAMED_GROUP 14295
#define IDS_TAB_AX_ANNOUNCE_TAB_ADDED_TO_NAMED_GROUP 14296
#define IDS_TAB_AX_ANNOUNCE_TAB_REMOVED_FROM_UNNAMED_GROUP 14297
#define IDS_TAB_AX_ANNOUNCE_TAB_REMOVED_FROM_NAMED_GROUP 14298
#define IDS_PAGE_LOADING_AX_TITLE_FORMAT 14299
#define IDS_TAB_AX_INACTIVE_TAB 14300
#define IDS_TAB_AX_MEMORY_SAVINGS 14301
#define IDS_TAB_AX_MEMORY_USAGE 14302
#define IDS_TAB_AX_HIGH_MEMORY_USAGE 14303
#define IDS_PROFILE_IN_USE_LINUX_QUIT 14304
#define IDS_PROFILE_IN_USE_LINUX_RELAUNCH 14305
#define IDS_DESKTOP_MEDIA_PICKER_SHARE 14323
#define IDS_PUSH_MESSAGING_GENERIC_NOTIFICATION_BODY 14324
#define IDS_DEVICE_PERMISSIONS_DIALOG_SELECT 14325
#define IDS_DEVICE_PERMISSIONS_DIALOG_LOADING_LABEL 14326
#define IDS_DEVICE_PERMISSIONS_DIALOG_LOADING_LABEL_TOOLTIP 14327
#define IDS_DEVICE_LOG_TITLE 14328
#define IDS_DEVICE_AUTO_REFRESH 14329
#define IDS_DEVICE_SELECT_TYPES 14330
#define IDS_DEVICE_LOG_REFRESH 14331
#define IDS_DEVICE_LOG_CLEAR 14332
#define IDS_DEVICE_LOG_CLEAR_TYPES 14333
#define IDS_DEVICE_LOG_NO_ENTRIES 14334
#define IDS_DEVICE_LOG_LEVEL_LABEL 14335
#define IDS_DEVICE_LOG_LEVEL_ERROR 14336
#define IDS_DEVICE_LOG_LEVEL_USER 14337
#define IDS_DEVICE_LOG_LEVEL_EVENT 14338
#define IDS_DEVICE_LOG_LEVEL_DEBUG 14339
#define IDS_DEVICE_LOG_TYPE_LOGIN 14340
#define IDS_DEVICE_LOG_TYPE_MEMORY 14341
#define IDS_DEVICE_LOG_TYPE_NETWORK 14342
#define IDS_DEVICE_LOG_TYPE_POWER 14343
#define IDS_DEVICE_LOG_TYPE_BLUETOOTH 14344
#define IDS_DEVICE_LOG_TYPE_USB 14345
#define IDS_DEVICE_LOG_TYPE_HID 14346
#define IDS_DEVICE_LOG_TYPE_PRINTER 14347
#define IDS_DEVICE_LOG_TYPE_FIDO 14348
#define IDS_DEVICE_LOG_TYPE_SERIAL 14349
#define IDS_DEVICE_LOG_TYPE_CAMERA 14350
#define IDS_DEVICE_LOG_TYPE_GEOLOCATION 14351
#define IDS_DEVICE_LOG_TYPE_EXTENSIONS 14352
#define IDS_DEVICE_LOG_TYPE_DISPLAY 14353
#define IDS_DEVICE_LOG_TYPE_FIRMWARE 14354
#define IDS_DEVICE_LOG_FILEINFO 14355
#define IDS_DEVICE_LOG_TIME_DETAIL 14356
#define IDS_DEVICE_LOG_ENTRY 14357
#define IDS_WEBUSB_DEVICE_DETECTED_NOTIFICATION 14358
#define IDS_WEBUSB_DEVICE_DETECTED_NOTIFICATION_TITLE 14359
#define IDS_WEBHID_SYSTEM_TRAY_ICON_HID_SETTINGS 14360
#define IDS_WEBHID_SYSTEM_TRAY_ICON_ABOUT_HID_DEVICE 14361
#define IDS_WEBUSB_SYSTEM_TRAY_ICON_USB_SETTINGS 14362
#define IDS_WEBUSB_SYSTEM_TRAY_ICON_ABOUT_USB_DEVICE 14363
#define IDS_DEVICE_CONNECTED_BY_EXTENSION 14366
#define IDS_DEFAULT_AUDIO_DEVICE_NAME 14375
#define IDS_SERIAL_DEVICE_CHOOSER_ADAPTER_OFF 14384
#define IDS_SERIAL_DEVICE_CHOOSER_TURN_ON_BLUETOOTH_LINK_TEXT 14385
#define IDS_SERIAL_DEVICE_CHOOSER_AUTHORIZE_BLUETOOTH_LINK_TEXT 14386
#define IDS_BLUETOOTH_DEVICE_CHOOSER_RE_SCAN 14387
#define IDS_BLUETOOTH_DEVICE_CHOOSER_RE_SCAN_TOOLTIP 14388
#define IDS_DEVICE_CHOOSER_GET_HELP_LINK_WITH_SCANNING_STATUS 14389
#define IDS_DEVICE_CHOOSER_GET_HELP_LINK_WITH_RE_SCAN_LINK 14390
#define IDS_DEVICE_CHOOSER_PAIRED_STATUS_TEXT 14391
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_AND_PAIRED_STATUS_TEXT 14392
#define IDS_DEVICE_CHOOSER_ACCNAME_COMPATIBLE_DEVICES_LIST 14393
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_UNKNOWN_DEVICE_WITH_VENDOR_NAME 14394
#define IDS_DEVICE_CHOOSER_DEVICE_NAME_UNKNOWN_DEVICE_WITH_VENDOR_ID_AND_PRODUCT_ID 14395
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_PRODUCT_ID_AND_VENDOR_NAME 14396
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_PRODUCT_ID_AND_VENDOR_ID 14397
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_VENDOR_ID 14398
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_VENDOR_NAME 14399
#define IDS_USB_POLICY_DEVICE_DESCRIPTION_FOR_ANY_VENDOR 14400
#define IDS_SERIAL_PORT_CHOOSER_PROMPT 14401
#define IDS_SERIAL_PORT_CHOOSER_CONNECT_BUTTON_TEXT 14402
#define IDS_SERIAL_PORT_CHOOSER_LOADING_LABEL 14403
#define IDS_SERIAL_PORT_CHOOSER_LOADING_LABEL_TOOLTIP 14404
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_PRODUCT_ID_AND_VENDOR_NAME 14405
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_VENDOR_NAME 14406
#define IDS_SERIAL_PORT_CHOOSER_NAME_WITH_PATH 14407
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_PRODUCT_ID_AND_VENDOR_ID 14408
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_USB_VENDOR_ID 14409
#define IDS_SERIAL_POLICY_DESCRIPTION_FOR_ANY_PORT 14410
#define IDS_HID_CHOOSER_PROMPT 14411
#define IDS_HID_CHOOSER_ITEM_WITHOUT_NAME 14412
#define IDS_HID_CHOOSER_LOADING_LABEL 14413
#define IDS_HID_CHOOSER_LOADING_LABEL_TOOLTIP 14414
#define IDS_HID_POLICY_DESCRIPTION_FOR_VENDOR_ID_AND_PRODUCT_ID 14415
#define IDS_HID_POLICY_DESCRIPTION_FOR_VENDOR_ID 14416
#define IDS_HID_POLICY_DESCRIPTION_FOR_USAGE_AND_USAGE_PAGE 14417
#define IDS_HID_POLICY_DESCRIPTION_FOR_USAGE_PAGE 14418
#define IDS_HID_POLICY_DESCRIPTION_FOR_ANY_DEVICE 14419
#define IDS_WEB_APP_FILE_HANDLING_LIST_SEPARATOR 14420
#define IDS_WEB_APP_FILE_HANDLING_DIALOG_QUESTION 14421
#define IDS_WEB_APP_FILE_HANDLING_DIALOG_QUESTION_MULTIPLE 14422
#define IDS_WEB_APP_FILE_HANDLING_DIALOG_STICKY_CHOICE 14423
#define IDS_WEB_APP_FILE_HANDLING_POSITIVE_BUTTON 14424
#define IDS_WEB_APP_FILE_HANDLING_NEGATIVE_BUTTON 14425
#define IDS_WEB_APP_PERMISSION_NEGATIVE_BUTTON 14426
#define IDS_PROTOCOL_HANDLER_INTENT_PICKER_QUESTION 14427
#define IDS_FONT_ACCESS_CHOOSER_PROMPT_ORIGIN 14428
#define IDS_FONT_ACCESS_CHOOSER_NO_FONTS_FOUND_PROMPT 14429
#define IDS_FONT_ACCESS_CHOOSER_IMPORT_BUTTON_TEXT 14430
#define IDS_FONT_ACCESS_CHOOSER_CANCEL_BUTTON_TEXT 14431
#define IDS_FONT_ACCESS_CHOOSER_SELECT_ALL_CHECKBOX_TEXT 14432
#define IDS_FONT_ACCESS_CHOOSER_LOADING_LABEL 14433
#define IDS_FONT_ACCESS_CHOOSER_LOADING_LABEL_TOOLTIP 14434
#define IDS_IME_API_ACTIVATED_WARNING 14435
#define IDS_IME_API_NEVER_SHOW 14436
#define IDS_BLOCKED_ADS_PROMPT_TOOLTIP 14437
#define IDS_REDIRECT_BLOCKED_MESSAGE 14440
#define IDS_REDIRECT_BLOCKED_TITLE 14441
#define IDS_REDIRECT_BLOCKED_TOOLTIP 14442
#define IDS_ALWAYS_ALLOW_REDIRECTS 14443
#define IDS_OPEN_REDIRECT 14444
#define IDS_UTILITY_PROCESS_SYSTEM_SIGNALS_NAME 14445
#define IDS_CONTROLLED_BY_AUTOMATION 14448
#define IDS_CHROME_FOR_TESTING_DISCLAIMER 14449
#define IDS_DOWNLOAD_CHROME 14450
#define IDS_DOWNLOAD_OPEN_CONFIRMATION_DIALOG_TITLE 14452
#define IDS_DOWNLOAD_OPEN_CONFIRMATION_DIALOG_MESSAGE 14453
#define IDS_CONFIRM_FILE_UPLOAD_TITLE 14454
#define IDS_CONFIRM_FILE_UPLOAD_TEXT 14455
#define IDS_CONFIRM_FILE_UPLOAD_OK_BUTTON 14456
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_TITLE 14457
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_ALLOW_TEXT 14458
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_WRITE_PERMISSION_FILE_TEXT 14459
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_WRITE_PERMISSION_DIRECTORY_TEXT 14460
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_READ_PERMISSION_FILE_TEXT 14461
#define IDS_FILE_SYSTEM_ACCESS_ORIGIN_SCOPED_READ_PERMISSION_DIRECTORY_TEXT 14462
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_FILE_TEXT 14463
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_DIRECTORY_TEXT 14464
#define IDS_FILE_SYSTEM_ACCESS_READ_PERMISSION_FILE_TEXT 14465
#define IDS_FILE_SYSTEM_ACCESS_READ_PERMISSION_DIRECTORY_TEXT 14466
#define IDS_FILE_SYSTEM_ACCESS_EDIT_FILE_PERMISSION_TITLE 14467
#define IDS_FILE_SYSTEM_ACCESS_EDIT_DIRECTORY_PERMISSION_TITLE 14468
#define IDS_FILE_SYSTEM_ACCESS_READ_FILE_PERMISSION_TITLE 14469
#define IDS_FILE_SYSTEM_ACCESS_READ_DIRECTORY_PERMISSION_TITLE 14470
#define IDS_FILE_SYSTEM_ACCESS_EDIT_FILE_PERMISSION_ALLOW_TEXT 14471
#define IDS_FILE_SYSTEM_ACCESS_EDIT_DIRECTORY_PERMISSION_ALLOW_TEXT 14472
#define IDS_FILE_SYSTEM_ACCESS_VIEW_FILE_PERMISSION_ALLOW_TEXT 14473
#define IDS_FILE_SYSTEM_ACCESS_VIEW_DIRECTORY_PERMISSION_ALLOW_TEXT 14474
#define IDS_FILE_SYSTEM_ACCESS_WRITE_PERMISSION_CANCEL_TEXT 14475
#define IDS_FILE_SYSTEM_ACCESS_EDIT_FILE_PERMISSION_CANCEL_TEXT 14476
#define IDS_FILE_SYSTEM_ACCESS_EDIT_DIRECTORY_PERMISSION_CANCEL_TEXT 14477
#define IDS_FILE_SYSTEM_ACCESS_VIEW_FILE_PERMISSION_CANCEL_TEXT 14478
#define IDS_FILE_SYSTEM_ACCESS_VIEW_DIRECTORY_PERMISSION_CANCEL_TEXT 14479
#define IDS_FILE_SYSTEM_ACCESS_RESTORE_PERMISSION_DESCRIPTION 14480
#define IDS_FILE_SYSTEM_ACCESS_WRITE_USAGE_TOOLTIP 14481
#define IDS_FILE_SYSTEM_ACCESS_DIRECTORY_USAGE_TOOLTIP 14482
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_WRITABLE_FILE_TEXT 14483
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_WRITABLE_FILES_TEXT 14484
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_WRITABLE_DIRECTORY_TEXT 14485
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_WRITABLE_DIRECTORIES_TEXT 14486
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_WRITABLE_FILES_AND_DIRECTORIES_TEXT 14487
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_READABLE_FILE_TEXT 14488
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READABLE_FILES_TEXT 14489
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SINGLE_READABLE_DIRECTORY_TEXT 14490
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READABLE_DIRECTORIES_TEXT 14491
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READABLE_FILES_AND_DIRECTORIES_TEXT 14492
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_READ_AND_WRITE 14493
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_SAVE_CHANGES 14494
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_VIEW_CHANGES 14495
#define IDS_FILE_SYSTEM_ACCESS_USAGE_BUBBLE_FILES_TEXT 14496
#define IDS_FILE_SYSTEM_ACCESS_USAGE_EXPAND 14497
#define IDS_FILE_SYSTEM_ACCESS_USAGE_COLLAPSE 14498
#define IDS_FILE_SYSTEM_ACCESS_USAGE_REMOVE_ACCESS 14499
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_READABLE_DIRECTORY_TITLE 14500
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_WRITABLE_DIRECTORY_TITLE 14501
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_SAVE_FILE_TITLE 14502
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_READABLE_FILE_TITLE 14503
#define IDS_FILE_SYSTEM_ACCESS_CHOOSER_OPEN_READABLE_FILES_TITLE 14504
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_DIRECTORY_TITLE 14505
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_DIRECTORY_TEXT 14506
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_DIRECTORY_BUTTON 14507
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_FILE_TITLE 14508
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_FILE_TEXT 14509
#define IDS_FILE_SYSTEM_ACCESS_RESTRICTED_FILE_BUTTON 14510
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_TITLE 14511
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_TEXT 14512
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_DONT_SAVE 14513
#define IDS_FILE_SYSTEM_ACCESS_DANGEROUS_FILE_SAVE 14514
#define IDS_RELAUNCH_ACCEPT_BUTTON 14515
#define IDS_RELAUNCH_REQUIRED_CANCEL_BUTTON 14516
#define IDS_IDLE_TIMEOUT_INCOGNITO 14517
#define IDS_IDLE_TIMEOUT_CLOSE_COUNTDOWN 14518
#define IDS_IDLE_TIMEOUT_CLEAR_COUNTDOWN 14519
#define IDS_WEBAUTHN_GENERIC_TITLE 14520
#define IDS_WEBAUTHN_CONTINUE 14521
#define IDS_WEBAUTHN_TRANSPORT_USB 14522
#define IDS_WEBAUTHN_TRANSPORT_INTERNAL 14524
#define IDS_WEBAUTHN_TRANSPORT_CABLE 14525
#define IDS_WEBAUTHN_TRANSPORT_WINDOWS_HELLO_OR_SECURITY_KEY 14526
#define IDS_WEBAUTHN_TRANSPORT_WINDOWS_HELLO 14527
#define IDS_WEBAUTHN_TRANSPORT_ICLOUD_KEYCHAIN 14528
#define IDS_WEBAUTHN_TRANSPORT_EXTERNAL_SECURITY_KEY 14529
#define IDS_WEBAUTHN_USB_ACTIVATE_DESCRIPTION 14530
#define IDS_WEBAUTHN_ERROR_GENERIC_TITLE 14531
#define IDS_WEBAUTHN_ERROR_WRONG_KEY_TITLE 14532
#define IDS_WEBAUTHN_ERROR_WRONG_DEVICE_TITLE 14533
#define IDS_WEBAUTHN_ERROR_WRONG_DEVICE_REGISTER_DESCRIPTION 14534
#define IDS_WEBAUTHN_ERROR_WRONG_KEY_SIGN_DESCRIPTION 14535
#define IDS_WEBAUTHN_ERROR_TIMEOUT_DESCRIPTION 14536
#define IDS_WEBAUTHN_ERROR_INTERNAL_UNRECOGNIZED_TITLE 14537
#define IDS_WEBAUTHN_ERROR_INTERNAL_UNRECOGNIZED_DESCRIPTION 14538
#define IDS_WEBAUTHN_WINDOWS_HELLO_NOT_ENABLED_TITLE 14539
#define IDS_WEBAUTHN_WINDOWS_HELLO_NOT_ENABLED_DESCRIPTION 14540
#define IDS_WEBAUTHN_ERROR_NO_PASSKEYS_TITLE 14541
#define IDS_WEBAUTHN_ERROR_NO_PASSKEYS_DESCRIPTION 14542
#define IDS_WEBAUTHN_ERROR_GPM_DISABLED_TITLE 14543
#define IDS_WEBAUTHN_ERROR_GPM_DISABLED_DESCRIPTION 14544
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_AUTO_TITLE 14545
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_AUTO_DESCRIPTION 14546
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_AUTO_NEXT 14547
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_MANUAL_TITLE 14548
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_MANUAL_DESCRIPTION 14549
#define IDS_WEBAUTHN_BLUETOOTH_POWER_ON_MANUAL_NEXT 14550
#define IDS_WEBAUTHN_LOADING 14551
#define IDS_WEBAUTHN_CABLE_ACTIVATE_TITLE 14553
#define IDS_WEBAUTHN_CABLE_ACTIVATE_TITLE_DEVICE 14554
#define IDS_WEBAUTHN_CABLE_ACTIVATE_DESCRIPTION 14555
#define IDS_WEBAUTHN_CABLEV2_CONNECTING_TITLE 14556
#define IDS_WEBAUTHN_CABLEV2_CONNECTED_DESCRIPTION 14557
#define IDS_WEBAUTHN_CABLEV2_ERROR_DESCRIPTION 14558
#define IDS_WEBAUTHN_CABLEV2_ERROR_CLOSE 14559
#define IDS_WEBAUTHN_PASSKEY_PHONE_OR_TABLET_LABEL 14560
#define IDS_WEBAUTHN_PASSKEY_PHONE_TABLET_OR_SECURITY_KEY_LABEL 14561
#define IDS_WEBAUTHN_PIN_ENTRY_TITLE 14562
#define IDS_WEBAUTHN_PIN_ENTRY_DESCRIPTION 14563
#define IDS_WEBAUTHN_PIN_ENTRY_PIN_LABEL 14564
#define IDS_WEBAUTHN_PIN_ENTRY_NEXT 14565
#define IDS_WEBAUTHN_PIN_SETUP_DESCRIPTION 14566
#define IDS_WEBAUTHN_PIN_SETUP_CONFIRMATION_LABEL 14567
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_INVALID_CHARACTERS 14568
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_TOO_SHORT 14569
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_FAILED_RETRIES 14570
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_FAILED 14571
#define IDS_WEBAUTHN_PIN_SETUP_ERROR_FAILED 14572
#define IDS_WEBAUTHN_PIN_TAP_AGAIN_DESCRIPTION 14573
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_MISMATCH 14574
#define IDS_WEBAUTHN_CLIENT_PIN_SOFT_BLOCK_DESCRIPTION 14575
#define IDS_WEBAUTHN_CLIENT_PIN_HARD_BLOCK_DESCRIPTION 14576
#define IDS_WEBAUTHN_CLIENT_PIN_AUTHENTICATOR_REMOVED_DESCRIPTION 14577
#define IDS_WEBAUTHN_PIN_ENTRY_ERROR_SAME_AS_CURRENT 14578
#define IDS_WEBAUTHN_USE_PHONE_WITH_NAME 14579
#define IDS_WEBAUTHN_INLINE_ENROLLMENT_CANCEL_LABEL 14580
#define IDS_WEBAUTHN_UV_RETRY_TITLE 14581
#define IDS_WEBAUTHN_UV_RETRY_DESCRIPTION 14582
#define IDS_WEBAUTHN_UV_RETRY_ERROR_FAILED_RETRIES 14583
#define IDS_WEBAUTHN_UV_ERROR_LOCKED 14584
#define IDS_WEBAUTHN_FORCE_PIN_CHANGE 14585
#define IDS_WEBAUTHN_UNKNOWN_ACCOUNT 14586
#define IDS_WEBAUTHN_RESIDENT_KEY_PRIVACY 14587
#define IDS_WEBAUTHN_RESIDENT_KEY_PREFERRED_PRIVACY 14588
#define IDS_WEBAUTHN_ERROR_MISSING_CAPABILITY_TITLE 14589
#define IDS_WEBAUTHN_ERROR_MISSING_CAPABILITY_DESC 14590
#define IDS_WEBAUTHN_STORAGE_FULL_DESC 14591
#define IDS_WEBAUTHN_ATTESTATION_WARNING 14592
#define IDS_WEBAUTHN_ENTERPRISE_ATTESTATION_WARNING 14593
#define IDS_WEBAUTHN_RETRY 14594
#define IDS_WEBAUTHN_PLATFORM_AUTHENTICATOR_OFF_THE_RECORD_INTERSTITIAL_TITLE 14595
#define IDS_WEBAUTHN_PLATFORM_AUTHENTICATOR_OFF_THE_RECORD_INTERSTITIAL_DESCRIPTION 14596
#define IDS_WEBAUTHN_PLATFORM_AUTHENTICATOR_OFF_THE_RECORD_INTERSTITIAL_DENY 14597
#define IDS_WEBAUTHN_CREATE_PASSKEY_TITLE 14598
#define IDS_WEBAUTHN_CREATE_PASSKEY_EXTRA 14599
#define IDS_WEBAUTHN_CREATE_PASSKEY_EXTRA_INCOGNITO 14600
#define IDS_WEBAUTHN_CREATE_PASSKEY_CHOOSE_DEVICE_TITLE 14601
#define IDS_WEBAUTHN_USE_PASSKEY_CHOOSE_DEVICE_TITLE 14602
#define IDS_WEBAUTHN_USE_PASSKEY_CHOOSE_DEVICE_BODY 14603
#define IDS_WEBAUTHN_USE_PASSKEY_TITLE 14604
#define IDS_WEBAUTHN_CHOOSE_PASSKEY_TITLE 14605
#define IDS_WEBAUTHN_CHOOSE_PASSKEY_BODY 14606
#define IDS_WEBAUTHN_CREATE_PASSKEY_QR_TITLE 14607
#define IDS_WEBAUTHN_CREATE_PASSKEY_QR_BODY 14608
#define IDS_WEBAUTHN_USE_PASSKEY_QR_TITLE 14609
#define IDS_WEBAUTHN_USE_PASSKEY_QR_BODY 14610
#define IDS_WEBAUTHN_QR_CODE_ALT_TEXT 14611
#define IDS_WEBAUTHN_USE_A_DIFFERENT_PASSKEY 14612
#define IDS_WEBAUTHN_QR_CREATE_PASSKEY_ON_SECURITY_KEY_LABEL 14613
#define IDS_WEBAUTHN_QR_USE_PASSKEY_ON_SECURITY_KEY_LABEL 14614
#define IDS_WEBAUTHN_CHOOSE_PASSKEY_FOR_RP_TITLE 14615
#define IDS_WEBAUTHN_THIS_DEVICE_LABEL 14616
#define IDS_WEBAUTHN_FROM_PHONE_LABEL 14617
#define IDS_WEBAUTHN_OTHER_DEVICES_LABEL 14618
#define IDS_WEBAUTHN_SOURCE_CHROME_PROFILE 14619
#define IDS_WEBAUTHN_SOURCE_ICLOUD_KEYCHAIN 14620
#define IDS_WEBAUTHN_SOURCE_WINDOWS_HELLO 14621
#define IDS_WEBAUTHN_SOURCE_GOOGLE_PASSWORD_MANAGER 14622
#define IDS_WEBAUTHN_SOURCE_USB_SECURITY_KEY 14623
#define IDS_WEBAUTHN_PASSKEYS_AND_SECURITY_KEYS 14624
#define IDS_WEBAUTHN_PASSKEYS 14625
#define IDS_WEBAUTHN_USE_YOUR_PHONE_OR_TABLET 14626
#define IDS_WEBAUTHN_USE_YOUR_PHONE_OR_TABLET_CREATE_DESCRIPTION 14627
#define IDS_WEBAUTHN_USE_YOUR_PHONE_OR_TABLET_SIGN_IN_DESCRIPTION 14628
#define IDS_WEBAUTHN_USE_YOUR_SECURITY_KEY 14629
#define IDS_WEBAUTHN_USE_YOUR_SECURITY_KEY_CREATE_DESCRIPTION 14630
#define IDS_WEBAUTHN_USE_YOUR_SECURITY_KEY_SIGN_IN_DESCRIPTION 14631
#define IDS_WEBAUTHN_CREATE 14632
#define IDS_WEBAUTHN_CREATE_PASSKEY 14633
#define IDS_WEBAUTHN_GPM_CREATE_PASSKEY_TITLE 14634
#define IDS_WEBAUTHN_GPM_CREATE_PASSKEY_DESC 14635
#define IDS_WEBAUTHN_SAVE_ANOTHER_WAY 14636
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_CREATION_TITLE 14637
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_CREATION_DESC 14638
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_ASSERTION_TITLE 14639
#define IDS_WEBAUTHN_GPM_TRUST_THIS_COMPUTER_ASSERTION_DESC 14640
#define IDS_WEBAUTHN_USE_A_DIFFERENT_DEVICE 14641
#define IDS_WEBAUTHN_TOUCH_ID_ASSERTION_DESC 14642
#define IDS_WEBAUTHN_TOUCH_ID_CONTINUE 14643
#define IDS_WEBAUTHN_TOUCH_ID_LOCKED 14644
#define IDS_WEBAUTHN_TOUCH_ID_ENTER_PASSWORD 14645
#define IDS_WEBAUTHN_GPM_ERROR_TITLE 14646
#define IDS_WEBAUTHN_GPM_ERROR_DESC 14647
#define IDS_WEBAUTHN_SIGN_IN_AGAIN_TITLE 14648
#define IDS_WEBAUTHN_SIGN_IN_AGAIN_DESCRIPTION 14649
#define IDS_WEBAUTHN_GPM_PIN_OPTION_NUMBERS 14650
#define IDS_WEBAUTHN_GPM_PIN_OPTION_ALPHANUMERIC 14651
#define IDS_WEBAUTHN_GPM_CREATE_PIN_TITLE 14652
#define IDS_WEBAUTHN_GPM_CREATE_ALPHANUMERIC_PIN_ACCESSIBILITY 14653
#define IDS_WEBAUTHN_GPM_CREATE_SIX_DIGIT_PIN_ACCESSIBILITY 14654
#define IDS_WEBAUTHN_GPM_CREATE_SIX_DIGIT_PIN_ACCESSIBILITY_WITH_FOCUSED_DIGIT 14655
#define IDS_WEBAUTHN_GPM_CREATE_PIN_DESC 14656
#define IDS_WEBAUTHN_GPM_ENTER_PIN_TITLE 14657
#define IDS_WEBAUTHN_GPM_ENTER_ALPHANUMERIC_PIN_ACCESSIBILITY 14658
#define IDS_WEBAUTHN_GPM_ENTER_ALPHANUMERIC_PIN_ACCESSIBILITY_WITH_WEBSITE 14659
#define IDS_WEBAUTHN_GPM_ENTER_SIX_DIGIT_PIN_ACCESSIBILITY 14660
#define IDS_WEBAUTHN_GPM_ENTER_SIX_DIGIT_PIN_ACCESSIBILITY_WITH_FOCUSED_DIGIT 14661
#define IDS_WEBAUTHN_GPM_ENTER_PIN_DESC 14662
#define IDS_WEBAUTHN_GPM_SIX_DIGIT_PIN_ACCESSIBILITY_LABEL 14663
#define IDS_WEBAUTHN_FORGOT_GPM_PIN_BUTTON 14664
#define IDS_WEBAUTHN_GPM_PIN_OPTIONS_BUTTON 14665
#define IDS_WEBAUTHN_GPM_WRONG_PIN_ERROR 14666
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_TITLE 14667
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_PIN_CREATED_TITLE 14668
#define IDS_WEBAUTHN_SHOW_PIN 14669
#define IDS_WEBAUTHN_HIDE_PIN 14670
#define IDS_WEBAUTHN_CHANGE_PIN 14671
#define IDS_WEBAUTHN_LOCKED_GPM_PIN_TITLE 14672
#define IDS_WEBAUTHN_LOCKED_GPM_PIN_DESCRIPTION 14673
#define IDS_WEBAUTHN_GPM_PIN_DIGIT_HINT 14674
#define IDS_WEBAUTHN_GPM_PIN_LENGTH_HINT 14675
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_LABEL 14676
#define IDS_WEBAUTHN_GPM_PASSKEY_SAVED_LINK 14677
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATE_NEEDED_TITLE 14678
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATE_NEEDED_LABEL 14679
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATED_TITLE 14680
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATED_LABEL 14681
#define IDS_WEBAUTHN_GPM_PASSKEY_UPDATED_LINK 14682
#define IDS_WEBAUTHN_GPM_PASSKEY_DELETED_TITLE 14683
#define IDS_WEBAUTHN_GPM_PASSKEY_DELETED_LABEL 14684
#define IDS_WEBAUTHN_GPM_PASSKEY_DOESNT_WORK_LABEL 14685
#define IDS_WEBAUTHN_GPM_PASSKEY_DELETED_LINK 14686
#define IDS_WEBAUTHN_GPM_SETTINGS 14687
#define IDS_WEBAUTHN_SIGN_IN_TO_WEBSITE_DIALOG_TITLE 14688
#define IDS_WEBAUTHN_SIGN_IN_AS_PROMPT 14689
#define IDS_PASSKEY_UPGRADE_BUBBLE_TITLE 14690
#define IDS_PASSKEY_UPGRADE_BUBBLE_DESCRIPTION 14691
#define IDS_PASSKEY_UPGRADE_BUBBLE_LEARN_MORE 14692
#define IDS_PASSKEY_UPGRADE_BUBBLE_MANAGE_BUTTON 14693
#define IDS_WEB_DIGITAL_CREDENTIALS_BLUETOOTH_POWER_ON_MANUAL_TITLE 14694
#define IDS_WEB_DIGITAL_CREDENTIALS_BLUETOOTH_POWER_ON_MANUAL_DESCRIPTION 14695
#define IDS_WEB_DIGITAL_CREDENTIALS_BLUETOOTH_POWER_ON_MANUAL_NEXT 14696
#define IDS_WEB_DIGITAL_CREDENTIALS_QR_TITLE 14697
#define IDS_WEB_DIGITAL_CREDENTIALS_PRESENTATION_QR_BODY 14698
#define IDS_WEB_DIGITAL_CREDENTIALS_ISSUANCE_QR_BODY 14699
#define IDS_WEB_DIGITAL_CREDENTIALS_QR_CODE_ALT_TEXT 14700
#define IDS_WEB_DIGITAL_CREDENTIALS_CABLEV2_CONNECTING_TITLE 14701
#define IDS_WEB_DIGITAL_CREDENTIALS_CABLEV2_CONNECTED_TITLE 14702
#define IDS_WEB_DIGITAL_CREDENTIALS_FLOW_CANCEL_BUTTON_TEXT 14703
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_DIALOG_TITLE 14704
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_LOW_RISK_DIALOG_TEXT 14705
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_LOW_RISK_NEGATIVE_BUTTON_TEXT 14706
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_HIGH_RISK_DIALOG_TEXT 14707
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_HIGH_RISK_NEGATIVE_BUTTON_TEXT 14708
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_POSITIVE_BUTTON_TEXT 14709
#define IDS_WEB_DIGITAL_CREDENTIALS_INTERSTITIAL_REQUEST_ABORTED_DIALOG_TEXT 14710
#define IDS_INCOGNITO_PROFILE_MENU_TITLE 14711
#define IDS_INCOGNITO_PROFILE_MENU_CLOSE_BUTTON 14712
#define IDS_INCOGNITO_CLEAR_BROWSING_DATA_DIALOG_PRIMARY_TEXT 14713
#define IDS_INCOGNITO_CLEAR_BROWSING_DATA_DIALOG_SECONDARY_TEXT 14714
#define IDS_INCOGNITO_CLEAR_BROWSING_DATA_DIALOG_CLOSE_WINDOWS_BUTTON 14715
#define IDS_INCOGNITO_HISTORY_BUBBLE_PRIMARY_TEXT 14716
#define IDS_INCOGNITO_HISTORY_BUBBLE_SECONDARY_TEXT 14717
#define IDS_INCOGNITO_HISTORY_BUBBLE_CLOSE_INCOGNITO_BUTTON_TEXT 14718
#define IDS_INCOGNITO_HISTORY_BUBBLE_CANCEL_BUTTON_TEXT 14719
#define IDS_NOTIFICATION_DEFAULT_HELPFUL_BUTTON_TEXT 14720
#define IDS_NOTIFICATION_DEFAULT_UNHELPFUL_BUTTON_TEXT 14721
#define IDS_DEEP_SCANNING_DIALOG_TITLE 14722
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_PENDING_MESSAGE 14723
#define IDS_DEEP_SCANNING_DIALOG_PRINT_PENDING_MESSAGE 14724
#define IDS_DEEP_SCANNING_DIALOG_SUCCESS_MESSAGE 14725
#define IDS_DEEP_SCANNING_DIALOG_PRINT_SUCCESS_MESSAGE 14726
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_FAILURE_MESSAGE 14727
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_FAIL_CLOSED_MESSAGE 14728
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_WARNING_MESSAGE 14729
#define IDS_DEEP_SCANNING_DIALOG_PRINT_WARNING_MESSAGE 14730
#define IDS_DEEP_SCANNING_DIALOG_TIMEOUT_MESSAGE 14731
#define IDS_DEEP_SCANNING_DIALOG_PROCEED_BUTTON 14732
#define IDS_DEEP_SCANNING_DIALOG_CANCEL_WARNING_BUTTON 14733
#define IDS_DEEP_SCANNING_DIALOG_CANCEL_UPLOAD_BUTTON 14734
#define IDS_DEEP_SCANNING_DIALOG_LARGE_FILE_FAILURE_MESSAGE 14735
#define IDS_DEEP_SCANNING_DIALOG_LARGE_PRINT_FAILURE_MESSAGE 14736
#define IDS_DEEP_SCANNING_DIALOG_ENCRYPTED_FILE_FAILURE_MESSAGE 14737
#define IDS_DEEP_SCANNING_DIALOG_CUSTOM_MESSAGE 14738
#define IDS_DEEP_SCANNING_DIALOG_DOWNLOADS_CUSTOM_MESSAGE 14739
#define IDS_DEEP_SCANNING_DIALOG_CUSTOM_MESSAGE_LEARN_MORE_LINK 14740
#define IDS_DEEP_SCANNING_DIALOG_DOWNLOADS_DISCARD_FILE_BUTTON 14741
#define IDS_DEEP_SCANNING_DIALOG_UPLOAD_BYPASS_JUSTIFICATION_LABEL 14742
#define IDS_DEEP_SCANNING_DIALOG_PASTE_BYPASS_JUSTIFICATION_LABEL 14743
#define IDS_DEEP_SCANNING_DIALOG_PRINT_BYPASS_JUSTIFICATION_LABEL 14744
#define IDS_DEEP_SCANNING_DIALOG_DOWNLOAD_BYPASS_JUSTIFICATION_LABEL 14745
#define IDS_DEEP_SCANNING_DIALOG_BYPASS_JUSTIFICATION_TEXT_LIMIT_LABEL 14746
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_STORAGE_LABEL 14747
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_FILENAME_PLACEHOLDER 14748
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_STORAGE_MESSAGE 14749
#define IDS_DEEP_SCANNING_DIALOG_SAVE_TO_CLOUD_STORAGE_CUSTOM_MESSAGE 14750
#define IDS_DATA_SHARING_BUBBLE_DIALOG_TITLE 14751
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_IPH_BUBBLE_TEXT 14752
#define IDS_SETTINGS_SAFEBROWSING_ENHANCED_IPH_BUBBLE_CLOSE_BUTTON_ARIA_LABEL_TEXT 14753
#define IDS_TAILORED_SECURITY_ENABLED_DIALOG_TITLE 14754
#define IDS_TAILORED_SECURITY_DISABLED_DIALOG_TITLE 14755
#define IDS_TAILORED_SECURITY_ENABLED_DIALOG_MAIN_TEXT 14756
#define IDS_TAILORED_SECURITY_DISABLED_DIALOG_MAIN_TEXT 14757
#define IDS_TAILORED_SECURITY_DISABLED_DIALOG_ACCEPT_BUTTON 14758
#define IDS_TAILORED_SECURITY_DIALOG_SETTINGS_BUTTON 14759
#define IDS_TAILORED_SECURITY_UNCONSENTED_MODAL_TITLE 14760
#define IDS_TAILORED_SECURITY_UNCONSENTED_MODAL_BODY 14761
#define IDS_TAILORED_SECURITY_UNCONSENTED_ACCEPT_BUTTON 14762
#define IDS_TAILORED_SECURITY_UNCONSENTED_CANCEL_BUTTON 14763
#define IDS_TAILORED_SECURITY_CONSENTED_ENABLE_MESSAGE_TITLE 14764
#define IDS_TAILORED_SECURITY_CONSENTED_ENABLE_MESSAGE_DESCRIPTION 14765
#define IDS_TAILORED_SECURITY_CONSENTED_DISABLE_MESSAGE_TITLE 14766
#define IDS_TAILORED_SECURITY_CONSENTED_DISABLE_MESSAGE_DESCRIPTION 14767
#define IDS_TAILORED_SECURITY_CONSENTED_MESSAGE_OK_BUTTON 14768
#define IDS_TAILORED_SECURITY_CONSENTED_ENHANCED_PROTECTION_ENABLE_MESSAGE_TITLE 14769
#define IDS_PROMPT_APP_UNINSTALL_TITLE 14770
#define IDS_APP_UNINSTALL_PROMPT_REMOVE_DATA_CHECKBOX_FOR_NON_GOOGLE 14771
#define IDS_APP_UNINSTALL_PROMPT_REMOVE_DATA_CHECKBOX_FOR_GOOGLE 14772
#define IDS_APP_UNINSTALL_PROMPT_LEARN_MORE 14773
#define IDS_APP_UNINSTALL_PROMPT_ADDITIONAL_UNINSTALLS_MESSAGE 14774
#define IDS_SUB_APPS_UNINSTALL_NOTIFICATION_TITLE 14775
#define IDS_SUB_APPS_UNINSTALL_NOTIFICATION_DESCRIPTION 14776
#define IDS_UTILITY_PROCESS_SPEECH_RECOGNITION_SERVICE_NAME 14777
#define IDS_APP_PAUSE_PROMPT_TITLE 14778
#define IDS_APP_PAUSE_HEADING 14779
#define IDS_APP_PAUSE_HEADING_FOR_WEB_APPS 14780
#define IDS_APP_BLOCK_PROMPT_TITLE 14781
#define IDS_APP_BLOCK_HEADING_FOR_CHILD 14782
#define IDS_APP_BLOCK_HEADING 14783
#define IDS_APP_LOCAL_BLOCK_PROMPT_TITLE 14784
#define IDS_APP_LOCAL_BLOCK_PROMPT_MULTIPLE_TITLE 14785
#define IDS_APP_LOCAL_BLOCK_HEADING 14786
#define IDS_ENTERPRISE_EXTENSION_REQUEST_APPROVED_TITLE 14787
#define IDS_ENTERPRISE_EXTENSION_REQUEST_REJECTED_TITLE 14788
#define IDS_ENTERPRISE_EXTENSION_REQUEST_FORCE_INSTALLED_TITLE 14789
#define IDS_ENTERPRISE_EXTENSION_REQUEST_CLICK_TO_INSTALL 14790
#define IDS_ENTERPRISE_EXTENSION_REQUEST_CLICK_TO_VIEW 14791
#define IDS_ENTERPRISE_EXTENSION_REQUEST_JUSTIFICATION 14792
#define IDS_ENTERPRISE_EXTENSION_REQUEST_JUSTIFICATION_PLACEHOLDER 14793
#define IDS_ENTERPRISE_EXTENSION_REQUEST_JUSTIFICATION_LENGTH_LIMIT 14794
#define IDS_NAME_WINDOW_PROMPT_TITLE 14795
#define IDS_NAME_WINDOW_PROMPT_FIELD_LABEL 14796
#define IDS_CHROMELABS_RELAUNCH_BUTTON_LABEL 14797
#define IDS_WINDOW_TITLE_EXPERIMENTS 14798
#define IDS_CHROMELABS_SEND_FEEDBACK 14799
#define IDS_CHROMELABS_SEND_FEEDBACK_DESCRIPTION_PLACEHOLDER 14800
#define IDS_CHROMELABS_DEFAULT 14801
#define IDS_CHROMELABS_ENABLED 14802
#define IDS_CHROMELABS_DISABLED 14803
#define IDS_CHROMELABS_ENABLED_WITH_VARIATION_NAME 14804
#define IDS_LENS_REGION_SEARCH_BUBBLE_TEXT 14805
#define IDS_CAPTURE_REGION_BUBBLE_TEXT 14806
#define IDS_THUMBNAIL_TAB_STRIP_EXPERIMENT_NAME 14807
#define IDS_THUMBNAIL_TAB_STRIP_EXPERIMENT_DESCRIPTION 14808
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_NOTIFICATION_DESCRIPTION 14811
#define IDS_TAILORED_SECURITY_UNCONSENTED_PROMOTION_NOTIFICATION_ACCEPT 14812
#define IDS_TAILORED_SECURITY_CONSENTED_PROMOTION_MESSAGE_TURN_ON 14813
#define IDS_TAILORED_SECURITY_CONSENTED_ESB_OFF_MESSAGE_TITLE 14814
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_SIGN_IN 14815
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_SIGN_UP 14816
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_USE 14817
#define IDS_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT_CONTINUE 14818
#define IDS_ACCOUNT_SELECTION_SHEET_SUBTITLE_FOR_EMBED 14819
#define IDS_ACCOUNT_SELECTION_CONTINUE 14820
#define IDS_ACCOUNT_SELECTION_CHOOSE_AN_ACCOUNT 14821
#define IDS_ACCOUNT_SELECTION_CHOOSE_AN_ACCOUNT_BUTTON 14822
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_NAME 14823
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_EMAIL 14824
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_PICTURE 14825
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_PHONE 14826
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_USERNAME 14827
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT_NO_PP_OR_TOS 14828
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT_NO_PP 14829
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT_NO_TOS 14830
#define IDS_ACCOUNT_SELECTION_DATA_SHARING_CONSENT 14831
#define IDS_ACCOUNT_SELECTION_USE_OTHER_ACCOUNT 14832
#define IDS_ACCOUNT_SELECTION_USE_OTHER_ACCOUNT_MULTI_IDP 14833
#define IDS_ACCOUNT_SELECTION_OPENS_IN_NEW_TAB 14834
#define IDS_ACCOUNT_SELECTION_BACK 14835
#define IDS_SIGNIN_CONTINUE 14836
#define IDS_IDP_SIGNIN_STATUS_MISMATCH_DIALOG_BODY 14837
#define IDS_SIGNIN_GENERIC_ERROR_DIALOG_SUMMARY 14838
#define IDS_SIGNIN_GENERIC_ERROR_DIALOG_DESCRIPTION 14839
#define IDS_SIGNIN_UNAUTHORIZED_CLIENT_ERROR_DIALOG_SUMMARY 14840
#define IDS_SIGNIN_UNAUTHORIZED_CLIENT_ERROR_DIALOG_DESCRIPTION 14841
#define IDS_SIGNIN_INVALID_REQUEST_ERROR_DIALOG_SUMMARY 14842
#define IDS_SIGNIN_INVALID_REQUEST_ERROR_DIALOG_DESCRIPTION 14843
#define IDS_SIGNIN_ACCESS_DENIED_ERROR_DIALOG_SUMMARY 14844
#define IDS_SIGNIN_ACCESS_DENIED_ERROR_DIALOG_DESCRIPTION 14845
#define IDS_SIGNIN_SERVER_ERROR_DIALOG_SUMMARY 14846
#define IDS_SIGNIN_SERVER_ERROR_DIALOG_DESCRIPTION 14847
#define IDS_SIGNIN_TEMPORARILY_UNAVAILABLE_ERROR_DIALOG_SUMMARY 14848
#define IDS_SIGNIN_TEMPORARILY_UNAVAILABLE_ERROR_DIALOG_DESCRIPTION 14849
#define IDS_SIGNIN_ERROR_DIALOG_GOT_IT_BUTTON 14850
#define IDS_SIGNIN_ERROR_DIALOG_MORE_DETAILS_BUTTON 14851
#define IDS_SIGNIN_ERROR_DIALOG_MORE_DETAILS_PROMPT 14852
#define IDS_SIGNIN_ERROR_DIALOG_TRY_OTHER_WAYS_PROMPT 14853
#define IDS_SIGNIN_ERROR_DIALOG_MORE_DETAILS_RETRY_PROMPT 14854
#define IDS_SIGNIN_ERROR_DIALOG_TRY_OTHER_WAYS_RETRY_PROMPT 14855
#define IDS_MULTI_IDP_ACCOUNT_SELECTION_SHEET_TITLE_EXPLICIT 14856
#define IDS_MULTI_IDP_ACCOUNT_ORIGIN_AND_LAST_USED 14857
#define IDS_USED_ON_THIS_SITE 14858
#define IDS_VERIFY_SHEET_TITLE 14859
#define IDS_VERIFY_SHEET_TITLE_AUTO_REAUTHN 14860
#define IDS_AUTO_REAUTHN_OPTOUT_CHECKBOX 14861
#define IDS_FILTERED_ACCOUNT_MESSAGE 14862
#define IDS_FEDERATION_SIGN_IN_TITLE 14863
#define IDS_FEDERATION_SIGNING_IN_TITLE 14864
#define IDS_FEDERATION_SIGN_UP_TITLE 14865
#define IDS_BATTERY_SAVER_BUTTON_TOOLTIP 14868
#define IDS_BATTERY_SAVER_BUTTON_ACCNAME 14869
#define IDS_BATTERY_SAVER_BUBBLE_TITLE 14870
#define IDS_BATTERY_SAVER_BUBBLE_DESCRIPTION 14871
#define IDS_BATTERY_SAVER_SESSION_TURN_OFF 14872
#define IDS_MEMORY_SAVER_CHIP_LABEL 14873
#define IDS_MEMORY_SAVER_CHIP_ACCNAME 14874
#define IDS_MEMORY_SAVER_CHIP_WITH_SAVINGS_ACCNAME 14875
#define IDS_MEMORY_SAVER_CHIP_SAVINGS_LABEL 14876
#define IDS_MEMORY_SAVER_DIALOG_TITLE 14877
#define IDS_MEMORY_SAVER_DIALOG_SETTINGS_BUTTON 14878
#define IDS_MEMORY_SAVER_DIALOG_SAVINGS_ACCNAME 14879
#define IDS_MEMORY_SAVER_DIALOG_BUTTON_ADD_TO_EXCLUSION_LIST 14880
#define IDS_MEMORY_SAVER_DIALOG_SAVINGS_LABEL 14881
#define IDS_MEMORY_SAVER_DIALOG_SMALL_SAVINGS_LABEL 14882
#define IDS_MEMORY_SAVER_DIALOG_MEDIUM_SAVINGS_LABEL 14883
#define IDS_MEMORY_SAVER_DIALOG_LARGE_SAVINGS_LABEL 14884
#define IDS_MEMORY_SAVER_DIALOG_VERY_LARGE_SAVINGS_LABEL 14885
#define IDS_HOVERCARD_TAB_MEMORY_USAGE 14886
#define IDS_HOVERCARD_TAB_HIGH_MEMORY_USAGE 14887
#define IDS_HOVERCARD_INACTIVE_TAB_MEMORY_SAVINGS 14888
#define IDS_HOVERCARD_INACTIVE_TAB 14889
#define IDS_PERFORMANCE_INTERVENTION_CLOSE_BUTTON_ACCNAME 14890
#define IDS_PERFORMANCE_INTERVENTION_SINGLE_SUGGESTED_ROW_ACCNAME 14891
#define IDS_PERFORMANCE_INTERVENTION_TAB_LIST_ACCNAME 14892
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_V1 14893
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_UPDATED_V1 14894
#define IDS_PERFORMANCE_INTERVENTION_DIALOG_TITLE_UPDATED_V2 14895
#define IDS_PERFORMANCE_INTERVENTION_DEACTIVATE_TABS_BUTTON_V1 14896
#define IDS_PERFORMANCE_INTERVENTION_DEACTIVATE_TABS_BUTTON_UPDATED_V1 14897
#define IDS_PERFORMANCE_INTERVENTION_DEACTIVATE_TABS_BUTTON_UPDATED_V2 14898
#define IDS_PERFORMANCE_INTERVENTION_DISMISS_BUTTON 14899
#define IDS_PERFORMANCE_INTERVENTION_BUTTON_TOOLTIP 14900
#define IDS_PERFORMANCE_INTERVENTION_BUTTON_ACCNAME 14901
#define IDS_TOAST_MENU_BUTTON_NAME 14902
#define IDS_TRANSLATE_TOAST_BODY 14903
#define IDS_TRANSLATE_TOAST_UNDO_BUTTON 14904
#define IDS_MULTISTEP_FILTER_SUGGESTION_TITLE 14905
#define IDS_MULTISTEP_FILTER_SUGGESTION_APPLY_BUTTON 14906
#define IDS_MULTISTEP_FILTER_SUGGESTION_RECENT_TITLE 14907
#define IDS_MULTISTEP_FILTER_SUGGESTION_RECENT_APPLY_BUTTON 14908
#define IDS_LINK_COPIED_TOAST_BODY 14909
#define IDS_IMAGE_COPIED_TOAST_BODY 14910
#define IDS_VIDEO_FRAME_COPIED_TOAST_BODY 14911
#define IDS_LINK_COPIED_TO_HIGHLIGHT_TOAST_BODY 14912
#define IDS_READING_LIST_TOAST_BODY 14913
#define IDS_READING_LIST_TOAST_BUTTON 14914
#define IDS_CLOSE_PINNED_TAB_TOAST_BODY 14915
#define IDS_TOAST_CLOSE_TOOLTIP 14916
#define IDS_NON_MILESTONE_UPDATE_TOAST_BODY 14917
#define IDS_GLIC_SHARE_IMAGE_FAILED_TOAST_BODY 14918
#define IDS_GLIC_SELECTION_OVERLAY_RENDERER_LABEL 14919
#define IDS_GLIC_SELECTION_OVERLAY_PRESELECTION_BUBBLE_TEXT 14920
#define IDS_COPIED_TO_CLIPBOARD_TOAST_BODY 14921
#define IDS_SPLIT_VIEW_CREATED_TOAST_BODY 14922
#define IDS_SPLIT_VIEW_SEPARATE_VIEWS_ACTION_BUTTON 14923
#define IDS_SPLIT_VIEW_UNDO_SPLIT_ACTION_BUTTON 14924
#define IDS_PROTECTED_AUDIENCE_DEBUGGING_DISCLAIMER 14928
#define IDS_OVERFLOW_MENU_ITEM_TEXT_PROFILE 14929
#define IDS_OVERFLOW_MENU_ITEM_TEXT_DOWNLOADS 14930
#define IDS_OVERFLOW_MENU_ITEM_TEXT_EXTENSIONS 14931
#define IDS_OVERFLOW_MENU_ITEM_TEXT_FORWARD 14932
#define IDS_OVERFLOW_MENU_ITEM_TEXT_HOME 14933
#define IDS_OVERFLOW_MENU_ITEM_TEXT_LABS 14934
#define IDS_OVERFLOW_MENU_ITEM_TEXT_MEDIA_CONTROLS 14935
#define IDS_OVERFLOW_MENU_ITEM_TEXT_NEW_TAB 14936
#define IDS_OVERFLOW_MENU_ITEM_TEXT_SIDE_PANEL 14937
#define IDS_OVERFLOW_MENU_ITEM_TEXT_SPLIT_TABS 14938
#define IDS_OVERFLOW_MENU_ITEM_TEXT_CONTEXTUAL_TASKS 14939
#define IDS_OVERFLOW_MENU_ITEM_TEXT_ENERGY_SAVER 14940
#define IDS_PROMISE_STATUS_WAITING 14941
#define IDS_PROMISE_STATUS_INSTALLING 14942
#define IDS_PROMISE_APP_ACCESSIBLE_LABEL_WAITING 14943
#define IDS_PROMISE_APP_ACCESSIBLE_LABEL_INSTALLING 14944
#define IDS_PROMISE_APP_PLACEHOLDER_ACCESSIBLE_LABEL_WAITING 14945
#define IDS_PROMISE_APP_PLACEHOLDER_ACCESSIBLE_LABEL_INSTALLING 14946
#define IDS_IWA_INSTALLER_DISABLED_TITLE 14947
#define IDS_IWA_INSTALLER_DISABLED_CHANGE_PREFERENCE 14948
#define IDS_IWA_INSTALLER_DISABLED_SUBTITLE 14949
#define IDS_IWA_INSTALLER_ALREADY_INSTALLED_TITLE 14950
#define IDS_IWA_INSTALLER_ALREADY_INSTALLED_SUBTITLE 14951
#define IDS_IWA_INSTALLER_BODY_SCREENREADER_NAME 14952
#define IDS_IWA_INSTALLER_DETAILS_SCREENREADER_NAME 14953
#define IDS_IWA_INSTALLER_PROGRESS_SCREENREADER_NAME 14954
#define IDS_IWA_INSTALLER_INSTALL_SUBTITLE 14955
#define IDS_IWA_INSTALLER_INSTALL_PROGRESS 14956
#define IDS_IWA_INSTALLER_SHOW_METADATA_SUBTITLE 14957
#define IDS_IWA_INSTALLER_SHOW_METADATA_APP_NAME_LABEL 14958
#define IDS_IWA_INSTALLER_SHOW_METADATA_APP_VERSION_LABEL 14959
#define IDS_IWA_INSTALLER_SHOW_METADATA_APP_ENTERPRISE_NAME_LABEL 14960
#define IDS_IWA_INSTALLER_CONFIRM_TITLE 14961
#define IDS_IWA_INSTALLER_CONFIRM_SUBTITLE 14962
#define IDS_IWA_INSTALLER_CONFIRM_CONTINUE 14963
#define IDS_IWA_INSTALLER_INSTALL_FAILED_TITLE 14964
#define IDS_IWA_INSTALLER_INSTALL_FAILED_SUBTITLE 14965
#define IDS_IWA_INSTALLER_INSTALL_FAILED_BUNDLE_BLOCKED_USER_INSTALL_ALLOWLIST_BLOCKLIST_TITLE 14966
#define IDS_IWA_INSTALLER_INSTALL_FAILED_BUNDLE_NOT_ON_USER_INSTALL_ALLOWLIST_MESSAGE 14967
#define IDS_IWA_INSTALLER_INSTALL_FAILED_BUNDLE_BLOCKLISTED_MESSAGE 14968
#define IDS_IWA_INSTALLER_INSTALL_FAILED_RETRY 14969
#define IDS_IWA_INSTALLER_SUCCESS_SUBTITLE 14970
#define IDS_IWA_INSTALLER_SUCCESS_FINISH 14971
#define IDS_IWA_INSTALLER_SUCCESS_LAUNCH_APPLICATION 14972
#define IDS_IWA_INSTALLER_VERIFICATION_TITLE 14973
#define IDS_IWA_INSTALLER_VERIFICATION_SUBTITLE 14974
#define IDS_IWA_INSTALLER_VERIFICATION_STATUS 14975
#define IDS_IWA_INSTALLER_VERIFICATION_ERROR_TITLE 14976
#define IDS_IWA_INSTALLER_VERIFICATION_ERROR_SUBTITLE 14977
#define IDS_ISOLATED_WEB_APPS_WINDOW_OPEN_PERMISSION_NOTIFICATION_TITLE 14979
#define IDS_ISOLATED_WEB_APPS_WINDOW_OPEN_PERMISSION_NOTIFICATION_MESSAGE 14980
#define IDS_ISOLATED_WEB_APPS_WINDOW_OPEN_PERMISSION_NOTIFICATION_BUTTON_SETTINGS 14981
#define IDS_THUMBS_DOWN 14988
#define IDS_THUMBS_UP 14989
#define IDS_EXPERIMENTAL_FEATURE_DISCLAIMER 14990
#define IDS_PDF_INK_SIGNATURES_IPH_BODY 14991
#define IDS_PDF_SEARCHIFY_IPH_TITLE 14992
#define IDS_PDF_SEARCHIFY_IPH_BODY 14993
#define IDS_PDF_SEARCHIFY_IPH_BODY_SCREEN_READER 14994
#define IDS_SELECT_AUDIO_OUTPUT_DIALOG_TITLE 14995
#define IDS_SELECT_AUDIO_OUTPUT_DIALOG_CHOOSE_DEVICE 14996
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_TITLE 15012
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_BODY 15013
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_TITLE_NEW 15014
#define IDS_CHROME_NO_LONGER_SHOW_WARNINGS_NOTIFICATION_BODY_NEW 15015
#define IDS_MERCHANT_TRUST_IPH_TITLE 15016
#define IDS_MERCHANT_TRUST_IPH_BODY 15017
#define IDS_MERCHANT_TRUST_IPH_BODY_SCREEN_READER 15018
#define IDS_PDF_GLIC_SUMMARIZE 15023
#define IDS_PDF_GLIC_SUMMARIZE_TOOLTIP 15024
#define IDS_PDF_GLIC_SUMMARIZE_PROMPT 15025
#define IDS_NTP_PROMO_DISMISS 15034
#define IDS_NTP_PROMO_MENU_TOOLTIP 15035
#define IDS_NTP_PROMO_MENU_A11Y_LABEL 15036
#define IDS_NTP_EXTENSIONS_PROMO 15037
#define IDS_ACCOUNT_CHOOSER_SINGLE_ACCOUNT_TITLE 15038
#define IDS_ACCOUNT_CHOOSER_MULTI_ACCOUNT_TITLE 15039
#define IDS_ACCOUNT_CHOOSER_SUBTITLE 15040
#define IDS_SAVE_TO_DRIVE_FOLDER_NAME 15041
#define IDS_ACCOUNT_CHOOSER_DRIVE 15042
#define IDS_ACCOUNT_CHOOSER_ADD_ACCOUNT 15043
#define IDS_ACCOUNT_CHOOSER_RADIO_GROUP_ACCESSIBILITY_LABEL 15044
#define IDS_ACCOUNT_CHOOSER_HEADER_ACCESSIBILITY_LABEL 15045
#define IDS_TIPS_NOTIFICATIONS_HELPFUL_BUTTON_TEXT 15046
#define IDS_TIPS_NOTIFICATIONS_ENHANCED_SAFE_BROWSING_TITLE 15047
#define IDS_TIPS_NOTIFICATIONS_ENHANCED_SAFE_BROWSING_SUBTITLE 15048
#define IDS_TIPS_NOTIFICATIONS_QUICK_DELETE_TITLE 15049
#define IDS_TIPS_NOTIFICATIONS_QUICK_DELETE_SUBTITLE 15050
#define IDS_TIPS_NOTIFICATIONS_GOOGLE_LENS_TITLE 15051
#define IDS_TIPS_NOTIFICATIONS_GOOGLE_LENS_SUBTITLE 15052
#define IDS_TIPS_NOTIFICATIONS_BOTTOM_OMNIBOX_TITLE 15053
#define IDS_TIPS_NOTIFICATIONS_BOTTOM_OMNIBOX_SUBTITLE 15054
#define IDS_TIPS_NOTIFICATIONS_PASSWORD_AUTOFILL_TITLE 15055
#define IDS_TIPS_NOTIFICATIONS_PASSWORD_AUTOFILL_SUBTITLE 15056
#define IDS_TIPS_NOTIFICATIONS_SIGNIN_TITLE 15057
#define IDS_TIPS_NOTIFICATIONS_SIGNIN_SUBTITLE 15058
#define IDS_TIPS_NOTIFICATIONS_CREATE_TAB_GROUPS_TITLE 15059
#define IDS_TIPS_NOTIFICATIONS_CREATE_TAB_GROUPS_SUBTITLE 15060
#define IDS_TIPS_NOTIFICATIONS_CUSTOMIZE_MVT_TITLE 15061
#define IDS_TIPS_NOTIFICATIONS_CUSTOMIZE_MVT_SUBTITLE 15062
#define IDS_TIPS_NOTIFICATIONS_RECENT_TABS_TITLE 15063
#define IDS_TIPS_NOTIFICATIONS_RECENT_TABS_SUBTITLE 15064
#define IDS_UPDATER_ACTIVATION_FAILED 15065
#define IDS_UPDATER_ACTIVATION_SUCCEEDED 15066
#define IDS_UPDATER_ADD_FILTER 15067
#define IDS_UPDATER_APP 15068
#define IDS_UPDATER_APP_COLUMN 15069
#define IDS_UPDATER_APPLY 15070
#define IDS_UPDATER_APP_NAME_OR_ID 15071
#define IDS_UPDATER_APP_POLICIES 15072
#define IDS_UPDATER_APP_STATES_QUERY_FAILED 15073
#define IDS_UPDATER_CANCEL 15074
#define IDS_UPDATER_CLEAR_ALL_FILTERS 15075
#define IDS_UPDATER_COLLAPSE_ALL 15076
#define IDS_UPDATER_COMMAND_LINE 15077
#define IDS_UPDATER_COMMAND_OUTCOME 15078
#define IDS_UPDATER_COMMON 15079
#define IDS_UPDATER_DATE 15080
#define IDS_UPDATER_DATE_FILTER_AFTER 15081
#define IDS_UPDATER_DATE_FILTER_BEFORE 15082
#define IDS_UPDATER_DATE_FILTER_RANGE 15083
#define IDS_UPDATER_DISPLAYED_EVENTS_COUNT 15084
#define IDS_UPDATER_DURATION 15085
#define IDS_UPDATER_EFFECTIVE_POLICY_SET 15086
#define IDS_UPDATER_END_DATE 15087
#define IDS_UPDATER_ERROR_ACCESS_DENIED 15088
#define IDS_UPDATER_ERROR_CORRUPT 15089
#define IDS_UPDATER_ERROR_DISABLED 15090
#define IDS_UPDATER_ERROR_DISK_FULL 15091
#define IDS_UPDATER_ERROR_DOWNLOAD 15092
#define IDS_UPDATER_ERROR_INSTALL 15093
#define IDS_UPDATER_ERROR_INSTALLER_FAILED 15094
#define IDS_UPDATER_ERROR_NETWORK 15095
#define IDS_UPDATER_ERROR_RESTRICTED 15096
#define IDS_UPDATER_ERROR_UNPACK 15097
#define IDS_UPDATER_ERROR_UPDATE_CHECK 15098
#define IDS_UPDATER_ERROR_UNKNOWN 15099
#define IDS_UPDATER_EVENT_LIST_TITLE 15100
#define IDS_UPDATER_EVENT_TYPE 15101
#define IDS_UPDATER_EVENT_TYPE_ACTIVATE 15102
#define IDS_UPDATER_EVENT_TYPE_APP_COMMAND 15103
#define IDS_UPDATER_EVENT_TYPE_INSTALL 15104
#define IDS_UPDATER_EVENT_TYPE_LOAD_POLICY 15105
#define IDS_UPDATER_EVENT_TYPE_PERSISTED_DATA 15106
#define IDS_UPDATER_EVENT_TYPE_POST_REQUEST 15107
#define IDS_UPDATER_EVENT_TYPE_QUALIFY 15108
#define IDS_UPDATER_EVENT_TYPE_UNINSTALL 15109
#define IDS_UPDATER_EVENT_TYPE_UPDATE 15110
#define IDS_UPDATER_EVENT_TYPE_UPDATER_PROCESS 15111
#define IDS_UPDATER_EXPAND_ALL 15112
#define IDS_UPDATER_EXPORT_HISTORY_FILE 15113
#define IDS_UPDATER_FILTER_CHIP_APP 15114
#define IDS_UPDATER_FILTER_CHIP_DATE 15115
#define IDS_UPDATER_FILTER_CHIP_EVENT_TYPE 15116
#define IDS_UPDATER_FILTER_CHIP_UPDATE_OUTCOME 15117
#define IDS_UPDATER_FILTER_CHIP_UPDATER_SCOPE 15118
#define IDS_UPDATER_INACTIVE_VERSIONS_LABEL 15119
#define IDS_UPDATER_INSTALL_PATH_LABEL 15120
#define IDS_UPDATER_INSTALL_SUMMARY 15121
#define IDS_UPDATER_INSTALLED_APPS_TITLE 15122
#define IDS_UPDATER_INTERNAL 15123
#define IDS_UPDATER_LAST_CHECKED_LABEL 15124
#define IDS_UPDATER_LAST_STARTED_LABEL 15125
#define IDS_UPDATER_LOAD_HISTORY_FILE 15126
#define IDS_UPDATER_LOAD_HISTORY_FILE_ERROR 15127
#define IDS_UPDATER_NO_APPS_FOUND 15128
#define IDS_UPDATER_NO_POLICIES 15129
#define IDS_UPDATER_NO_UPDATER_FOUND 15130
#define IDS_UPDATER_NEVER 15131
#define IDS_UPDATER_NEXT_VERSION 15132
#define IDS_UPDATER_NO_UPDATE 15133
#define IDS_UPDATER_OMAHA_REQUEST 15134
#define IDS_UPDATER_OMAHA_RESPONSE 15135
#define IDS_UPDATER_OTHER 15136
#define IDS_UPDATER_OUTCOME 15137
#define IDS_UPDATER_OUTCOME_UNKNOWN 15138
#define IDS_UPDATER_PAGE_TITLE 15139
#define IDS_UPDATER_PARSE_ERROR_EVENTS 15140
#define IDS_UPDATER_PERSISTED_DATA_SUMMARY 15141
#define IDS_UPDATER_POLICY_CONFLICT_WARNING 15142
#define IDS_UPDATER_POLICY_IGNORED 15143
#define IDS_UPDATER_POLICY_NAME 15144
#define IDS_UPDATER_POLICY_OK 15145
#define IDS_UPDATER_POLICY_SOURCE 15146
#define IDS_UPDATER_POLICY_STATUS 15147
#define IDS_UPDATER_POLICY_VALUE 15148
#define IDS_UPDATER_PROCESS_SUMMARY 15149
#define IDS_UPDATER_QUALIFICATION_FAILED 15150
#define IDS_UPDATER_QUALIFICATION_SUCCEEDED 15151
#define IDS_UPDATER_QUERY_FAILED 15152
#define IDS_UPDATER_REMOVE_FILTER 15153
#define IDS_UPDATER_RETURN_TO_LOCAL 15154
#define IDS_UPDATER_SCOPE 15155
#define IDS_UPDATER_SCOPE_SYSTEM 15156
#define IDS_UPDATER_SCOPE_USER 15157
#define IDS_UPDATER_START_DATE 15158
#define IDS_UPDATER_STATE_TITLE 15159
#define IDS_UPDATER_UNDATED_EVENTS 15160
#define IDS_UPDATER_UNINSTALL_SUMMARY 15161
#define IDS_UPDATER_UPDATED_TO 15162
#define IDS_UPDATER_UPDATER_POLICIES 15163
#define IDS_UPDATER_UPDATER_VERSION 15164
#define IDS_UPDATER_VERSION_COLUMN 15165
#define IDS_UPDATER_VERSION_LABEL 15166
#define IDS_UPDATER_VIEWING_HISTORY_FILES 15167
#define IDS_UPDATER_UPDATE_ERROR 15168
#define IDS_UPDATER_UPDATE_OUTCOME 15169
#define IDS_UPDATER_UPDATE_OUTCOME_NO_UPDATE 15170
#define IDS_UPDATER_UPDATE_OUTCOME_UPDATED 15171
#define IDS_UPDATER_UPDATE_OUTCOME_UPDATE_ERROR 15172
#define IDS_UPDATER_VIEW_RAW_DETAILS 15173
#define IDS_REPORT_UNSAFE_SITE_DIALOG_INCLUDE_SCREENSHOT_CHECKBOX_LABEL 15174
#define IDS_REPORT_UNSAFE_SITE_DIALOG_SEND_BUTTON_LABEL 15175
#define IDS_REPORT_UNSAFE_SITE_DIALOG_URL_LABEL 15176
#define IDS_REPORT_UNSAFE_SITE_DIALOG_SENDING_BUTTON_LABEL 15177
#define IDS_REPORT_UNSAFE_SITE_CONFIRMATION_TOAST 15178
#define IDS_INDIGO_TOOLBAR_CAPTION 15179
#define IDS_INDIGO_TOOLBAR_EXPAND 15180
#define IDS_INDIGO_TOOLBAR_COLLAPSE 15181
#define IDS_INDIGO_TOOLBAR_REGENERATE 15182
#define IDS_INDIGO_TOOLBAR_REPLACE_ORIGINAL_PHOTO 15183
#define IDS_INDIGO_TOOLBAR_DELETE_ORIGINAL_PHOTO 15184
#define IDS_CHROME_FINDS_NOTIFICATIONS_HELPFUL_BUTTON_TEXT 15185
#define IDS_CHROME_FINDS_NOTIFICATIONS_UNHELPFUL_BUTTON_TEXT 15186

// ---------------------------------------------------------------------------
// From locale_settings.h:

#define IDS_SPELLCHECK_DICTIONARY 16000
#define IDS_EDITBOOKMARK_DIALOG_WIDTH_CHARS 16001
#define IDS_EDITBOOKMARK_DIALOG_HEIGHT_LINES 16002
#define IDS_WEBSTORE_URL 16003
#define IDS_MEDIA_GALLERIES_DIALOG_CONTENT_WIDTH_CHARS 16004

// ---------------------------------------------------------------------------
// From omnibox_pedal_synonyms.h:

#define IDS_OMNIBOX_PEDALS_IGNORE_GROUP 41220
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_REQUIRED_CLEAR_BROWSER_CACHE 41221
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_OPTIONAL_GOOGLE_CHROME 41222
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_REQUIRED_DELETE 41223
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLEAR_BROWSING_DATA_ONE_REQUIRED_INFORMATION 41224
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_REQUIRED_MANAGE_CHROME_PASSWORDS 41225
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_OPTIONAL_GOOGLE_CHROME 41226
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_OPTIONAL_MANAGER 41227
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_PASSWORDS_ONE_REQUIRED_PASSWORDS 41228
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_REQUIRED_MANAGE_PAYMENT_METHODS 41229
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_OPTIONAL_GOOGLE_CHROME 41230
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_REQUIRED_CHANGE 41231
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CREDIT_CARD_ONE_REQUIRED_CREDIT_CARD_INFORMATION 41232
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_REQUIRED_ENTER_INCOGNITO_MODE 41233
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_OPTIONAL_GOOGLE_CHROME 41234
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_OPTIONAL_CREATE 41235
#define IDS_OMNIBOX_PEDAL_SYNONYMS_LAUNCH_INCOGNITO_ONE_REQUIRED_INCOGNITO_WINDOW 41236
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_REQUIRED_TRANSLATE_THIS_PAGE 41237
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_OPTIONAL_GOOGLE_CHROME 41238
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_REQUIRED_CHANGE_LANGUAGE 41239
#define IDS_OMNIBOX_PEDAL_SYNONYMS_TRANSLATE_ONE_REQUIRED_THIS_PAGE 41240
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CHROME_ONE_REQUIRED_UPDATE_CHROME 41241
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CHROME_ONE_REQUIRED_GOOGLE_CHROME 41242
#define IDS_OMNIBOX_PEDAL_SYNONYMS_UPDATE_CHROME_ONE_REQUIRED_INSTALL 41243
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_REQUIRED_RUN_CHROME_SAFETY_CHECK 41244
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_OPTIONAL_ACTIVATE 41245
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_OPTIONAL_GOOGLE_CHROME 41246
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_REQUIRED_CHECKUP 41247
#define IDS_OMNIBOX_PEDAL_SYNONYMS_RUN_CHROME_SAFETY_CHECK_ONE_REQUIRED_PASSWORDS 41248
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ONE_REQUIRED_MANAGE_SECURITY_SETTINGS 41249
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ANY_OPTIONAL_GOOGLE_CHROME 41250
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ONE_REQUIRED_ENHANCED_PROTECTION 41251
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SECURITY_SETTINGS_ONE_OPTIONAL_ALTER 41252
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ONE_REQUIRED_CHROME_COOKIE_SETTINGS 41253
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ONE_REQUIRED_COOKIE_SETTINGS 41254
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ANY_REQUIRED_GOOGLE_CHROME 41255
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_COOKIES_ANY_OPTIONAL_THIRD_PARTY 41256
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_REQUIRED_ADD_ADDRESS 41257
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_REQUIRED_CONTROL 41258
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_REQUIRED_SHIPPING_ADDRESSES 41259
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_ADDRESSES_ONE_OPTIONAL_GOOGLE_CHROME 41260
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ONE_REQUIRED_CHANGE_CHROME_BROWSER_SYNC_SETTINGS 41261
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ONE_REQUIRED_SYNC_SETTINGS 41262
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ONE_REQUIRED_SYNC_SETTINGS_UPDATED 41263
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_ANY_REQUIRED_GOOGLE_CHROME 41264
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SYNC_UPDATED 41265
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SITE_SETTINGS_ONE_REQUIRED_ADJUST_SITE_PERMISSIONS 41266
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SITE_SETTINGS_ONE_REQUIRED_SITE_PERMISSIONS 41267
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_SITE_SETTINGS_ANY_REQUIRED_GOOGLE_CHROME 41268
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ONE_REQUIRED_CREATE_GOOGLE_DOC 41269
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ONE_REQUIRED_GOOGLE_WORKSPACE 41270
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ANY_REQUIRED_CREATE 41271
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_DOC_ONE_REQUIRED_DOCUMENT 41272
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ONE_REQUIRED_CREATE_GOOGLE_SHEET 41273
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ANY_REQUIRED_CREATE 41274
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ONE_REQUIRED_GOOGLE_WORKSPACE 41275
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SHEET_ONE_REQUIRED_SPREADSHEET 41276
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ONE_REQUIRED_CREATE_GOOGLE_SLIDE 41277
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ONE_REQUIRED_CREATE 41278
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ONE_REQUIRED_PRESENTATION 41279
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SLIDE_ANY_REQUIRED_WORKSPACE 41280
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ONE_REQUIRED_CREATE_GOOGLE_CAL_INVITE 41281
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ANY_REQUIRED_SCHEDULE 41282
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ANY_REQUIRED_WORKSPACE 41283
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_CALENDAR_EVENT_ONE_REQUIRED_MEETING 41284
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ONE_REQUIRED_CREATE_GOOGLE_SITE 41285
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ANY_REQUIRED_CREATE 41286
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ANY_REQUIRED_WORKSPACE 41287
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_SITE_ONE_REQUIRED_WEBSITE 41288
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ONE_REQUIRED_CREATE_GOOGLE_KEEP_NOTE 41289
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ANY_REQUIRED_CREATE 41290
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ANY_REQUIRED_WORKSPACE 41291
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_KEEP_NOTE_ONE_REQUIRED_NOTES 41292
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ONE_REQUIRED_CREATE_GOOGLE_FORM 41293
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ANY_REQUIRED_CREATE 41294
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ANY_REQUIRED_WORKSPACE 41295
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CREATE_GOOGLE_FORM_ONE_REQUIRED_SURVEY 41296
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ONE_REQUIRED_CHROME_FEATURES 41297
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ONE_OPTIONAL_MAKE_THE_MOST_OF 41298
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ANY_OPTIONAL_BROWSER 41299
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SEE_CHROME_TIPS_ONE_REQUIRED_NEW_CHROME_FEATURES 41300
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ONE_REQUIRED_CONTROL_MY_GOOGLE_ACCOUNT 41301
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ONE_REQUIRED_GOOGLE_ACCOUNT 41302
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ANY_OPTIONAL_BROWSER 41303
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_ACCOUNT_ONE_REQUIRED_CONTROL 41304
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ONE_REQUIRED_CHANGE_GMAIL_PASSWORD 41305
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ONE_REQUIRED_GOOGLE_ACCOUNT_PASSWORD 41306
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ANY_OPTIONAL_BROWSER 41307
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CHANGE_GOOGLE_PASSWORD_ONE_REQUIRED_CHANGE 41308
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLOSE_INCOGNITO_WINDOWS_ONE_REQUIRED_CLOSE_INCOGNITO_WINDOW 41309
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLOSE_INCOGNITO_WINDOWS_ONE_REQUIRED_DELETE 41310
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CLOSE_INCOGNITO_WINDOWS_ONE_REQUIRED_INCOGNITO_WINDOW 41311
#define IDS_OMNIBOX_PEDAL_SYNONYMS_PLAY_CHROME_DINO_GAME_ONE_REQUIRED_CHROME_DINO 41312
#define IDS_OMNIBOX_PEDAL_SYNONYMS_PLAY_CHROME_DINO_GAME_ONE_REQUIRED_PLAY_CHROME_DINO_GAME 41313
#define IDS_OMNIBOX_PEDAL_SYNONYMS_FIND_MY_PHONE_ONE_REQUIRED_FIND_LOST_PHONE 41314
#define IDS_OMNIBOX_PEDAL_SYNONYMS_FIND_MY_PHONE_ONE_REQUIRED_HELP_ME_LOCATE 41315
#define IDS_OMNIBOX_PEDAL_SYNONYMS_FIND_MY_PHONE_ONE_REQUIRED_LOST_DEVICE 41316
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_PRIVACY_ONE_REQUIRED_CHANGE_GOOGLE_PRIVACY_SETTINGS 41317
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_GOOGLE_PRIVACY_ONE_REQUIRED_MANAGE_GOOGLE_PRIVACY_SETTINGS 41318
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_SETTINGS_ONE_REQUIRED_CHANGE_CHROME_SETTINGS 41319
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_SETTINGS_ONE_OPTIONAL_CONTROL 41320
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_SETTINGS_ONE_REQUIRED_CHROME_BROWSER_SETTINGS 41321
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_DOWNLOADS_ONE_REQUIRED_MANAGE_CHROME_DOWNLOADS 41322
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_DOWNLOADS_ONE_REQUIRED_CONTROL 41323
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_DOWNLOADS_ONE_REQUIRED_CHROME_BROWSER_DOWNLOADS 41324
#define IDS_OMNIBOX_PEDAL_SYNONYMS_VIEW_CHROME_HISTORY_ONE_REQUIRED_SEE_CHROME_HISTORY 41325
#define IDS_OMNIBOX_PEDAL_SYNONYMS_VIEW_CHROME_HISTORY_ONE_REQUIRED_REVISIT 41326
#define IDS_OMNIBOX_PEDAL_SYNONYMS_VIEW_CHROME_HISTORY_ONE_REQUIRED_GOOGLE_CHROME_BROWSING_HISTORY 41327
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SHARE_THIS_PAGE_ONE_REQUIRED_SHARE_THIS_PAGE 41328
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SHARE_THIS_PAGE_ONE_REQUIRED_SHARE_LINK_WITH_QR_CODE 41329
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_ACCESSIBILITY_ONE_REQUIRED_CUSTOMIZE_CHROME_ACCESSIBILITY 41330
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_ACCESSIBILITY_ONE_OPTIONAL_CUSTOMIZE 41331
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_ACCESSIBILITY_ONE_REQUIRED_ACCESSIBILITY_SETTINGS 41332
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_REQUIRED_CHANGE_BROWSER_FONT 41333
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_OPTIONAL_CUSTOMIZE 41334
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_REQUIRED_GOOGLE_CHROME 41335
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_CHROME_FONTS_ONE_REQUIRED_FONT_SIZING 41336
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_THEMES_ONE_REQUIRED_CUSTOMIZE_CHROME_APPEARANCE 41337
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_THEMES_ONE_OPTIONAL_CUSTOMIZE 41338
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROME_THEMES_ONE_REQUIRED_CHROME_BACKGROUNDS 41339
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_REQUIRED_ADD_CUSTOM_SEARCH 41340
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_OPTIONAL_CUSTOMIZE 41341
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_REQUIRED_CUSTOM_SEARCH_ENGINES 41342
#define IDS_OMNIBOX_PEDAL_SYNONYMS_CUSTOMIZE_SEARCH_ENGINES_ONE_OPTIONAL_GOOGLE_CHROME 41343
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROMEOS_ACCESSIBILITY_ONE_REQUIRED_CUSTOMIZE_CHROMEOS_ACCESSIBILITY 41344
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROMEOS_ACCESSIBILITY_ONE_OPTIONAL_CUSTOMIZE 41345
#define IDS_OMNIBOX_PEDAL_SYNONYMS_MANAGE_CHROMEOS_ACCESSIBILITY_ONE_REQUIRED_ACCESSIBILITY_SETTINGS 41346
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_REQUIRED_ALWAYS_OPEN_LINKS_IN_CHROME 41347
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_REQUIRED_HOW_TO_MAKE_CHROME_MY_DEFAULT_BROWSER 41348
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_OPTIONAL_SELECT 41349
#define IDS_OMNIBOX_PEDAL_SYNONYMS_SET_CHROME_AS_DEFAULT_BROWSER_ONE_OPTIONAL_DEFAULT_BROWSER 41350

// ---------------------------------------------------------------------------
// From permission_element_generated_strings.h:

#define IDS_PERMISSION_REQUEST_LAUNCH_af 56640
#define IDS_PERMISSION_REQUEST_CAMERA_af 56641
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_af 56642
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_af 56643
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_af 56644
#define IDS_PERMISSION_REQUEST_INSTALL_af 56645
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_af 56646
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_af 56647
#define IDS_PERMISSION_REQUEST_MICROPHONE_af 56648
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_af 56649
#define IDS_PERMISSION_REQUEST_GEOLOCATION_af 56650
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_af 56651
#define IDS_PERMISSION_REQUEST_USING_LOCATION_af 56652
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_af 56653
#define IDS_PERMISSION_REQUEST_LAUNCH_am 56654
#define IDS_PERMISSION_REQUEST_CAMERA_am 56655
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_am 56656
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_am 56657
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_am 56658
#define IDS_PERMISSION_REQUEST_INSTALL_am 56659
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_am 56660
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_am 56661
#define IDS_PERMISSION_REQUEST_MICROPHONE_am 56662
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_am 56663
#define IDS_PERMISSION_REQUEST_GEOLOCATION_am 56664
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_am 56665
#define IDS_PERMISSION_REQUEST_USING_LOCATION_am 56666
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_am 56667
#define IDS_PERMISSION_REQUEST_LAUNCH_ar 56668
#define IDS_PERMISSION_REQUEST_CAMERA_ar 56669
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ar 56670
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ar 56671
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ar 56672
#define IDS_PERMISSION_REQUEST_INSTALL_ar 56673
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ar 56674
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ar 56675
#define IDS_PERMISSION_REQUEST_MICROPHONE_ar 56676
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ar 56677
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ar 56678
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ar 56679
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ar 56680
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ar 56681
#define IDS_PERMISSION_REQUEST_LAUNCH_as 56682
#define IDS_PERMISSION_REQUEST_CAMERA_as 56683
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_as 56684
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_as 56685
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_as 56686
#define IDS_PERMISSION_REQUEST_INSTALL_as 56687
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_as 56688
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_as 56689
#define IDS_PERMISSION_REQUEST_MICROPHONE_as 56690
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_as 56691
#define IDS_PERMISSION_REQUEST_GEOLOCATION_as 56692
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_as 56693
#define IDS_PERMISSION_REQUEST_USING_LOCATION_as 56694
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_as 56695
#define IDS_PERMISSION_REQUEST_LAUNCH_az 56696
#define IDS_PERMISSION_REQUEST_CAMERA_az 56697
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_az 56698
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_az 56699
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_az 56700
#define IDS_PERMISSION_REQUEST_INSTALL_az 56701
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_az 56702
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_az 56703
#define IDS_PERMISSION_REQUEST_MICROPHONE_az 56704
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_az 56705
#define IDS_PERMISSION_REQUEST_GEOLOCATION_az 56706
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_az 56707
#define IDS_PERMISSION_REQUEST_USING_LOCATION_az 56708
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_az 56709
#define IDS_PERMISSION_REQUEST_LAUNCH_be 56710
#define IDS_PERMISSION_REQUEST_CAMERA_be 56711
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_be 56712
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_be 56713
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_be 56714
#define IDS_PERMISSION_REQUEST_INSTALL_be 56715
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_be 56716
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_be 56717
#define IDS_PERMISSION_REQUEST_MICROPHONE_be 56718
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_be 56719
#define IDS_PERMISSION_REQUEST_GEOLOCATION_be 56720
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_be 56721
#define IDS_PERMISSION_REQUEST_USING_LOCATION_be 56722
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_be 56723
#define IDS_PERMISSION_REQUEST_LAUNCH_bg 56724
#define IDS_PERMISSION_REQUEST_CAMERA_bg 56725
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bg 56726
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_bg 56727
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bg 56728
#define IDS_PERMISSION_REQUEST_INSTALL_bg 56729
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bg 56730
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bg 56731
#define IDS_PERMISSION_REQUEST_MICROPHONE_bg 56732
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bg 56733
#define IDS_PERMISSION_REQUEST_GEOLOCATION_bg 56734
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bg 56735
#define IDS_PERMISSION_REQUEST_USING_LOCATION_bg 56736
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bg 56737
#define IDS_PERMISSION_REQUEST_LAUNCH_bn 56738
#define IDS_PERMISSION_REQUEST_CAMERA_bn 56739
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bn 56740
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_bn 56741
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bn 56742
#define IDS_PERMISSION_REQUEST_INSTALL_bn 56743
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bn 56744
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bn 56745
#define IDS_PERMISSION_REQUEST_MICROPHONE_bn 56746
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bn 56747
#define IDS_PERMISSION_REQUEST_GEOLOCATION_bn 56748
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bn 56749
#define IDS_PERMISSION_REQUEST_USING_LOCATION_bn 56750
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bn 56751
#define IDS_PERMISSION_REQUEST_LAUNCH_bs 56752
#define IDS_PERMISSION_REQUEST_CAMERA_bs 56753
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_bs 56754
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_bs 56755
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_bs 56756
#define IDS_PERMISSION_REQUEST_INSTALL_bs 56757
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_bs 56758
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_bs 56759
#define IDS_PERMISSION_REQUEST_MICROPHONE_bs 56760
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_bs 56761
#define IDS_PERMISSION_REQUEST_GEOLOCATION_bs 56762
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_bs 56763
#define IDS_PERMISSION_REQUEST_USING_LOCATION_bs 56764
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_bs 56765
#define IDS_PERMISSION_REQUEST_LAUNCH_ca 56766
#define IDS_PERMISSION_REQUEST_CAMERA_ca 56767
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ca 56768
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ca 56769
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ca 56770
#define IDS_PERMISSION_REQUEST_INSTALL_ca 56771
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ca 56772
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ca 56773
#define IDS_PERMISSION_REQUEST_MICROPHONE_ca 56774
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ca 56775
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ca 56776
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ca 56777
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ca 56778
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ca 56779
#define IDS_PERMISSION_REQUEST_LAUNCH_cs 56780
#define IDS_PERMISSION_REQUEST_CAMERA_cs 56781
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_cs 56782
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_cs 56783
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_cs 56784
#define IDS_PERMISSION_REQUEST_INSTALL_cs 56785
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_cs 56786
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_cs 56787
#define IDS_PERMISSION_REQUEST_MICROPHONE_cs 56788
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_cs 56789
#define IDS_PERMISSION_REQUEST_GEOLOCATION_cs 56790
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_cs 56791
#define IDS_PERMISSION_REQUEST_USING_LOCATION_cs 56792
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_cs 56793
#define IDS_PERMISSION_REQUEST_LAUNCH_cy 56794
#define IDS_PERMISSION_REQUEST_CAMERA_cy 56795
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_cy 56796
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_cy 56797
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_cy 56798
#define IDS_PERMISSION_REQUEST_INSTALL_cy 56799
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_cy 56800
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_cy 56801
#define IDS_PERMISSION_REQUEST_MICROPHONE_cy 56802
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_cy 56803
#define IDS_PERMISSION_REQUEST_GEOLOCATION_cy 56804
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_cy 56805
#define IDS_PERMISSION_REQUEST_USING_LOCATION_cy 56806
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_cy 56807
#define IDS_PERMISSION_REQUEST_LAUNCH_da 56808
#define IDS_PERMISSION_REQUEST_CAMERA_da 56809
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_da 56810
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_da 56811
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_da 56812
#define IDS_PERMISSION_REQUEST_INSTALL_da 56813
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_da 56814
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_da 56815
#define IDS_PERMISSION_REQUEST_MICROPHONE_da 56816
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_da 56817
#define IDS_PERMISSION_REQUEST_GEOLOCATION_da 56818
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_da 56819
#define IDS_PERMISSION_REQUEST_USING_LOCATION_da 56820
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_da 56821
#define IDS_PERMISSION_REQUEST_LAUNCH_de 56822
#define IDS_PERMISSION_REQUEST_CAMERA_de 56823
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_de 56824
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_de 56825
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_de 56826
#define IDS_PERMISSION_REQUEST_INSTALL_de 56827
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_de 56828
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_de 56829
#define IDS_PERMISSION_REQUEST_MICROPHONE_de 56830
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_de 56831
#define IDS_PERMISSION_REQUEST_GEOLOCATION_de 56832
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_de 56833
#define IDS_PERMISSION_REQUEST_USING_LOCATION_de 56834
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_de 56835
#define IDS_PERMISSION_REQUEST_LAUNCH_el 56836
#define IDS_PERMISSION_REQUEST_CAMERA_el 56837
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_el 56838
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_el 56839
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_el 56840
#define IDS_PERMISSION_REQUEST_INSTALL_el 56841
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_el 56842
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_el 56843
#define IDS_PERMISSION_REQUEST_MICROPHONE_el 56844
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_el 56845
#define IDS_PERMISSION_REQUEST_GEOLOCATION_el 56846
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_el 56847
#define IDS_PERMISSION_REQUEST_USING_LOCATION_el 56848
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_el 56849
#define IDS_PERMISSION_REQUEST_LAUNCH_en_GB 56850
#define IDS_PERMISSION_REQUEST_CAMERA_en_GB 56851
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_en_GB 56852
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_en_GB 56853
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_en_GB 56854
#define IDS_PERMISSION_REQUEST_INSTALL_en_GB 56855
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_en_GB 56856
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_en_GB 56857
#define IDS_PERMISSION_REQUEST_MICROPHONE_en_GB 56858
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_en_GB 56859
#define IDS_PERMISSION_REQUEST_GEOLOCATION_en_GB 56860
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_en_GB 56861
#define IDS_PERMISSION_REQUEST_USING_LOCATION_en_GB 56862
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_en_GB 56863
#define IDS_PERMISSION_REQUEST_LAUNCH_es_419 56864
#define IDS_PERMISSION_REQUEST_CAMERA_es_419 56865
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_es_419 56866
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_es_419 56867
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_es_419 56868
#define IDS_PERMISSION_REQUEST_INSTALL_es_419 56869
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_es_419 56870
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_es_419 56871
#define IDS_PERMISSION_REQUEST_MICROPHONE_es_419 56872
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_es_419 56873
#define IDS_PERMISSION_REQUEST_GEOLOCATION_es_419 56874
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_es_419 56875
#define IDS_PERMISSION_REQUEST_USING_LOCATION_es_419 56876
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_es_419 56877
#define IDS_PERMISSION_REQUEST_LAUNCH_es 56878
#define IDS_PERMISSION_REQUEST_CAMERA_es 56879
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_es 56880
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_es 56881
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_es 56882
#define IDS_PERMISSION_REQUEST_INSTALL_es 56883
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_es 56884
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_es 56885
#define IDS_PERMISSION_REQUEST_MICROPHONE_es 56886
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_es 56887
#define IDS_PERMISSION_REQUEST_GEOLOCATION_es 56888
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_es 56889
#define IDS_PERMISSION_REQUEST_USING_LOCATION_es 56890
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_es 56891
#define IDS_PERMISSION_REQUEST_LAUNCH_et 56892
#define IDS_PERMISSION_REQUEST_CAMERA_et 56893
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_et 56894
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_et 56895
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_et 56896
#define IDS_PERMISSION_REQUEST_INSTALL_et 56897
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_et 56898
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_et 56899
#define IDS_PERMISSION_REQUEST_MICROPHONE_et 56900
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_et 56901
#define IDS_PERMISSION_REQUEST_GEOLOCATION_et 56902
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_et 56903
#define IDS_PERMISSION_REQUEST_USING_LOCATION_et 56904
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_et 56905
#define IDS_PERMISSION_REQUEST_LAUNCH_eu 56906
#define IDS_PERMISSION_REQUEST_CAMERA_eu 56907
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_eu 56908
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_eu 56909
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_eu 56910
#define IDS_PERMISSION_REQUEST_INSTALL_eu 56911
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_eu 56912
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_eu 56913
#define IDS_PERMISSION_REQUEST_MICROPHONE_eu 56914
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_eu 56915
#define IDS_PERMISSION_REQUEST_GEOLOCATION_eu 56916
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_eu 56917
#define IDS_PERMISSION_REQUEST_USING_LOCATION_eu 56918
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_eu 56919
#define IDS_PERMISSION_REQUEST_LAUNCH_fa 56920
#define IDS_PERMISSION_REQUEST_CAMERA_fa 56921
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fa 56922
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fa 56923
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fa 56924
#define IDS_PERMISSION_REQUEST_INSTALL_fa 56925
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fa 56926
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fa 56927
#define IDS_PERMISSION_REQUEST_MICROPHONE_fa 56928
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fa 56929
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fa 56930
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fa 56931
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fa 56932
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fa 56933
#define IDS_PERMISSION_REQUEST_LAUNCH_fi 56934
#define IDS_PERMISSION_REQUEST_CAMERA_fi 56935
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fi 56936
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fi 56937
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fi 56938
#define IDS_PERMISSION_REQUEST_INSTALL_fi 56939
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fi 56940
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fi 56941
#define IDS_PERMISSION_REQUEST_MICROPHONE_fi 56942
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fi 56943
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fi 56944
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fi 56945
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fi 56946
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fi 56947
#define IDS_PERMISSION_REQUEST_LAUNCH_fil 56948
#define IDS_PERMISSION_REQUEST_CAMERA_fil 56949
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fil 56950
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fil 56951
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fil 56952
#define IDS_PERMISSION_REQUEST_INSTALL_fil 56953
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fil 56954
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fil 56955
#define IDS_PERMISSION_REQUEST_MICROPHONE_fil 56956
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fil 56957
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fil 56958
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fil 56959
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fil 56960
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fil 56961
#define IDS_PERMISSION_REQUEST_LAUNCH_fr_CA 56962
#define IDS_PERMISSION_REQUEST_CAMERA_fr_CA 56963
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fr_CA 56964
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fr_CA 56965
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fr_CA 56966
#define IDS_PERMISSION_REQUEST_INSTALL_fr_CA 56967
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fr_CA 56968
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fr_CA 56969
#define IDS_PERMISSION_REQUEST_MICROPHONE_fr_CA 56970
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fr_CA 56971
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fr_CA 56972
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fr_CA 56973
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fr_CA 56974
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fr_CA 56975
#define IDS_PERMISSION_REQUEST_LAUNCH_fr 56976
#define IDS_PERMISSION_REQUEST_CAMERA_fr 56977
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_fr 56978
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_fr 56979
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_fr 56980
#define IDS_PERMISSION_REQUEST_INSTALL_fr 56981
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_fr 56982
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_fr 56983
#define IDS_PERMISSION_REQUEST_MICROPHONE_fr 56984
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_fr 56985
#define IDS_PERMISSION_REQUEST_GEOLOCATION_fr 56986
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_fr 56987
#define IDS_PERMISSION_REQUEST_USING_LOCATION_fr 56988
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_fr 56989
#define IDS_PERMISSION_REQUEST_LAUNCH_gl 56990
#define IDS_PERMISSION_REQUEST_CAMERA_gl 56991
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_gl 56992
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_gl 56993
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_gl 56994
#define IDS_PERMISSION_REQUEST_INSTALL_gl 56995
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_gl 56996
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_gl 56997
#define IDS_PERMISSION_REQUEST_MICROPHONE_gl 56998
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_gl 56999
#define IDS_PERMISSION_REQUEST_GEOLOCATION_gl 57000
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_gl 57001
#define IDS_PERMISSION_REQUEST_USING_LOCATION_gl 57002
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_gl 57003
#define IDS_PERMISSION_REQUEST_LAUNCH_gu 57004
#define IDS_PERMISSION_REQUEST_CAMERA_gu 57005
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_gu 57006
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_gu 57007
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_gu 57008
#define IDS_PERMISSION_REQUEST_INSTALL_gu 57009
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_gu 57010
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_gu 57011
#define IDS_PERMISSION_REQUEST_MICROPHONE_gu 57012
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_gu 57013
#define IDS_PERMISSION_REQUEST_GEOLOCATION_gu 57014
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_gu 57015
#define IDS_PERMISSION_REQUEST_USING_LOCATION_gu 57016
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_gu 57017
#define IDS_PERMISSION_REQUEST_LAUNCH_hi 57018
#define IDS_PERMISSION_REQUEST_CAMERA_hi 57019
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hi 57020
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hi 57021
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hi 57022
#define IDS_PERMISSION_REQUEST_INSTALL_hi 57023
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hi 57024
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hi 57025
#define IDS_PERMISSION_REQUEST_MICROPHONE_hi 57026
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hi 57027
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hi 57028
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hi 57029
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hi 57030
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hi 57031
#define IDS_PERMISSION_REQUEST_LAUNCH_hr 57032
#define IDS_PERMISSION_REQUEST_CAMERA_hr 57033
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hr 57034
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hr 57035
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hr 57036
#define IDS_PERMISSION_REQUEST_INSTALL_hr 57037
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hr 57038
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hr 57039
#define IDS_PERMISSION_REQUEST_MICROPHONE_hr 57040
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hr 57041
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hr 57042
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hr 57043
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hr 57044
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hr 57045
#define IDS_PERMISSION_REQUEST_LAUNCH_hu 57046
#define IDS_PERMISSION_REQUEST_CAMERA_hu 57047
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hu 57048
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hu 57049
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hu 57050
#define IDS_PERMISSION_REQUEST_INSTALL_hu 57051
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hu 57052
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hu 57053
#define IDS_PERMISSION_REQUEST_MICROPHONE_hu 57054
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hu 57055
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hu 57056
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hu 57057
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hu 57058
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hu 57059
#define IDS_PERMISSION_REQUEST_LAUNCH_hy 57060
#define IDS_PERMISSION_REQUEST_CAMERA_hy 57061
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_hy 57062
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_hy 57063
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_hy 57064
#define IDS_PERMISSION_REQUEST_INSTALL_hy 57065
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_hy 57066
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_hy 57067
#define IDS_PERMISSION_REQUEST_MICROPHONE_hy 57068
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_hy 57069
#define IDS_PERMISSION_REQUEST_GEOLOCATION_hy 57070
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_hy 57071
#define IDS_PERMISSION_REQUEST_USING_LOCATION_hy 57072
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_hy 57073
#define IDS_PERMISSION_REQUEST_LAUNCH_id 57074
#define IDS_PERMISSION_REQUEST_CAMERA_id 57075
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_id 57076
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_id 57077
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_id 57078
#define IDS_PERMISSION_REQUEST_INSTALL_id 57079
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_id 57080
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_id 57081
#define IDS_PERMISSION_REQUEST_MICROPHONE_id 57082
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_id 57083
#define IDS_PERMISSION_REQUEST_GEOLOCATION_id 57084
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_id 57085
#define IDS_PERMISSION_REQUEST_USING_LOCATION_id 57086
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_id 57087
#define IDS_PERMISSION_REQUEST_LAUNCH_is 57088
#define IDS_PERMISSION_REQUEST_CAMERA_is 57089
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_is 57090
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_is 57091
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_is 57092
#define IDS_PERMISSION_REQUEST_INSTALL_is 57093
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_is 57094
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_is 57095
#define IDS_PERMISSION_REQUEST_MICROPHONE_is 57096
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_is 57097
#define IDS_PERMISSION_REQUEST_GEOLOCATION_is 57098
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_is 57099
#define IDS_PERMISSION_REQUEST_USING_LOCATION_is 57100
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_is 57101
#define IDS_PERMISSION_REQUEST_LAUNCH_it 57102
#define IDS_PERMISSION_REQUEST_CAMERA_it 57103
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_it 57104
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_it 57105
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_it 57106
#define IDS_PERMISSION_REQUEST_INSTALL_it 57107
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_it 57108
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_it 57109
#define IDS_PERMISSION_REQUEST_MICROPHONE_it 57110
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_it 57111
#define IDS_PERMISSION_REQUEST_GEOLOCATION_it 57112
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_it 57113
#define IDS_PERMISSION_REQUEST_USING_LOCATION_it 57114
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_it 57115
#define IDS_PERMISSION_REQUEST_LAUNCH_iw 57116
#define IDS_PERMISSION_REQUEST_CAMERA_iw 57117
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_iw 57118
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_iw 57119
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_iw 57120
#define IDS_PERMISSION_REQUEST_INSTALL_iw 57121
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_iw 57122
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_iw 57123
#define IDS_PERMISSION_REQUEST_MICROPHONE_iw 57124
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_iw 57125
#define IDS_PERMISSION_REQUEST_GEOLOCATION_iw 57126
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_iw 57127
#define IDS_PERMISSION_REQUEST_USING_LOCATION_iw 57128
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_iw 57129
#define IDS_PERMISSION_REQUEST_LAUNCH_ja 57130
#define IDS_PERMISSION_REQUEST_CAMERA_ja 57131
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ja 57132
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ja 57133
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ja 57134
#define IDS_PERMISSION_REQUEST_INSTALL_ja 57135
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ja 57136
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ja 57137
#define IDS_PERMISSION_REQUEST_MICROPHONE_ja 57138
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ja 57139
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ja 57140
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ja 57141
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ja 57142
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ja 57143
#define IDS_PERMISSION_REQUEST_LAUNCH_ka 57144
#define IDS_PERMISSION_REQUEST_CAMERA_ka 57145
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ka 57146
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ka 57147
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ka 57148
#define IDS_PERMISSION_REQUEST_INSTALL_ka 57149
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ka 57150
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ka 57151
#define IDS_PERMISSION_REQUEST_MICROPHONE_ka 57152
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ka 57153
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ka 57154
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ka 57155
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ka 57156
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ka 57157
#define IDS_PERMISSION_REQUEST_LAUNCH_kk 57158
#define IDS_PERMISSION_REQUEST_CAMERA_kk 57159
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_kk 57160
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_kk 57161
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_kk 57162
#define IDS_PERMISSION_REQUEST_INSTALL_kk 57163
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_kk 57164
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_kk 57165
#define IDS_PERMISSION_REQUEST_MICROPHONE_kk 57166
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_kk 57167
#define IDS_PERMISSION_REQUEST_GEOLOCATION_kk 57168
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_kk 57169
#define IDS_PERMISSION_REQUEST_USING_LOCATION_kk 57170
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_kk 57171
#define IDS_PERMISSION_REQUEST_LAUNCH_km 57172
#define IDS_PERMISSION_REQUEST_CAMERA_km 57173
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_km 57174
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_km 57175
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_km 57176
#define IDS_PERMISSION_REQUEST_INSTALL_km 57177
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_km 57178
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_km 57179
#define IDS_PERMISSION_REQUEST_MICROPHONE_km 57180
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_km 57181
#define IDS_PERMISSION_REQUEST_GEOLOCATION_km 57182
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_km 57183
#define IDS_PERMISSION_REQUEST_USING_LOCATION_km 57184
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_km 57185
#define IDS_PERMISSION_REQUEST_LAUNCH_kn 57186
#define IDS_PERMISSION_REQUEST_CAMERA_kn 57187
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_kn 57188
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_kn 57189
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_kn 57190
#define IDS_PERMISSION_REQUEST_INSTALL_kn 57191
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_kn 57192
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_kn 57193
#define IDS_PERMISSION_REQUEST_MICROPHONE_kn 57194
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_kn 57195
#define IDS_PERMISSION_REQUEST_GEOLOCATION_kn 57196
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_kn 57197
#define IDS_PERMISSION_REQUEST_USING_LOCATION_kn 57198
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_kn 57199
#define IDS_PERMISSION_REQUEST_LAUNCH_ko 57200
#define IDS_PERMISSION_REQUEST_CAMERA_ko 57201
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ko 57202
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ko 57203
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ko 57204
#define IDS_PERMISSION_REQUEST_INSTALL_ko 57205
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ko 57206
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ko 57207
#define IDS_PERMISSION_REQUEST_MICROPHONE_ko 57208
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ko 57209
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ko 57210
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ko 57211
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ko 57212
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ko 57213
#define IDS_PERMISSION_REQUEST_LAUNCH_ky 57214
#define IDS_PERMISSION_REQUEST_CAMERA_ky 57215
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ky 57216
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ky 57217
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ky 57218
#define IDS_PERMISSION_REQUEST_INSTALL_ky 57219
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ky 57220
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ky 57221
#define IDS_PERMISSION_REQUEST_MICROPHONE_ky 57222
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ky 57223
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ky 57224
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ky 57225
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ky 57226
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ky 57227
#define IDS_PERMISSION_REQUEST_LAUNCH_lo 57228
#define IDS_PERMISSION_REQUEST_CAMERA_lo 57229
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lo 57230
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_lo 57231
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lo 57232
#define IDS_PERMISSION_REQUEST_INSTALL_lo 57233
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lo 57234
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lo 57235
#define IDS_PERMISSION_REQUEST_MICROPHONE_lo 57236
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lo 57237
#define IDS_PERMISSION_REQUEST_GEOLOCATION_lo 57238
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lo 57239
#define IDS_PERMISSION_REQUEST_USING_LOCATION_lo 57240
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lo 57241
#define IDS_PERMISSION_REQUEST_LAUNCH_lt 57242
#define IDS_PERMISSION_REQUEST_CAMERA_lt 57243
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lt 57244
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_lt 57245
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lt 57246
#define IDS_PERMISSION_REQUEST_INSTALL_lt 57247
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lt 57248
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lt 57249
#define IDS_PERMISSION_REQUEST_MICROPHONE_lt 57250
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lt 57251
#define IDS_PERMISSION_REQUEST_GEOLOCATION_lt 57252
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lt 57253
#define IDS_PERMISSION_REQUEST_USING_LOCATION_lt 57254
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lt 57255
#define IDS_PERMISSION_REQUEST_LAUNCH_lv 57256
#define IDS_PERMISSION_REQUEST_CAMERA_lv 57257
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_lv 57258
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_lv 57259
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_lv 57260
#define IDS_PERMISSION_REQUEST_INSTALL_lv 57261
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_lv 57262
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_lv 57263
#define IDS_PERMISSION_REQUEST_MICROPHONE_lv 57264
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_lv 57265
#define IDS_PERMISSION_REQUEST_GEOLOCATION_lv 57266
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_lv 57267
#define IDS_PERMISSION_REQUEST_USING_LOCATION_lv 57268
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_lv 57269
#define IDS_PERMISSION_REQUEST_LAUNCH_mk 57270
#define IDS_PERMISSION_REQUEST_CAMERA_mk 57271
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mk 57272
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_mk 57273
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mk 57274
#define IDS_PERMISSION_REQUEST_INSTALL_mk 57275
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mk 57276
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mk 57277
#define IDS_PERMISSION_REQUEST_MICROPHONE_mk 57278
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mk 57279
#define IDS_PERMISSION_REQUEST_GEOLOCATION_mk 57280
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mk 57281
#define IDS_PERMISSION_REQUEST_USING_LOCATION_mk 57282
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mk 57283
#define IDS_PERMISSION_REQUEST_LAUNCH_ml 57284
#define IDS_PERMISSION_REQUEST_CAMERA_ml 57285
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ml 57286
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ml 57287
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ml 57288
#define IDS_PERMISSION_REQUEST_INSTALL_ml 57289
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ml 57290
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ml 57291
#define IDS_PERMISSION_REQUEST_MICROPHONE_ml 57292
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ml 57293
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ml 57294
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ml 57295
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ml 57296
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ml 57297
#define IDS_PERMISSION_REQUEST_LAUNCH_mn 57298
#define IDS_PERMISSION_REQUEST_CAMERA_mn 57299
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mn 57300
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_mn 57301
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mn 57302
#define IDS_PERMISSION_REQUEST_INSTALL_mn 57303
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mn 57304
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mn 57305
#define IDS_PERMISSION_REQUEST_MICROPHONE_mn 57306
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mn 57307
#define IDS_PERMISSION_REQUEST_GEOLOCATION_mn 57308
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mn 57309
#define IDS_PERMISSION_REQUEST_USING_LOCATION_mn 57310
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mn 57311
#define IDS_PERMISSION_REQUEST_LAUNCH_mr 57312
#define IDS_PERMISSION_REQUEST_CAMERA_mr 57313
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_mr 57314
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_mr 57315
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_mr 57316
#define IDS_PERMISSION_REQUEST_INSTALL_mr 57317
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_mr 57318
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_mr 57319
#define IDS_PERMISSION_REQUEST_MICROPHONE_mr 57320
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_mr 57321
#define IDS_PERMISSION_REQUEST_GEOLOCATION_mr 57322
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_mr 57323
#define IDS_PERMISSION_REQUEST_USING_LOCATION_mr 57324
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_mr 57325
#define IDS_PERMISSION_REQUEST_LAUNCH_ms 57326
#define IDS_PERMISSION_REQUEST_CAMERA_ms 57327
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ms 57328
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ms 57329
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ms 57330
#define IDS_PERMISSION_REQUEST_INSTALL_ms 57331
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ms 57332
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ms 57333
#define IDS_PERMISSION_REQUEST_MICROPHONE_ms 57334
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ms 57335
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ms 57336
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ms 57337
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ms 57338
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ms 57339
#define IDS_PERMISSION_REQUEST_LAUNCH_my 57340
#define IDS_PERMISSION_REQUEST_CAMERA_my 57341
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_my 57342
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_my 57343
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_my 57344
#define IDS_PERMISSION_REQUEST_INSTALL_my 57345
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_my 57346
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_my 57347
#define IDS_PERMISSION_REQUEST_MICROPHONE_my 57348
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_my 57349
#define IDS_PERMISSION_REQUEST_GEOLOCATION_my 57350
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_my 57351
#define IDS_PERMISSION_REQUEST_USING_LOCATION_my 57352
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_my 57353
#define IDS_PERMISSION_REQUEST_LAUNCH_ne 57354
#define IDS_PERMISSION_REQUEST_CAMERA_ne 57355
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ne 57356
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ne 57357
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ne 57358
#define IDS_PERMISSION_REQUEST_INSTALL_ne 57359
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ne 57360
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ne 57361
#define IDS_PERMISSION_REQUEST_MICROPHONE_ne 57362
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ne 57363
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ne 57364
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ne 57365
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ne 57366
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ne 57367
#define IDS_PERMISSION_REQUEST_LAUNCH_nl 57368
#define IDS_PERMISSION_REQUEST_CAMERA_nl 57369
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_nl 57370
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_nl 57371
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_nl 57372
#define IDS_PERMISSION_REQUEST_INSTALL_nl 57373
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_nl 57374
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_nl 57375
#define IDS_PERMISSION_REQUEST_MICROPHONE_nl 57376
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_nl 57377
#define IDS_PERMISSION_REQUEST_GEOLOCATION_nl 57378
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_nl 57379
#define IDS_PERMISSION_REQUEST_USING_LOCATION_nl 57380
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_nl 57381
#define IDS_PERMISSION_REQUEST_LAUNCH_no 57382
#define IDS_PERMISSION_REQUEST_CAMERA_no 57383
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_no 57384
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_no 57385
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_no 57386
#define IDS_PERMISSION_REQUEST_INSTALL_no 57387
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_no 57388
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_no 57389
#define IDS_PERMISSION_REQUEST_MICROPHONE_no 57390
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_no 57391
#define IDS_PERMISSION_REQUEST_GEOLOCATION_no 57392
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_no 57393
#define IDS_PERMISSION_REQUEST_USING_LOCATION_no 57394
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_no 57395
#define IDS_PERMISSION_REQUEST_LAUNCH_or 57396
#define IDS_PERMISSION_REQUEST_CAMERA_or 57397
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_or 57398
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_or 57399
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_or 57400
#define IDS_PERMISSION_REQUEST_INSTALL_or 57401
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_or 57402
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_or 57403
#define IDS_PERMISSION_REQUEST_MICROPHONE_or 57404
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_or 57405
#define IDS_PERMISSION_REQUEST_GEOLOCATION_or 57406
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_or 57407
#define IDS_PERMISSION_REQUEST_USING_LOCATION_or 57408
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_or 57409
#define IDS_PERMISSION_REQUEST_LAUNCH_pa 57410
#define IDS_PERMISSION_REQUEST_CAMERA_pa 57411
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pa 57412
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pa 57413
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pa 57414
#define IDS_PERMISSION_REQUEST_INSTALL_pa 57415
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pa 57416
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pa 57417
#define IDS_PERMISSION_REQUEST_MICROPHONE_pa 57418
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pa 57419
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pa 57420
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pa 57421
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pa 57422
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pa 57423
#define IDS_PERMISSION_REQUEST_LAUNCH_pl 57424
#define IDS_PERMISSION_REQUEST_CAMERA_pl 57425
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pl 57426
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pl 57427
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pl 57428
#define IDS_PERMISSION_REQUEST_INSTALL_pl 57429
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pl 57430
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pl 57431
#define IDS_PERMISSION_REQUEST_MICROPHONE_pl 57432
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pl 57433
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pl 57434
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pl 57435
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pl 57436
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pl 57437
#define IDS_PERMISSION_REQUEST_LAUNCH_pt_BR 57438
#define IDS_PERMISSION_REQUEST_CAMERA_pt_BR 57439
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pt_BR 57440
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pt_BR 57441
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pt_BR 57442
#define IDS_PERMISSION_REQUEST_INSTALL_pt_BR 57443
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pt_BR 57444
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pt_BR 57445
#define IDS_PERMISSION_REQUEST_MICROPHONE_pt_BR 57446
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pt_BR 57447
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pt_BR 57448
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pt_BR 57449
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pt_BR 57450
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pt_BR 57451
#define IDS_PERMISSION_REQUEST_LAUNCH_pt_PT 57452
#define IDS_PERMISSION_REQUEST_CAMERA_pt_PT 57453
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_pt_PT 57454
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_pt_PT 57455
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_pt_PT 57456
#define IDS_PERMISSION_REQUEST_INSTALL_pt_PT 57457
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_pt_PT 57458
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_pt_PT 57459
#define IDS_PERMISSION_REQUEST_MICROPHONE_pt_PT 57460
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_pt_PT 57461
#define IDS_PERMISSION_REQUEST_GEOLOCATION_pt_PT 57462
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_pt_PT 57463
#define IDS_PERMISSION_REQUEST_USING_LOCATION_pt_PT 57464
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_pt_PT 57465
#define IDS_PERMISSION_REQUEST_LAUNCH_ro 57466
#define IDS_PERMISSION_REQUEST_CAMERA_ro 57467
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ro 57468
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ro 57469
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ro 57470
#define IDS_PERMISSION_REQUEST_INSTALL_ro 57471
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ro 57472
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ro 57473
#define IDS_PERMISSION_REQUEST_MICROPHONE_ro 57474
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ro 57475
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ro 57476
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ro 57477
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ro 57478
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ro 57479
#define IDS_PERMISSION_REQUEST_LAUNCH_ru 57480
#define IDS_PERMISSION_REQUEST_CAMERA_ru 57481
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ru 57482
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ru 57483
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ru 57484
#define IDS_PERMISSION_REQUEST_INSTALL_ru 57485
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ru 57486
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ru 57487
#define IDS_PERMISSION_REQUEST_MICROPHONE_ru 57488
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ru 57489
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ru 57490
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ru 57491
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ru 57492
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ru 57493
#define IDS_PERMISSION_REQUEST_LAUNCH_si 57494
#define IDS_PERMISSION_REQUEST_CAMERA_si 57495
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_si 57496
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_si 57497
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_si 57498
#define IDS_PERMISSION_REQUEST_INSTALL_si 57499
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_si 57500
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_si 57501
#define IDS_PERMISSION_REQUEST_MICROPHONE_si 57502
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_si 57503
#define IDS_PERMISSION_REQUEST_GEOLOCATION_si 57504
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_si 57505
#define IDS_PERMISSION_REQUEST_USING_LOCATION_si 57506
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_si 57507
#define IDS_PERMISSION_REQUEST_LAUNCH_sk 57508
#define IDS_PERMISSION_REQUEST_CAMERA_sk 57509
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sk 57510
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sk 57511
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sk 57512
#define IDS_PERMISSION_REQUEST_INSTALL_sk 57513
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sk 57514
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sk 57515
#define IDS_PERMISSION_REQUEST_MICROPHONE_sk 57516
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sk 57517
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sk 57518
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sk 57519
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sk 57520
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sk 57521
#define IDS_PERMISSION_REQUEST_LAUNCH_sl 57522
#define IDS_PERMISSION_REQUEST_CAMERA_sl 57523
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sl 57524
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sl 57525
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sl 57526
#define IDS_PERMISSION_REQUEST_INSTALL_sl 57527
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sl 57528
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sl 57529
#define IDS_PERMISSION_REQUEST_MICROPHONE_sl 57530
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sl 57531
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sl 57532
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sl 57533
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sl 57534
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sl 57535
#define IDS_PERMISSION_REQUEST_LAUNCH_sq 57536
#define IDS_PERMISSION_REQUEST_CAMERA_sq 57537
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sq 57538
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sq 57539
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sq 57540
#define IDS_PERMISSION_REQUEST_INSTALL_sq 57541
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sq 57542
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sq 57543
#define IDS_PERMISSION_REQUEST_MICROPHONE_sq 57544
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sq 57545
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sq 57546
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sq 57547
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sq 57548
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sq 57549
#define IDS_PERMISSION_REQUEST_LAUNCH_sr_Latn 57550
#define IDS_PERMISSION_REQUEST_CAMERA_sr_Latn 57551
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sr_Latn 57552
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sr_Latn 57553
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sr_Latn 57554
#define IDS_PERMISSION_REQUEST_INSTALL_sr_Latn 57555
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sr_Latn 57556
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sr_Latn 57557
#define IDS_PERMISSION_REQUEST_MICROPHONE_sr_Latn 57558
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sr_Latn 57559
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sr_Latn 57560
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sr_Latn 57561
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sr_Latn 57562
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sr_Latn 57563
#define IDS_PERMISSION_REQUEST_LAUNCH_sr 57564
#define IDS_PERMISSION_REQUEST_CAMERA_sr 57565
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sr 57566
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sr 57567
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sr 57568
#define IDS_PERMISSION_REQUEST_INSTALL_sr 57569
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sr 57570
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sr 57571
#define IDS_PERMISSION_REQUEST_MICROPHONE_sr 57572
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sr 57573
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sr 57574
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sr 57575
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sr 57576
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sr 57577
#define IDS_PERMISSION_REQUEST_LAUNCH_sv 57578
#define IDS_PERMISSION_REQUEST_CAMERA_sv 57579
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sv 57580
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sv 57581
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sv 57582
#define IDS_PERMISSION_REQUEST_INSTALL_sv 57583
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sv 57584
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sv 57585
#define IDS_PERMISSION_REQUEST_MICROPHONE_sv 57586
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sv 57587
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sv 57588
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sv 57589
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sv 57590
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sv 57591
#define IDS_PERMISSION_REQUEST_LAUNCH_sw 57592
#define IDS_PERMISSION_REQUEST_CAMERA_sw 57593
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_sw 57594
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_sw 57595
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_sw 57596
#define IDS_PERMISSION_REQUEST_INSTALL_sw 57597
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_sw 57598
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_sw 57599
#define IDS_PERMISSION_REQUEST_MICROPHONE_sw 57600
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_sw 57601
#define IDS_PERMISSION_REQUEST_GEOLOCATION_sw 57602
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_sw 57603
#define IDS_PERMISSION_REQUEST_USING_LOCATION_sw 57604
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_sw 57605
#define IDS_PERMISSION_REQUEST_LAUNCH_ta 57606
#define IDS_PERMISSION_REQUEST_CAMERA_ta 57607
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ta 57608
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ta 57609
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ta 57610
#define IDS_PERMISSION_REQUEST_INSTALL_ta 57611
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ta 57612
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ta 57613
#define IDS_PERMISSION_REQUEST_MICROPHONE_ta 57614
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ta 57615
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ta 57616
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ta 57617
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ta 57618
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ta 57619
#define IDS_PERMISSION_REQUEST_LAUNCH_te 57620
#define IDS_PERMISSION_REQUEST_CAMERA_te 57621
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_te 57622
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_te 57623
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_te 57624
#define IDS_PERMISSION_REQUEST_INSTALL_te 57625
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_te 57626
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_te 57627
#define IDS_PERMISSION_REQUEST_MICROPHONE_te 57628
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_te 57629
#define IDS_PERMISSION_REQUEST_GEOLOCATION_te 57630
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_te 57631
#define IDS_PERMISSION_REQUEST_USING_LOCATION_te 57632
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_te 57633
#define IDS_PERMISSION_REQUEST_LAUNCH_th 57634
#define IDS_PERMISSION_REQUEST_CAMERA_th 57635
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_th 57636
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_th 57637
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_th 57638
#define IDS_PERMISSION_REQUEST_INSTALL_th 57639
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_th 57640
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_th 57641
#define IDS_PERMISSION_REQUEST_MICROPHONE_th 57642
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_th 57643
#define IDS_PERMISSION_REQUEST_GEOLOCATION_th 57644
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_th 57645
#define IDS_PERMISSION_REQUEST_USING_LOCATION_th 57646
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_th 57647
#define IDS_PERMISSION_REQUEST_LAUNCH_tr 57648
#define IDS_PERMISSION_REQUEST_CAMERA_tr 57649
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_tr 57650
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_tr 57651
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_tr 57652
#define IDS_PERMISSION_REQUEST_INSTALL_tr 57653
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_tr 57654
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_tr 57655
#define IDS_PERMISSION_REQUEST_MICROPHONE_tr 57656
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_tr 57657
#define IDS_PERMISSION_REQUEST_GEOLOCATION_tr 57658
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_tr 57659
#define IDS_PERMISSION_REQUEST_USING_LOCATION_tr 57660
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_tr 57661
#define IDS_PERMISSION_REQUEST_LAUNCH_uk 57662
#define IDS_PERMISSION_REQUEST_CAMERA_uk 57663
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_uk 57664
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_uk 57665
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_uk 57666
#define IDS_PERMISSION_REQUEST_INSTALL_uk 57667
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_uk 57668
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_uk 57669
#define IDS_PERMISSION_REQUEST_MICROPHONE_uk 57670
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_uk 57671
#define IDS_PERMISSION_REQUEST_GEOLOCATION_uk 57672
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_uk 57673
#define IDS_PERMISSION_REQUEST_USING_LOCATION_uk 57674
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_uk 57675
#define IDS_PERMISSION_REQUEST_LAUNCH_ur 57676
#define IDS_PERMISSION_REQUEST_CAMERA_ur 57677
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_ur 57678
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_ur 57679
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_ur 57680
#define IDS_PERMISSION_REQUEST_INSTALL_ur 57681
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_ur 57682
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_ur 57683
#define IDS_PERMISSION_REQUEST_MICROPHONE_ur 57684
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_ur 57685
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ur 57686
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ur 57687
#define IDS_PERMISSION_REQUEST_USING_LOCATION_ur 57688
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ur 57689
#define IDS_PERMISSION_REQUEST_LAUNCH_uz 57690
#define IDS_PERMISSION_REQUEST_CAMERA_uz 57691
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_uz 57692
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_uz 57693
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_uz 57694
#define IDS_PERMISSION_REQUEST_INSTALL_uz 57695
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_uz 57696
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_uz 57697
#define IDS_PERMISSION_REQUEST_MICROPHONE_uz 57698
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_uz 57699
#define IDS_PERMISSION_REQUEST_GEOLOCATION_uz 57700
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_uz 57701
#define IDS_PERMISSION_REQUEST_USING_LOCATION_uz 57702
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_uz 57703
#define IDS_PERMISSION_REQUEST_LAUNCH_vi 57704
#define IDS_PERMISSION_REQUEST_CAMERA_vi 57705
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_vi 57706
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_vi 57707
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_vi 57708
#define IDS_PERMISSION_REQUEST_INSTALL_vi 57709
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_vi 57710
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_vi 57711
#define IDS_PERMISSION_REQUEST_MICROPHONE_vi 57712
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_vi 57713
#define IDS_PERMISSION_REQUEST_GEOLOCATION_vi 57714
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_vi 57715
#define IDS_PERMISSION_REQUEST_USING_LOCATION_vi 57716
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_vi 57717
#define IDS_PERMISSION_REQUEST_LAUNCH_zh_CN 57718
#define IDS_PERMISSION_REQUEST_CAMERA_zh_CN 57719
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_CN 57720
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zh_CN 57721
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_CN 57722
#define IDS_PERMISSION_REQUEST_INSTALL_zh_CN 57723
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_CN 57724
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_CN 57725
#define IDS_PERMISSION_REQUEST_MICROPHONE_zh_CN 57726
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_CN 57727
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zh_CN 57728
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_CN 57729
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zh_CN 57730
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_CN 57731
#define IDS_PERMISSION_REQUEST_LAUNCH_zh_HK 57732
#define IDS_PERMISSION_REQUEST_CAMERA_zh_HK 57733
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_HK 57734
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zh_HK 57735
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_HK 57736
#define IDS_PERMISSION_REQUEST_INSTALL_zh_HK 57737
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_HK 57738
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_HK 57739
#define IDS_PERMISSION_REQUEST_MICROPHONE_zh_HK 57740
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_HK 57741
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zh_HK 57742
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_HK 57743
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zh_HK 57744
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_HK 57745
#define IDS_PERMISSION_REQUEST_LAUNCH_zh_TW 57746
#define IDS_PERMISSION_REQUEST_CAMERA_zh_TW 57747
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zh_TW 57748
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zh_TW 57749
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zh_TW 57750
#define IDS_PERMISSION_REQUEST_INSTALL_zh_TW 57751
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zh_TW 57752
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zh_TW 57753
#define IDS_PERMISSION_REQUEST_MICROPHONE_zh_TW 57754
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zh_TW 57755
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zh_TW 57756
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zh_TW 57757
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zh_TW 57758
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zh_TW 57759
#define IDS_PERMISSION_REQUEST_LAUNCH_zu 57760
#define IDS_PERMISSION_REQUEST_CAMERA_zu 57761
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED_zu 57762
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST_zu 57763
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED_zu 57764
#define IDS_PERMISSION_REQUEST_INSTALL_zu 57765
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED_zu 57766
#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED_zu 57767
#define IDS_PERMISSION_REQUEST_MICROPHONE_zu 57768
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED_zu 57769
#define IDS_PERMISSION_REQUEST_GEOLOCATION_zu 57770
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_zu 57771
#define IDS_PERMISSION_REQUEST_USING_LOCATION_zu 57772
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_zu 57773

// ---------------------------------------------------------------------------
// From permission_element_strings.h:

#define IDS_PERMISSION_REQUEST_CAMERA_ALLOWED 46950
#define IDS_PERMISSION_REQUEST_CAMERA 46951
#define IDS_PERMISSION_REQUEST_MICROPHONE_ALLOWED 46952
#define IDS_PERMISSION_REQUEST_MICROPHONE 46953
#define IDS_PERMISSION_REQUEST_GEOLOCATION_ALLOWED 46954
#define IDS_PERMISSION_REQUEST_GEOLOCATION 46955
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE_ALLOWED 46956
#define IDS_PERMISSION_REQUEST_CAMERA_MICROPHONE 46957
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION_ALLOWED 46958
#define IDS_PERMISSION_REQUEST_PRECISE_GEOLOCATION 46959
#define IDS_PERMISSION_REQUEST_USING_LOCATION 46960
#define IDS_PERMISSION_REQUEST_INSTALL 46961
#define IDS_PERMISSION_REQUEST_INSTALL_WITH_HOST 46962
#define IDS_PERMISSION_REQUEST_LAUNCH 46963

// ---------------------------------------------------------------------------
// From platform_locale_settings.h:

#define IDS_STANDARD_FONT_FAMILY 16100
#define IDS_FIXED_FONT_FAMILY 16101
#define IDS_SERIF_FONT_FAMILY 16102
#define IDS_SANS_SERIF_FONT_FAMILY 16103
#define IDS_NTP_FONT_FAMILY 16104
#define IDS_CURSIVE_FONT_FAMILY 16105
#define IDS_FANTASY_FONT_FAMILY 16106
#define IDS_MATH_FONT_FAMILY 16107
#define IDS_FIXED_FONT_FAMILY_JAPANESE 16108
#define IDS_STANDARD_FONT_FAMILY_JAPANESE 16109
#define IDS_SERIF_FONT_FAMILY_JAPANESE 16110
#define IDS_SANS_SERIF_FONT_FAMILY_JAPANESE 16111
#define IDS_STANDARD_FONT_FAMILY_KOREAN 16112
#define IDS_SERIF_FONT_FAMILY_KOREAN 16113
#define IDS_SANS_SERIF_FONT_FAMILY_KOREAN 16114
#define IDS_STANDARD_FONT_FAMILY_SIMPLIFIED_HAN 16115
#define IDS_SERIF_FONT_FAMILY_SIMPLIFIED_HAN 16116
#define IDS_SANS_SERIF_FONT_FAMILY_SIMPLIFIED_HAN 16117
#define IDS_STANDARD_FONT_FAMILY_TRADITIONAL_HAN 16118
#define IDS_SERIF_FONT_FAMILY_TRADITIONAL_HAN 16119
#define IDS_SANS_SERIF_FONT_FAMILY_TRADITIONAL_HAN 16120
#define IDS_STANDARD_FONT_FAMILY_DEVANAGARI 16121
#define IDS_FIXED_FONT_FAMILY_DEVANAGARI 16122
#define IDS_SERIF_FONT_FAMILY_DEVANAGARI 16123
#define IDS_SANS_SERIF_FONT_FAMILY_DEVANAGARI 16124
#define IDS_MINIMUM_FONT_SIZE 16125
#define IDS_MINIMUM_LOGICAL_FONT_SIZE 16126

// ---------------------------------------------------------------------------
// From services_strings.h:

#define IDS_PROXY_RESOLVER_DISPLAY_NAME 46770
#define IDS_WINDOWS_SYSTEM_PROXY_RESOLVER_DISPLAY_NAME 46771
#define IDS_PDF_OCR_RESULT_BEGIN 46772
#define IDS_PDF_OCR_RESULT_END 46773

// ---------------------------------------------------------------------------
// From ui_strings.h:

#define IDS_TIME_SECS 50720
#define IDS_TIME_LONG_SECS 50721
#define IDS_TIME_LONG_SECS_2ND 50722
#define IDS_TIME_MINS 50723
#define IDS_TIME_LONG_MINS 50724
#define IDS_TIME_LONG_MINS_1ST 50725
#define IDS_TIME_LONG_MINS_2ND 50726
#define IDS_TIME_HOURS 50727
#define IDS_TIME_HOURS_1ST 50728
#define IDS_TIME_HOURS_2ND 50729
#define IDS_TIME_DAYS 50730
#define IDS_TIME_DAYS_1ST 50731
#define IDS_TIME_MONTHS 50732
#define IDS_TIME_YEARS 50733
#define IDS_TIME_REMAINING_SECS 50734
#define IDS_TIME_REMAINING_LONG_SECS 50735
#define IDS_TIME_REMAINING_MINS 50736
#define IDS_TIME_REMAINING_LONG_MINS 50737
#define IDS_TIME_REMAINING_HOURS 50738
#define IDS_TIME_REMAINING_DAYS 50739
#define IDS_TIME_REMAINING_MONTHS 50740
#define IDS_TIME_REMAINING_YEARS 50741
#define IDS_TIME_ELAPSED_SECS 50742
#define IDS_TIME_ELAPSED_LONG_SECS 50743
#define IDS_TIME_ELAPSED_MINS 50744
#define IDS_TIME_ELAPSED_LONG_MINS 50745
#define IDS_TIME_ELAPSED_HOURS 50746
#define IDS_TIME_ELAPSED_DAYS 50747
#define IDS_TIME_ELAPSED_MONTHS 50748
#define IDS_TIME_ELAPSED_YEARS 50749
#define IDS_TIME_TITLE_CASE_ELAPSED_LONG_SECS 50750
#define IDS_TIME_TITLE_CASE_ELAPSED_LONG_MINS 50751
#define IDS_TIME_TITLE_CASE_ELAPSED_HOURS 50752
#define IDS_TIME_TITLE_CASE_ELAPSED_DAYS 50753
#define IDS_TIME_TITLE_CASE_ELAPSED_MONTHS 50754
#define IDS_TIME_TITLE_CASE_ELAPSED_YEARS 50755
#define IDS_PAST_TIME_TODAY 50756
#define IDS_PAST_TIME_YESTERDAY 50757
#define IDS_TIME_TOMORROW 50758
#define IDS_APP_MENU_EMPTY_SUBMENU 50759
#define IDS_APP_MENU_AX_ANNOUNCE_EMPTY_SUBMENU 50760
#define IDS_CLIPBOARD_MENU_HTML 50761
#define IDS_CLIPBOARD_MENU_IMAGE 50762
#define IDS_CLIPBOARD_MENU_RTF_CONTENT 50763
#define IDS_CLIPBOARD_MENU_WEB_SMART_PASTE 50764
#define IDS_CLIPBOARD_MENU_CLIPBOARD 50765
#define IDS_CLIPBOARD_MENU_DELETE_ALL 50766
#define IDS_EXTENSION_PINNED 50767
#define IDS_EXTENSION_UNPINNED 50768
#define IDS_NEW_BADGE 50769
#define IDS_NEW_BADGE_SCREEN_READER_MESSAGE 50770
#define IDS_PREVIEW_BADGE 50771
#define IDS_PREVIEW_BADGE_SCREEN_READER_MESSAGE 50772
#define IDS_SENTENCE_END 50773
#define IDS_CONCAT_TWO_STRINGS_WITH_COMMA 50774
#define IDS_CONCAT_THREE_STRINGS_WITH_COMMA 50775
#define IDS_CONCAT_TWO_STRINGS_WITH_PERIODS 50776
#define IDS_SELECT_UPLOAD_FOLDER_DIALOG_TITLE 50780
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_MENU 50788
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_DEFAULT 50789
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_LTR 50790
#define IDS_CONTENT_CONTEXT_WRITING_DIRECTION_RTL 50791
#define IDS_SELECT_FOLDER_DIALOG_TITLE 50792
#define IDS_SAVE_AS_DIALOG_TITLE 50793
#define IDS_OPEN_FILE_DIALOG_TITLE 50794
#define IDS_OPEN_FILES_DIALOG_TITLE 50795
#define IDS_SAVEAS_ALL_FILES 50796
#define IDS_SELECT_UPLOAD_FOLDER_DIALOG_UPLOAD_BUTTON 50797
#define IDS_APP_ACCNAME_BACK 50798
#define IDS_APP_ACCNAME_CENTER 50799
#define IDS_APP_ACCNAME_CLOSE 50800
#define IDS_APP_ACCNAME_MINIMIZE 50801
#define IDS_APP_ACCNAME_MAXIMIZE 50802
#define IDS_APP_ACCNAME_RESTORE 50803
#define IDS_APP_ACCNAME_MENU 50804
#define IDS_APP_ACCNAME_COLOR_CHOOSER_HEX_INPUT 50805
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLHERE 50806
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLLEFTEDGE 50807
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLRIGHTEDGE 50808
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLHOME 50809
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLEND 50810
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLPAGEUP 50811
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLPAGEDOWN 50812
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLLEFT 50813
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLRIGHT 50814
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLUP 50815
#define IDS_APP_SCROLLBAR_CXMENU_SCROLLDOWN 50816
#define IDS_APP_TABLE_COLUMN_NOT_SORTED_ACCNAME 50817
#define IDS_APP_TABLE_COLUMN_SORTED_ASC_ACCNAME 50818
#define IDS_APP_TABLE_COLUMN_SORTED_DESC_ACCNAME 50819
#define IDS_APP_TABLE_HEADER_NOT_SORTED_ACCNAME 50820
#define IDS_APP_TABLE_HEADER_NOT_SORTED_ACCNAME_MAC 50821
#define IDS_APP_TABLE_HEADER_SORTED_ASC_ACCNAME 50822
#define IDS_APP_TABLE_HEADER_SORTED_DESC_ACCNAME 50823
#define IDS_APP_UNDO 50824
#define IDS_APP_CUT 50825
#define IDS_APP_COPY 50826
#define IDS_APP_PASTE 50827
#define IDS_APP_DELETE 50828
#define IDS_APP_SELECT_ALL 50829
#define IDS_APP_SELECT 50830
#define IDS_CONTENT_CONTEXT_EMOJI 50831
#define IDS_APP_OK 50834
#define IDS_APP_CANCEL 50835
#define IDS_APP_CLOSE 50836
#define IDS_APP_CONTINUE 50837
#define IDS_APP_TURN_ON 50838
#define IDS_APP_ESC_KEY 50839
#define IDS_APP_TAB_KEY 50840
#define IDS_APP_INSERT_KEY 50841
#define IDS_APP_HOME_KEY 50842
#define IDS_APP_DELETE_KEY 50843
#define IDS_APP_END_KEY 50844
#define IDS_APP_PAGEUP_KEY 50845
#define IDS_APP_PAGEDOWN_KEY 50846
#define IDS_APP_LEFT_ARROW_KEY 50847
#define IDS_APP_RIGHT_ARROW_KEY 50848
#define IDS_APP_UP_ARROW_KEY 50849
#define IDS_APP_DOWN_ARROW_KEY 50850
#define IDS_APP_ENTER_KEY 50851
#define IDS_APP_SPACE_KEY 50852
#define IDS_APP_F1_KEY 50853
#define IDS_APP_F5_KEY 50854
#define IDS_APP_F6_KEY 50855
#define IDS_APP_F11_KEY 50856
#define IDS_APP_BACKSPACE_KEY 50857
#define IDS_APP_COMMA_KEY 50858
#define IDS_APP_PERIOD_KEY 50859
#define IDS_APP_MEDIA_NEXT_TRACK_KEY 50860
#define IDS_APP_MEDIA_PLAY_PAUSE_KEY 50861
#define IDS_APP_MEDIA_PREV_TRACK_KEY 50862
#define IDS_APP_MEDIA_STOP_KEY 50863
#define IDS_APP_ALT_KEY 50864
#define IDS_APP_COMMAND_KEY 50865
#define IDS_APP_CTRL_KEY 50866
#define IDS_APP_SEARCH_KEY 50867
#define IDS_APP_SHIFT_KEY 50868
#define IDS_APP_SUPER_KEY 50870
#define IDS_APP_BYTES 50874
#define IDS_APP_KIBIBYTES 50875
#define IDS_APP_MEBIBYTES 50876
#define IDS_APP_GIBIBYTES 50877
#define IDS_APP_TEBIBYTES 50878
#define IDS_APP_PEBIBYTES 50879
#define IDS_APP_BYTES_PER_SECOND 50880
#define IDS_APP_KIBIBYTES_PER_SECOND 50881
#define IDS_APP_MEBIBYTES_PER_SECOND 50882
#define IDS_APP_GIBIBYTES_PER_SECOND 50883
#define IDS_APP_TEBIBYTES_PER_SECOND 50884
#define IDS_APP_PEBIBYTES_PER_SECOND 50885
#define IDS_MESSAGE_CENTER_ACCESSIBLE_NAME 50886
#define IDS_MESSAGE_CENTER_NOTIFICATION_ACCESSIBLE_NAME 50887
#define IDS_MESSAGE_CENTER_NOTIFICATION_ACCESSIBLE_NAME_PLURAL 50888
#define IDS_MESSAGE_CENTER_EXPAND_NOTIFICATION 50889
#define IDS_MESSAGE_CENTER_COLLAPSE_NOTIFICATION 50890
#define IDS_MESSAGE_CENTER_LIST_NOTIFICATION_MESSAGE_WITH_DIVIDER 50891
#define IDS_MESSAGE_CENTER_LIST_NOTIFICATION_HEADER_OVERFLOW_INDICATOR 50892
#define IDS_MESSAGE_CENTER_NOTIFICATION_PROGRESS_PERCENTAGE 50893
#define IDS_MESSAGE_CENTER_NOTIFICATION_CHROMEOS_SYSTEM 50894
#define IDS_MESSAGE_CENTER_NOTIFICATION_INLINE_REPLY_PLACEHOLDER 50895
#define IDS_MESSAGE_CENTER_NOTIFICATION_INLINE_REPLY_ACCESSIBLE_NAME 50896
#define IDS_MESSAGE_NOTIFICATION_NOW_STRING_SHORTEST 50897
#define IDS_MESSAGE_NOTIFICATION_DURATION_MINUTES_SHORTEST 50898
#define IDS_MESSAGE_NOTIFICATION_DURATION_HOURS_SHORTEST 50899
#define IDS_MESSAGE_NOTIFICATION_DURATION_DAYS_SHORTEST 50900
#define IDS_MESSAGE_NOTIFICATION_DURATION_YEARS_SHORTEST 50901
#define IDS_MESSAGE_NOTIFICATION_DURATION_MINUTES_SHORTEST_FUTURE 50902
#define IDS_MESSAGE_NOTIFICATION_DURATION_HOURS_SHORTEST_FUTURE 50903
#define IDS_MESSAGE_NOTIFICATION_DURATION_DAYS_SHORTEST_FUTURE 50904
#define IDS_MESSAGE_NOTIFICATION_DURATION_YEARS_SHORTEST_FUTURE 50905
#define IDS_MESSAGE_CENTER_BLOCK_ALL_NOTIFICATIONS_SITE 50906
#define IDS_MESSAGE_CENTER_BLOCK_ALL_NOTIFICATIONS_APP 50907
#define IDS_MESSAGE_CENTER_BLOCK_ALL_NOTIFICATIONS 50908
#define IDS_MESSAGE_CENTER_DONT_BLOCK_NOTIFICATIONS 50909
#define IDS_MESSAGE_CENTER_SETTINGS_DONE 50910
#define IDS_MESSAGE_CENTER_CLOSE_NOTIFICATION_BUTTON_ACCESSIBLE_NAME 50911
#define IDS_MESSAGE_CENTER_CLOSE_NOTIFICATION_BUTTON_TOOLTIP 50912
#define IDS_MESSAGE_CENTER_NOTIFICATION_SNOOZE_BUTTON_TOOLTIP 50913
#define IDS_MESSAGE_NOTIFICATION_SETTINGS_BUTTON_ACCESSIBLE_NAME 50914
#define IDS_MESSAGE_NOTIFICATION_ACCESSIBLE_NAME 50915
#define IDS_MESSAGE_NOTIFICATION_SEND_TAB_TO_SELF_CONFIRMATION_FAILURE_TITLE 50916
#define IDS_MESSAGE_NOTIFICATION_SEND_TAB_TO_SELF_CONFIRMATION_FAILURE_MESSAGE 50917
#define IDS_CLIPBOARD_HISTORY_MENU_PNG_IMAGE 50919
#define IDS_CLIPBOARD_HISTORY_MENU_HTML_IMAGE 50920
#define IDS_CLIPBOARD_HISTORY_MENU_TITLE 50921
#define IDS_CLIPBOARD_HISTORY_DELETE_ITEM_TEXT 50922
#define IDS_CLIPBOARD_HISTORY_DELETE_BUTTON_HOVER_TEXT 50923
#define IDS_CLIPBOARD_HISTORY_ITEM_DELETION 50924
#define IDS_DISPLAY_TOUCH_CALIBRATION_EXIT_LABEL 50925
#define IDS_DISPLAY_TOUCH_CALIBRATION_SECONDARY_SKIP_LABEL 50926
#define IDS_DISPLAY_TOUCH_CALIBRATION_PRIMARY_SKIP_LABEL 50927
#define IDS_DISPLAY_TOUCH_CALIBRATION_HINT_LABEL_TEXT 50928
#define IDS_DISPLAY_TOUCH_CALIBRATION_HINT_SUBLABEL_TEXT 50929
#define IDS_DISPLAY_TOUCH_CALIBRATION_TAP_HERE_LABEL 50930
#define IDS_DISPLAY_TOUCH_CALIBRATION_FINISH_LABEL 50931
#define IDS_DISPLAY_TOUCH_CALIBRATION_A11Y_TARGET_MOVED_TOP_RIGHT 50932
#define IDS_DISPLAY_TOUCH_CALIBRATION_A11Y_TARGET_MOVED_BOTTOM_LEFT 50933
#define IDS_DISPLAY_TOUCH_CALIBRATION_A11Y_TARGET_MOVED_BOTTOM_RIGHT 50934
#define IDS_DISPLAY_NAME_UNKNOWN 50935
#define IDS_DISPLAY_NAME_INTERNAL 50936
#define IDS_CROSTINI_USE_LOW_DENSITY 50937
#define IDS_CROSTINI_USE_HIGH_DENSITY 50938
#define IDS_CROSTINI_APP_RESTART_BODY 50939
#define IDS_SATURATED_BADGE_CONTENT 50940
#define IDS_BADGE_UNREAD_NOTIFICATIONS_SATURATED 50941
#define IDS_BADGE_UNREAD_NOTIFICATIONS_UNSPECIFIED 50942
#define IDS_BADGE_UNREAD_NOTIFICATIONS 50943
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_TITLE_LABEL 50944
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_TITLE_NO_DEVICES 50945
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_CALL_BUTTON_LABEL 50946
#define IDS_BROWSER_SHARING_OMNIBOX_SENDING_LABEL 50947
#define IDS_BROWSER_SHARING_DIALOG_DEVICE_SUBTITLE_LAST_ACTIVE_DAYS 50948
#define IDS_BROWSER_SHARING_CLICK_TO_CALL_DIALOG_INITIATING_ORIGIN 50949
#define IDS_BROWSER_SHARING_CONTENT_TYPE_TEXT 50950
#define IDS_BROWSER_SHARING_CONTENT_TYPE_NUMBER 50951
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TITLE_GENERIC_ERROR 50952
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TITLE_INTERNAL_ERROR 50953
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_NETWORK_ERROR 50954
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_DEVICE_ACK_TIMEOUT 50955
#define IDS_BROWSER_SHARING_ERROR_DIALOG_TEXT_INTERNAL_ERROR 50956
#define IDS_BROWSER_SHARING_SHARED_CLIPBOARD_ERROR_DIALOG_TITLE_PAYLOAD_TOO_LARGE 50957
#define IDS_BROWSER_SHARING_SHARED_CLIPBOARD_ERROR_DIALOG_TEXT_PAYLOAD_TOO_LARGE 50958
#define IDS_SETTINGS_PASSWORD_SHOW 50962
#define IDS_SETTINGS_PASSWORD_HIDE 50963
#define IDS_TABLE_VIEW_AX_ANNOUNCE_ROW_SELECTED 50964
#define IDS_LINK_COPIED 50965
#define IDS_INCOGNITO_NAVIGATION_BLOCKED_PAGE_TITLE 50966
#define IDS_INCOGNITO_NAVIGATION_MESSAGE 50967
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS 50968
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_1 50969
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_2 50970
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_3 50971
#define IDS_INCOGNITO_NAVIGATION_INSTRUCTIONS_STEP_4 50972
#define IDS_INCOGNITO_NAVIGATION_MISSING_TITLE 50973
#define IDS_INCOGNITO_NAVIGATION_MISSING_EXTENSIONS 50974

#endif  // CEF_INCLUDE_CEF_PACK_STRINGS_H_
